<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegateway
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Mollie.php 2017-06-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Engine_Service_Mollie extends Zend_Service_Abstract {

    /**
     * Here you can define the API keys of your new payment gateway which will use later in this file.  
     *
     * @var string
     */
    protected $_merchant_key;

    /**
     * Here you can define the API keys of your new payment gateway which will use later in this file. 
     *
     * @var string
     */
    //protected $_secret;

    /**
     * The log to send debug messages to
     * 
     * @var Zend_Log
     */
    protected $_log;

    /**
     * Constructor
     *
     * @param array $options
     */
    public function __construct(array $options) {
        $this->setOptions($options);

        // Force the curl adapter if it's available
        if (extension_loaded('curl')) {
            $adapter = new Zend_Http_Client_Adapter_Curl();
            $adapter->setCurlOption(CURLOPT_SSL_VERIFYPEER, false);
            $adapter->setCurlOption(CURLOPT_SSL_VERIFYHOST, false);
            //$adapter->setCurlOption(CURLOPT_VERBOSE, false);
            $this->getHttpClient()->setAdapter($adapter);
        }
        $this->getHttpClient()->setConfig(array('timeout' => 15));
    }

    /**
     * Set credentials for your gateway. 
     */
    public function setOptions(array $options) {
        foreach ($options as $key => $value) {
            $property = '_' . $key;
            if (property_exists($this, $property)) {
                $this->$property = $value;
            }
        } 
    }

    /**
     * Get the http client and set default parameters
     *
     */
    protected function _prepareHttpClient() {
        
    }

    /**
     * Check params (This method call is useful, if you want to check some required parameters for some methods.)
     *
     * @param array $params
     * @param array $requiredParams
     * @param array $supportedParams
     * @return array
     */
    protected function _checkParams(array $params, $requiredParams = null, $supportedParams = null) {
        // Check params
        if (!is_array($params)) {
            if (!empty($params)) {
                throw new Engine_Service_Mollie_Exception('Invalid data type', 'UNKNOWN_PARAM');
            } else {
                $params = array();
            }
        }

        // Check required params
        if (is_string($requiredParams)) {
            $requiredParams = array($requiredParams);
        } else if (null === $requiredParams) {
            $requiredParams = array();
        }

        // Check supported params
        if (is_string($supportedParams)) {
            $supportedParams = array($supportedParams);
        } else if (null === $supportedParams) {
            $supportedParams = array();
        }

        // Nothing to do
        if (empty($requiredParams) && empty($supportedParams) &&
                is_array($requiredParams) && is_array($supportedParams)) {
            return array();
        }

        // Build full supported
        if (is_array($supportedParams) && is_array($requiredParams)) {
            $supportedParams = array_unique(array_merge($supportedParams, $requiredParams));
        }

        // Run strtoupper on all keys?
        $params = array_combine(array_map('strtolower', array_keys($params)), array_values($params));

        // Init
        $processedParams = array();
        $foundKeys = array();

        // Process out simple params
        $processedParams = array_merge($processedParams, array_intersect_key($params, array_flip($supportedParams)));
        $params = array_diff_key($params, array_flip($supportedParams));
        $foundKeys = array_merge($foundKeys, array_keys($processedParams));

        // Process out complex params
        foreach ($supportedParams as $supportedFormat) {
            foreach ($params as $key => $value) {
                if (count($parts = sscanf($key, $supportedFormat)) > 0) {
                    $foundKeys[] = $supportedFormat;
                    $processedParams[$key] = $value;
                }
            }
        }

        // Remove complex params
        $params = array_diff_key($params, $processedParams);

        // Anything left is an unsupported param
        if (!empty($params)) {
            $paramStr = '';
            foreach ($params as $key => $unsupportedParam) {
                if ($paramStr != '')
                    $paramStr .= ', ';
                $paramStr .= "$key:" . $unsupportedParam;
            }

            throw new Engine_Service_Mollie_Exception(sprintf('Unknown param(s): ' .
                    '%1$s', $paramStr), 'UNKNOWN_PARAM');
        }

        // Let's check required against foundKeys
        if (count($missingRequiredParams = array_diff_key($requiredParams, $foundKeys)) > 0) {
            $paramStr = '';
            foreach ($missingRequiredParams as $missingRequiredParam) {
                if ($paramStr != '')
                    $paramStr .= ', ';
                $paramStr .= $missingRequiredParam;
            }
            throw new Engine_Service_Mollie_Exception(sprintf('Missing required ' .
                    'param(s): %1$s', $paramStr), 'MISSING_REQUIRED');
        }

        return $processedParams;
    } 

     /**
     * Used to create customer in account.
     *
     * @link  
     * @param array $params
     * @return object
     */
    public function createCustomer(array $params = array()) {


        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key); 
        $customer = $mollie->customers->create($params); 

        return $customer;
    } 

     /**
     * Used to create subscription in account.
     *
     * @link  
     * @param array $params
     * @return object
     */
    public function createSubscription(array $params = array(), $customer_id) { 

        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key);
       
        $subscription = $mollie->customers_subscriptions->withParentId($customer_id)->create($params);
 
        return $subscription;
    } 

    /**
     * Used to create payment.
     *
     * @link  
     * @param array $params
     * @return object
     */
    public function createPayment(array $params = array()) {

        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key); 
        $payment = $mollie->payments->create($params); 

        return $payment;
    }

    /**
     * Used to get payment.
     *
     * @link  
     * @param array $params
     * @return object
     */
    public function getPayment($transaction_id) {

        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key); 
        $payment = $mollie->payments->get($transaction_id);   

        return $payment;
    }

 /**
     * Used to return mandates related to customer id
     *
     * @link  
     * @param array $params
     * @return object
     */
    public function customerMandates($customerId) {

        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key);
        $mandates = $mollie->customers_mandates->withParentId($customerId)->all(); 
 
        return $mandates;
    }  
        /**
     * Used to create charge in account.
     *
     * @link https://stripe.com/docs/webhooks
     * @param array $params
     * @return array
     */
    public function getWebHookDatas(array $params = array()) {

        $this->_prepareHttpClient();

        //Retrieve the request's body and parse it as JSON
        $input = @file_get_contents("php://input");
        $event_json = json_decode($input);
        $data = (array) $event_json;

        return $data;
    }

     /**
     * Used to return all methods related a api key
     * 
     * @api_key
     * @return object
     */
    public function paymentMethods() {

        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key);
        $methods = $mollie->methods->all(); 
 
        return $methods;
    }

     /**
     * Used to cancel recurring payment profile. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin.
     *
     * @param string $profileId
     * @return object
     */
    public function cancelRecurringPaymentsProfile($transaction_id) { 
         
        $mollie = new Mollie_API_Client;
        $mollie->setApiKey($this->_merchant_key); 

        //GET PAYMENT RELATED TO TO TRANSCATION ID TO HAVE CUSTOMER ID AND ORDER_ID
        $payment = $mollie->payments->get($transaction_id); 
        $customerId = $payment->customerId;
        $order_id = $payment->metadata->order_id;
        $order = Engine_Api::_()->getItem('payment_order', $order_id);
        $subscription_id = $order->gateway_transaction_id;//SUBSCRIPTION ID WAS SAVED IN GATEWAY_TRANSACTION_ID

        //CANCEL SUBSCRIPTION
        $mollie->customers_subscriptions->withParentId($customerId)->cancel($subscription_id); 
        
        return $this;
    }


    /**
     * Add the code to create products/plans in this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin.
     *
     */
    public function createProduct(array $params = array()) {
        
    }

    /**
     * Add the code to retrieve created products/plans from this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin.
     *
     */
    public function retrieveProduct($productId) {
        
    }

    /**
     * Add the code to update created products/plans in this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin.
     *
     */
    public function updateProduct($productId, $params = null) {
        
    }

    /**
     * Add the code to delete created products/plans of this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin.
     *
     */
    public function deleteProduct($productId) {
        
    }

    /**
     * Gets product details by vendor product id. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin.
     * 
     * @param string $vendorProductId
     * @return object
     */
    public function detailVendorProduct($vendorProductId) {
        
    } 
    
    /**
     * Write the coupon creation code if this gateway provide discount coupon feature and you have installed the SocialEngineAddOns - Discount Coupons Plugin at your site.
     */    
    public function createCoupon(array $params = array()) {

    }    
    
    /**
     * Write the coupon edit code if this gateway provide discount coupon feature and you have installed the SocialEngineAddOns - Discount Coupons Plugin at your site.
     */       
    public function editCoupon($couponCode, $params = null) {

    }     
    
    /**
     * Write the coupon deletetion code if this gateway provide discount coupon feature and you have installed the SocialEngineAddOns - Discount Coupons Plugin at your site.
     */       
    public function deleteCoupon($couponCode) {

    }       

}
