<?php 


abstract class Zend_FcmPush_Abstract implements Zend_FcmPush_Interface
{
    /**
     * Is Connected
     *
     * @var boolean
     */
    protected $_isConnected = false;

    /**
     * Connect to the Push Server
     * 
     * @return Zend_Mobile_Push_Abstract
     */
    public function connect()
    {
        $this->_isConnected = true;
        return $this;
    }

    /**
     * Send a Push Message
     *
     * @param Zend_Mobile_Push_Message_Abstract $message
     * @return boolean
     * @throws DomainException
     */
    public function send(Zend_FcmPush_Message_Abstract $message)
    {
        if (!$this->_isConnected) {
            $this->connect();
        }
        return true;
    }

    /**
     * Close the Connection to the Push Server
     *
     * @return void
     */
    public function close()
    {
        $this->_isConnected = false;
    }

    /**
     * Is Connected
     *
     * @return boolean
     */
    public function isConnected()
    {
        return $this->_isConnected;
    }

    /**
     * Set Options
     *
     * @param array $options
     * @return Zend_Mobile_Push_Abstract
     * @throws Zend_Mobile_Push_Exception
     */
    public function setOptions(array $options)
    {
        foreach ($options as $k => $v) {
            $method = 'set' . ucwords($k);
            if (!method_exists($this, $method)) {
                // throw new Zend_Mobile_Push_Exception('The method "' . $method . "' does not exist.");
                echo "Zend_FcmPush_Abstract method doesnt exists"; die();
            }
            $this->$method($v);
        }
        return $this;
    }
}
