<?php

/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Form
 * @subpackage Element
 * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 */
/** Zend_Form_Element_Xhtml */
// require_once 'Zend/Form/Element/Xhtml.php';

/**
 * Recaptcha form element
 *
 * @category   Zend
 * @package    Zend_Form
 * @subpackage Element
 * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: Recaptcha.php 24593 2012-01-05 20:35:02Z matthew $
 */
class Zend_Form_Element_Recaptcha extends Zend_Form_Element_Xhtml {

    /**
     * Use formRecaptcha view helper by default
     * @var string
     */
    public $helper = 'formRecaptcha';

    /** @var string siteKey for Google Recaptcha */
    protected $_siteKey = '';

    /** @var string secretKey for Google Recaptcha */
    protected $_secretKey = '';

    /**
     * @var boolean Already validated ?
     */
    protected $_validated = false;

    /**
     * Constructor for element and adds validator
     *
     * @param array|string|Zend_Config $spec
     * @param null $options
     * @throws \Zend_Exception
     * @throws \Zend_Form_Exception
     */
    public function __construct($spec, $options = null) {
        if (empty($options['siteKey']) || empty($options['secretKey'])) {
            throw new \Zend_Exception('Site key and secret key must be specified.');
        }
        $this->_siteKey = trim($options['siteKey']); // trim the white space if there is any just to be sure
        $this->_secretKey = trim($options['secretKey']); // trim the white space if there is any just to be sure
        $this->addValidator('Recaptcha', false, array('secretKey' => $this->_secretKey));
        $this->_validated = false;
        $this->setAllowEmpty(false);
        parent::__construct($spec, $options);
    }

    /**
     * Override isValid()
     *
     * Ensure that validation error messages mask recaptcha value.
     *
     * @param  string $value
     * @param  mixed $context
     * @return bool
     */
    public function isValid($value, $context = null) {

        if ($this->_validated) {
            return true;
        }

        foreach ($this->getValidators() as $validator) {
            if ($validator instanceof Zend_Validate_Recaptcha) {
                $validator->setObscureValue(true);
            }
        }
        $this->_validated = parent::isValid($value, $context);
        return $this->_validated;
    }

}
