<?php

class Zend_Validate_Recaptcha extends Zend_Validate_Abstract {

    /** @var string secret key */
    protected $_secretKey;

    /** @const string invalid captcha */
    const INVALID_CAPTCHA = 'invalidCaptcha';

    /** @const string invalid captcha */
    const CAPTCHA_EMPTY = 'captchaEmpty';

    /** @const string URL to where requests are posted */
    const SITE_VERIFY_URL = 'https://www.google.com/recaptcha/api/siteverify';

    /** @const string http method for communicating with google */
    const POST_METHOD = 'POST';

    /** @const string peer key for communication */
    const PEER_KEY = 'www.google.com';

    protected $_messageTemplates = array(
        self::INVALID_CAPTCHA => 'The captcha was invalid.',
        self::CAPTCHA_EMPTY => 'The captcha must be completed.'
    );

    /**
     * @param $options
     */
    public function __construct($options) {

        if (isset($options['secretKey'])) {
            $this->_secretKey = $options['secretKey'];
        } else {
            $this->_secretKey = $options;
        }
    }

    /**
     * Validate our form's element
     *
     * @param mixed $value
     * @param null $context
     * @return bool
     */
    public function isValid($value, $context = null) {
        if (empty($value)) {
            $this->_error(self::CAPTCHA_EMPTY);
            return false;
        }
        $this->_value = $value;

        if (!$this->_verify($value)) {
            $this->_error(self::INVALID_CAPTCHA);
            return false;
        }

        return true;
    }

    /**
     * Calls the reCAPTCHA siteverify API to verify whether the user passes the captcha test.
     *
     * @param  mixed $value
     * @return boolean
     * @link   https://github.com/google/recaptcha
     */
    protected function _verify($value) {
        $queryString = http_build_query(array(
            'secret' => Engine_Api::_()->getApi('settings', 'core')->getSetting("siterecaptcha.secret.key"),
            'response' => $value,
            'remoteIp' => $_SERVER['REMOTE_ADDR']
        ));

        /**
         * PHP 5.6.0 changed the way you specify the peer name for SSL context options.
         * Using "CN_name" will still work, but it will raise deprecated errors.
         */
        $peerKey = version_compare(PHP_VERSION, '5.6.0', '<') ? 'CN_name' : 'peer_name';
        $context = stream_context_create(array(
            'http' => array(
                'header' => "Content-type: application/x-www-form-urlencoded\r\n",
                'method' => self::POST_METHOD,
                'content' => $queryString,
                'verify_peer' => true,
                $peerKey => self::PEER_KEY
            )
        ));

        $jsonObject = json_decode(@file_get_contents(self::SITE_VERIFY_URL, false, $context));
        $url = "https://www.google.com/recaptcha/api/siteverify?secret=" . Engine_Api::_()->getApi('settings', 'core')->getSetting("siterecaptcha.secret.key") . "&response=" . $value . "&remoteip=" . $_SERVER['REMOTE_ADDR'];
        if (empty($jsonObject)) {
            $response = json_decode(@file_get_contents($url));

            if (empty($response)) {
                $response = json_decode($this->curl_get_contents($url));
            }

            return $response->success;
        } else {
            return $jsonObject->success;
        }

        return $jsonObject->success;
    }

    function curl_get_contents($url) {
        $ch = curl_init();

        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, $url);

        $data = curl_exec($ch);
        curl_close($ch);

        return $data;
    }

}
