<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Advancedpagecache
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2012-26-01 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Advancedpagecache_Api_Core extends Core_Api_Abstract {

    /**
     * Check default "/index.php/application/" valid or not * 
     * @return boolean
     */
    public function isRootFileValid() {
        if (file_exists(APPLICATION_PATH.'/boot.php')) {
          return true;
        }
        $isValidFileAvailable = false;
        $file = APPLICATION_PATH . "/application/index.php";
        if (file_exists($file) && is_readable($file)) {
            $myfile = @fopen($file, "r") or die("Unable to open file!");
            // Output one line until end-of-file
            while (!feof($myfile)) {
                $rowContent = @fgets($myfile);
                if (strstr($rowContent, "include_once APPLICATION_PATH_MOD . DS . 'Advancedpagecache/cache.php';")) {
                    $isValidFileAvailable = true;
                    break;
                }
            }
            @fclose($myfile);
        }
        return $isValidFileAvailable;
    }

    /**
     * find free space available on disk
     * @param type $disk
     * @return float */
    public function getFreeDiskSpace($disk) {
        $bytes = disk_free_space($disk);
        $gb = round(($bytes / 1073741824), 2);
        return $gb;
    }

    public function isSiteMobileModeEnabled() {
        return $this->checkSitemobileMode('tablet-mode') || $this->checkSitemobileMode('mobile-mode');
    }

    public function checkSitemobileMode($mode = 'fullsite-mode') {
        if (Engine_Api::_()->hasModuleBootstrap('sitemobile')) {
            return (bool) (Engine_API::_()->sitemobile()->getViewMode() === $mode);
        } else {
            return (bool) ('fullsite-mode' === $mode);
        }
    }

    function checkVersion($databaseVersion, $checkDependancyVersion) {
        if (strcasecmp($databaseVersion, $checkDependancyVersion) == 0)
            return -1;
        $databaseVersionArr = explode(".", $databaseVersion);
        $checkDependancyVersionArr = explode('.', $checkDependancyVersion);
        $fValueCount = $count = count($databaseVersionArr);
        $sValueCount = count($checkDependancyVersionArr);
        if ($fValueCount > $sValueCount)
            $count = $sValueCount;
        for ($i = 0; $i < $count; $i++) {
            $fValue = $databaseVersionArr[$i];
            $sValue = $checkDependancyVersionArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                $result = $this->compareValues($fValue, $sValue);
                if ($result == -1) {
                    if (($i + 1) == $count) {
                        return $this->compareValues($fValueCount, $sValueCount);
                    } else
                        continue;
                }
                return $result;
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);
                $result = $this->compareValues($fsArr[0], $sValue);
                return $result == -1 ? 1 : $result;
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);
                $result = $this->compareValues($fValue, $ssArr[0]);
                return $result == -1 ? 0 : $result;
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                $result = $this->compareValues($fsArr[0], $ssArr[0]);
                if ($result != -1)
                    return $result;
                $result = $this->compareValues($fsArr[1], $ssArr[1]);
                return $result;
            }
        }
    }

    public function compareValues($firstVal, $secondVal) {
        $num = $firstVal - $secondVal;
        return ($num > 0) ? 1 : ($num < 0 ? 0 : -1);
    }

}
