<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Advancedpagecache
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminSettingsController.php 6590 2012-26-01 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Advancedpagecache_AdminSettingsController extends Core_Controller_Action_Admin
{

  public function indexAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('advancedpagecache_admin_main', array(), 'advancedpagecache_admin_main_settings');
    // Make form
    $this->view->form = $form = new Advancedpagecache_Form_Admin_Settings_Global();
    //getting browser cache setting file

    $this->view->isRootFileValid = Engine_Api::_()->getApi('core', 'advancedpagecache')->isRootFileValid();
    $browser_setting_file = APPLICATION_PATH . '/application/settings/advancedpagecache.php';
    $defaultFilePath = APPLICATION_PATH . '/temporary/sitecache';
    if( !is_dir($defaultFilePath) ) {
      mkdir($defaultFilePath);
      chmod($defaultFilePath, 0777);
    }
    if( file_exists($browser_setting_file) ) {
      $browser_currentCache = include $browser_setting_file;
    } else {
      $browser_currentCache = array(
        'browser_lifetime' => 600,
        'ignoreUrl' => array(),
        'utilization_space' => 1,
        'default_backend' => 'File',
        'frontend' => array(
          'lifetime' => 1200,
          'cache_id_prefix' => 'advancedpagecache_page_',
          'default_options' => array(
            'cache_with_get_variables' => true,
            'cache_with_cookie_variables' => true,
            'cache_with_session_variables' => true,
            'tags' => array('browse_cache'),
            'cache' => true
          ),
          'memorize_headers' => array('location'),
        ),
        'backend' => array(
          'File' => array(
            'cache_dir' => APPLICATION_PATH . '/temporary/sitecache',
          ),
        ),
      );
    }
    $browser_currentCache['default_file_path'] = $defaultFilePath;
    $this->view->browserEnabled = $browser_currentCache['disable_browse'];
    if( key($browser_currentCache['backend']) == "File" ) {
      $this->view->freeSpace = Engine_Api::_()->getApi('core', 'advancedpagecache')->getFreeDiskSpace(APPLICATION_PATH . '/temporary/sitecache');
    }

    //getting partial page cache setting file
    $partial_setting_file = APPLICATION_PATH . '/application/settings/advancedpagecache_partial.php';

    if( file_exists($partial_setting_file) ) {
      $partial_currentCache = include $partial_setting_file;
    } else {
      $partial_currentCache = array(
        'disable_partial' => 0,
        'partial_lifetime' => 600,
      );
    }
    // Populate settings
    $populate = empty(array_merge($partial_currentCache, $browser_currentCache)) ? array() : array_merge($partial_currentCache, $browser_currentCache);
    $form->populate($populate);

    //get timeout time for automatic clear setting
    $tasksTable = Engine_Api::_()->getDbtable('tasks', 'core');
    $taskstable_result = $tasksTable->fetchRow(array('title = ?' => 'Cache Clear', 'plugin = ?' => 'Advancedpagecache_Plugin_Task_Clear'));
    $form->automatic_clear->setValue($taskstable_result['timeout']);
    // disable caching types not supported
    $disabledTypeOptions = array();
    foreach( array_keys($form->getElement('type')->options) as $backend ) {
      $disabledExtension = '';
      if( 'Apc' == $backend && !extension_loaded('apc') ) {
        $disabledTypeOptions[] = $backend;
      }

      if( 'Memcached' == $backend && !extension_loaded('memcache') ) {
        $disabledTypeOptions[] = $backend;
      }

      if( 'Xcache' == $backend && !extension_loaded('xcache') ) {
        $disabledTypeOptions[] = $backend;
      }

      if( 'Engine_Cache_Backend_Redis' == $backend && !extension_loaded('redis') ) {
        $disabledTypeOptions[] = $backend;
      }

      if( in_array($backend, $disabledTypeOptions) ) {
        $disabledExtension = 'Memcached' == $backend ? 'memcache' : strtolower($backend);
        $form->getElement('type')->options[$backend] .= vsprintf(' - <code>%1$s</code> extension is not loaded', array($disabledExtension));
      }
    }

    $form->getElement('type')->setAttrib('disable', $disabledTypeOptions);
    $customBackendNaming = false;
    // set required elements before checking for validity
    switch( $this->getRequest()->getPost('type') ) {
      case 'File':
        $form->getElement('file_path')->setRequired(true)->setAllowEmpty(false);
        break;
      case 'Memcached':
        $form->getElement('memcache_host')->setRequired(true)->setAllowEmpty(false);
        $form->getElement('memcache_port')->setRequired(true)->setAllowEmpty(false);
        break;
      case 'Xcache':
        $form->getElement('xcache_username')->setRequired(true)->setAllowEmpty(false);
        $form->getElement('xcache_password')->setRequired(true)->setAllowEmpty(false);
        break;
      case 'Engine_Cache_Backend_Redis':
        $customBackendNaming = true;
        $form->getElement('redis_host')->setRequired(true)->setAllowEmpty(false);
        $form->getElement('redis_port')->setRequired(true)->setAllowEmpty(false);
        break;
      case 'Engine_Cache_Backend_Apc':
        $customBackendNaming = true;
        break;
    }


    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    if( is_writable($browser_setting_file) || (is_writable(dirname($browser_setting_file)) && !file_exists($browser_setting_file)) ) {
      // do nothing
    } else {
      //if files are not writable
      $phrase = Zend_Registry::get('Zend_Translate')->_('Changes made to this form will not be saved.  Please adjust the permissions (CHMOD) of file %s to 777 and try again.');
      $form->addError(sprintf($phrase, '/application/settings/advancedpagecache.php'));
      return;
    }
    if( is_writable($partial_setting_file) || (is_writable(dirname($partial_setting_file)) && !file_exists($partial_setting_file)) ) {
      // do nothing
    } else {
      //if files are not writable
      $phrase = Zend_Registry::get('Zend_Translate')->_('Changes made to this form will not be saved.  Please adjust the permissions (CHMOD) of file %s to 777 and try again.');
      $form->addError(sprintf($phrase, '/application/settings/advancedpagecache_partial.php'));
      return;
    }
    // Process
    // set values for cache variables
    $values = $form->getValues();

    //update timeout time.
    $tasksTable->update(array('timeout' => $values['automatic_clear']), array('title = ?' => 'Cache Clear', 'plugin = ?' => 'Advancedpagecache_Plugin_Task_Clear'));

    // update info in setting file
    $browser_currentCache['frontend']['lifetime'] = $values['browser_lifetime'];
    $browser_currentCache['disable_browse'] = $values['disable_browse'];
    $browser_currentCache['utilization_space'] = $values['utilization_space'];
    $browser_currentCache['frontend']['cache_id_prefix'] = $values['cache_id_prefix'];
    if( empty($browser_currentCache['ignoreUrl']) ) {
      $browser_currentCache['ignoreUrl'] = array();
    }
    //for backend options
    $this->view->isPost = true;
    $doFlush = false;
    foreach( $form->getElement('type')->options as $type => $label )
      if( array_key_exists($type, $browser_currentCache['backend']) && $type != $this->_getParam('type') )
        $doFlush = true;

    $options = array();
    switch( $this->getRequest()->getPost('type') ) {
      case 'File':
        $options['file_locking'] = (bool) $this->_getParam('file_locking');
        $options['cache_dir'] = $this->_getParam('file_path');
        if( !is_writable($options['cache_dir']) ) {
          $options['cache_dir'] = $defaultFilePath;
          $form->getElement('file_path')->setValue($defaultFilePath);
        }
        break;
      case 'Memcached':
        $options['servers'] = array();
        $options['servers'][] = array(
          'host' => $this->_getParam('memcache_host'),
          'port' => (int) $this->_getParam('memcache_port'),
        );
        $options['compression'] = (bool) $this->_getParam('memcache_compression');
        break;
      case 'Engine_Cache_Backend_Redis':
        $options['servers'] = array();
        $options['servers'][] = array(
          'host' => $this->_getParam('redis_host'),
          'port' => (int) $this->_getParam('redis_port'),
        );
        break;
    }
    $browser_currentCache['backend'] = array($this->_getParam('type') => $options);

    $browser_code = "<?php\ndefined('_ENGINE') or die('Access Denied');\nreturn ";
    $browser_code .= var_export($browser_currentCache, true);
    $browser_code .= '; ?>';

    $partial_currentCache['disable_partial'] = $values['disable_partial'];
    $partial_currentCache['partial_lifetime'] = $values['partial_lifetime'];
    $partial_code = "<?php\n\nreturn ";
    $partial_code .= var_export($partial_currentCache, true);
    $partial_code .= '; ?>';

    $backend = null;
    if( !$browser_currentCache['disable_browse'] ) {
      $this->view->success = true;
    } else {
      $backend = Zend_Cache::_makeBackend($this->_getParam('type'), $options, $customBackendNaming);
      if( $browser_currentCache['disable_browse'] && @$backend->save('test_value', 'test_id') && @$backend->test('test_id') ) {
        $this->view->success = true;
      } else {
        $this->view->success = false;
        $form->getElement('type')->setErrors(array('Unable to use this backend.  Please check your settings or try another one.'));
      }
    }
    //flush browse cache only
    if( $doFlush ) {
      if( $backend instanceof Zend_Cache_Backend ) {
        $backend->clean();
        $form->addNotice('Cache has been flushed.');
      }
    }

    //flush whole cache
    if( $form->getElement('flush')->getValue() ) {
      if( $backend instanceof Zend_Cache_Backend ) {
        $backend->clean();
        $form->getElement('flush')->setValue(0);
        $form->addNotice('Cache has been flushed.');
      }
    }
    // Save settings
    // $settings->advancedpagecache = $values;
    if( file_put_contents($browser_setting_file, $browser_code) && file_put_contents($partial_setting_file, $partial_code) ) {
      $form->addNotice('Your changes have been saved.');
    }
  }

  public function faqAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('advancedpagecache_admin_main', array(), 'advancedpagecache_admin_main_faq');
  }

  public function deleteBrowserAction()
  {

    if( !$this->getRequest()->isPost() ) {
      return;
    }

    $cacheOptions = array(
      'cache_with_get_variables' => true,
      'cache_with_cookie_variables' => true,
      'cache_with_session_variables' => true,
      'tags' => array('browse_cache'),
      'cache' => true
    );
    $frontendOptions = array(
      'lifetime' => 1200,
      'cache_id_prefix' => 'advancedpagecache_page_',
      'default_options' => $cacheOptions,
      'memorize_headers' => array('location'),
    );

    // Get configurations
    $cacheSettingFile = APPLICATION_PATH . '/application/settings/advancedpagecache.php';
    if( file_exists($cacheSettingFile) ) {
      $cacheConfig = include $cacheSettingFile;
      $backend = key($cacheConfig['backend']);
      $backendOptions = $cacheConfig['backend'][$backend];
      $frontendOptions = $cacheConfig['frontend'];
    } else {
      $path = APPLICATION_PATH . '/temporary/sitecache';
      !@is_dir($path) && @mkdir($path, 0777, true);
      $backend = 'File';
      $backendOptions = array(
        'cache_dir' => $path
      );
    }
    $customBackendNaming = false;
    if( $backend == 'Engine_Cache_Backend_Redis' )
      $customBackendNaming = true;
    if( $backend == 'Engine_Cache_Backend_Apc' )
      $customBackendNaming = true;
    // getting a Zend_Cache_Frontend_Page object
    $backend_type = $backend;
    $backend = Zend_Cache::_makeBackend($backend, $backendOptions, $customBackendNaming);
    $cache = Zend_Cache::factory('Page', $backend, $frontendOptions, $backendOptions, false, true, true);
    if( $backend_type == "File" ) {
      $cache->clean(
        Zend_Cache::CLEANING_MODE_MATCHING_TAG, array('browse_cache')
      );
    } else
      $backend->clean();

    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array('Single User Cache has been cleared.')
    ));
  }

  public function deletePartialAction()
  {
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    // [FOR DEVELOPER: ADD TAB CODE]

    $cache = Zend_Registry::get('Zend_Cache');
    $cache->clean(
      Zend_Cache::CLEANING_MODE_MATCHING_TAG, array('partial_page')
    );

    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array('Multiple Users Cache has been cleared.')
    ));
  }

  public function editRootFileAction()
  {
    
  }

}