<?php

/**
 * SocialEngine
 *
 * @category   Application_Core
 * @package    Core
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: Menus.php 9747 2012-07-26 02:08:08Z john $
 * @author     John
 */

/**
 * @category   Application_Core
 * @package    Core
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 */
class Bigstep_Api_Menus extends Core_Api_Menus {

    public function getNavigation($name, array $options = array(), $activeItem = null) {
        $pages = $this->getMenuParams($name, $options, $activeItem);
        $navigation = new Zend_Navigation();
        $navigation->addPages($pages);
        return $navigation;
    }

    public function getMenuParams($name, array $options = array(), $activeItem = null) {
        $tempCoreMenu = array();
        $menu = $this->getMenu($name, $options);
        $pages = array();

        foreach ($menu as $row) {
            // Check enabled
//      if( empty($isCoreWidget) && isset($row->enabled) && !$row->enabled ) {
//        continue;
//      }
            // Plugin
            $page = null;
            $multi = false;
            if (!empty($row->plugin)) {

                // Support overriding the method
                if (strpos($row->plugin, '::') !== false) {
                    list($pluginName, $method) = explode('::', $row->plugin);
                } else {
                    $pluginName = $row->plugin;
                    $method = 'onMenuInitialize_' . $this->_formatMenuName($row->name);
                }

                // Load the plugin
                try {
                    $plugin = Engine_Api::_()->loadClass($pluginName);
                } catch (Exception $e) {
                    // Silence exceptions
                    continue;
                }

                // Run plugin
                try {
                    $result = $plugin->$method($row);
                } catch (Exception $e) {
                    // Silence exceptions
                    continue;
                }

                if ($result === true) {
                    // Just generate normally
                } else if ($result === false) {
                    // Don't generate
                    continue;
                } else if (is_array($result)) {
                    // We got either page params or multiple page params back
                    // Single
                    if (array_values($result) !== $result) {
                        $page = $result;
                    }
                    // Multi
                    else {
                        // We have to do this manually
                        foreach ($result as $key => $value) {
                            if (is_numeric($key)) {
                                if (!empty($options)) {
                                    $value = array_merge_recursive($value, $options);
                                }
                                if (!isset($result['label']))
                                    $result['label'] = $row->label;
                                $pages[] = $value;
                            }
                        }
                        continue;
                    }
                } else if ($result instanceof Zend_Db_Table_Row_Abstract && $result->getTable() instanceof Core_Model_DbTable_MenuItems) {
                    // We got the row (or a different row?) back ...
                    $row = $result;
                } else {
                    // We got a weird data type back
                    continue;
                }
            }

            // No page was made, use row
            if (null === $page) {
                $page = (array) $row->params;
            }

            // Add label
            if (!isset($page['label'])) {
                $page['label'] = $row->label;
            }

            // Add custom options
            if (!empty($options)) {
                $page = array_merge_recursive($page, $options);
            }

            // Standardize arguments
            if (!isset($page['reset_params'])) {
                $page['reset_params'] = true;
            }

            // Set page as active, if necessary
            if (!isset($page['active']) && null !== $activeItem && $activeItem == $row->name) {
                $page['active'] = true;
            }

            $page['class'] = (!empty($page['class']) ? $page['class'] . ' ' : '' ) . 'menu_' . $name;
            $page['class'] .= " " . $row->name;

            // Get submenu
            if ($row->submenu) {
                $page['pages'] = $this->getMenuParams($row->submenu);
            }

            // Maintain menu item order 
//      if( !empty($isCoreWidget) && ($row->id == '3189' || $row->id == '2772') ) {
            if ($row->id == '3189')
                $page['order'] = '99999999';
            else if ($row->id == '2772')
                $page['order'] = '99999998';
            else
                $page['order'] = $row->order;

            $pages[] = $page;
        }

        return $pages;
    }

    public function getMenu($name, $options = array()) {
        // Get only enabled modules
        $enabledModuleNames = Engine_Api::_()->getDbtable('modules', 'core')->getEnabledModuleNames();

        // Get items
        $table = Engine_Api::_()->getDbtable('menuItems', 'core');
        $select = $table->select()
                ->where('menu = ?', $name)
                ->where('module IN(?)', $enabledModuleNames)
                ->order('order ASC');

        // IF CORE MAIN MENU WIDGET IS CALLED, THEN WE HAVE CUSTOMIZED IT ACCORDING TO ADVANCED MENUS PLUGIN REQUIREMENTS.
//    if( isset($options['is_core_widget']) && !empty($options['is_core_widget']) ) {
        // IDS WHICH WE WANT TO SHOW IN CORE MAIN MENU BUT NOT IN ADVANCED MENUS PLUGIN
        $tempCustomMenusIds = array('634', '635', '636', '637', '802', '1218', '1454', '2393', '2772', '3189');
        $customMenusIds = implode(',', $tempCustomMenusIds);
        $select->where("enabled = 1 OR id IN (3189, 2772, 1218)");
        $select->where("custom = 0 OR (custom = 1 AND id IN ($customMenusIds))");
//    }
//    if( isset($options['is_core_widget']) && !empty($options['is_core_widget']) ) {
//      $select->where("enabled = 1 OR id IN (3189, 2772, 1218)");
//      $select->where("id < 3190");
//    }
        return $table->fetchAll($select);
    }

    protected function _formatMenuName($name) {
        $name = str_replace('_', ' ', $name);
        $name = ucwords($name);
        $name = str_replace(' ', '', $name);
        return $name;
    }

}