<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_Form_Schedule_Create extends Engine_Form
{
	public $_error = array();

	public function init()
	{
		$this->setTitle('Create New Schedule')
				->setAttrib('class', 'global_form global_form_popup');

		$user = Engine_Api::_()->user()->getViewer();
		$calendars = Engine_Api::_()->getItemTable('calendar')->getAllCalendars();
		$options = array(''=>'Select');
		foreach ($calendars as $calendar) {
			$options[$calendar->getIdentity()] = $calendar->getTitle();
		}
		$this->addElement('Select', 'calendar_id', array(
				'label' => 'Calendar',
				'multiOptions' => $options,
				'required' => true,
		));
		$request = Zend_Controller_Front::getInstance()->getRequest();
		if($request->getParam('calendar_id')) {
			$this->calendar_id->setValue($request->getParam('calendar_id')) ;
		}
		$this->addElement('Text', 'title', array(
			'label' => 'Title',
			'allowEmpty' => false,
			'required' => true,
			'maxlength' => '63',
			'filters' => array(
				new Engine_Filter_Censor(),
				'StripTags',
				new Engine_Filter_StringLength(array('max' => '63'))
			),
			'autofocus' => 'autofocus',
		));

		 // Start time
		$calendar_start = new Engine_Form_Element_CalendarDateTime('start_datetime');
		$calendar_start->setLabel("Start Date");
		$calendar_start->setAllowEmpty(false);
		$calendar_start->setRequired(true);
		$this->addElement($calendar_start);

		// End time
		$calendar_end = new Engine_Form_Element_CalendarDateTime('end_datetime');
		$calendar_end->setLabel("End Date");
		$calendar_end->setAllowEmpty(false);
		$calendar_end->setRequired(true);
		$this->addElement($calendar_end);

		if($request->getParam('start_date')) {
			$starttime = strtotime($request->getParam('start_date'));
			$endtime = strtotime($request->getParam('end_date'));
			$calendar_start->setValue(date("Y-m-d H:i:s", ($starttime)));
			$calendar_end->setValue(date("Y-m-d H:i:s", ($endtime)));
		} else {
			$starttime = time();
			$oldTz = date_default_timezone_get();
			date_default_timezone_set($user->timezone);
			$calendar_start->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
			$calendar_end->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
			date_default_timezone_set($oldTz);
		}

		$this->addElement('Text', 'location', array(
			'label' => 'Location',
			'id'=>'location',
			'placeholder'=> 'Enter Location',
			'allowEmpty' => false,
			'required' => true,
		));

		$this->addElement('textarea', 'body', array(
			'label' => 'Details',
			'attribs' => array('rows' => 24, 'cols' => 180, 'style' => 'height:120px;'),
			'maxlength' => '250',
			'filters' => array(
				'StripTags',
				new Engine_Filter_Censor(),
			),
		));

		$this->addElement('Hidden', 'location_region', array(
			'id' => 'locationParams',
			'order' => 999,
		));

		// Element: submit
		$this->addElement('Button', 'submit', array(
			'label' => 'Save',
			'type' => 'submit',
		));

		$this->addElement('Cancel', 'cancel', array(
			'label' => 'cancel',
			'link' => true,
			'prependText' => ' or ',
			'onclick' => 'javascript:parent.Smoothbox.close()',
			'decorators' => array(
				'ViewHelper',
			),
		));

		$this->addDisplayGroup(array(
			'submit',
			'cancel',
		), 'buttons', array(
			'decorators' => array(
				'FormElements',
				'DivDivDivWrapper'
			),
		));

	}
}