<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_Model_DbTable_Calendars extends Core_Model_Item_DbTable_Abstract
{
    protected $_rowClass = "Calendar_Model_Calendar";

    /**
     * Gets a select object for the user's calendar entries
     *
     * @param Core_Model_Item_Abstract $user The user to get the messages for
     * @return Zend_Db_Table_Select
     */

    public function getAllCalendars($identity = 0, $show_mine = 0) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $select = $this->select()
                    ->where('owner_id = ?', $viewer->getIdentity());
        if ($identity) {
            $select = $select->where('calendar_id != ?', $identity);
        }
        if(!$show_mine) {
            $ownTable = Engine_Api::_()->getDbtable('owners', 'calendar');
            $ownSelect = $ownTable->select()
                            ->where('user_id = ?', $viewer->getIdentity())
                            ->where('custom = ?', 1)
                            ->where('calendar_id != ?', $identity);

            $rows = $ownTable->fetchAll($ownSelect);
            $calendars = array();
            foreach ($rows as $row) {
                $calendars[] = $row->calendar_id;
            }

            if(!empty($calendars)) {
                $select->orwhere('calendar_id IN(?)', $calendars);
            }
        }

        $select = $select->order('creation_date DESC');
        return $this->fetchAll($select);
    }

    public function getUsers($title, $limit = 10) {

    //MAKE QUERY
        $viewer = Engine_Api::_()->user()->getViewer();
        $table = Engine_Api::_()->getDbtable('users', 'user');
        $select = $table->select()
                ->from($table->info('name'), array('user_id', 'displayname', 'photo_id', 'email'));
                
        $select->where($table->info('name') . ".displayname LIKE ? ", '%' . $title . '%')
                ->where('enabled = ?', '1')
                ->where('user_id != ?', $viewer->getIdentity())
                ->where('verified = ?', '1')
                ->where('approved = ?', '1')
                ->order('displayname ASC')
                ->limit($limit);

        //FETCH RESULTS
        return $table->fetchAll($select);
    }

    public function addCustomNotifications(User_Model_User $user, Core_Model_Item_Abstract $subject, Core_Model_Item_Abstract $object, $type, array $params = null) {

        if( !$user->getIdentity() || !$subject->getIdentity() || !$object->getIdentity() )
        {
            return;
        }

        $row = Engine_Api::_()->getDbtable('notifications', 'activity')->createRow();
        $row->user_id = $user->getIdentity();
        $row->subject_type = $subject->getType();
        $row->subject_id = $subject->getIdentity();
        $row->object_type = $object->getType();
        $row->object_id = $object->getIdentity();
        $row->type = $type;
        $row->params = $params;
        $row->date = date('Y-m-d H:i:s');
        $row->save();

        return $row;
    }

    public function addGroup($group_id, $calendar) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
        $userTable = Engine_Api::_()->getDbtable('users', 'user');
        $row = $memberTable->createRow();
        $row->calendar_id = $calendar->calendar_id;
        $row->group_id = $group_id;
        $row->save();

        $members = Engine_Api::_()->getItemTable('calendar_groupmember')->getAllMembers($group_id);

        foreach ($members as $member) {
            $select = $userTable->select()
                              ->where('email = ? ', $member->user_email);
            $user = $userTable->fetchRow($select);
            if(!empty($user->email)) {
                $this->addCustomNotifications($user, $viewer, $calendar, 'calendar_member_add');
            }
        }
    }

    public function getBrowseCalendars() {
        $viewer = Engine_Api::_()->user()->getViewer();

        $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');
        $select = $memberTable->select()
                        ->where('user_email = ?', $viewer->email);

        $rows = $memberTable->fetchAll($select);
        $groups = array();
        foreach ($rows as $row) {
            $groups[] = $row->group_id;
        }

        $table = Engine_Api::_()->getDbtable('members', 'calendar');
        $select = $table->select()
                        ->where('user_email = ?', $viewer->email);

        if(!empty($groups)) {
            $select = $select->orwhere('group_id IN(?)', $groups);
        }

        $rows = $table->fetchAll($select);
        $calendars = array();
        foreach ($rows as $row) {
            $calendars[] = $row->calendar_id;
        }

        if(empty($calendars))
            return;

        $select = $this->select()
                    ->where('calendar_id IN(?)', $calendars)
                    ->where('custom = ?', 1)
                    ->where('owner_id != ?', $viewer->getIdentity());

        return $this->fetchAll($select);
    }

    public function getOwnCalendars() {
        $viewer = Engine_Api::_()->user()->getViewer();

        $table = Engine_Api::_()->getDbtable('owners', 'calendar');
        $select = $table->select()
                        ->where('user_id = ?', $viewer->getIdentity())
                        ->where('custom = ?', 1);

        $rows = $table->fetchAll($select);
        $calendars = array();
        foreach ($rows as $row) {
            $calendars[] = $row->calendar_id;
        }

        if(empty($calendars))
            return;

        $select = $this->select()
                    ->where('calendar_id IN(?)', $calendars);

        return $this->fetchAll($select);
    }

    public function getCalendarsCount() {

        $viewer = Engine_Api::_()->user()->getViewer();
        $user_id = $viewer->getIdentity();
        //MAKE QUERY
        $select = $this->select()
                ->from($this->info('name'), array('COUNT(*) AS count'))
                ->where('owner_id = ?', $user_id);

        $totalCalendars = $select->query()->fetchColumn();

        //RETURN CALENDAR COUNT
        return $totalCalendars;
    }
}