<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_Model_DbTable_Schedules extends Core_Model_Item_DbTable_Abstract
{
    protected $_rowClass = "Calendar_Model_Schedule";

    public function getCalendarSchedules($calendar_id) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $select = $this->select()
        ->where('calendar_id = ?', $calendar_id);

        $rows = $this->fetchAll($select);
        $data = array();
        foreach($rows as $row)
        {
            $calendar = Engine_Api::_()->getItem('calendar', $row->calendar_id);
            if(empty($calendar->background_color)) {
                $color = '#3E8BFD';
            } else {
                $color = $calendar->background_color;
            }
            $dt = date('Y-m-d H:i:s', strtotime($row->start_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $start_datetime = $date->format('Y-m-d H:i:s');

            $dt = date('Y-m-d H:i:s', strtotime($row->end_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $end_datetime = $date->format('Y-m-d H:i:s');
            $data[] = array(
                'id'   => $row->getIdentity(),
                'title' => $row->title,
                'body'  => $row->body,
                'start'   => $start_datetime,
                'end'   => $end_datetime,
                'color' => $color,
                'location' => $row->location
            );
        }
        return $data;
    }

    public function getUserSchedules($user_id,$params = array()) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
        $select = $table->select()
        ->from($table->info('name'), array('calendar_id'))
        ->where('calendar_id != ?', 0)
        ->where('owner_id = ?', $user_id);

        $calendars = $table->fetchAll($select);
        $data = array();
        foreach ($calendars as $calendar) {
            $data[] = $calendar->calendar_id;
        }
        if(empty($data))
            return;

        $select = $this->select()
        ->where('calendar_id IN (?)', $data);


        if(!empty($params['date']) && empty($params['isDateEvent'])){
            $month = explode('-', $params['date']);
            $select->where('(MONTH(start_datetime) = '.$month[1].' OR MONTH(end_datetime) = '.$month[1].')');
        }

        //FETCH RESULTS

        $rows = $this->fetchAll($select);
        $details = array();
        foreach($rows as $row)
        {
            $calendar = Engine_Api::_()->getItem('calendar', $row->calendar_id);
            if(empty($calendar->background_color)) {
                $color = '#3E8BFD';
            } else {
                $color = $calendar->background_color;
            }
            $dt = date('Y-m-d H:i:s', strtotime($row->start_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $start_datetime = $date->format('Y-m-d H:i:s');

            $dt = date('Y-m-d H:i:s', strtotime($row->end_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $end_datetime = $date->format('Y-m-d H:i:s');
            $details[] = array(
                'id'   => $row->getIdentity(),
                'title' => $row->title,
                'body'  => $row->body,
                'start'   => $start_datetime,
                'end'   => $end_datetime,
                'color' => $color,
                'location' => $row->location,
                'calendar_id' => $row->calendar_id,
            );
        }
        return $details;
    }

    public function setBookingSchedules($item, $duration)
    {
        $setting = Engine_Api::_()->getApi('settings', 'core')->getSetting("calendar.integration",'0');
        if($setting == '2' || $setting == '3') {

            $this->setProviderBookingSchedules($item, $duration);

            $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
            $select = $table->select()
            ->where('owner_id = ?', $item->user_id)
            ->where('custom = ?', 0)
            ->where('title = ?', 'My Bookings');

            $calendar = $table->fetchRow($select);
            if(empty($calendar->calendar_id)) {
                $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
                $user = Engine_Api::_()->getItem('user', $item->user_id);
                $calendar = $table->createRow();
                $calendar->title = 'My Bookings';
                $calendar->owner_id = $item->user_id;
                $calendar->custom = 0;
                $calendar->search = 0;
                $calendar->background_color = "#ee0af2";
                $calendar->save();

                $member = $memberTable->createRow();
                $member->calendar_id = $calendar->calendar_id;
                $member->user_email = $user->email;
                $member->user_id = $item->user_id;
                $member->save();

                // save owner
                $ownerRow = $ownerTable->createRow();
                $ownerRow->calendar_id = $calendar->calendar_id;
                $ownerRow->user_id = $item->user_id;
                $ownerRow->custom = 0;
                $ownerRow->save();
            }

            $serviceItem = Engine_Api::_()->getItem('sitebooking_ser',$item->ser_id);
            $duration = json_decode($duration);
            foreach ($duration as $key => $value) {
                $timings = explode(",",$value);
                foreach ($timings as $timing) {
                    $time = explode("-", $timing);
                    $row = $this->createRow();
                    $row->calendar_id = $calendar->calendar_id;
                    $row->owner_id = $item->user_id;
                    $row->title = $serviceItem->title;
                    $row->start_datetime = $key." ".$time[0];
                    $row->end_datetime = $key." ".$time[1];
                    $row->save();
                }
            }
        }
    }

    public function setProviderBookingSchedules($item, $duration)
    {
        $setting = Engine_Api::_()->getApi('settings', 'core')->getSetting("calendar.integration",'0');
        if($setting == '2' || $setting == '3') {
            $providerItem = Engine_Api::_()->getItem('sitebooking_pro', $item->pro_id);
            $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
            $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $select = $table->select()
            ->where('owner_id = ?', $providerItem->owner_id)
            ->where('custom = ?', 0)
            ->where('title = ?', 'Services Provided');

            $calendar = $table->fetchRow($select);
            if(empty($calendar->calendar_id)) {
                $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
                $user = Engine_Api::_()->getItem('user', $providerItem->owner_id);
                $calendar = $table->createRow();
                $calendar->title = 'Services Provided';
                $calendar->owner_id = $providerItem->owner_id;
                $calendar->custom = 0;
                $calendar->search = 0;
                $calendar->background_color = "#ee0af2";
                $calendar->save();

                $member = $memberTable->createRow();
                $member->calendar_id = $calendar->calendar_id;
                $member->user_email = $user->email;
                $member->user_id = $providerItem->owner_id;
                $member->save();

                // save owner
                $ownerRow = $ownerTable->createRow();
                $ownerRow->calendar_id = $calendar->calendar_id;
                $ownerRow->user_id = $providerItem->owner_id;
                $ownerRow->custom = 0;
                $ownerRow->save();
            }

            $serviceItem = Engine_Api::_()->getItem('sitebooking_ser',$item->ser_id);
            $duration = json_decode($duration);
            foreach ($duration as $key => $value) {
                $timings = explode(",",$value);
                foreach ($timings as $timing) {
                    $time = explode("-", $timing);
                    $row = $this->createRow();
                    $row->calendar_id = $calendar->calendar_id;
                    $row->owner_id = $providerItem->owner_id;
                    $row->title = Engine_Api::_()->getItem('user', $item->user_id)->getTitle();
                    $row->body = $serviceItem->title." "."Service booked";
                    $row->start_datetime = $key." ".$time[0];
                    $row->end_datetime = $key." ".$time[1];
                    $row->save();
                }
            }
        }
    }

    public function setEventSchedules($item) {
        $setting = Engine_Api::_()->getApi('settings', 'core')->getSetting("calendar.integration",'0');
        if($setting == '1' || $setting == '3') {
            $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
            $select = $table->select()
            ->where('owner_id = ?', $item->user_id)
            ->where('custom = ?', 0)
            ->where('title = ?', 'Events');

            $calendar = $table->fetchRow($select);
            if(empty($calendar->calendar_id)) {
                $user = Engine_Api::_()->getItem('user', $item->user_id);
                $calendar = $table->createRow();
                $calendar->title = 'Events';
                $calendar->owner_id = $item->user_id;
                $calendar->custom = 0;
                $calendar->search = 0;
                $calendar->background_color = "#36c423";
                $calendar->save();

                $member = $memberTable->createRow();
                $member->calendar_id = $calendar->calendar_id;
                $member->user_email = $user->email;
                $member->user_id = $item->user_id;
                $member->save();

                // save owner
                $ownerRow = $ownerTable->createRow();
                $ownerRow->calendar_id = $calendar->calendar_id;
                $ownerRow->user_id = $item->user_id;
                $ownerRow->custom = 0;
                $ownerRow->save();
            }
            $siteevent = Engine_Api::_()->getItem('siteevent_event', $item->event_id);
            $row = $this->createRow();
            $row->calendar_id = $calendar->calendar_id;
            $row->owner_id = $item->user_id;
            $row->title = $siteevent->title;
            $row->start_datetime = $item->occurrence_starttime;
            $row->end_datetime = $item->occurrence_endtime;
            $row->save();
        }
    }

    public function setUserEventSchedules($item, $start, $end) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $dt = date('Y-m-d H:i:s', strtotime($start));
        $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
        $date->setTimezone(new DateTimeZone('UTC'));
        $start = $date->format('Y-m-d H:i:s');

        $dt = date('Y-m-d H:i:s', strtotime($end));
        $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
        $date->setTimezone(new DateTimeZone('UTC'));
        $end = $date->format('Y-m-d H:i:s');

        $setting = Engine_Api::_()->getApi('settings', 'core')->getSetting("calendar.integration",'0');
        if($setting == '1' || $setting == '3') {
            $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
            $select = $table->select()
            ->where('owner_id = ?', $item->owner_id)
            ->where('custom = ?', 0)
            ->where('title = ?', 'Events');

            $calendar = $table->fetchRow($select);
            if(empty($calendar->calendar_id)) {
                $user = Engine_Api::_()->getItem('user', $item->owner_id);
                $calendar = $table->createRow();
                $calendar->title = 'Events';
                $calendar->owner_id = $item->owner_id;
                $calendar->custom = 0;
                $calendar->search = 0;
                $calendar->background_color = "#36c423";
                $calendar->save();

                $member = $memberTable->createRow();
                $member->calendar_id = $calendar->calendar_id;
                $member->user_email = $user->email;
                $member->user_id = $item->owner_id;
                $member->save();

                // save owner
                $ownerRow = $ownerTable->createRow();
                $ownerRow->calendar_id = $calendar->calendar_id;
                $ownerRow->user_id = $item->owner_id;
                $ownerRow->custom = 0;
                $ownerRow->save();
            }
            if(!empty($calendar->calendar_id)) {
                $row = $this->createRow();
                $row->calendar_id = $calendar->calendar_id;
                $row->owner_id = $item->owner_id;
                $row->title = $item->title;
                $row->start_datetime = $start;
                $row->end_datetime = $end;
                $row->save();
            }

            if(($item->host_type == 'user') && ($item->owner_id != $item->host_id)) {
                $select = $table->select()
                ->where('owner_id = ?', $item->host_id)
                ->where('custom = ?', 0)
                ->where('title = ?', 'Events');

                $calendar = $table->fetchRow($select);
                if(empty($calendar->calendar_id)) {
                    $user = Engine_Api::_()->getItem('user', $item->host_id);
                    $calendar = $table->createRow();
                    $calendar->title = 'Events';
                    $calendar->owner_id = $item->host_id;
                    $calendar->custom = 0;
                    $calendar->search = 0;
                    $calendar->background_color = "#36c423";
                    $calendar->save();

                    $member = $memberTable->createRow();
                    $member->calendar_id = $calendar->calendar_id;
                    $member->user_email = $user->email;
                    $member->user_id = $item->host_id;
                    $member->save();

                    // save owner
                    $ownerRow = $ownerTable->createRow();
                    $ownerRow->calendar_id = $calendar->calendar_id;
                    $ownerRow->user_id = $item->host_id;
                    $ownerRow->custom = 0;
                    $ownerRow->save();
                }
                if(!empty($calendar->calendar_id)) {
                    $row = $this->createRow();
                    $row->calendar_id = $calendar->calendar_id;
                    $row->owner_id = $item->host_id;
                    $row->title = $item->title;
                    $row->start_datetime = $start;
                    $row->end_datetime = $end;
                    $row->save();
                }
            }
        }
    }

    public function getBrowseSchedules($calendar_id,$params = array()) {

        //MAKE QUERY
        $viewer = Engine_Api::_()->user()->getViewer();
        if(empty($calendar_id)) {
            $groupMemberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');
            $select = $groupMemberTable->select()
            ->where('user_email = ?', $viewer->email);
            $groups = $groupMemberTable->fetchAll($select);
            $data = array();
            foreach ($groups as $group) {
                $data[] = $group->group_id;
            }

            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $select = $memberTable->select()
            ->where('user_email = ?', $viewer->email);

            if(!empty($data)) {
                $select->orwhere('group_id IN (?)', $data);
            }

            $calendars = $memberTable->fetchAll($select);
            $members = array();
            foreach ($calendars as $calendar) {
                $members[] = $calendar->calendar_id;
            }

            if(empty($members))
                return;

            $members = array_unique($members);
            $select = $this->select()
            ->where('calendar_id IN(?)', $members);
        } else {
            $select = $this->select()
            ->where('calendar_id = ?', $calendar_id);
        }

        if(!empty($params['date'])){
            $month = explode('-', $params['date']);
            $select->where('(MONTH(start_datetime) = '.$month[1].' OR MONTH(end_datetime) = '.$month[1].')');
        }

        $rows = $this->fetchAll($select);
        $schedules = array();
        foreach($rows as $row)
        {
            $calendar = Engine_Api::_()->getItem('calendar', $row->calendar_id);
            if(empty($calendar->background_color)) {
                $color = '#3E8BFD';
            } else {
                $color = $calendar->background_color;
            }
            $dt = date('Y-m-d H:i:s', strtotime($row->start_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $start_datetime = $date->format('Y-m-d H:i:s');

            $dt = date('Y-m-d H:i:s', strtotime($row->end_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $end_datetime = $date->format('Y-m-d H:i:s');
            $isOwner = Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($row->calendar_id);
            
            $isOwner = (!empty($isOwner) || ($viewer->getIdentity() ==  $row->owner_id)) ? true : false;
            $schedules[] = array(
                'id'   => $row->getIdentity(),
                'title' => trim($row->title, "\r"),
                'body'  => trim($row->body, "\r"),
                'start'   => $start_datetime,
                'end'   => $end_datetime,
                'color' => $color,
                'location' => trim($row->location, "\r"),
                'isOwner' => $isOwner,
                'calendar_id' => $row->calendar_id,
            );
        }
        return $schedules;
    }

    public function getUserScheduless($user_id,$params = array()) {
        $viewer = Engine_Api::_()->user()->getViewer();
        if (isset($params['start_time']) && !empty($params['start_time'])) {
            $select = $this->select()->distinct()->from($this->info('name'), 'DATE(start_datetime)');
        }  else {
            $select = $this->select();
        }
        $table = Engine_Api::_()->getDbtable('calendars', 'calendar');
        $select1 = $table->select()
        ->from($table->info('name'), array('calendar_id'))
        ->where('calendar_id != ?', 0)
        ->where('owner_id = ?', $user_id);

        $calendars = $table->fetchAll($select1);
        $data = array();
        foreach ($calendars as $calendar) {
            $data[] = $calendar->calendar_id;
        }
        if(empty($data))
            return;

        $select->where('calendar_id IN (?)', $data);


        if(!empty($params['date']) && empty($params['isDateEvent'])){
            $month = explode('-', $params['date']);
            $select->where('(MONTH(start_datetime) = '.$month[1].' OR MONTH(end_datetime) = '.$month[1].')');
        }

        if(!empty($params['isDateEvent'])){
            $select->where('((DATE(start_datetime) <= "'.$params['date'].'") AND (DATE(end_datetime) >= "'.$params['date'].'"))');
        }
        if (isset($params['start_time']) && !empty($params['start_time']))
            return $select;

        //FETCH RESULTS
        $rows = $this->fetchAll($select);
        $details = array();
        foreach($rows as $row)
        {
            $calendar = Engine_Api::_()->getItem('calendar', $row->calendar_id);
            if(empty($calendar->background_color)) {
                $color = '#3E8BFD';
            } else {
                $color = $calendar->background_color;
            }
            $dt = date('Y-m-d H:i:s', strtotime($row->start_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $start_datetime = $date->format('Y-m-d H:i:s');

            $dt = date('Y-m-d H:i:s', strtotime($row->end_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $end_datetime = $date->format('Y-m-d H:i:s');

            if (isset($params['start']) && !empty($params['start'])) {
                $datediff = strtotime($end_datetime) - strtotime($start_datetime);
                $days = round($datediff / (60 * 60 * 24));
            }

            $isOwner = Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($row->calendar_id);

            $details[] = array(
                'id'   => $row->getIdentity(),
                'title' => $row->title,
                'body'  => $row->body,
                'start'   => $start_datetime,
                'end'   => $end_datetime,
                'color' => $color,
                'location' => $row->location,
                'isOwner' => $isOwner,
                'time_diff' => $days
            );
        }
        return $details;
    }

    public function getBrowseScheduless($calendar_id,$params = array()) {

        //MAKE QUERY

        if (isset($params['start_time']) && !empty($params['start_time'])) {
            $select = $this->select()->distinct()->from($this->info('name'), 'DATE(start_datetime)');
        }  else {
            $select = $this->select();
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        if(empty($calendar_id)) {
            $groupMemberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');
            $select1 = $groupMemberTable->select()
            ->where('user_email = ?', $viewer->email);
            $groups = $groupMemberTable->fetchAll($select1);
            $data = array();
            foreach ($groups as $group) {
                $data[] = $group->group_id;
            }

            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $select1 = $memberTable->select()
            ->where('user_email = ?', $viewer->email);

            if(!empty($data)) {
                $select1->orwhere('group_id IN (?)', $data);
            }

            $calendars = $memberTable->fetchAll($select1);
            $members = array();
            foreach ($calendars as $calendar) {
                $members[] = $calendar->calendar_id;
            }

            if(empty($members))
                return;

            $members = array_unique($members);
            
            $select->where('calendar_id IN(?)', $members);
        } else {
            
            $select->where('calendar_id = ?', $calendar_id);
        }

        if(!empty($params['date']) && empty($params['isDateEvent'])){
            $month = explode('-', $params['date']);
            $select->where('(MONTH(start_datetime) = '.$month[1].' OR MONTH(end_datetime) = '.$month[1].')');
        }

        if(!empty($params['isDateEvent'])){
            $select->where('((DATE(start_datetime) <= "'.$params['date'].'") AND (DATE(end_datetime) >= "'.$params['date'].'"))');
        }
        if (isset($params['start_time']) && !empty($params['start_time']))
            return $select;

        $rows = $this->fetchAll($select);

        $schedules = array();
        foreach($rows as $row)
        {
            $calendar = Engine_Api::_()->getItem('calendar', $row->calendar_id);
            if(empty($calendar->background_color)) {
                $color = '#3E8BFD';
            } else {
                $color = $calendar->background_color;
            }
            $dt = date('Y-m-d H:i:s', strtotime($row->start_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $start_datetime = $date->format('Y-m-d H:i:s');

            $dt = date('Y-m-d H:i:s', strtotime($row->end_datetime));
            $date = new DateTime($dt, new DateTimeZone('UTC'));
            $date->setTimezone(new DateTimeZone($viewer->timezone));
            $end_datetime = $date->format('Y-m-d H:i:s');

            if (isset($params['start']) && !empty($params['start'])) {
                $datediff = strtotime($end_datetime) - strtotime($start_datetime);
                $days = round($datediff / (60 * 60 * 24));
            }
            $isOwner = Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($row->calendar_id);
            $schedules[] = array(
                'id'   => $row->getIdentity(),
                'title' => $row->title,
                'body'  => $row->body,
                'start'   => $start_datetime,
                'end'   => $end_datetime,
                'color' => $color,
                'location' => $row->location,
                'isOwner' => $isOwner,
                'time_diff' => $days
            );
        }
        return $schedules;
    }
}