<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_IndexController extends Core_Controller_Action_Standard
{
    public function init() {
        if( !$this->_helper->requireUser()->isValid() ) return;
    }

    public function indexAction()
    {
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
            return;
        }

        $this->view->calendar_id = $this->_getParam('search');
        // Render
        $this->_helper->content
            //->setNoRender()
        ->setEnabled()
            ;
    }

    public function claimCalendarsAction()
    {
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
            return;
        }

        $viewer = Engine_Api::_()->user()->getViewer();

        // Render
        $this->_helper->content
            //->setNoRender()
        ->setEnabled()
            ;

        $page = $this->_getParam('page', 1);
        // Get all calendars
        $calendars = Engine_Api::_()->getItemTable('calendar')->getBrowseCalendars();
        if($calendars != NULL){
            $this->view->paginator = $paginator = Zend_Paginator::factory($calendars);
            $this->view->paginator->setItemCountPerPage(12);
            $this->view->paginator->setCurrentPageNumber($page);
            $this->view->totalItemCount = $this->view->paginator->getTotalItemCount();
        }
        else
            $this->view->totalItemCount = 0;
    }

    public function manageAction()
    {
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
            return;
        }

        $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();

    	$this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('calendar_main_manage', array(), 'calendar_main_manage_calendars');

        $this->view->canCreate = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->checkRequire();

        // Render
        $this->_helper->content->setEnabled();

        // Get all calendars
        $page = $this->_getParam('page', 1);
        $this->view->paginator = $paginator = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getAllCalendars(0, 1));
        $this->view->paginator->setItemCountPerPage(12);
        $this->view->paginator = $paginator->setCurrentPageNumber($page);

    }

    public function viewAction()
    {
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
            return;
        }
        
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->isValid()) {
            return;
        }

        // Check permission
        $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));

        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('calendar_main_manage', array(), 'calendar_main_manage_calendars');

        if( $calendar ) {
            Engine_Api::_()->core()->setSubject($calendar);
        }

        if( !$this->_helper->requireSubject()->isValid() ) {
            return;
        }
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', $viewer, 'view')->isValid()) 
        {
            return;
        }
        if( !$calendar) {
            return $this->_helper->requireSubject->forward();
        }

        $this->view->canCreate = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->checkRequire();
        $this->view->canEdit = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'edit')->checkRequire();
        $this->view->canDelete = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'delete')->checkRequire();

        // Prepare data
        $calendarTable = Engine_Api::_()->getDbtable('calendars', 'calendar');

        $this->view->calendar = $calendar;
        $this->view->owner = $owner = $calendar->getOwner();
        $this->view->viewer = $viewer;

        $this->view->claim = Engine_Api::_()->getDbtable('claims', 'calendar')->isClaimed($this->_getParam('calendar_id'));

        // Get all Members
        $this->view->members = $members = Engine_Api::_()->getDbtable('members', 'calendar')->getMembers($this->_getParam('calendar_id'));

        // Get all Owners
        $this->view->owners = $owners = Engine_Api::_()->getDbtable('owners', 'calendar')->getOwners($this->_getParam('calendar_id'));

        // check if viewer is owner
        $this->view->isCalendarowner = $owners = Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($this->_getParam('calendar_id'));

        //check if it has schedules
        $this->view->hasSchedules = false;
        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar->getIdentity());

        if(!empty($schedules))
            $this->view->hasSchedules = true;

        // Render
        $this->_helper->content
            //->setNoRender()
            ->setEnabled()
        ;
    }

    public function createAction()
    { 
    
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->isValid()) {
        return;
        }

        $viewer = Engine_Api::_()->user()->getViewer();

        // Render
        $this->_helper->content
            //->setNoRender()
            ->setEnabled()
            ;

        // Prepare form
        $this->view->form = $form = new Calendar_Form_Create();

        //GET CORE SETTING 
        $settings = Engine_Api::_()->getApi('settings', 'core');
        $this->view->quota = $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'calendar', 'max');
        
        $paginator = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getAllCalendars(0, 1));

        $this->view->current_count = $paginator->getTotalItemCount();

        // check duplicacy of title
        if($this->_getParam('isAjax')){
            $calendarTable = Engine_Api::_()->getItemTable('calendar');
            $title = $this->_getParam('title');
            $calendars = $calendarTable->fetchRow($calendarTable->select()->where("title LIKE ?", $title));

            $flag = true;
            if(!empty($calendars)){
                $flag = false;
            }
            $check['flag'] = $flag;
            return $this->_helper->json($check);
        }

        // If not post or form not valid, return
        if( !$this->getRequest()->isPost() ) {
            return;
        }

        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        $table = Engine_Api::_()->getItemTable('calendar');
        $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
        $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
        $db = $table->getAdapter();
        $db->beginTransaction();

        try {
            $formValues = $form->getValues();
            $calendars = $table->fetchRow($table->select()->where('title LIKE ?',$formValues['title']));

            if(!empty($calendars)){
                return $form->addError('Title: This title is already taken, please try another');
            }
            // Create Calendar
            $viewer = Engine_Api::_()->user()->getViewer();

            // differniate groups and members
            $toValues = explode(",",$formValues['toValues']);
            $members = array();
            $groups = array();
            foreach ($toValues as $data) {
                if(strpos($data, '_group') !== false) {
                    $groups[] = preg_replace('/[^0-9]/', '', $data);
                } else {
                    $members[] = $data;
                }
            }

            $non_members = explode(',', $formValues['non_members']);
            //Mail to non existing members
            if($formValues['non_members']){
                foreach ($non_members as $key => $value) {
                    Engine_Api::_()->getApi('mail', 'core')->sendSystem($value, 'NOTIFY_NONEXISTING_USER', array(
                        'member_name' => $viewer->displayname,
                        'calendar_name' =>$formValues['title'],
                    ));
                }
            }

            $resources = array_unique (array_merge ($members, $non_members));

            $values = array_merge($formValues, array(
                'owner_id' => $viewer->getIdentity()
            ));

            $calendar = $table->createRow();
            $calendar->setFromArray($values);
            $calendar->save();
            $row = $memberTable->createRow();
            $row->calendar_id = $calendar->calendar_id;
            $row->user_email = $viewer->email;
            $row->user_id = $viewer->getIdentity();
            $row->save();

            // save owner
            $ownerRow = $ownerTable->createRow();
            $ownerRow->calendar_id = $calendar->calendar_id;
            $ownerRow->user_id = $viewer->getIdentity();
            $ownerRow->custom = 0;
            $ownerRow->save();

            // Add members
            foreach ($resources as $resource) {
                $user = Engine_Api::_()->getItem('user', $resource);
                $row = $memberTable->createRow();
                $row->calendar_id = $calendar->calendar_id;
                 if(!empty($user->email)) {
                    $row->user_email = $user->email;
                    $row->user_id = $user->user_id;
                    $row->save();
                    Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_member_add');
                } else if(!empty($resource)) {
                    $row->user_email = $resource;
                    $row->save();
                }
            }

            //Add groups
            foreach ($groups as $group) {
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addGroup($group, $calendar);
            }
            // Commit
            $db->commit();
        } catch( Exception $e ) {
            return $this->exceptionWrapper($e, $form, $db);
        }

        return $this->_helper->redirector->gotoRoute(array('action' => 'manage'));
    }

    public function editAction()
    {
        if( !$this->_helper->requireUser()->isValid() ) return;

        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->calendar = $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
        if( !Engine_Api::_()->core()->hasSubject('calendar') ) {
            Engine_Api::_()->core()->setSubject($calendar);
        }

        if( !$this->_helper->requireAuth()->setAuthParams($calendar, $calendar->getOwner(), 'edit')->isValid() ) return;
        
        if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($calendar->getIdentity())) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        // Prepare form
        $this->view->form = $form = new Calendar_Form_Edit(array('BackGroundColor' => $calendar->background_color));

        //Make field not-editable in non-custom form
        if($calendar->custom == 0)
            $form->title->setAttrib('readonly', 'readonly');

        $members = Engine_Api::_()->getDbtable('members', 'calendar')->getCalendarMembers($calendar);

        $data = $calendar->toArray();

        if(!empty($members['exist'])) {
            $this->view->isPopulated = true;
            $this->view->buddy = $members['exist'];
        }

        if(!empty($members['users'])) {
            $this->view->isPopulated = false;
            $data['non_members'] = implode(',', $members['users']);
        }

        // Populate form
        $form->populate($data);

        // check duplicacy of title
        if($this->_getParam('isAjax')){
          $calendarTable = Engine_Api::_()->getItemTable('calendar');
          $title = $this->_getParam('title');
          $calendars = $calendarTable->fetchRow($calendarTable->select()->where("title LIKE ?", $title));

          $flag = true;
            if(!empty($calendars) && $calendars->getIdentity() != $this->_getParam('calendar_id')){
              $flag = false;

            }
          $check['flag'] = $flag;
          return $this->_helper->json($check);
        }
        // Check post/form
        if( !$this->getRequest()->isPost() ) {
            return;
        }
        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        // Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');

        try {
            // Edit Calendar
            $viewer = Engine_Api::_()->user()->getViewer();
            $formValues = $form->getValues();
            $calendarTable = Engine_Api::_()->getItemTable('calendar');
            if($calendar->custom == 1) {
                $calendars = $calendarTable->fetchAll($calendarTable->select()->where('title LIKE ?',$formValues['title']));
                foreach($calendars as $value){
                    if($value->calendar_id != $this->_getParam('calendar_id')){
                      return $form->addError('Title: This Title is already taken, please try another');
                    }
                }
            }
            // differniate groups and members
            $toValues = explode(",",$formValues['toValues']);
            $members = array();
            $groups = array();
            foreach ($toValues as $data) {
                if(strpos($data, '_group') !== false) {
                    $groups[] = preg_replace('/[^0-9]/', '', $data);
                } else {
                    $members[] = $data;
                }
            }

            $non_members = explode(',', $formValues['non_members']);
            $resources = array_unique (array_merge ($members, $non_members));

            $values = array_merge($formValues, array(
                'owner_id' => $viewer->getIdentity()
            ));

            $values = $form->getValues();
            $calendar->modified_date = date('Y-m-d H:i:s');
            $calendar->setFromArray($values);
            $calendar->save();

            foreach ($resources as $resource) {
                $select = $memberTable->select()
                                    ->where('calendar_id = ?', $calendar->calendar_id)
                                    ->where('user_id = ?', $resource);

                $data = $memberTable->fetchRow($select);

                if(empty($data->member_id)) {
                    $user = Engine_Api::_()->getItem('user', $resource);
                    $row = $memberTable->createRow();
                    $row->calendar_id = $calendar->calendar_id;
                     if(!empty($user->email)) {
                        $row->user_email = $user->email;
                        $row->user_id = $user->user_id;
                        $row->custom = 0;
                        $row->save();
                        Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_member_add');
                    } else if(!empty($resource)) {
                        $row->user_email = $resource;
                        $row->custom = 1;
                        $row->save();
                    }
                }
            }
            //Add groups
            foreach ($groups as $group) {
                $select = $memberTable->select()
                                    ->where('calendar_id = ?', $calendar->calendar_id)
                                    ->where('group_id = ?', $group);

                $data = $memberTable->fetchRow($select);
                if(empty($data->member_id)) {
                    Engine_Api::_()->getDbtable('calendars', 'calendar')->addGroup($group, $calendar);
                }
            }

            $removeMembers = explode(",",$formValues['remove_member']);
            foreach ($removeMembers as $removeMember) {
                if(!empty($removeMember)) {
                    if(strpos($removeMember, '_group') !== false) {
                        $memberTable->deleteCalendarMembers($calendar->calendar_id, $removeMember);
                    } else {
                        $user = Engine_Api::_()->getItem('user', $removeMember);
                        $memberTable->deleteCalendarMembers($calendar->calendar_id, $user->email, true);
                    }
                }
            }
            $db->commit();
        }
        catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'manage'));
    }

    public function deleteAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $this->getRequest()->getParam('calendar_id'));
        if( !$this->_helper->requireAuth()->setAuthParams($calendar, null, 'delete')->isValid()) return;

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');

        $this->view->form = $form = new Calendar_Form_Delete();

        if( !$calendar ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("Calendar doesn't exist or not authorized to delete");
            return;
        }

        if( !$this->getRequest()->isPost() ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $db = $calendar->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            // delete all members
            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $memberSelect = $memberTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $memberTable->fetchAll($memberSelect) as $member ) {
                $member->delete();
            }
            // delete owners
            $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
            $ownerSelect = $ownerTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $ownerTable->fetchAll($ownerSelect) as $owner ) {
                $owner->delete();
            }
            // Delete schedules
            $scheduleTable = Engine_Api::_()->getDbtable('schedules', 'calendar');
            $scheduleSelect = $scheduleTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $scheduleTable->fetchAll($scheduleSelect) as $schedule ) {
                $schedule->delete();
            }
            // delete all claims
            $claimTable = Engine_Api::_()->getDbtable('claims', 'calendar');
            $claimSelect = $claimTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $claimTable->fetchAll($claimSelect) as $claim ) {
                $claim->delete();
            }

            $calendar->delete();

            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your calendar has been deleted Successfully.');
        return $this->_forward('success' ,'utility', 'core', array(
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'calendar_general', true),
            'messages' => Array($this->view->message)
        ));
    }

    public function manageScheduleAction()
    {
        // Render
        $this->_helper->content
            //->setNoRender()
            ->setEnabled()
        ;
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('calendar_main_manage', array(), 'calendar_main_manageschedule');
    }

    public function getusersAction() {
        $search_text = $this->_getParam('value', null);
        $limit = $this->_getParam('limit', 40);

        $data = array();

        $moduleContents = Engine_Api::_()->getItemTable('calendar')->getUsers($search_text, $limit = 10);

        foreach ($moduleContents as $moduleContent) {

            $content_photo = $this->view->itemPhoto($moduleContent, 'thumb.icon');

            $data[] = array(
                'id' => $moduleContent->user_id,
                'label' => $moduleContent->displayname,
                'photo' => $content_photo,
                'email' => $moduleContent->email
            );
        }
        return $this->_helper->json($data);
    }

    public function getMembersAction() {
        $search_text = $this->_getParam('value', null);
        $limit = $this->_getParam('limit', 40);

        $data = array();

        $moduleContents = Engine_Api::_()->getItemTable('calendar')->getUsers($search_text, $limit = 10);

        $userGroups = Engine_Api::_()->getDbtable('groups', 'calendar')->getSearchGroups($search_text);

        foreach ($moduleContents as $moduleContent) {

            $content_photo = $this->view->itemPhoto($moduleContent, 'thumb.icon');

            $data[] = array(
                'id' => $moduleContent->user_id,
                'label' => $moduleContent->displayname,
                'photo' => $content_photo,
                'email' => $moduleContent->email,
            );
        }

        foreach ($userGroups as $userGroup) {

            $content_photo = $this->view->itemPhoto($userGroup, 'thumb.icon');

            $data[] = array(
                'id' => $userGroup->group_id."_group",
                'label' => $userGroup->title." (Group)",
                'photo' => $content_photo,
                // 'type' => 'group'
            );
        }
        return $this->_helper->json($data);
    }

    public function getOwnersAction() {
        $search_text = $this->_getParam('value', null);
        $limit = $this->_getParam('limit', 40);

        $data = array();
        $calendar_id = $this->getRequest()->getParam('calendar_id');
        $moduleContents = Engine_Api::_()->getDbtable('owners', 'calendar')->getUsers($search_text, $limit = 10, $calendar_id);

        foreach ($moduleContents as $moduleContent) {

            $content_photo = $this->view->itemPhoto($moduleContent, 'thumb.icon');

            $data[] = array(
                'id' => $moduleContent->user_id,
                'label' => $moduleContent->displayname,
                'photo' => $content_photo,
                'email' => $moduleContent->email,
            );
        }

        return $this->_helper->json($data);
    }

    public function browseSchedulesAction() {
        // Get all schedules
        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getBrowseSchedules($this->_getParam('calendar_id', 0));
        echo json_encode($schedules);
        exit;
    }

    public function claimAction() {

        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('id'));
        $viewer = Engine_Api::_()->user()->getViewer();
        $table = Engine_Api::_()->getItemTable('calendar_claim');
        $db = $table->getAdapter();
        $db->beginTransaction();

        try {
                $row = $table->createRow();
                $row->calendar_id = $calendar->getIdentity();
                $row->user_id = $viewer->getIdentity();
                $row->status = 'Pending';
                $row->save();
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($calendar->getOwner(), $viewer, $calendar, 'calendar_claim');
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($viewer, $viewer, $calendar, 'calendar_claim_request');
                // Commit
                $db->commit();
            } catch( Exception $e ) {
                return $this->exceptionWrapper($e, $form, $db);
            }
        $this->_redirect('calendar/index/claim-calendars');
    }

    public function statusAction() {

        $claim_id = (int) $this->_getParam('claim_id');
        $action = $this->_getParam('claim_action');
        $calendar_id = $this->_getParam('calendar_id');
        $calendar = Engine_Api::_()->getItem('calendar', $calendar_id);
        $user_id = (int) $this->_getParam('user_id');
        $user = Engine_Api::_()->getItem('user', $user_id);
        $viewer = Engine_Api::_()->user()->getViewer();

        if($action == "Rejected") {
            Engine_Api::_()->getItemTable('calendar_claim')->update(array('status' => $action), array('claim_id = ?' => $claim_id));
        }

        if($action == "Accepted") {
            Engine_Api::_()->getItemTable('calendar')->update(array(
                'owner_id' => $user_id,
            ), array(
                'calendar_id = ?' => $calendar_id,
            ));

            Engine_Api::_()->getItemTable('calendar_schedule')->update(array(
                'owner_id' => $user_id,
            ), array(
                'calendar_id = ?' => $calendar_id,
            ));

            Engine_Api::_()->getDbtable('owners', 'calendar')->update(array(
                'user_id' => $user_id,
            ), array(
                'calendar_id = ?' => $calendar_id,
            ));
            // delete all claims
            $claimTable = Engine_Api::_()->getDbtable('claims', 'calendar');
            $claimSelect = $claimTable->select()->where('calendar_id = ?', $calendar_id);
            foreach( $claimTable->fetchAll($claimSelect) as $claim ) {
                $claim->delete();
            }
        }

        Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_claim_status', array('status' => strtolower($action)));
        exit;
    }

    public function icalAction() {
        $calendar_id = $this->_getParam('calendar_id');
        $calendar = Engine_Api::_()->getItem('calendar', $calendar_id);
        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar_id);
        $viewer = Engine_Api::_()->user()->getViewer();
        $icsPath = APPLICATION_PATH . '/application/modules/Calendar/settings';
        $icsFile = 'calendar.ics';

        //KILL ZEND'S OB
        $isGZIPEnabled = false;
        if (ob_get_level()) {
            $isGZIPEnabled = true;
            @ob_end_clean();
        }

        // Send headers
        header("Content-Disposition: attachment; filename=" . urlencode(basename($icsFile)), true);
        header("Content-Transfer-Encoding: Binary", true);
        header("Content-Type: application/force-download", true);
        header("Content-Type: application/octet-stream", true);
        header("Content-Type: application/download", true);
        header("Content-Description: File Transfer", true);

        if (empty($isGZIPEnabled)) {
            header('content-length: ' . filesize($icsPath . DIRECTORY_SEPARATOR . $icsFile));
        }

        flush();
        $http = _ENGINE_SSL ? 'https://' : 'http://';
        $handle = fopen($icsPath . DIRECTORY_SEPARATOR . $icsFile, 'r');
        echo "BEGIN:VCALENDAR\n";
        echo "VERSION:2.0\n";
        echo "X-WR-CALNAME:" . $calendar->getTitle() . "\n";
        echo "CALSCALE:GREGORIAN\n";
        echo "METHOD:REQUEST\n"; // requied by Outlook
        foreach ($schedules as $schedule) {
            $dt = date('Y-m-d H:i:s', strtotime($schedule['start']));
            $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
            $date->setTimezone(new DateTimeZone('UTC'));
            $start = $date->format('Y-m-d H:i:s');

            $dt = date('Y-m-d H:i:s', strtotime($schedule['end']));
            $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
            $date->setTimezone(new DateTimeZone('UTC'));
            $end = $date->format('Y-m-d H:i:s');
            echo "BEGIN:VEVENT\n";
            echo "DTSTART:" . date('Ymd\THis\Z', strtotime($start)) . "\n";
            echo "DTEND:" . date('Ymd\THis\Z', strtotime($end)) . "\n";
            echo "SUMMARY:" . $schedule['title'] . "\n";
            echo "DESCRIPTION:" . $schedule['body'] . "\n";
            echo "LOCATION:" . $schedule['location'] . "\n";
            echo "UID:" . uniqid() . "\n";
            echo "END:VEVENT\n";
        }
        echo "END:VCALENDAR\n";
        flush();
        exit();
    }

    public function addOwnersAction() {
        if( !$this->_helper->requireUser()->isValid() ) return;

        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->calendar = $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');

        // Prepare form
        $this->view->form = $form = new Calendar_Form_Add();

        if( !$calendar ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("Calendar doesn't exist");
            return;
        }

        if( !$this->getRequest()->isPost() ) {
            return;
        }
        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        $db = $calendar->getTable()->getAdapter();
        $db->beginTransaction();
        $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');

        try {
            $formValues = $form->getValues();

            $members = explode(",",$formValues['toValues']);

            foreach ($members as $resource) {
                $user = Engine_Api::_()->getItem('user', $resource);
                $row = $ownerTable->createRow();
                $row->calendar_id = $calendar->getIdentity();
                $row->user_id = $user->getIdentity();
                $row->save();
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_owner_add');
            }
            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 3000,
            'parentRefresh' => 3000,
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Calendar owners have been added.'))
        ));
    }

    public function removeOwnerAction() {
        $calendar_id = $this->getRequest()->getParam('calendar_id');
        $user_id = $this->getRequest()->getParam('user_id');
        $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $calendar_id);

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');

        try {
            $ownerTable->delete(array('calendar_id = ?'=> $calendar_id, 'user_id = ?' => $user_id));
            Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications(Engine_Api::_()->getItem('user', $user_id), $calendar->getOwner(), $calendar, 'calendar_owner_remove');
            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 3000,
          'parentRefresh' => 3000,
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have removed the calendar owner.'))
        ));
    }

    public function ownedAction()
    {
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
            return;
        }

        $viewer = Engine_Api::_()->user()->getViewer();

        // Render
        $this->_helper->content
            //->setNoRender()
        ->setEnabled()
            ;
        // Get all calendars
        $page = $this->_getParam('page', 1);
        $calendars = Engine_Api::_()->getItemTable('calendar')->getOwnCalendars();
        if($calendars != NULL){
            $this->view->paginator = $paginator = Zend_Paginator::factory($calendars);
            $this->view->paginator->setItemCountPerPage(12);
            $this->view->paginator->setCurrentPageNumber($page);
            $this->view->totalItemCount = $this->view->paginator->getTotalItemCount();
        }
        else{
            $this->view->totalItemCount = 0;
        }
    }

    public function smoothboxAction(){

        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

        $schedule_id = $this->_getParam('schedule_id');
        
        $this->view->schedule = $schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
    
    }
}