<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */


class Calendar_IndexController extends Siteapi_Controller_Action_Standard
{
	public function createAction()
    {  
    	$viewer = Engine_Api::_()->user()->getViewer();

    	// Must be able to create blogs
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->isValid()) {
        	$this->respondWithError('unauthorized');
        }

        // If method not Post or form not valid , Return
        if ($this->getRequest()->isPost()) {

        	$quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'calendar', 'max');

        	$paginator = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getAllCalendars(0, 1));

        	$currentCount = $paginator->getTotalItemCount();

        	if ($currentCount >= $quota && !empty($quota))
            	$this->respondWithError('calendar_creation_quota_exceed', 'Your calendar creation limit has been exceeded');

        	// CONVERT POST DATA INTO THE ARRAY.
            $values = array();
            $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getCalendarForm();
            foreach ($getForm as $element) {
                if (isset($_REQUEST[$element['name']]))
                    $values[$element['name']] = $_REQUEST[$element['name']];
            }

            // CONVERT POST DATA INTO AN ARRAY.
            $data = $values = @array_merge($values, array('user_id' => $viewer_id));

            $values['background_color'] = $_REQUEST['background_color'];

            // START FORM VALIDATION
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'calendar')->getCalendarFormValidators();
            $data['validators'] = $validators;
            $validationMessage = $this->isValid($data);
            
            // check duplicacy of title
            $calendarTable = Engine_Api::_()->getItemTable('calendar');
            $title = $values['title'];
            if(!empty($title)){
            	$calendars = $calendarTable->fetchRow($calendarTable->select()->where("title LIKE ?", $title));

	            if(!empty($calendars)){
	                $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
	                    $validationMessage['title'] = $this->translate('This title is already taken, please try another');
	            }
	        }

            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }

	        $table = Engine_Api::_()->getItemTable('calendar');
	        $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
	        $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');
	        $db = $table->getAdapter();
	        $db->beginTransaction();

        	try {
           
	            // Create Calendar
	            $viewer = Engine_Api::_()->user()->getViewer();

	            // differniate groups and members
	            $toValues = explode(",",$values['toValues']);
	            $members = array();
	            $groups = array();
	            foreach ($toValues as $data) {
	                if(strpos($data, '0000') !== false) {
	                    $groups[] = substr($data, 0, -4);
	                } else {
	                    $members[] = substr($data, 0, -4);
	                }
	            }
	            $non_members = explode(',', $values['non_members']);

	            foreach ($non_members as $key => $value) {
	            	if(empty($value))
	            		continue;
	                Engine_Api::_()->getApi('mail', 'core')->sendSystem($value, 'NOTIFY_NONEXISTING_USER', array(
	                    'member_name' => $viewer->displayname,
	                    'calendar_name' =>$values['title'],
	                ));
	            }
				
	            $resources = array_unique (array_merge ($members, $non_members));

	            $values = array_merge($values, array(
	                'owner_id' => $viewer->getIdentity()
	            ));

	            $calendar = $table->createRow();
	            $calendar->setFromArray($values);
	            $calendar->save();
	            $row = $memberTable->createRow();
	            $row->calendar_id = $calendar->calendar_id;
	            $row->user_email = $viewer->email;
	            $row->user_id = $viewer->getIdentity();
	            $row->save();

	            // save owner
	            $ownerRow = $ownerTable->createRow();
	            $ownerRow->calendar_id = $calendar->calendar_id;
	            $ownerRow->user_id = $viewer->getIdentity();
	            $ownerRow->custom = 0;
	            $ownerRow->save();

	            // Add members
	            foreach ($resources as $resource) {
	                $user = Engine_Api::_()->getItem('user', $resource);
	                $row = $memberTable->createRow();
	                $row->calendar_id = $calendar->calendar_id;
	                 if(!empty($user->email)) {
	                    $row->user_email = $user->email;
	                    $row->user_id = $user->user_id;
	                    $row->save();
	                    Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_member_add');
	                } else if(!empty($resource)) {
	                    $row->user_email = $resource;
	                    $row->save();
	                }
	            }

	            //Add groups
	            foreach ($groups as $group) {
	                Engine_Api::_()->getDbtable('calendars', 'calendar')->addGroup($group, $calendar);
	            }
	            // Commit
	            $db->commit();
	        } catch( Exception $e ) {
	        	$db->rollBack();
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
	        }

	        $this->setRequestMethod();
            $this->_forward('view', 'index', 'calendar', array(
                'calendar_id' => $calendar->getIdentity(),
            ));
	    }

    }

    public function editAction()
    {
        if( !$this->_helper->requireUser()->isValid() )
        	$this->respondWithError("unauthorized");

        $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
        if( !Engine_Api::_()->core()->hasSubject('calendar') ) {
            Engine_Api::_()->core()->setSubject($calendar);
        }

        if( !$this->_helper->requireAuth()->setAuthParams($calendar, $calendar->getOwner(), 'edit')->isValid() || !Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($calendar->getIdentity()) ) {
        	$this->respondWithError("unauthorized");
        }

        // Prepare form
        if ($this->getRequest()->isGet()) {
            $form['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getCalendarForm();
            $form['formValues'] = $calendar->toArray();
            $members = Engine_Api::_()->getDbtable('members', 'calendar')->getCalendarMembers($calendar);
            $form['formValues']['members'] = $members['exist'];

            $form['formValues']['non_members'] = implode(',', $members['users']);
            $this->respondWithSuccess($form);
        }

        
        // Check post/form
	        if($this->getRequest()->isPost()) {
	        // Process
	        $db = Engine_Db_Table::getDefaultAdapter();
	        $db->beginTransaction();
	        $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');

	        try {
	            // Edit Calendar
	            $viewer = Engine_Api::_()->user()->getViewer();

	            $values = array();
	            $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getCalendarForm();
	            foreach ($getForm as $element) {
	                if (isset($_REQUEST[$element['name']]))
	                    $values[$element['name']] = $_REQUEST[$element['name']];
	            }
	            $formValues = $values;
	            
	            $calendarTable = Engine_Api::_()->getItemTable('calendar');
	            if($calendar->custom == 1) {
	                $calendars = $calendarTable->fetchAll($calendarTable->select()->where('title LIKE ?',$formValues['title']));
	                foreach($calendars as $value){
	                    if($value->calendar_id != $this->_getParam('calendar_id')){
	                      	$validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
	                    	$validationMessage['title'] = $this->translate('This title is already taken, please try another');
	                    }
	                }
	            }
	            if (!empty($validationMessage) && @is_array($validationMessage)) {
	                $this->respondWithValidationError('validation_fail', $validationMessage);
	            }
	            // differniate groups and members
	            $toValues = explode(",",$_REQUEST['toValues']);
	            $members = array();
	            $groups = array();
	            foreach ($toValues as $data) {
	                if(strpos($data, '0000') !== false) {
	                    $groups[] = substr($data, 0, -4);
	                } else {
	                    $members[] = substr($data, 0, -4);
	                }
	            }

	            $non_members = explode(',', $formValues['non_members']);
	            $resources = array_unique (array_merge ($members, $non_members));

	            $values = array_merge($formValues, array(
	                'owner_id' => $viewer->getIdentity()
	            ));
	            $values['background_color'] = $_REQUEST['background_color'];
	            
	            $calendar->modified_date = date('Y-m-d H:i:s');
	            $calendar->setFromArray($values);
	            $calendar->save();

	            foreach ($resources as $resource) {
	                $select = $memberTable->select()
	                                    ->where('calendar_id = ?', $calendar->calendar_id)
	                                    ->where('user_id = ?', $resource);

	                $data = $memberTable->fetchRow($select);

	                if(empty($data->member_id)) {
	                    $user = Engine_Api::_()->getItem('user', $resource);
	                    $row = $memberTable->createRow();
	                    $row->calendar_id = $calendar->calendar_id;
	                     if(!empty($user->email)) {
	                        $row->user_email = $user->email;
	                        $row->user_id = $user->user_id;
	                        $row->custom = 0;
	                        $row->save();
	                        Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_member_add');
	                    } else if(!empty($resource)) {
	                        $row->user_email = $resource;
	                        $row->custom = 1;
	                        $row->save();
	                    }
	                }
	            }
	            //Add groups
	            foreach ($groups as $group) {
	                $select = $memberTable->select()
	                                    ->where('calendar_id = ?', $calendar->calendar_id)
	                                    ->where('group_id = ?', $group);

	                $data = $memberTable->fetchRow($select);
	                if(empty($data->member_id)) {
	                    Engine_Api::_()->getDbtable('calendars', 'calendar')->addGroup($group, $calendar);
	                }
	            }

	            $removeMembers = explode(",",$formValues['remove_member']);
	            foreach ($removeMembers as $removeMember) {
	                if(!empty($removeMember)) {
	                    if(strpos($removeMember, '_group') !== false) {
	                        $memberTable->deleteCalendarMembers($calendar->calendar_id, $removeMember);
	                    } else {
	                        $user = Engine_Api::_()->getItem('user', $removeMember);
	                        $memberTable->deleteCalendarMembers($calendar->calendar_id, $user->email, true);
	                    }
	                }
	            }
	            $db->commit();
	            $this->successResponseNoContent('no_content', true);
	        }
	        catch( Exception $e ) {
	            $db->rollBack();
            	$this->respondWithValidationError('internal_server_error', $e->getMessage());
	        }
	    }
    }

    public function viewAction()
    {
    	if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
           	$this->respondWithError('unauthorized');
        }

        // Check permission
        $viewer = Engine_Api::_()->user()->getViewer();

        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));


        if( $calendar ) {
            Engine_Api::_()->core()->setSubject($calendar);
        }

        if( !$this->_helper->requireSubject()->isValid() ) {
            $this->respondWithError("unauthorized");
        }
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', $viewer, 'view')->isValid()) 
        {
            $this->respondWithError("unauthorized");
        }
        if( !$calendar) {
            $this->respondWithError("unauthorized");
        }

        $canCreate = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->checkRequire();
        $canEdit = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'edit')->checkRequire();
        $canDelete = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'delete')->checkRequire();

        // Prepare data
        $calendarTable = Engine_Api::_()->getDbtable('calendars', 'calendar');

        $calendarArr = $calendar->toArray();
        $owner = $calendar->getOwner();
        $calendarOwnerArr = $calendar->getOwner()->toArray();
        
        $claim = Engine_Api::_()->getDbtable('claims', 'calendar')->isClaimed($this->_getParam('calendar_id'));
        
        if ($viewer->getIdentity() != $calendar->owner_id) {
	        if ((!$claim && $calendar->isClaimable()))
	        	$calendarArr['status'] = "";
	        else
	        	$calendarArr['status'] = $claim->status;
		}


        // Get all Members
        $members = Engine_Api::_()->getDbtable('members', 'calendar')->getMembers($this->_getParam('calendar_id'));

        // Get all Owners
        $owners = Engine_Api::_()->getDbtable('owners', 'calendar')->getOwners($this->_getParam('calendar_id'));

        // check if viewer is owner
        $isCalendarowner = Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($this->_getParam('calendar_id'));

        //check if it has schedules
        $hasSchedules = false;
        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar->getIdentity());

        if(!empty($schedules))
            $hasSchedules = true;

        $tempMenu = array();

        $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
      	$baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
      	$baseParentUrl = @trim($baseParentUrl, "/");
      	$getHost = $getParentHost. DIRECTORY_SEPARATOR. $baseParentUrl;

        if ($calendar->isOwner($viewer) || $isCalendarowner) {
	        
        	$tempMenu[] = array(
                'label' => $this->translate('Add Owner'),
                'name' => 'add-owners',
                'url' => 'calendar/add-owners/' . $calendar->getIdentity(),
        	);

        	if (!empty(Engine_Api::_()->getDbtable('permissions', 'authorization')->getAllowed('calendar', $viewer->level_id, 'edit')))
	        	$tempMenu[] = array(
	                'label' => $this->translate('Edit'),
	                'name' => 'edit',
	                'url' => 'calendar/edit/' . $calendar->getIdentity(),
	            );
	       

            if($calendar->custom != 0 && $calendar->isOwner($viewer)){
            	if(!empty(Engine_Api::_()->getDbtable('permissions', 'authorization')->getAllowed('calendar', $viewer->level_id, 'delete')))
	                $tempMenu[] = array(
	                    'name' => 'delete',
	                    'label' => $this->translate('Delete'),
	                    'url' => 'calendar/delete/' . $calendar->getIdentity()
	                );

                $tempMenu[] = array(
	                'label' => $this->translate('Claimed Requests'),
	                'name' => 'claim_request',
	                'url' => 'calendar/claimed-requests/' . $calendar->getIdentity(),
	        	);
            }

            $tempMenu[] = array(
                'name' => 'view-schedule',
                'label' => $this->translate('View Schedules'),
                'url' => 'calendars/browse-schedules-date',
            );

            $tempMenu[] = array(
                'name' => 'import-schedule',
                'label' => $this->translate('Import Schedules'),
                'url' => $getHost . 'schedules/import-schedules/' . $calendar->getIdentity()
            );

            if(!empty($hasSchedules))
            	$tempMenu[] = array(
                    'name' => 'export',
                    'label' => $this->translate('Export'),
                    'url' => $getHost . 'calendars/ical/' . $calendar->getIdentity()
                );

            $tempMenu[] = array(
                'label' => $this->translate('Get Owners List'),
                'name' => 'get-owners',
                'url' => 'calendar/get-owners/' . $calendar->getIdentity(),
        	);      
        }
        elseif((!$claim) && $calendar->isClaimable()){
        	if(!empty($hasSchedules))
            	$tempMenu[] = array(
                    'name' => 'export',
                    'label' => $this->translate('Export'),
                    'url' => $getHost . 'calendars/ical/' . $calendar->getIdentity()
                ); 
        }

        if( count($members) > 0 ){

        	$userTable = Engine_Api::_()->getDbtable('users', 'user');
        	foreach( $members as $item ){
        		$userArr = array();
        		if(!empty($item->user_email)){
        			$select = $userTable->select()
                              ->where('email = ? ', $item->user_email);
         			$user = $userTable->fetchRow($select);
         			if(!empty($user->email)){
         				$getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
         				$userArr = $user->toArray();
         				$userArr = $this->_sanitizeArray($userArr);
            			$userArr['image_icon'] = $getContentImages['image_icon'];
         			}
         			else{
         				$userArr = $item->toArray();
         				$userArr['user_email'] = $item->user_email;
         				$userArr['image_icon'] = $getHost . '/application/modules/User/externals/images/nophoto_user_thumb_icon.png';
         			}
        		}
        		elseif(!empty($item->group_id)){
        			$group = Engine_Api::_()->getItem('calendar_group', $item->group_id);
        			$getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($group);
        			$userArr = $item->toArray();
        			$userArr['group_title'] = $group->title;
            		$userArr['image_icon'] = $getContentImages['image_icon'];
        		}
        		$usersArr[] = $userArr;
        	}
        }

        

    	if(!empty($calendarArr)){
            $response['calendar'] = $calendarArr;
            $response['owner'] = $this->_sanitizeArray($calendarOwnerArr);
            $response['menu'] = $tempMenu;
            $response['members'] = $usersArr;
        }
        else
            $response['calendar'] = "";
        
        $this->respondWithSuccess($response);
    }

    public function getOwnersAction()
    {
    	// Check permission
        $viewer = Engine_Api::_()->user()->getViewer();

        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));


        if( $calendar ) {
            Engine_Api::_()->core()->setSubject($calendar);
        }

        // check if viewer is owner
        $isCalendarowner = Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($this->_getParam('calendar_id'));

        if( !$this->_helper->requireSubject()->isValid() ) {
            $this->respondWithError("unauthorized");
        }
        if( !$this->_helper->requireAuth()->setAuthParams('calendar', $viewer, 'view')->isValid()) 
        {
            $this->respondWithError("unauthorized");
        }
        if( !$calendar) {
            $this->respondWithError("unauthorized");
        }

        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);
        $response = array();
        $owner = $calendar->getOwner();

        if(Engine_Api::_()->getDbtable('owners', 'calendar')->getOwners($this->_getParam('calendar_id')) != null){
	        // Get all Owners
	        $owners = Zend_Paginator::factory(Engine_Api::_()->getDbtable('owners', 'calendar')->getOwners($this->_getParam('calendar_id')));
	        $owners->setItemCountPerPage($values['limit']);
	        $owners->setCurrentPageNumber($values['page']);
	        $response['totalItemCount'] = $owners->getTotalItemCount();

        }
	    else
	    	$response['totalItemCount'] = 0;

        $ownersArr = array();
    	if( count($owners) > 0 ){
    		foreach( $owners as $calendarOwner ){
    			$ownerArr = array();
    			$user = Engine_Api::_()->getItem('user', $calendarOwner->user_id);

    			$ownerArr = $user->toArray();
         		$ownerArr = $this->_sanitizeArray($ownerArr);
    			$getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
        		$ownerArr = array_merge($ownerArr, $getContentImages);

        		if(($user->getIdentity() != $owner->getIdentity()) && $isCalendarowner){
        			$ownerArr['canBeRemoved'] = 1;
        		}

        		$ownersArr[] = $ownerArr;
    		}    		
    	}

    	if(!empty($ownersArr))
    		$response['owner'] = $ownersArr;	
        else
            $response['owner'] = "";
        
        $this->respondWithSuccess($response);

    }
    private function _sanitizeArray($dataArray = array(), $ignoreParams = array()) {
        $restrictedFields = array('email', 'password', 'salt', 'creation_ip', 'lastlogin_ip');
        foreach ($restrictedFields as $restrictedValue) {
            if (!in_array($restrictedValue, $ignoreParams) && in_array($restrictedValue, $dataArray)) {
                unset($dataArray[$restrictedValue]);
            }
        }
        return $dataArray;
    }

    public function claimcalendarsAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        
        // Must be able to view calendar
	    if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
           	$this->respondWithError('unauthorized');
        }

	    // Must be able to claim calendar
	    if( !Engine_Api::_()->authorization()->isAllowed('calendar', $viewer, 'claim') ) {
	      	$this->respondWithError("unauthorized");
	    }

        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);
        $response = array();

        // Get all calendars
        if(Engine_Api::_()->getItemTable('calendar')->getBrowseCalendars() != NULL){
	        $calendars = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getBrowseCalendars());
	        $calendars->setItemCountPerPage($values['limit']);
	        $calendars->setCurrentPageNumber($values['page']);
	        $response['totalItemCount'] = $calendars->getTotalItemCount();
	    }
	    else
	    	$response['totalItemCount'] = 0;

	    $response['allowCreation'] = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->isValid();

        foreach($calendars as $calendar){
            $calendarArr = $calendar->toArray();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($calendar);

            $calendarArr = array_merge($calendarArr, $getContentImages);
            if(!empty($calendar->owner_id))
            	$calendarArr['owner_title'] = $calendar->getOwner()->getTitle();

            $calendarClaim = Engine_Api::_()->getItemTable('calendar_claim');
            $claimSelect = $calendarClaim->select()->where('calendar_id = ?',$calendar->getIdentity())
            										->where('user_id = ?', $viewer->getIdentity());
            $claimStatus = $calendarClaim->fetchRow($claimSelect);

            if($claimStatus)
            	$calendarArr['status'] = $claimStatus->status;
            else
            	$calendarArr['status'] = "";
            $calendarsArr[] = $calendarArr;
        }
        if(!empty($calendarsArr)){
            $response['response'] = $calendarsArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
    }

    public function claimedRequestsAction()
    {	
    	$calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
        $viewer = Engine_Api::_()->user()->getViewer();
        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);

        $table = Engine_Api::_()->getItemTable('calendar_claim');
        $claimRequestSelect = $table->select()->where('calendar_id = ?', $this->_getParam('calendar_id'));
        if($table->fetchAll($claimRequestSelect) != null){
	        $claimObjs = Zend_Paginator::factory($table->fetchAll($claimRequestSelect));
	        $claimObjs->setItemCountPerPage($values['limit']);
	        $claimObjs->setCurrentPageNumber($values['page']);
	        $response['totalItemCount'] = $claimObjs->getTotalItemCount();
	    }
	    else
	    	$response['totalItemCount'] = 0;

        $claimArr = array();
        foreach($claimObjs as $claimObj){
        	$claimArr = $claimObj->toArray();
        	$user = Engine_Api::_()->getItem('user', $claimObj->user_id);
        	$claimArr['displayname'] = $user->displayname;
    			$getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
        	$claimArr = array_merge($claimArr, $getContentImages);	

        	$claimArrs[] = $claimArr;
        }

        if(!empty($claimArrs)){
            $response['claim_request'] = $claimArrs;
        }
        else
            $response['claim_request'] = "";

        $this->respondWithSuccess($response);
    }

    public function claimAction() {

        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
        $viewer = Engine_Api::_()->user()->getViewer();

        $table = Engine_Api::_()->getItemTable('calendar_claim');
        $db = $table->getAdapter();
        $db->beginTransaction();

        $claimRequestSelect = $table->select()->where('calendar_id = ?', $this->_getParam('calendar_id'))
        									  ->where('user_id = ?', $viewer->getIdentity());
        $claimObj = $table->fetchRow($claimRequestSelect);
        if($claimObj){
        	$this->respondWithError("unauthorized", 'Claimed Request already sent.');
        }

        try {
            $row = $table->createRow();
            $row->calendar_id = $calendar->getIdentity();
            $row->user_id = $viewer->getIdentity();
            $row->status = 'Pending';
            $row->save();
            Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($calendar->getOwner(), $viewer, $calendar, 'calendar_claim');
            Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($viewer, $viewer, $calendar, 'calendar_claim_request');
            // Commit
            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch( Exception $e ) {
            $db->rollBack();
        	$this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }

	public function calendarListAction() {
		$calendars = Engine_Api::_()->getItemTable('calendar')->getAllCalendars();
		$is_move = $this->_getParam('is_move',0);

    	if(!empty($is_move))
    	{	$calendar_id = $this->_getParam('calendar_id',0);
    		$calendars = Engine_Api::_()->getItemTable('calendar')->getAllCalendars($calendar_id);
    		if(empty($calendars->toArray()))
    			$this->respondWithError('unauthorized', 'Please create other calendars to move schedule.');
    		$response = array();
    	}
    	else{
	    	$res['calendar_id'] = 0;
	    	$res['title'] = 'All Calendars';
	    	$response[] = $res;
	    }
    	foreach ($calendars as $calendar) {
    		$options['calendar_id'] = $calendar->getIdentity();
        	$options['title'] = $calendar->getTitle();
        	$response[] = $options;
    	}

        $this->respondWithSuccess($response);
	}

    public function statusAction() {

        $claim_id = (int) $this->_getParam('claim_id');
        $action = $this->_getParam('claim_action');
        $calendar_id = $this->_getParam('calendar_id');
        $calendar = Engine_Api::_()->getItem('calendar', $calendar_id);
        $user_id = (int) $this->_getParam('user_id');
        $user = Engine_Api::_()->getItem('user', $user_id);
        $viewer = Engine_Api::_()->user()->getViewer();

        if($action == "Rejected") {
            Engine_Api::_()->getItemTable('calendar_claim')->update(array('status' => $action), array('claim_id = ?' => $claim_id));
        }

        if($action == "Accepted") {
            Engine_Api::_()->getItemTable('calendar')->update(array(
                'owner_id' => $user_id,
            ), array(
                'calendar_id = ?' => $calendar_id,
            ));

            Engine_Api::_()->getItemTable('calendar_schedule')->update(array(
                'owner_id' => $user_id,
            ), array(
                'calendar_id = ?' => $calendar_id,
            ));
            // delete all claims
            $claimTable = Engine_Api::_()->getDbtable('claims', 'calendar');
            $claimSelect = $claimTable->select()->where('calendar_id = ?', $calendar_id);
            foreach( $claimTable->fetchAll($claimSelect) as $claim ) {
                $claim->delete();
            }
        }

        Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_claim_status', array('status' => $action));
        $this->successResponseNoContent('no_content', true);
    }

    public function manageAction()
    {	
    	if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
           	$this->respondWithError('unauthorized');
        }

        $viewer = Engine_Api::_()->user()->getViewer();

        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);
        $response = array();

    	// Get all calendars
        if(Engine_Api::_()->getItemTable('calendar')->getAllCalendars(0,1) != null){
	        $calendars = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getAllCalendars(0,1));

	        $calendars->setItemCountPerPage($values['limit']);
	        $calendars->setCurrentPageNumber($values['page']);
	        $response['totalItemCount'] = $calendars->getTotalItemCount();
	    }
	    else
	    	$response['totalItemCount'] = 0;

	    $response['allowCreation'] = $this->_helper->requireAuth()->setAuthParams('calendar', null, 'create')->isValid();

        foreach($calendars as $calendar){
            $calendarArr = $calendar->toArray();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($calendar);
            $calendarArr = array_merge($calendarArr, $getContentImages);
            $calendarArr['owner_title'] = $calendar->getOwner()->getTitle();

            $tempMenu = array();
             
            $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
	      	$baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
	      	$baseParentUrl = @trim($baseParentUrl, "/");
	      	$getHost = $getParentHost. DIRECTORY_SEPARATOR. $baseParentUrl;

            if ($calendar->isOwner($viewer)) {
                if (!empty(Engine_Api::_()->getDbtable('permissions', 'authorization')->getAllowed('calendar', $viewer->level_id, 'edit')))
	                $tempMenu[] = array(
	                    'label' => $this->translate('Edit'),
	                    'name' => 'edit',
	                    'url' => 'calendar/edit/' . $calendar->getIdentity(),
	                );

                if($calendar->custom != 0 && !empty(Engine_Api::_()->getDbtable('permissions', 'authorization')->getAllowed('calendar', $viewer->level_id, 'delete')))
	                $tempMenu[] = array(
	                    'name' => 'delete',
	                    'label' => $this->translate('Delete'),
	                    'url' => 'calendar/delete/' . $calendar->getIdentity()
	                );

	            if(!empty(Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar->getIdentity())))
	            	$tempMenu[] = array(
	                    'name' => 'export',
	                    'label' => $this->translate('Export'),
	                    'url' => $getHost . '/calendars/ical/' . $calendar->getIdentity()
	                );
                  
            }
            $calendarArr["menu"] = $tempMenu;

            $calendarsArr[] = $calendarArr;
        }
        if(!empty($calendarsArr)){
            $response['response'] = $calendarsArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
    }

    public function deleteAction()
    {
    	// Validate request methods
        $this->validateRequestMethod('DELETE');
        $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $this->getRequest()->getParam('calendar_id'));
        if( !$this->_helper->requireAuth()->setAuthParams($calendar, null, 'delete')->isValid())
        	$this->respondWithError("unauthorized");

        if( !$calendar ) {
            $this->respondWithError("unauthorized","Calendar doesn't exist or not authorized to delete");
        }

        $db = $calendar->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            // delete all members
            $memberTable = Engine_Api::_()->getDbtable('members', 'calendar');
            $memberSelect = $memberTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $memberTable->fetchAll($memberSelect) as $member ) {
                $member->delete();
            }
            // Delete schedules
            $scheduleTable = Engine_Api::_()->getDbtable('schedules', 'calendar');
            $scheduleSelect = $scheduleTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $scheduleTable->fetchAll($scheduleSelect) as $schedule ) {
                $schedule->delete();
            }
            // delete all claims
            $claimTable = Engine_Api::_()->getDbtable('claims', 'calendar');
            $claimSelect = $claimTable->select()->where('calendar_id = ?', $calendar->calendar_id);
            foreach( $claimTable->fetchAll($claimSelect) as $claim ) {
                $claim->delete();
            }

            $calendar->delete();

            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch( Exception $e ) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }

    public function browseSchedulesAction() {
        // Get all schedules
        $values['isDateEvent'] = $this->_getParam('isDateEvent', 1);
        $values['date'] = $this->_getParam('date');

        $param = array(
        	'isDateEvent' => $values['isDateEvent'],
        	'date' => $values['date']
        );
        $viewer = Engine_Api::_()->user()->getViewer();

        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getBrowseSchedules($this->_getParam('calendar_id', 0),$param);

        foreach($schedules as $schedule){
	    	$start = date("Y-m-d",strtotime($schedule['start']));
        	$end = date("Y-m-d",strtotime($schedule['end']));
        	$time = new DateTime($values['date'].'00:00:00');
        	$compare = $time->format('Y-m-d H:i:s');
        	if($start <= $values['date'] && $end >= $values['date'] && $schedule['end'] != $compare ) {
            	$scheduleArr = $schedule;
        	} else {
        		continue;
        	}

            $tempMenu = array();
            if (!empty($scheduleArr['isOwner'])) {
                $tempMenu[] = array(
                    'label' => $this->translate('Edit'),
                    'name' => 'edit',
                    'url' => 'schedule/edit/' . $schedule['id'],
                );
                
                $tempMenu[] = array(
                    'name' => 'delete',
                    'label' => $this->translate('Delete'),
                    'url' => 'schedule/delete/' . $schedule['id'],
                );

            	$tempMenu[] = array(
                    'name' => 'move',
                    'label' => $this->translate('Move'),
                    'url' => 'schedule/move/' . $schedule['id'],
                    'urlParams' => array(
               			'calendar_id' => $schedule['calendar_id'],
                	),
                );
                  
            }
            $scheduleArr["menu"] = $tempMenu;
            if (empty($scheduleArr['body']))
            	$scheduleArr['body'] = '';
            $schedulesArr[] = $scheduleArr;
        }
        if(!empty($schedulesArr)){
            $response['response'] = $schedulesArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
    }

    public function browseSchedulesDateAction() {    		
    	
        // Get all schedules
        $values['isDateEvent'] = $this->_getParam('isDateEvent', 0);
        $values['date'] = $this->_getParam('date');

        $param = array( 
        	'isDateEvent' => $values['isDateEvent'],
        	'date' => $values['date']
        );

        // fetch all start dates
        $select = Engine_Api::_()->getDbtable('schedules', 'calendar')->getBrowseScheduless($this->_getParam('calendar_id', 0),array_merge($param, array('start_time' => 1)));
        $start_dates = array();
        if( $select != null)
        	$start_dates = array_column($select->query()->fetchAll(), 'DATE(start_datetime)');


        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getBrowseScheduless($this->_getParam('calendar_id', 0),array_merge($param, array('start' => 1)));

        // Fetch all dates
        foreach ($schedules as $schedule) {
        	$start = date("Y-m-d", strtotime($schedule['start']));
        	if (!in_array($start, $start_dates))
        		$start_dates[] = $start;
        	$count = $schedule['time_diff'];
	        if ($count > 0) {
	        	for ($i=1; $i <= $count; $i++) {
	        		$date = date("Y-m-d", strtotime("$i day", strtotime($schedule['start'])));
	        		if (!in_array($date, $start_dates))
    					$start_dates[] = $date;
	        	}
	        }
        }
        
        foreach ($start_dates as $start_date) {
        	if (date("m", strtotime($values['date'])) != date("m", strtotime($start_date)))
        		continue;
        	$k = 0;
	        foreach ($schedules as $schedule) {
	        	$start = date("Y-m-d",strtotime($schedule['start']));
	        	$end = date("Y-m-d",strtotime($schedule['end']));
	        	$time = new DateTime($start_date.'00:00:00');
	        	$compare = $time->format('Y-m-d H:i:s');
	        	if($start <= $start_date && $end >= $start_date && $schedule['end'] != $compare ) {
	        		$k ++;
	        	}
	        }
	        if ($k > 0) {
		        $response['count'] = $k;
		        $response['start_date'] = $start_date;
		        $final_array[] = $response;
		    }
        }

        $response1['response'] = $final_array;

        $this->respondWithSuccess($response1);
        
    }

    public function owncalendarsAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();

        if( !$this->_helper->requireAuth()->setAuthParams('calendar', null, 'view')->isValid()) {
           	$this->respondWithError('unauthorized');
        }

        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);
        $response = array();

        // Get all calendars
        if(Engine_Api::_()->getItemTable('calendar')->getOwnCalendars() != null){
	        $calendars = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getOwnCalendars());

	        $calendars->setItemCountPerPage($values['limit']);
	        $calendars->setCurrentPageNumber($values['page']);
	        $response['totalItemCount'] = $calendars->getTotalItemCount();
	    }
	    else
	    	$response['totalItemCount'] = 0;
	    
        foreach($calendars as $calendar){
            $calendarArr = $calendar->toArray();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($calendar);
            $calendarArr = array_merge($calendarArr, $getContentImages);
            $calendarArr['owner_title'] = $calendar->getOwner()->getTitle();

            $tempMenu = array();
            if ($calendar->isOwner($viewer)) {
                $tempMenu[] = array(
                    'label' => $this->translate('Edit'),
                    'name' => 'edit',
                    'url' => 'calendar/edit/' . $calendar->getIdentity(),
                );

                if($calendar->custom != 0)
	                $tempMenu[] = array(
	                    'name' => 'delete',
	                    'label' => $this->translate('Delete'),
	                    'url' => 'calendar/delete/' . $calendar->getIdentity()
	                );

	            if(!empty(Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar->getIdentity())))
	            	$tempMenu[] = array(
	                    'name' => 'export',
	                    'label' => $this->translate('Export'),
	                    'url' => 'calendars/ical/' . $calendar->getIdentity()
	                );
                  
            }
            $calendarArr["menu"] = $tempMenu;

            $calendarsArr[] = $calendarArr;
        }
        if(!empty($calendarsArr)){
            $response['response'] = $calendarsArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
    }

    public function removeOwnerAction() {
        $calendar_id = $this->getRequest()->getParam('calendar_id');
        $user_id = $this->getRequest()->getParam('user_id');
        $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $calendar_id);

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');

        try {
            $ownerTable->delete(array('calendar_id = ?'=> $calendar_id, 'user_id = ?' => $user_id));
            Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications(Engine_Api::_()->getItem('user', $user_id), $calendar->getOwner(), $calendar, 'calendar_owner_remove');
            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch( Exception $e ) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }

    public function addOwnersAction() {
        if( !$this->_helper->requireUser()->isValid() )
        	$this->respondWithError("unauthorized");

        $viewer = Engine_Api::_()->user()->getViewer();
        $calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));

        if( !$calendar ) {
            $this->respondWithError("unauthorized","Calendar doesn't exist");
        }

        if( $this->getRequest()->isPost() ) {
           
	        $db = $calendar->getTable()->getAdapter();
	        $db->beginTransaction();
	        $ownerTable = Engine_Api::_()->getDbtable('owners', 'calendar');

	        try {

	            $members = explode(",",$_REQUEST['toValues']);
	            
	            foreach ($members as $resource) {
	                $user = Engine_Api::_()->getItem('user', $resource);
	                $row = $ownerTable->createRow();
	                $row->calendar_id = $calendar->getIdentity();
	                $row->user_id = $user->getIdentity();
	                $row->save();
	                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $calendar, 'calendar_owner_add');
	            }
	            $db->commit();
	            $this->successResponseNoContent('no_content', true);
	        } catch( Exception $e ) {
	            $db->rollBack();
            	$this->respondWithValidationError('internal_server_error', $e->getMessage());
	        }
	    }
    }
}