<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_ScheduleController extends Siteapi_Controller_Action_Standard
{
	public function viewAction() {
		$this->view->calendar_id = $this->_getParam('calendar_id');
		$this->view->calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
		// Render
		$this->_helper->content
			->setEnabled();

	}

	public function createAction() {

		$viewer = Engine_Api::_()->user()->getViewer();

		if(empty(Engine_Api::_()->getItemTable('calendar')->getCalendarsCount()))
			$this->respondWithError("unauthorized", 'You have not created any calendar, Please create a calendar for creating schedules.');

		// Prepare form
	    if ($this->getRequest()->isGet()) {
            $form['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getScheduleForm();
            $this->respondWithSuccess($form);
        }

	    // If not post or form not valid, return
	    if( $this->getRequest()->isPost() ) {
	   
		    // Process
		    $table = Engine_Api::_()->getDbtable('schedules', 'calendar');
		    $location = Engine_Api::_()->getItemTable('calendar_schedulelocation');
		    $db = $table->getAdapter();
		    $db->beginTransaction();

		    try {
		        // Create Calendar
		        $viewer = Engine_Api::_()->user()->getViewer();
		        $values = array();
		        $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getScheduleForm();
                foreach ($getForm as $element) {
                    if (isset($_REQUEST[$element['name']]))
                        $values[$element['name']] = $_REQUEST[$element['name']];
                }
                $formValues = $values;
		        // START FORM VALIDATION
	            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'calendar')->getScheduleFormValidator();
	            $formValues['validators'] = $validators;
	            $validationMessage = $this->isValid($formValues);
	            
		        if($formValues['start_datetime'] == $formValues['end_datetime']) {
		        	$validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
                    $validationMessage['end_datetime'] = $this->translate('Start and End Time must not be same.');
		        }

		        if (!empty($validationMessage) && @is_array($validationMessage)) {
	                $this->respondWithValidationError('validation_fail', $validationMessage);
	            }
		        $dt = date('Y-m-d H:i:s', strtotime($formValues['start_datetime']));
	            $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
	            $date->setTimezone(new DateTimeZone('UTC'));
	            $formValues['start_datetime'] = $date->format('Y-m-d H:i:s');

	            $dt = date('Y-m-d H:i:s', strtotime($formValues['end_datetime']));
	            $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
	            $date->setTimezone(new DateTimeZone('UTC'));
	            $formValues['end_datetime'] = $date->format('Y-m-d H:i:s');

		        $values = array_merge($formValues, array(
		            'owner_id' => $viewer->getIdentity(),
		            'search' => 0
		        ));
		        $Schedule = $table->createRow();
		        $Schedule->setFromArray($values);
		        $Schedule->save();

		        // save location
		        $location = $location->createRow();
		        $locationValues = $_REQUEST['locationParams'];
		        $locationValues = json_decode($locationValues, true);
		        $locationValues['schedule_id'] = $Schedule->getIdentity();

		        $location->setFromArray($locationValues);
		        $location->save();
		        // Commit
		        $db->commit();
		        $this->successResponseNoContent('no_content', true);
		    } catch( Exception $e ) {
		        $db->rollBack();
            	$this->respondWithValidationError('internal_server_error', $e->getMessage());
		    }
		}
	}

	public function manageAction() {
		$calendar_id = $this->_getParam('calendar_id');
		$calendar = Engine_Api::_()->getItem('calendar', $calendar_id);

		$schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar_id);

		echo json_encode($schedules);
		exit;
	}

	public function getSchedulesAction() {
		$viewer = Engine_Api::_()->user()->getViewer();

		$values['isDateEvent'] = $this->_getParam('isDateEvent', 0);
        $values['date'] = $this->_getParam('date');

        $param = array( 'isDateEvent' => $values['isDateEvent'],
        				'date' => $values['date']
        		);

		$schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getUserSchedules($viewer->getIdentity(),$param);

        $scheduleArr = array();
        foreach($schedules as $schedule){
            $start = date("Y-m-d",strtotime($schedule['start']));
        	$end = date("Y-m-d",strtotime($schedule['end']));
        	$time = new DateTime($values['date'].'00:00:00');
        	$compare = $time->format('Y-m-d H:i:s');
        	if($start <= $values['date'] && $end >= $values['date'] && $schedule['end'] != $compare ) {
            	$scheduleArr = $schedule;
        	} else {
        		continue;
        	}

            $tempMenu = array();
            
            $tempMenu[] = array(
                'label' => $this->translate('Edit'),
                'name' => 'edit',
                'url' => 'schedule/edit/' . $schedule['id'],
            );
            
            $tempMenu[] = array(
                'name' => 'delete',
                'label' => $this->translate('Delete'),
                'url' => 'schedule/delete/' . $schedule['id'],
            );

        	$tempMenu[] = array(
                'name' => 'move',
                'label' => $this->translate('Move'),
                'url' => 'schedule/move/' . $schedule['id'],
                'urlParams' => array(
                				'calendar_id' => $schedule['calendar_id'],
                			),
            );
             
            $scheduleArr["menu"] = $tempMenu;
            if (empty($scheduleArr['body']))
            	$scheduleArr['body'] = '';
            $schedulesArr[] = $scheduleArr;
        }
        if(!empty($schedulesArr)){
            $response['response'] = $schedulesArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
	}

	public function getSchedulesDateAction() {  		
    	$viewer = Engine_Api::_()->user()->getViewer();
        // Get all schedules
        $values['isDateEvent'] = $this->_getParam('isDateEvent', 0);
        $values['date'] = $this->_getParam('date');

        $param = array( 'isDateEvent' => $values['isDateEvent'],
        				'date' => $values['date']
        		);

        // fetch all start dates
        $start_dates = array();
        $select = Engine_Api::_()->getDbtable('schedules', 'calendar')->getUserScheduless($viewer->getIdentity(),array_merge($param, array('start_time' => 1)));
        if($select != null)
        	$start_dates = array_column($select->query()->fetchAll(), 'DATE(start_datetime)');


        $schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getUserScheduless($viewer->getIdentity(),array_merge($param, array('start' => 1)));

        // Fetch all dates
        foreach ($schedules as $schedule) {
        	$count = $schedule['time_diff'];
	        if ($count > 1) {
	        	for ($i=1; $i <= $count; $i++) {
	        		$date = date("Y-m-d", strtotime("$i day", strtotime($schedule['start'])));
	        		if (!in_array($date, $start_dates))
    					$start_dates[] = $date;
	        	}
	        }
	        else{
	        	$dt = date('Y-m-d', strtotime($schedule['start']));
	            $date = new DateTime($dt, new DateTimeZone('UTC'));
	            $date->setTimezone(new DateTimeZone($viewer->timezone));
	            $start_datetime = $date->format('Y-m-d');
	            if (!in_array($start_datetime, $start_dates))
    				$start_dates[] = $start_datetime;
	        }
        }
        
        foreach ($start_dates as $start_date) {
        	if (date("m", strtotime($values['date'])) != date("m", strtotime($start_date)))
        		continue;
        	$k = 0;
	        foreach ($schedules as $schedule) {
	        	$start = date("Y-m-d",strtotime($schedule['start']));
	        	$end = date("Y-m-d",strtotime($schedule['end']));
	        	$time = new DateTime($start_date.'00:00:00');
	        	$compare = $time->format('Y-m-d H:i:s');
	        	if($start <= $start_date && $end >= $start_date && $schedule['end'] != $compare ) {
	        		$k ++;
	        	}
	        }
	        if ($k > 0) {
		        $response['count'] = $k;
		        $response['start_date'] = $start_date;
		        $final_array[] = $response;
		    }
        }

        $response1['response'] = $final_array;

        $this->respondWithSuccess($response1);
        
    }

	public function updateAction() {
		$schedule_id = $this->_getParam('schedule_id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		// Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $schedule->setFromArray($_REQUEST);
            $schedule->modified_date = date('Y-m-d H:i:s');
            $schedule->save();

            $db->commit();
            $this->successResponseNoContent('no_content', true);
        }
        catch( Exception $e ) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }		
	}

	public function editAction() {
		try{
		$schedule_id = $this->_getParam('schedule_id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		$viewer = Engine_Api::_()->user()->getViewer();
		
		if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($schedule->calendar_id)) {
			$this->respondWithError("unauthorized");
		}
        
        // Prepare form
	    if ($this->getRequest()->isGet()) {
            $form['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getScheduleForm();
            
            $dt = date('Y-m-d H:i:s', strtotime($schedule->start_datetime));
	        $date = new DateTime($dt, new DateTimeZone('UTC'));
	        $date->setTimezone(new DateTimeZone($viewer->timezone));
	        $schedule->start_datetime = $date->format('Y-m-d H:i:s');

	        $dt = date('Y-m-d H:i:s', strtotime($schedule->end_datetime));
	        $date = new DateTime($dt, new DateTimeZone('UTC'));
	        $date->setTimezone(new DateTimeZone($viewer->timezone));
	        $schedule->end_datetime = $date->format('Y-m-d H:i:s');

	        $form['formValues'] = $schedule->toArray();

            $this->respondWithSuccess($form);
        }

        // Check post/form
        if( $this->getRequest()->isPost() ) {
	        // Process
			$locationTable = Engine_Api::_()->getDbtable('schedulelocations','calendar');
			$location = $locationTable->fetchRow('schedule_id = '.$this->_getParam('schedule_id'));
			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();

	        try {

	        	$getForm = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getScheduleForm();
	            foreach ($getForm as $element) {
	                if (isset($_REQUEST[$element['name']]))
	                    $values[$element['name']] = $_REQUEST[$element['name']];
	            }

	            $formValues = $values;

	           // START FORM VALIDATION
	            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'calendar')->getScheduleFormValidator();
	            $formValues['validators'] = $validators;
	            $validationMessage = $this->isValid($formValues);

	            if($values['start_datetime'] == $values['end_datetime']) {
		        	$validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
	                $validationMessage['end_datetime'] = $this->translate('Start and End Time must not be same.');
		        }

		        if (!empty($validationMessage) && @is_array($validationMessage)) {
	                $this->respondWithValidationError('validation_fail', $validationMessage);
	            }
	            
		        $dt = date('Y-m-d H:i:s', strtotime($values['start_datetime']));
	            $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
	            $date->setTimezone(new DateTimeZone('UTC'));
	            $values['start_datetime'] = $date->format('Y-m-d H:i:s');

	            $dt = date('Y-m-d H:i:s', strtotime($values['end_datetime']));
	            $date = new DateTime($dt, new DateTimeZone($viewer->timezone));
	            $date->setTimezone(new DateTimeZone('UTC'));
	            $values['end_datetime'] = $date->format('Y-m-d H:i:s');

	            $schedule->setFromArray($values);
	            $schedule->modified_date = date('Y-m-d H:i:s');
	            $schedule->save();


	            if($values['location_region'] ){
		        	$locationValues = $values['locationParams'];
		        	$locationValues = json_decode($locationValues, true);
					if(empty($location)) {
						$location = $locationTable->createRow();
					}

		        	$location->setFromArray($locationValues);
		        	$location->save();
		     	}

	            $db->commit();
	            $this->successResponseNoContent('no_content', true);
	        }
	        catch( Exception $e ) {
	            $db->rollBack();
            	$this->respondWithValidationError('internal_server_error', $e->getMessage());
	        }
	    }
	}
	catch(Exception $e){
		echo $e;
		die;
	}
      
	}

	public function deleteAction()
    {
    	$this->validateRequestMethod('DELETE');
        
        $schedule_id = $this->_getParam('schedule_id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		$viewer = Engine_Api::_()->user()->getViewer();

		if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($schedule->calendar_id)) {
			$this->respondWithError("unauthorized");
		}

        $db = $schedule->getTable()->getAdapter();
        $db->beginTransaction();
        $status = true;
        $error = '';
        try {
            $schedule->delete();
            $status = true;
            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch( Exception $e ) {
        	$db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }

    public function importSchedulesAction() {
		$viewer = Engine_Api::_()->user()->getViewer();

		$calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
		// In smoothbox
        $this->_helper->layout->setLayout('default-simple');
		// Prepare form
	    $this->view->form = $form = new Calendar_Form_Schedule_Import();

	    // If not post or form not valid, return
	    if( !$this->getRequest()->isPost() ) {
	        return;
	    }

	    if( !$form->isValid($this->getRequest()->getPost()) ) {
	        return;
	    }

	    $icalString = file_get_contents($_FILES['filename']['tmp_name']);
	    $icsEvents = array ();
        /* Explode the ICs Data to get datas as array according to string ‘BEGIN:’ */echo "<pre>";
        $icsData = explode ( "BEGIN:", $icalString );
        /* Iterating the icsData value to make all the start end dates as sub array */
        foreach ( $icsData as $key => $value ) {
            $icsDatesMeta [$key] = explode ( "\n", $value );
        }
        /* Itearting the Ics Meta Value */
        foreach ( $icsDatesMeta as $key => $value ) {
            foreach ( $value as $subKey => $subValue ) {
                /* to get ics events in proper order */
                $icsEvents = $this->getICSDates ( $key, $subKey, $subValue, $icsEvents );
            }
        }

	    // Process
	    $table = Engine_Api::_()->getDbtable('schedules', 'calendar');
	    $db = $table->getAdapter();
	    $db->beginTransaction();

	    try {
	        // Create Calendar
	        $viewer = Engine_Api::_()->user()->getViewer();
	        foreach($icsEvents as $event) {
				if(trim($event['BEGIN']) == 'VEVENT') {
					$start = date('Y-m-d H:i:s', strtotime($event['DTSTART']));

					$end = date('Y-m-d H:i:s', strtotime($event['DTEND']));

					$values = array(
			            'calendar_id' => $calendar->getIdentity(),
			            'title' => $event['SUMMARY'],
			            'body' => $event['DESCRIPTION'],
			            'location' => $event['LOCATION'] ? $event['LOCATION'] : '',
			            'start_datetime' => $start,
			            'end_datetime' => $end,
			            'owner_id' => $viewer->getIdentity(),
			            'search' => 0
			        );
			        $Schedule = $table->createRow();
			        $Schedule->setFromArray($values);
			        $Schedule->save();
				}
	        }
	        // Commit
	        $db->commit();
	    } catch( Exception $e ) {
	        return $this->exceptionWrapper($e, $form, $db);
	    }
	    $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 300,
          'parentRefresh' => 300,
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Schedules saved Successfully.'))
      ));
    }

    function getICSDates($key, $subKey, $subValue, $icsDates) {
        if ($key != 0 && $subKey == 0) {
            $icsDates [$key] ["BEGIN"] = $subValue;
        } else {
            $subValueArr = explode ( ":", $subValue, 2 );
			if (isset ( $subValueArr [1] )) {
				if (strpos($subValueArr [0], 'DTSTART') !== false) {
				    $icsDates [$key] ['DTSTART'] = $subValueArr [1];
				} else if (strpos($subValueArr [0], 'DTEND') !== false) {
				    $icsDates [$key] ['DTEND'] = $subValueArr [1];
				} else
					$icsDates [$key] [$subValueArr [0]] = $subValueArr [1];
            }
        }
        return $icsDates;
	}

	public function moveAction() {
		$schedule_id = $this->_getParam('schedule_id');
		$calendar_id = $this->_getParam('calendar_id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		$viewer = Engine_Api::_()->user()->getViewer();

		if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($schedule->calendar_id)) {
			$this->respondWithError("unauthorized");
		}
       
	    try {
	        // Move Schedule
	        Engine_Api::_()->getItemTable('calendar_schedule')->update(array('calendar_id' => $calendar_id), array('schedule_id = ?' => $schedule_id));

	    } catch( Exception $e ) {
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
	    }
	    $this->successResponseNoContent('no_content', true);	    
	}

	public function suggestAction() {
		// Validate request methods
        $this->validateRequestMethod();
        $viewer = Engine_Api::_()->user()->getViewer();

        if ($viewer->getIdentity()) {
            $data = array();
            $table = Engine_Api::_()->getItemTable('user');
            $tableGroup = Engine_Api::_()->getDbtable('groups', 'calendar');
          
            $select = Engine_Api::_()->getDbtable('users', 'user')->select();
            $select->where('user_id <> ?', $viewer->user_id);

            if (0 < ($limit = (int) $this->getRequestParam('limit', 10))) {
                $select->limit($limit);
            }

            if (null !== ($text = $this->getRequestParam('to'))) {
                $select->where('`' . $table->info('name') . '`.`displayname` LIKE ?', '%' . $text . '%');
                $tableGroupSelect = $tableGroup->select()->where('`' . $tableGroup->info('name') . '`.`title` LIKE ?', '%' . $text . '%');
            }
            $select->where('`' . $table->info('name') . '`.`user_id` <> ?', $viewer->getIdentity());
            $select->order("{$table->info('name')}.displayname ASC");

            $ids = array();
            foreach ($select->getTable()->fetchAll($select) as $user) {
                $tempData['type'] = 'user';
                $tempData['id'] = $user->getIdentity();
                $tempData['guid'] = $user->getIdentity().'1111';
                $tempData['label'] = $user->getTitle();

                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
                $tempData = array_merge($tempData, $getContentImages);

                $data[] = $tempData;
            }

            foreach ($tableGroup->fetchAll($tableGroupSelect) as $group) {
                $tempData['type'] = 'group';
                $tempData['id'] = $group->getIdentity();
                $tempData['guid'] = $group->getIdentity().'0000';
                $tempData['label'] = $group->getTitle();

                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($group);
                $tempData = array_merge($tempData, $getContentImages);

                $data[] = $tempData;
            }

            $this->respondWithSuccess($data);
        } 
	}

}