<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteapi
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    indexController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Communityad_IndexController extends Siteapi_Controller_Action_Standard {

    public function init() {
        Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
    }

    public function indexAction() {
        $placementCount = $this->_getParam('placementCount', 5);
        $viewer = Engine_Api::_()->user()->getViewer();

        if (empty($placementCount))
            $this->respondWithError('no_record');

        //2 = Community Ad
        //3 = Core Ad
        //4 = Sponsered Stories
        $adType = $this->getRequestParam('type', 1);
        $length = $this->getRequestParam('limit', Engine_Api::_()->getApi('settings', 'core')->getSetting('activity.length', 15));
        $totalNoOfAdv = (int) $length / $placementCount;
        $finalArray = array();
        try {
            if ($adType == 3) {
                $finalArray = $this->getCoreAd($totalNoOfAdv);
            } else if ($adType == 2) {
                $finalArray = $this->getCommunityAd($totalNoOfAdv);
            } else if ($adType == 4) {
                $finalArray = $this->getSponseredStories($totalNoOfAdv);
            }
            $response['advertisments'] = $finalArray;
            $response['totalItemCount'] = count($finalArray);
            $this->respondWithSuccess($response);
        } catch (Exception $e) {
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }

    public function getCoreAd($totalNoOfAdv) {
        //Display Core Adv.
        $viewer = Engine_Api::_()->user()->getViewer();

        $coreAdsSelectedArray = Engine_Api::_()->advancedactivity()->getCoreAddMultioptions(1);

        $totalAdsAvailable = count($coreAdsSelected);
        if ($totalAdsAvailable < $totalNoOfAdv)
            $totalNoOfAdv = $totalAdsAvailable;

        $random_ads = array_rand($coreAdsSelected, $totalNoOfAdv);
        if (!is_array($random_ads)) {
            $random_ads = array($random_ads);
        }
        foreach ($random_ads as $key => $random_ad) {
            if (!($ad_id = $coreAdsSelected[$random_ad] ) ||
                    !($ad = Engine_Api::_()->getItem('core_ad', $ad_id))) {
                return;
            }
            if (!($id = $ad->ad_campaign) ||
                    !($campaign = Engine_Api::_()->getItem('core_adcampaign', $id))) {
                return;
            }
            // Check limits, start, and expire
            if (!$campaign->isActive()) {
                return;
            }

            if (!$campaign->isAllowedToView($viewer)) {
                return;
            }

            $campaign->views++;
            $campaign->save();

            $ad->views++;
            $ad->save();

            if ($campaign && $ad) {
                $tempArray = $ad->toArray();
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($ad);
                $tempArray = array_merge($tempArray, $getContentImages);
                $advArray[] = $tempArray;
            }
        }

        return $advArray;
    }

    public function getCommunityAd($totalNoOfAdv) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $user_id = $viewer->getIdentity();
        $communityAdvArray = array();

        if(_ANDROID_VERSION <4.0){
        $communityAdsSelected = Engine_Api::_()->advancedactivity()->getCommunityAddsMultioptions(1);

        //Remove Ads Cancelled By User
        $cancelledAdvs = Engine_Api::_()->advancedactivity()->getCancelAdvs();
        if (is_array($communityAdsSelected)) {
            if (is_array($cancelledAdvs)) {
                $communityAdsSelected = array_diff($communityAdsSelected, $cancelledAdvs);
            }
        }

        $totalAdsAvailable = count($communityAdsSelected);

        //Set total ads per block to total ads if ads is less.
        if ($totalAdsAvailable < $totalNoOfAdv)
            $totalNoOfAdv = $totalAdsAvailable;

        $random_ads = array_rand($communityAdsSelected, $totalNoOfAdv);
        if (!is_array($random_ads)) {
            $random_ads = array($random_ads);
        }
        }
        else{
            $random_ads = Engine_Api::_()->communityad()->getAdvertisement($params);
        }
        foreach ($random_ads as $key => $random_ad) {
           if(_ANDROID_VERSION < 4.0){
            if (empty($communityAdsSelected[$random_ad]))
                continue;
            $community_ad = Engine_Api::_()->getItem('userads', $communityAdsSelected[$random_ad]);
            Engine_Api::_()->communityad()->adViewCount($community_ad['userad_id']);
           }
           else{
               $community_ad = $random_ad;
                Engine_Api::_()->communityad()->adViewCount($community_ad->userad_id);
           }
            if ($community_ad) {
                $tempArray = $community_ad->toArray();
                if (isset($tempArray['cads_url']) && !empty($tempArray['cads_url'])) {

                    $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
                    $serverHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
                    $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
                    $baseParentUrl = @trim($baseParentUrl, "/");

                    $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
                    $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();

                    $host = '';
                    if ($getDefaultStorageType == 'local')
                        $host = !empty($staticBaseUrl) ? $staticBaseUrl : $serverHost;

                    if (strstr($tempArray['cads_url'], 'http://') || strstr($tempArray['cads_url'], 'https://'))
                        $host = '';

                    $tempArray['cads_url'] = $host . $tempArray['cads_url'];
                    if (!strstr($tempArray['cads_url'], 'http'))
                        $tempArray['cads_url'] = $serverHost . DIRECTORY_SEPARATOR . $baseParentUrl . $tempArray['cads_url'];
                }
                if (!isset($tempArray['cmd_ad_format'])) {
                    $tempArray['cmd_ad_format'] = "";
                }
                if (!isset($tempArray['cta_button'])) {
                    $tempArray['cta_button'] = "";
                }
                
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($community_ad);
                $tempArray = array_merge($tempArray, $getContentImages);
            }
            $advArray[] = $tempArray;
        }
        return $advArray;
    }

    public function getSponseredStories($totalNoOfAdv) {
        $getStoryStatus = Engine_Api::_()->getItemTable('communityad_adtype')->getStatus('sponsored_stories');
        $table = Engine_Api::_()->getItemTable('userads');
        $totalAd = $table->fetchAll(array('ad_type' => 'sponsored_stories'))->count();

        $isSponsoredStoryExist = Engine_Api::_()->getApi('SponcerdStories', 'communityad')->getSponcerdStories(array('limit' => $totalAd));
        if (empty($isSponsoredStoryExist) || empty($getStoryStatus)) {
            return;
        }

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $viewer = Engine_Api::_()->user()->getViewer();
        $count = 0;

        // Check if ads to be displayed are not empty
        if (!empty($isSponsoredStoryExist)) {
            foreach ($isSponsoredStoryExist as $content) {
                $tempArray = array();
                $getResourceType = $content['resource_type'];
                $module_info = $content['module_info'];
                $ContentObject = $content['content_object'];
                $story_type = $content['story_type'];
                $resource_type = $content['resource_type'];
                $resource_id = $content['resource_id'];
                $owner_id = $content['owner_id'];
                $tempArray['ad_id'] = $ad_id = $content['userad_id'];
                $campagn_id = !empty($content['campaign_id']) ? $content['campaign_id'] : 0;
                if ($story_type == 2) {
                    $ownerObj = $content['owner_object'];
                    $getObj = $content['activity_body'];
                } else {
                    $fetchFriendArray = $content['getFriendLikeArray'];
                }

                switch ($story_type) {
                    // Case 1: Indicate the "Page Like" story.
                    case 1:
                        $contantTitle = $ContentObject->getTitle();
                        $getContantTitle = str_replace(' ', '&nbsp;', $contantTitle);
                        $contentOption = 'Like';
                        $tempflag = 0;
                        $friendFlag = 0;
                        $tempTitleArray = array();
                        $getFriendArray = array();
                        $tempArray['resource_id'] = $ContentObject->getIdentity();
                        $tempArray['resource_type'] = $ContentObject->getType();
                        $tempArray['resource_title'] = $ContentObject->getTitle();
                        $tempArray['module_title'] = @ucfirst($ContentObject->getShortType());
                        if (strstr($tempArray['resource_type'], 'video')) {
                            try {
                                $tempArray['video_url'] = Engine_Api::_()->getApi('Siteapi_Core', 'video')->getVideoURL($ContentObject);
                                $tempArray['video_type'] = $this->videoType($ContentObject->type);
                            } catch (Exception $ex) {
                                $tempArray['video_url'] = "";
                                $tempArray['video_type'] = "";
                            }
                        }
                        $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($ContentObject);
                        $tempArray["like_count"] = $ContentObject->likes()->getLikeCount();
                        $tempArray = array_merge($tempArray, $getContentImages);
                        $friendArray = array();
                        foreach ($fetchFriendArray as $friendIdArray) {
                            $friendId = $friendIdArray['poster_id'];
                            $friendObj = Engine_Api::_()->getItem('user', $friendId);
                            $tempFriendArray['user_id'] = $friendObj->getIdentity();
                            $tempFriendArray['user_title'] = $friendObj->getTitle();
                            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($friendObj);
                            $tempFriendArray = array_merge($tempFriendArray, $getContentImages);
                            $friendArray[] = $tempFriendArray;
                        }
                        $tempArray['likes'] = $friendArray;
                        break;
                }
                $like_id = '';

                if (!empty($viewer) && !empty($getResourceType) && !empty($resource_id)) {
                    $checkResourceType = $resourceType = $getResourceType;
                    $resource_id = $resource_id;
                    $owner_id = $owner_id;
                    $resource_url = null;
                    if (!empty($getResourceType) && !empty($resource_id)) {
                        $resource_url = Engine_Api::_()->communityad()->resourceUrl($getResourceType, $resource_id);
                    }

                    // Query: Return array of 'My Friend Id' which liked this advertisment.
                    $resource_info = $module_info; //Engine_Api::_()->getDbtable('modules', 'communityad')->getModuleInfo($resourceType);
                    if (!empty($resource_info)) {
                        $checkResourceType = $resource_info['table_name'];
                    }
                    $like_ids = Engine_Api::_()->getApi('SponcerdStories', 'communityad')->likeAvailability($getResourceType, $resource_id);

                    // Function Calling: Return int or empty, If loggden user does not liked this advertisment then return empty and if loggden user done liked this advertisment then return id of liked from 'core_likes' table.
                    if (!empty($like_ids[0]['like_id'])) {
                        $tempArray['isLike'] = 1;
                    } else {
                        $tempArray['isLike'] = 0;
                    }
                }

                $advArray[] = $tempArray;
                $count++;
                if ($count >= $totalNoOfAdv)
                    break;
            }
        } else {
            return;
        }
        return $advArray;
    }

    // For Cancel advertisment by viewer and for submit reasion
    public function removeAdAction() {
        $adsId = $this->_getParam('adsId');
        $type = $this->_getParam('type', 2);

        if (empty($adsId))
            $this->respondWithError('no_record');
        if ($this->getRequest()->isGet()) {
            $this->respondWithSuccess($this->getReportAdForm());
        } else if ($this->getRequest()->isPost()) {
            try {
                $adCancelReasion = (string) $this->_getParam('adCancelReason');
                $adDescription = (string) $this->_getParam('adDescription');
                $viewerId = Engine_Api::_()->user()->getViewer()->getIdentity();
                $adcancelTable = Engine_Api::_()->getItemTable('communityad_adcancel');
                $adcancelList = $adcancelTable->createRow();
                $adcancelList->user_id = $viewerId;
                $adcancelList->report_type = $adCancelReasion;
                if (!empty($adDescription)) {
                    $adcancelList->report_description = $adDescription;
                }
                $adcancelList->ad_id = $adsId;
                $adcancelList->save();
                $this->setRequestMethod();
                $this->_forward('index', 'index', 'communityad', array(
                    'limit' => 2,
                    'placementCount' => 2,
                    'type' => $type,
                ));
                return;
            } catch (Exception $e) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
            }
        }
    }

    public function getReportAdForm() {
        $reportCategories = array(
            'Misleading' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Misleading'),
            'Offensive' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Offensive'),
            'Inappropriate' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Inappropriate'),
            'Licensed Material' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Licensed Material'),
            'Other' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Other'),
        );

        $reportForm['form'][] = array(
            'type' => 'Radio',
            'name' => 'adCancelReason',
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Report'),
            'multiOptions' => $reportCategories,
            'hasValidator' => true
        );

        $reportForm['form'][] = array(
            'type' => 'Submit',
            'name' => 'submit',
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Submit'),
        );

        $reportForm['fields']['Other'][] = array(
            'type' => 'other',
            'name' => 'adDescription',
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Specify your reason here..'),
        );

        return $reportForm;
    }

    public function updateClickCountAction() {
        $adsId = $this->_getParam('userad_id');
        $userad = Engine_Api::_()->getItem('userads', $adsId);

        if (empty($userad))
            $this->respondWithError('no_record');
        try {
            Engine_Api::_()->communityad()->ad_clickcount($adsId, false);
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    public function videoType($type) {
        switch ($type) {
            case 1:
            case 'youtube':
                return 1;
            case 2:
            case 'vimeo':
                return 2;
            case 3:
            case 'mydevice':
            case 'upload' :
                return 3;
            case 4:
            case 'dailymotion':
                return 4;
            case 5:
            case 'embedcode':
                return 5;
            case 6;
            case 'iframely':
                return 6;
            default : return $type;
        }
    }

}
