<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Api_Core extends Core_Api_Abstract {

    /**
     * Delete document from server
     * @param int $document_id : document id
     */
    public function deleteServerDocument($document_id) {

        //GET DOCUMENT OBJECT
        $document = Engine_Api::_()->getItem('document', $document_id);

        //RETURN IF DOCUMENT OBJECT IS EMPTY
        if (empty($document)) {
            return;
        }

        //UNLINK THE DOCUMENT FILE
        $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
        $storageversion = $storagemodule->version;
        if ($storageversion < '4.1.1' && file_exists($document->storage_path) && !empty($document->storage_path)) {
            unlink($document->storage_path);
        }

        //DELETE STORAGE TABLE ENTRIES
        if (!empty($document->filename_id)) {
            $storage = Engine_Api::_()->getItem('storage_file', $document->filename_id);
            $fileName = $storage->name;
            $storage->delete();

            $document->storage_path = $fileName;
            $document->filename_id = 0;
            $document->save();
        }
    }

    /**
     * Return parse string
     *
     * @param string $content
     * @return parse string
     */
    public function parseString($content) {

        //RETURN PARSED STRING
        return str_replace("'", "\'", trim($content));
    }

    /**
     * Delete the document and belongings
     * 
     * @param int $document_id
     */
    public function deleteContent($document_id) {

        //GET THE DOCUMENT OBJECT
        $document = Engine_Api::_()->getItem('document', $document_id);

        //RETURN IF DOCUMENT ID IS EMPTY
        if (empty($document)) {
            return;
        }

        include_once APPLICATION_PATH . '/application/modules/Document/Api/Google/Google_Client.php';
        include_once APPLICATION_PATH . '/application/modules/Document/Api/Google/contrib/Google_DriveService.php';
        include_once APPLICATION_PATH . '/application/modules/Document/Api/GDSEMedia.php';

        $coreApi = Engine_Api::_()->document();

        $document_google_email = $coreApi->getGoogleEmail();
        $document_client_id = $coreApi->getGoogleClientId();
        $getGoogleClientSecretKey = $coreApi->getGoogleClientSecretKey();
        $document_hide_old_fields = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.hide.old.fields', 0);
        if ($document_hide_old_fields) {
            $GDSEMedia = new GDSEMedia($document_client_id, null, null, $getGoogleClientSecretKey);
        } else {
            $document_service_account_name = $coreApi->getGoogleServiceAccountName();
            $document_private_key_url_path = $coreApi->getPrivateKeyUrl();
            if ($document_google_email && $document_client_id && $document_service_account_name && $document_private_key_url_path) {
                $GDSEMedia = new GDSEMedia($document_client_id, $document_service_account_name, $document_private_key_url_path);
            }
        }
        if (!empty($document->google_file_id)) { 
            try {
                $GDSEMedia->deleteFile($document->google_file_id);
            } catch(Exception $ee){
            //do not care if some error occur 
            }
        }

        //DELETE ALL MAPPING VALUES FROM FIELD TABLES
        Engine_Api::_()->fields()->getTable('document', 'values')->delete(array('item_id = ?' => $document_id));
        Engine_Api::_()->fields()->getTable('document', 'search')->delete(array('item_id = ?' => $document_id));

        //DELETE RATING VALUES
        Engine_Api::_()->getDbtable('ratings', 'document')->delete(array('document_id = ?' => $document_id));

        //DELETE DOCUMENT FROM LOCAL SERVER
        $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
        $storageversion = $storagemodule->version;
        if ($storageversion < '4.1.1' && file_exists($document->storage_path) && !empty($document->storage_path)) {
            unlink($document->storage_path);
        }

        //DELETE DOCUMENT AND OTHER BELONGINGS
        $document->delete();
    }

    /**
     * Send email to document and page owner if document has been deleted from scirbd
     * @param array $document : document item
     */
    public function emailDocumentDelete($document) {

        //RETURN IF DOCUMENT OBJECT IS EMPTY
        if (empty($document)) {
            return;
        }

        //GET DOCUMENT OWNER EMAIL ID
        $document_owner_id = $document->owner_id;
        $userTable = Engine_Api::_()->getItemTable('user');
        $document_owner_email_id = $userTable->select()
                ->from($userTable, 'email')
                ->where('user_id = ?', $document_owner_id)
                ->limit(1)
                ->query()
                ->fetchColumn(0);

        //SEND THE EMAIL IF OWNER ID IS NOT EMPTY
        if (!empty($document_owner_email_id)) {

            $slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($document->document_title))), '-');

            $Zend_router = Zend_Controller_Front::getInstance()->getRouter();

            $document_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . $Zend_router->assemble(array('user_id' => $document->owner_id, 'document_id' => $document->document_id, 'slug' => $slug), 'document_detail_view') . ">$document->document_title</a>";

            $edit_document_link = 'http://' . $_SERVER['HTTP_HOST'] . $Zend_router->assemble(array('document_id' => $document->document_id), 'document_edit');

            $delete_document_link = 'http://' . $_SERVER['HTTP_HOST'] . $Zend_router->assemble(array('document_id' => $document->document_id), 'document_delete');

//            Engine_Api::_()->getApi('mail', 'core')->sendSystem($document_owner_email_id, 'notify_document_delete', array(
//                'document_title_with_link' => $document_title_with_link,
//                'edit_document_link' => $edit_document_link,
//                'delete_document_link' => $delete_document_link,
//                'queue' => true
//            ));
        }
    }

    /**
     * Get document tags created by users
     * @param int $owner_id : document owner id
     * @param int $total_tags : number tags to show
     */
    public function getTags($owner_id = 0, $total_tags = 100, $count_only = 0, $params = array()) {

        //GET TAGMAP TABLE NAME
        $tableTagmaps = 'engine4_core_tagmaps';

        //GET TAG TABLE NAME
        $tableTags = 'engine4_core_tags';

        //GET DOCUMENT TABLE
        $tableDocumentName = Engine_Api::_()->getDbtable('documents', 'document');
        $tableDocuments = $tableDocumentName->info('name');

        //MAKE QUERY
        $select = $tableDocumentName->select()
                ->setIntegrityCheck(false)
                ->from($tableDocuments, array(''))
                ->joinInner($tableTagmaps, "$tableDocuments.document_id = $tableTagmaps.resource_id", array('COUNT(resource_id) AS Frequency'))
                ->joinInner($tableTags, "$tableTags.tag_id = $tableTagmaps.tag_id", array('text', 'tag_id'));

        if (!empty($owner_id)) {
            $select = $select->where($tableDocuments . '.owner_id = ?', $owner_id);
        }

        $select = $select->where($tableDocuments . '.status = ?', "1")
                ->where($tableDocuments . '.approved = ?', "1")
                ->where($tableDocuments . '.draft = ?', "0")
                ->where($tableDocuments . '.search = ?', "1")
                ->where($tableTagmaps . '.resource_type = ?', 'document')
                ->group("$tableTags.text");
        // ->order("Frequency DESC");

        if (isset($params['orderingType']) && !empty($params['orderingType']))
            $select->order("$tableTags.text");
        else
            $select->order("Frequency DESC");

        if (!empty($total_tags)) {
            $select = $select->limit($total_tags);
        }
        $select = $tableDocumentName->getNetworkBaseSql($select);
        if (!empty($count_only)) {
            $total_results = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
            return Count($total_results);
        } 

        //RETURN RESULTS
        return $select->query()->fetchAll();
    }

    /**
     * Gets an absolute URL to the page to view this item
     *
     * @return string
     */
    public function getHref($document_id, $owner_id, $title) {
        $slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($title))), '-');

        $params = array();
        $params['route'] = 'document_detail_view';
        $params['reset'] = true;
        $params['user_id'] = $owner_id;
        $params['document_id'] = $document_id;
        $params['slug'] = $slug;

        return Zend_Controller_Front::getInstance()->getRouter()
                        ->assemble($params, 'document_detail_view', true);
    }

    /**
     * Show selected browse by field in search form at browse page
     *
     */
    public function showSelectedBrowseBy() {

        //GET CORE CONTENT TABLE
        $coreContentTable = Engine_Api::_()->getDbTable('content', 'core');
        $coreContentTableName = $coreContentTable->info('name');

        //GET CORE PAGES TABLE
        $corePageTable = Engine_Api::_()->getDbTable('pages', 'core');
        $corePageTableName = $corePageTable->info('name');

        //GET DATA
        $params = $coreContentTable->select()
                ->from($coreContentTableName, array('params'))
                ->joinLeft($corePageTableName, "$corePageTableName.page_id = $coreContentTableName.page_id", array(''))
                ->where($coreContentTableName . '.name = ?', 'document.browse-documents')
                ->where($corePageTableName . '.name = ?', 'document_index_browse')
                ->query()
                ->fetchColumn();

        $paramsArray = !empty($params) ? Zend_Json::decode($params) : array();
        if (isset($paramsArray['orderby']) && !empty($paramsArray['orderby']) && ($paramsArray['orderby'] == 'document_id' || $paramsArray['orderby'] == 'views' || $paramsArray['orderby'] == 'document_title')) {
            return $paramsArray['orderby'];
        } else {
            return 0;
        }
    }

    /**
     * Get Truncation String
     *
     * @param string $text
     * @param int $limit
     * @return truncate string
     */
    public function truncateText($text, $limit) {

        //GET STRIPPED TEXT
        $tmpBody = strip_tags($text);

        //RETURN TRUNCATE TEXT
        return ( Engine_String::strlen($tmpBody) > $limit ? Engine_String::substr($tmpBody, 0, $limit) . '..' : $tmpBody );
    }

    /**
     * Document base network enable
     *
     * @return bool
     */
    public function documentBaseNetworkEnable() {

        return (bool) ( Engine_Api::_()->getApi('settings', 'core')->getSetting('document.networks.type', 0) && (Engine_Api::_()->getApi('settings', 'core')->getSetting('document.network', 0) || Engine_Api::_()->getApi('settings', 'core')->getSetting('document.default.show', 0)));
    }

    /**
     * Plugin which return the error, if Siteadmin not using correct version for the plugin.
     *
     */
    public function isModulesSupport() {
        $modArray = array(
            'suggestion' => '4.2.3',
        );
        $finalModules = array();
        foreach ($modArray as $key => $value) {
            $isModEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($key);
            if (!empty($isModEnabled)) {
                $getModVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule($key);
                $isModSupport = $this->checkVersion($getModVersion->version, $value);
                if (empty($isModSupport)) {
                    $finalModules[] = $getModVersion->title;
                }
            }
        }
        return $finalModules;
    }

    private function checkVersion($databaseVersion, $checkDependancyVersion) {
        $f = $databaseVersion;
        $s = $checkDependancyVersion;
        if (strcasecmp($f, $s) == 0)
            return -1;

        $fArr = explode(".", $f);
        $sArr = explode('.', $s);
        if (count($fArr) <= count($sArr))
            $count = count($fArr);
        else
            $count = count($sArr);

        for ($i = 0; $i < $count; $i++) {
            $fValue = $fArr[$i];
            $sValue = $sArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                if ($fValue > $sValue)
                    return 1;
                elseif ($fValue < $sValue)
                    return 0;
                else {
                    if (($i + 1) == $count) {
                        return -1;
                    } else
                        continue;
                }
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);

                if ($fsArr[0] > $sValue)
                    return 1;
                elseif ($fsArr[0] < $sValue)
                    return 0;
                else {
                    return 1;
                }
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);

                if ($fValue > $ssArr[0])
                    return 1;
                elseif ($fValue < $ssArr[0])
                    return 0;
                else {
                    return 0;
                }
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                if ($fsArr[0] > $ssArr[0])
                    return 1;
                elseif ($fsArr[0] < $ssArr[0])
                    return 0;
                else {
                    if ($fsArr[1] > $ssArr[1])
                        return 1;
                    elseif ($fsArr[1] < $ssArr[1])
                        return 0;
                    else {
                        return -1;
                    }
                }
            }
        }
    }

    public function formatBytes($bytes, $precision = 2) {
        $label = array('B', 'KB', 'MB', 'GB', 'TB', 'PB');
        for ($i = 0; $bytes >= 1024 && $i < ( count($label) - 1 ); $bytes /= 1024, $i++)
            ;
        return( round($bytes, 2) . " " . $label[$i] );
    }

    public function getGoogleEmail() {
        return Engine_Api::_()->getApi('settings', 'core')->getSetting('document.google.email');
    }

    public function getGoogleClientId() {


        $google_client_id = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.google.client.id');

        if ($google_client_id) {
            return $google_client_id;
        } else {
            return Engine_Api::_()->getApi('settings', 'core')->getSetting('document.client.id');
        }
    }

    public function getGoogleClientSecretKey() {

        $google_client_secret_key = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.google.client.secret.key');
        if ($google_client_secret_key) {
            return $google_client_secret_key;
        }
    }

    public function getGoogleServiceAccountName() {
        return Engine_Api::_()->getApi('settings', 'core')->getSetting('document.service.account.name');
    }

    public function getPrivateKeyUrl() {
        return Engine_Api::_()->getApi('settings', 'core')->getSetting('document.private.key.url_path');
    }

    public function isCreatePrivacy($parent_type = null, $parent_id = null) {
        $viewer = Engine_Api::_()->user()->getViewer();
        if ($parent_type == 'sitepage_page' && Engine_Api::_()->hasItemType('sitepage_page')) {
            $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'edit');
            $issdcreate = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'sdcreate');

            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'sitebusiness_business' && Engine_Api::_()->hasItemType('sitebusiness_business')) {
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
            $issdcreate = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'sitegroup_group' && Engine_Api::_()->hasItemType('sitegroup_group')) {
            $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
            $issdcreate = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'sitestore_store' && Engine_Api::_()->hasItemType('sitestore_store')) {
            $sitestore = Engine_Api::_()->getItem('sitestore_store', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'edit');
            $issdcreate = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'siteevent_event' && Engine_Api::_()->hasItemType('siteevent_event')) {
            $siteevent = Engine_Api::_()->getItem('siteevent_event', $parent_id);
            $canCreate = Engine_Api::_()->authorization()->isAllowed($siteevent, $viewer, 'document');
            if (empty($canCreate)) {
                return false;
            }
        } else if (strpos($parent_type, "sitereview_listing") !== false) {
            $viewer = Engine_Api::_()->user()->getViewer();
            $sitereview = Engine_Api::_()->getItem('sitereview_listing', $parent_id);
            //AUTHORIZATION CHECK
            $canCreate = $sitereview->authorization()->isAllowed($viewer, "doc_listtype_$sitereview->listingtype_id");
            if (empty($canCreate)) {
                return false;
            }
        } else if ($parent_type == 'event' && Engine_Api::_()->hasItemType('event')) {
            $event = Engine_Api::_()->getItem('event', $parent_id);

            $canCreate = Engine_Api::_()->authorization()->isAllowed($event, $viewer, 'edcreate');
            if (empty($canCreate)) {
                return false;
            }
        } else if ($parent_type == 'group' && Engine_Api::_()->hasItemType('group')) {
            $group = Engine_Api::_()->getItem('group', $parent_id);
            $canCreate = Engine_Api::_()->authorization()->isAllowed($group, $viewer, 'gdcreate');
            if (empty($canCreate)) {
                return false;
            }
        } else {
            if (!Engine_Api::_()->authorization()->isAllowed('document', $viewer, "create")) {
                return false;
            }
        }

        return true;
    }

    public function isEditPrivacy($parent_type = null, $parent_id = null, $item = null) {
        $viewer = Engine_Api::_()->user()->getViewer();
        if ($parent_type == 'sitepage_page' && Engine_Api::_()->hasItemType('sitepage_page')) {
            $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'edit');
            $issdcreate = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'sitebusiness_business' && Engine_Api::_()->hasItemType('sitebusiness_business')) {
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
            $issdcreate = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'sitegroup_group' && Engine_Api::_()->hasItemType('sitegroup_group')) {
            $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
            $issdcreate = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'sitestore_store' && Engine_Api::_()->hasItemType('sitestore_store')) {
            $sitestore = Engine_Api::_()->getItem('sitestore_store', $parent_id);
            $isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'edit');
            $issdcreate = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'sdcreate');
            if (empty($issdcreate) && empty($isManageAdmin)) {
                return false;
            }
        } else if ($parent_type == 'siteevent_event' && Engine_Api::_()->hasItemType('siteevent_event')) {
            $parentTypeItem = Engine_Api::_()->getItem('siteevent_event', $parent_id);

            $canEdit = $parentTypeItem->authorization()->isAllowed($viewer, "edit");
            if (empty($canEdit))
                return false;
        } else {

            if (isset($item->owner_id)) {

                if ($viewer->getIdentity() != $item->owner_id && !$item->authorization()->isAllowed($viewer, 'edit'))
                    return false;
            } else {
                if ($viewer->getIdentity() != $item->user_id && !$item->authorization()->isAllowed($viewer, 'edit'))
                    return false;
            }
        }
        return true;
    }

    public function canDeletePrivacy($parent_type = null, $parent_id = null, $item = null) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }
        if ($parent_type == 'sitepage_page' && Engine_Api::_()->hasItemType('sitepage_page')) {
            $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
            //START MANAGE-ADMIN CHECK
            $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'edit');
            if ($viewer_id != $sitepage->owner_id && !$isManageAdmin) {
                return false;
            } else {
                return true;
            }
        } elseif ($parent_type == 'sitebusiness_business' && Engine_Api::_()->hasItemType('sitebusiness_business')) {
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parent_id);
            //START MANAGE-ADMIN CHECK
            $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
            if ($viewer_id != $sitebusiness->owner_id && !$isManageAdmin) {
                return false;
            } else {
                return true;
            }
        } elseif ($parent_type == 'sitegroup_group' && Engine_Api::_()->hasItemType('sitegroup_group')) {
            $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
            //START MANAGE-ADMIN CHECK
            $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
            if ($viewer_id != $sitegroup->owner_id && !$isManageAdmin) {
                return false;
            } else {
                return true;
            }
        } elseif ($parent_type == 'sitestore_store' && Engine_Api::_()->hasItemType('sitestore_store')) {
            $sitestore = Engine_Api::_()->getItem('sitestore_store', $parent_id);
            //START MANAGE-ADMIN CHECK
            $isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'edit');
            if ($viewer_id != $sitestore->owner_id && !$isManageAdmin) {
                return false;
            } else {
                return true;
            }
        } elseif (strpos($parent_type, "sitereview_listing") !== false) {
            $sitereview = Engine_Api::_()->getItem('sitereview_listing', $parent_id);

            $can_delete = $sitereview->authorization()->isAllowed($viewer, 'delete_listtype_' . $sitereview->listingtype_id);
            if ($can_delete) {
                return true;
            } else {
                return false;
            }
        } elseif ($parent_type == 'siteevent_event' && Engine_Api::_()->hasItemType('siteevent_event')) {
            $can_delete = Engine_Api::_()->authorization()->getPermission($level_id, 'document', "delete");
            if ($can_delete) {
                return true;
            } else {
                return false;
            }
        } else {
            if (!$item->authorization()->isAllowed($viewer, 'delete'))
                return false;
        }

        return true;
    }

    public function isParentViewPrivacy($document) {

        if (empty($document->parent_type) && empty($document->parent_id))
            return true;
        $parent = Engine_Api::_()->getItem($document->parent_type, $document->parent_id);
        if (!empty($parent)) {
            $parent_type = $parent->getType();
            $parent_id = $parent->getIdentity();
            if ($parent_type == 'sitepage_page' && $parent_id) {
                $sitepage = $parent;
                //PACKAGE BASE PRIYACY START
                if (Engine_Api::_()->sitepage()->hasPackageEnable()) {
                    if (!Engine_Api::_()->sitepage()->allowPackageContent($sitepage->package_id, "modules", "sitepagedocument")) {
                        return false;
                    }
                } else {
                    $isPageOwnerAllow = Engine_Api::_()->sitepage()->isPageOwnerAllow($sitepage, 'sdcreate');
                    if (empty($isPageOwnerAllow)) {
                        return false;
                    }
                }
                //PACKAGE BASE PRIYACY END
                //START MANAGE-ADMIN CHECK
                $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'view');
                if (empty($isManageAdmin)) {
                    return false;
                }

                //PAGE VIEW AUTHORIZATION
                if (!Engine_Api::_()->sitepage()->canViewPage($sitepage)) {
                    return false;
                }
            } elseif ($parent_type == 'sitebusiness_business' && $parent_id) {
                $sitebusiness = $parent;
                //PACKAGE BASE PRIYACY START
                if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                    if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessdocument")) {
                        return false;
                    }
                } else {
                    $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sdcreate');
                    if (empty($isBusinessOwnerAllow)) {
                        return false;
                    }
                }
                //PACKAGE BASE PRIYACY END
                //START MANAGE-ADMIN CHECK
                $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'view');
                if (empty($isManageAdmin)) {
                    return false;
                }

                //BUSINESS VIEW AUTHORIZATION
                if (!Engine_Api::_()->sitebusiness()->canViewBusiness($sitebusiness)) {
                    return false;
                }
            } elseif ($parent_type == 'sitegroup_group' && $parent_id) {
                $sitegroup = $parent;
                //PACKAGE BASE PRIYACY START
                if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
                    if (!Engine_Api::_()->sitegroup()->allowPackageContent($sitegroup->package_id, "modules", "sitegroupdocument")) {
                        return false;
                    }
                } else {
                    $isGroupOwnerAllow = Engine_Api::_()->sitegroup()->isGroupOwnerAllow($sitegroup, 'sdcreate');
                    if (empty($isGroupOwnerAllow)) {
                        return false;
                    }
                }
                //PACKAGE BASE PRIYACY END
                //START MANAGE-ADMIN CHECK
                $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'view');
                if (empty($isManageAdmin)) {
                    return false;
                }

                //GROUP VIEW AUTHORIZATION
                if (!Engine_Api::_()->sitegroup()->canViewGroup($sitegroup)) {
                    return false;
                }
            } elseif ($parent_type == 'sitestore_store' && $parent_id) {
                $sitestore = $parent;
                //PACKAGE BASE PRIYACY START
                if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
                    if (!Engine_Api::_()->sitestore()->allowPackageContent($sitestore->package_id, "modules", "sitestoredocument")) {
                        return false;
                    }
                } else {
                    $isStoreOwnerAllow = Engine_Api::_()->sitestore()->isStoreOwnerAllow($sitestore, 'sdcreate');
                    if (empty($isStoreOwnerAllow)) {
                        return false;
                    }
                }
                //PACKAGE BASE PRIYACY END
                //START MANAGE-ADMIN CHECK
                $isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'view');
                if (empty($isManageAdmin)) {
                    return false;
                }

                //STORE VIEW AUTHORIZATION
                if (!Engine_Api::_()->sitestore()->canViewStore($sitestore)) {
                    return false;
                }
            } else if ($parent_type == 'siteevent_event' && $parent_id) {
                if (!$parent->canView($viewer)) {
                    return false;
                }
            }
        }
        return true;
    }

    /**
     * Get Widgetized PageId
     * @param $params
     */
    public function getWidgetizedPageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $page_id = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'page_id')
                ->where('name =?', $params['name'])
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    public function getCategoryHomeRoute() {

        return 'document_category_home';
    }

    public function addPrivacyDocumentsSQl($select, $tableName = null) {

        $privacybase = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.privacybase', 0);
        if (empty($privacybase))
            return $select;

        $column = $tableName ? "$tableName.document_id" : "document_id";

        return $select->where("$column IN(?)", $this->getOnlyViewableDocumentsId());
    }

    public function getOnlyViewableDocumentsId() {

        $viewer = Engine_Api::_()->user()->getViewer();
        $documents_ids = array();
        $cache = Zend_Registry::get('Zend_Cache');
        $cacheName = 'document_ids_user_id_' . $viewer->getIdentity();

        $data = APPLICATION_ENV == 'development' ? ( Zend_Registry::isRegistered($cacheName) ? Zend_Registry::get($cacheName) : null ) : $cache->load($cacheName);
        if ($data && is_array($data)) {
            $documents_ids = $data;
        } else {
            set_time_limit(0);
            $table = Engine_Api::_()->getItemTable('document');
            $document_select = $table->select()
                    ->where('search = ?', true)
                    ->order('document_id DESC');

            // Create new array filtering out private documents
            $i = 0;
            foreach ($document_select->getTable()->fetchAll($document_select) as $document) {
                if ($document->isOwner($viewer) || Engine_Api::_()->authorization()->isAllowed($document, $viewer, 'view')) {
                    $documents_ids[$i++] = $document->document_id;
                }
            }

            // Try to save to cache
            if (empty($documents_ids))
                $documents_ids = array(0);

            if (APPLICATION_ENV == 'development') {
                Zend_Registry::set($cacheName, $documents_ids);
            } else {
                $cache->save($documents_ids, $cacheName);
            }
        }

        return $documents_ids;
    }

    public function get_mime_content_type($filename) {

        if (!function_exists('mime_content_type')) {
            return $this->mime_content_type($filename);
        } else {
            return mime_content_type($filename);
        }
    }

    public function mime_content_type($filename) {

        $mime_types = array(
            'txt' => 'text/plain',
            'htm' => 'text/html',
            'html' => 'text/html',
            'php' => 'text/html',
            'css' => 'text/css',
            'js' => 'application/javascript',
            'json' => 'application/json',
            'xml' => 'application/xml',
            'swf' => 'application/x-shockwave-flash',
            'flv' => 'video/x-flv',
            // images
            'png' => 'image/png',
            'jpe' => 'image/jpeg',
            'jpeg' => 'image/jpeg',
            'jpg' => 'image/jpeg',
            'gif' => 'image/gif',
            'bmp' => 'image/bmp',
            'ico' => 'image/vnd.microsoft.icon',
            'tiff' => 'image/tiff',
            'tif' => 'image/tiff',
            'svg' => 'image/svg+xml',
            'svgz' => 'image/svg+xml',
            // archives
            'zip' => 'application/zip',
            'rar' => 'application/x-rar-compressed',
            'exe' => 'application/x-msdownload',
            'msi' => 'application/x-msdownload',
            'cab' => 'application/vnd.ms-cab-compressed',
            // audio/video
            'mp3' => 'audio/mpeg',
            'qt' => 'video/quicktime',
            'mov' => 'video/quicktime',
            // adobe
            'pdf' => 'application/pdf',
            'psd' => 'image/vnd.adobe.photoshop',
            'ai' => 'application/postscript',
            'eps' => 'application/postscript',
            'ps' => 'application/postscript',
            // ms office
            'doc' => 'application/msword',
            'rtf' => 'application/rtf',
            'xls' => 'application/vnd.ms-excel',
            'ppt' => 'application/vnd.ms-powerpoint',
            // open office
            'odt' => 'application/vnd.oasis.opendocument.text',
            'ods' => 'application/vnd.oasis.opendocument.spreadsheet',
        );

        $ext = strtolower(array_pop(explode('.', $filename)));
        if (array_key_exists($ext, $mime_types)) {
            return $mime_types[$ext];
        } elseif (function_exists('finfo_open')) {
            $finfo = finfo_open(FILEINFO_MIME);
            $mimetype = finfo_file($finfo, $filename);
            finfo_close($finfo);
            return $mimetype;
        } else {
            return 'application/octet-stream';
        }
    }

}
