<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Form_Admin_Addnewdocument extends Engine_Form {

    protected $_profileType;
    protected $_defaultProfileId;
    protected $_item;
    public $_topLevelId;
    public $_topLevelValue;
    public $_processedValues = array();
    public $_isCreation = false;
    public $_hasPrivacy = false;
    public $_privacyValues = array();
    public $_controllerName;
    public static $getProfilePhoto = false;
    public static $getFilename = false;
    public static $getFileId;

    public function setProfileType($params) {
        $this->_profileType = $params;
    }

    public function getDefaultProfileId() {
        return $this->_defaultProfileId;
    }

    public function setDefaultProfileId($default_profile_id) {
        $this->_defaultProfileId = $default_profile_id;
        return $this;
    }

    public function setControllerName($name) {
        $this->_controllerName = $name;
    }

    public function getItem() {
        return $this->_item;
    }

    public function setItem(Core_Model_Item_Abstract $item) {
        $this->_item = $item;
        return $this;
    }

    public function setTopLevelId($id) {
        $this->_topLevelId = $id;
        return $this;
    }

    public function getTopLevelId() {
        return $this->_topLevelId;
    }

    public function setTopLevelValue($val) {
        $this->_topLevelValue = $val;
        return $this;
    }

    public function getTopLevelValue() {
        return $this->_topLevelValue;
    }

    public function setIsCreation($flag = true) {
        $this->_isCreation = (bool) $flag;
        return $this;
    }

    public function setProcessedValues($values) {
        $this->_processedValues = $values;
        $this->_setFieldValues($values);
        return $this;
    }

    public function getProcessedValues() {
        return $this->_processedValues;
    }

    public function setHasPrivacy($flag = false) {
        $this->_hasPrivacy = (bool) $flag;
        return $this;
    }

    public function setPrivacyValues($privacyValues) {
        $this->_privacyValues = (array) $privacyValues;
        return $this;
    }

    public function getFieldMeta() {
        return Engine_Api::_()->fields()->getFieldsMeta($this->getItem());
    }

    public function adddocumentprofilevalue($profileId) {
        $this->_topLevelValue = $profileId;
        $profileTypeField = $this->getProfileTypeField();
        $this->_topLevelId = $profileTypeField->field_id;
        $this->setIsCreation(true);
        $this->generate();
    }

    // Element: documentname as profile address.
    public function getProfileTypeField() {
        $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('document');
        if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
            return $topStructure[0]->getChild();
        }
    }

    public function init() {
        if (!$this->_item) {
            $document_item = new Document_Model_Document(array());
            $this->setItem($document_item);
        }
        $this
                ->setTitle('Upload New Document')
                ->setDescription("Upload your new document by filling the information below, then click 'Submit'.")
                ->setAttrib('id', 'form-upload-document')
                ->setAttrib('name', 'document_create')
                ->setAttrib('enctype', 'multipart/form-data')
                ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()));

        $settings = Engine_Api::_()->getApi('settings', 'core');
        $viewer = Engine_Api::_()->user()->getViewer();
        $level_id = $viewer->level_id;
        $this->addElement('Text', 'document_title', array(
            'label' => 'Document Title',
            'required' => true,
            'filters' => array(
                new Engine_Filter_Censor(),
                'StripTags',
            ),
        ));

        $filter = new Engine_Filter_Html();
        $editorAllow = $settings->getSetting('document.show.editor', 1);
        if ($editorAllow) {
            $this->addElement('TinyMce', 'document_description', array(
                'label' => 'Document description',
                'required' => false,
                'allowEmpty' => true,
                'filters' => array(
                    new Engine_Filter_Censor(),
                    $filter,
                ),
                'editorOptions' => Engine_Api::_()->seaocore()->tinymceEditorOptions(),
            ));
        } else {
            $this->addElement('textarea', 'document_description', array(
                'label' => 'Document description',
                'attribs' => array('rows' => 24, 'cols' => 80, 'style' => 'width:300px; max-width:553px;height:120px;'),
                'filters' => array(
                    $filter,
                    new Engine_Filter_Censor(),
                ),
            ));
        }

        //Add dynamic field of the document.
        $profileId = $this->_profileType;

        $categories = Engine_Api::_()->getDbTable('categories', 'document')->getCategories(0, 0);
        if (count($categories) != 0) {
            $categories_prepared[0] = "";
            foreach ($categories as $category) {
                // Categories matched to profile type
                if (isset($profileId) && !empty($profileId)) {
                    if (!empty($category->profile_type == $profileId)) {
                        $categories_prepared[$category->category_id] = $category->category_name;
                    }
                } else {
                    $categories_prepared[$category->category_id] = $category->category_name;
                }
            }

            $defaultProfileId = "0_0_" . $this->getDefaultProfileId();
            $onChangeEvent = "showFields(this.value, 1); subcategories(this.value, '', '');";
            $this->addElement('Select', 'category_id', array(
                'label' => 'Category',
                'allowEmpty' => false,
                'required' => true,
                'multiOptions' => $categories_prepared,
                'onchange' => $onChangeEvent
            ));

            $this->addElement('Select', 'subcategory_id', array(
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => 'application/modules/Document/views/scripts/_formSubcategory.tpl',
                            'class' => 'form element')))
            ));

            $this->addElement('Select', 'subsubcategory_id', array(
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => 'application/modules/Document/views/scripts/_formSubcategory.tpl',
                            'class' => 'form element')))
            ));
        }

        //Add documents belong to this.
        if (isset($profileId) && !empty($profileId))
            $this->adddocumentprofilevalue($profileId);
        $filesize = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'filesize');
        $extension = '';
        if (!$settings->getSetting('document.uploaded.extension', 0)) {
            $extension = $settings->getSetting('document.extension.type', 'pdf, txt, ps, rtf, epub, odt, odp, ods, odg, odf, sxw, sxc, sxi, sxd, doc, ppt, pps, xls, docx, pptx, ppsx, xlsx, tif, tiff, jpg,jpeg,png,gif');
            $description = Zend_Registry::get('Zend_Translate')->_('Browse and choose a file for your document. Maximum permissible size: %1$s KB and allowed file types: %2$s');
        } else {
            $description = Zend_Registry::get('Zend_Translate')->_('Browse and choose a file for your document.');
        }

        $description = sprintf($description, $filesize, $extension);
        $this->addElement('File', 'filename', array(
            'label' => 'Document File',
            'required' => true,
            'description' => $description
        ));
        $this->filename->getDecorator('Description')->setOption('placement', 'append');

        $required = 'false';
        if ($settings->getSetting('document.thumbnail', 0)) {
            $required = 'true';
        }
        $this->addElement('File', 'documentthumbnail', array(
            'label' => "Document's Main Photo",
            'description' => 'If you do not upload Document’s main photo then default thumbnail image return by Google will be displayed here.',
            'required' => $required
        ));
        $this->documentthumbnail->addValidator('Extension', false, 'jpg,jpeg,png,gif');
        $this->documentthumbnail->getDecorator('Description')->setOption('placement', 'append');


        $this->addElement('Text', 'tags', array(
            'label' => 'Tags (Keywords)',
            'autocomplete' => 'off',
            'description' => 'Separate tags with commas.',
            'filters' => array(
                new Engine_Filter_Censor(),
            ),
        ));
        $this->tags->getDecorator("Description")->setOption("placement", "append");

        $this->addElement('Select', 'draft', array(
            'label' => 'Status',
            'multiOptions' => array("0" => "Published", "1" => "Saved As Draft"),
            'description' => 'If this entry is published, it cannot be switched back to draft mode.'
        ));
        $this->draft->getDecorator('Description')->setOption('placement', 'append');

        $profile_doc = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc');
        $profile_doc_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc_show');
        if ($profile_doc == 1 && $profile_doc_show == 1) {
            $this->addElement('Radio', 'profile_doc', array(
                'label' => 'Make Profile Document',
                'multiOptions' => array(
                    1 => 'Yes, make this your Profile Document. (Note: At any time only one document can be showcased as your Profile Document. Thus, if you have made any document as your profile document currently, then it will be changed to this one.)',
                    0 => 'No, do not make this your Profile Document.'
                ),
                'value' => 0,
            ));
        }

        $download_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'download_allow');
        $download_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'download_show');
        if ($download_allow == 1 && $download_show == 1) {
            $this->addElement('Radio', 'download_allow', array(
                'label' => 'Allow Document Download',
                'multiOptions' => array(
                    1 => 'Yes, allow document download.',
                    0 => 'No, do not allow document download.'
                ),
                'value' => 1,
            ));
        }

        $email_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_allow');
        $email_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_show');
        if ($email_allow == 1 && $email_show == 1) {
            $this->addElement('Radio', 'email_allow', array(
                'label' => 'Allow Email Attachment',
                'multiOptions' => array(
                    1 => 'Yes, allow document to be emailed as attachment.',
                    0 => 'No, do not allow document to be emailed as attachment.'
                ),
                'value' => 1,
            ));
        }

        //NETWORK BASE PAGE VIEW PRIVACY
        if (Engine_Api::_()->document()->documentBaseNetworkEnable()) {
            // Make Network List
            $table = Engine_Api::_()->getDbtable('networks', 'network');
            $select = $table->select()
                    ->from($table->info('name'), array('network_id', 'title'))
                    ->order('title');
            $result = $table->fetchAll($select);

            $networksOptions = array('0' => 'Everyone');
            foreach ($result as $value) {
                $networksOptions[$value->network_id] = $value->title;
            }

            if (count($networksOptions) > 0) {
                $this->addElement('Multiselect', 'networks_privacy', array(
                    'label' => 'Networks Selection',
                    'description' => Zend_Registry::get('Zend_Translate')->_("Select the networks, members of which should be able to see your document. (Press Ctrl and click to select multiple networks. You can also choose to make your document viewable to everyone.)"),
                    'multiOptions' => $networksOptions,
                    'value' => array(0)
                ));
            } else {
                
            }
        }

        $this->addElement('Checkbox', 'search', array(
            'label' => "Show this document in search results.",
            'value' => 1
        ));

        $availableLabels = array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
        );

        $options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('document', $viewer, 'auth_view');
        $options = array_intersect_key($availableLabels, array_flip($options));
        $orderPrivacyHiddenFields = 786590;
        if (count($options) > 1) {
            $this->addElement('Select', 'auth_view', array(
                'label' => 'View Privacy',
                'description' => 'Who may see this document?',
                'multiOptions' => $options,
                'value' => 'everyone',
            ));
            $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
        } elseif (count($options) == 1) {
            $this->addElement('Hidden', 'auth_view', array(
                'value' => key($options),
                'order' => ++$orderPrivacyHiddenFields,
            ));
        } else {
            $this->addElement('Hidden', 'auth_view', array(
                'value' => 'everyone',
                'order' => ++$orderPrivacyHiddenFields,
            ));
        }

        $options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('document', $viewer, 'auth_comment');
        $options = array_intersect_key($availableLabels, array_flip($options));

        if (count($options) > 1) {
            $this->addElement('Select', 'auth_comment', array(
                'label' => 'Comment Privacy',
                'description' => 'Who may post comments on this document?',
                'multiOptions' => $options,
                'value' => 'registered',
            ));
            $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
        } elseif (count($options) == 1) {
            $this->addElement('Hidden', 'auth_comment', array(
                'value' => key($options),
                'order' => ++$orderPrivacyHiddenFields,
            ));
        } else {
            $this->addElement('Hidden', 'auth_comment', array(
                'value' => 'everyone',
                'order' => ++$orderPrivacyHiddenFields,
            ));
        }

        $this->addElement('Button', 'submit', array(
            'label' => 'Submit',
            'type' => 'submit',
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_formButtonCancel.tpl',
                        'class' => 'form element')))
        ));
    }

    // Main
    public function generate() {
        $struct = $this->getFieldStructure('document');
        $orderIndex = 0;
        $tabIndex = 6;
        foreach ($struct as $fskey => $map) {
            $field = $map->getChild();

            // Skip fields hidden on signup
            if (isset($field->show) && !$field->show && $this->_isCreation) {
                continue;
            }

            // Add field and load options if necessary
            $params = $field->getElementParams($this->getItem());

            //$key = 'field_' . $field->field_id;
            $key = $map->getKey();

            // If value set in processed values, set in element
            if (!empty($this->_processedValues[$field->field_id])) {
                $params['options']['value'] = $this->_processedValues[$field->field_id];
            }

            if (!@is_array($params['options']['attribs'])) {
                $params['options']['attribs'] = array();
            }

            // Heading
            if ($params['type'] == 'Heading') {
                $params['options']['value'] = Zend_Registry::get('Zend_Translate')->_($params['options']['label']);
                unset($params['options']['label']);
            }

            // Order
            $params['options']['order'] = $orderIndex++;

            $inflectedType = Engine_Api::_()->fields()->inflectFieldType($params['type']);
            unset($params['options']['alias']);
            unset($params['options']['publish']);
            $this->addElement($inflectedType, $key, $params['options']);

            $element = $this->getElement($key);

            if (method_exists($element, 'setFieldMeta')) {
                $element->setFieldMeta($field);
            }

            // Set attributes for hiding/showing fields using javscript
            $classes = 'field_container field_' . $map->child_id . ' option_' . $map->option_id . ' parent_' . $map->field_id;
            $element->setAttrib('class', $classes);

            //
            if ($field->canHaveDependents()) {
                $element->setAttrib('onchange', 'changeFields(this)');
            }

            // Set custom error message
            if ($field->error) {
                $element->addErrorMessage($field->error);
            }


            if ($params['type'] != 'Heading') {
                $element->setAttrib('tabIndex', $tabIndex++);
            }
            if ($field->isHeading()) {
                $element->removeDecorator('Label')
                        ->removeDecorator('HtmlTag')
                        ->getDecorator('HtmlTag2')->setOption('class', 'form-wrapper-heading');
            }
        }
    }

    public function getFieldStructure() {
        // Let's allow fallback for no profile type (for now at least)
        if (!$this->_topLevelId || !$this->_topLevelValue) {
            $this->_topLevelId = null;
            $this->_topLevelValue = null;
        }

        return Engine_Api::_()->fields()->getFieldsStructureFull($this->getItem(), $this->_topLevelId, $this->_topLevelValue);
    }

    // Main
    public function getProfileTypesBasedFieldStructure($spec, $profile_ids) {
        $fieldApi = Engine_Api::_()->fields();
        $type = $fieldApi->getFieldType($spec);
        $structure = array();
        foreach ($fieldApi->getFieldsMaps($type)->getRowsMatching('field_id', (int) $this->_topLevelId) as $map) {
            // Get child field
            $field = $fieldApi->getFieldsMeta($type)->getRowMatching('field_id', $map->child_id);
            if (empty($field)) {
                continue;
            }
            // Add to structure
            $structure[$map->getKey()] = $map;

            // Get children
            if ($field->canHaveDependents()) {
                foreach ($profile_ids as $profile_id) {
                    $structure +=$fieldApi->getFieldsStructureFull($spec, $map->child_id, $profile_id);
                }
            }
        }

        return $structure;
    }

    public function _setFieldValues($values) {
        // Iterate over elements and apply the values
        foreach ($this->getElements() as $key => $element) {
            if (count(explode('_', $key)) == 3) {
                list($parent_id, $option_id, $field_id) = explode('_', $key);
                if (isset($values[$field_id])) {
                    $element->setValue($values[$field_id]);
                }
            }
        }
    }

    /* Validate the values uploaded in the csv file */

    public function isValidStatic($data) {
        if (!is_array($data)) {
            throw new Zend_Form_Exception(__METHOD__ . ' expects an array');
        }
        $translator = $this->getTranslator();
        $valid = true;
        $eBelongTo = null;

        if ($this->isArray()) {
            $eBelongTo = $this->getElementsBelongTo();
            $data = $this->_dissolveArrayValue($data, $eBelongTo);
        }
        $context = $data;
        foreach ($this->getElements() as $key => $element) {


            if (!preg_match('/[^0-9_]/', $key)) {
                continue;
            } else if ($this->_controllerName == 'bulkInsertionAction' && $key == 'documentthumbnail') {
                $settings = Engine_Api::_()->getApi('settings', 'core');
                if (!$settings->getSetting('document.thumbnail', 0)) {
                    $data['documentthumbnail'] = '';
                }
                if ($this::$getProfilePhoto == true && $data['documentthumbnail'] != null || $data['documentthumbnail'] != '') {
                    $archiveProfilePhoto = APPLICATION_PATH . "/public/document" . DIRECTORY_SEPARATOR . "fileimport_" . $this::$getFileId . DIRECTORY_SEPARATOR . "documentthumbnail/";
                    $getSubDirInfo = scandir($archiveProfilePhoto);

                    foreach ($getSubDirInfo as $dirKey => $subDir) {
                        if ($subDir === '.' or $subDir === '..')
                            continue;

                        if (is_dir($archiveProfilePhoto . $subDir)) {
                            $getExtractFileName = $archiveProfilePhoto . $subDir;
                            break;
                        }
                    }
                    if (!file_exists($getExtractFileName)) {
                        $this->documentthumbnail->addErrorMessage('No photo Zip file has been uploaded. Leave image textbox area empty or upload the Zip file of photos. ');
                        $valid = false;
                        continue;
                    }
                    $getExtractFileName = $getExtractFileName . '/' . $data['documentthumbnail'];

                    if (preg_match('/.jpg$|.png$|.gif$|.jpeg$|.JPG$|.PNG$|.GIF$|.JPEG$/', $data['documentthumbnail'])) {
                        if (file_exists($getExtractFileName)) {
                            $valid = true;
                        } else {
                            $valid = false;
                            $this->documentthumbnail->addErrorMessage('Profile photo with this name is not available');
                        }
                    } else {
                        $valid = false;
                        $this->documentthumbnail->addErrorMessage('Extension of Profile photo is invalid.');
                    }
                } else {
                    $valid = true;
                }
                continue;
            } else if ($this->_controllerName == 'bulkInsertionAction' && $key == 'filename') {
                if ($this::$getFilename == true && $data['filename'] == null || $data['filename'] == '') {
                    $this->filename->addErrorMessage('No document file has been uploaded.Upload the file of document to be uploaded.');
                    $valid = false;
                } else {

                    $archiveFilename = APPLICATION_PATH . "/public/document" . DIRECTORY_SEPARATOR . "fileimport_" . $this::$getFileId . DIRECTORY_SEPARATOR . "documentfilename/";
                    $getSubDirInfo = scandir($archiveFilename);

                    foreach ($getSubDirInfo as $dirKey => $subDir) {
                        if ($subDir === '.' or $subDir === '..')
                            continue;

                        if (is_dir($archiveFilename . $subDir)) {
                            $getExtractFileName = $archiveFilename . $subDir;

                            break;
                        }
                    }

                    if (!file_exists($getExtractFileName)) {
                        $valid = false;
                        $this->filename->addErrorMessage('No File has been uploaded.Upload the file of document.');
                        continue;
                    }
                    $getExtractFileName = $getExtractFileName . '/' . $data['filename'];
                    $extension = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.extension.type', 'pdf, txt, ps, rtf, epub, odt, odp, ods, odg, odf, sxw, sxc, sxi, sxd, doc, ppt, pps, xls, docx, pptx, ppsx, xlsx, tif, tiff, jpg,jpeg,png,gif');
                }
                continue;
            }
            if (null !== $translator && $this->hasTranslator() && !$element->hasTranslator()) {
                $element->setTranslator($translator);
            }
            $check = $data;
            if (($belongsTo = $element->getBelongsTo()) !== $eBelongTo) {
                $check = $this->_dissolveArrayValue($data, $belongsTo);
            }
            if (!isset($check[$key])) {
                $valid = $element->isValid(null, $context) && $valid;
            } else {

                $valid = $element->isValid($check[$key], $context) && $valid;
                $data = $this->_dissolveArrayUnsetKey($data, $belongsTo, $key);
            }
        }
        foreach ($this->getSubForms() as $key => $form) {
            if (null !== $translator && $this->hasTranslator() && !$form->hasTranslator()) {
                $form->setTranslator($translator);
            }
            if (isset($data[$key]) && !$form->isArray()) {
                $valid = $form->isValid($data[$key]) && $valid;
            } else {
                $valid = $form->isValid($data) && $valid;
            }
        }

        $this->_errorsExist = !$valid;

        // If manually flagged as an error, return invalid status
        if ($this->_errorsForced) {
            return false;
        }

        return $valid;
    }

    public function isValid($data) {

        $isValid = $this->isValidStatic($data, $controllerName);

        if (!is_array($data)) {
            require_once 'Zend/Form/Exception.php';
            throw new Zend_Form_Exception(__CLASS__ . '::' . __METHOD__ . ' expects an array');
        }
        $translator = $this->getTranslator();
        $valid = true;

        if ($this->isArray()) {
            $data = $this->_dissolveArrayValue($data, $this->getElementsBelongTo());
        }

        // Changing this part
        $structure = $this->getFieldStructure();
        $selected = array();
        if (!empty($this->_topLevelId))
            $selected[$this->_topLevelId] = $this->_topLevelValue;

        foreach ($this->getElements() as $key => $element) {
            $element->setTranslator($translator);

            $parts = explode('_', $key);


            if (preg_match('/[^0-9_]/', $key)) {
                continue;
            }

            list($parent_id, $option_id, $field_id) = $parts;

            $fieldObject = $structure[$key];

            // All top level fields are always shown
            if (!empty($parent_id)) {

                $parent_field_id = $parent_id;
                $option_id = $option_id;

                if (isset($selected[$field_id]) || empty($selected[$parent_field_id])) {
                    $element->setIgnore(true);
                    continue;
                }

                // Parent option doesn't match
                if (is_scalar($selected[$parent_field_id]) && $selected[$parent_field_id] != $option_id) {
                    $element->setIgnore(true);
                    continue;
                } else if (is_array($selected[$parent_field_id]) && !in_array($option_id, $selected[$parent_field_id])) {
                    $element->setIgnore(true);
                    continue;
                }
            }

            // This field is being used
            if (isset($data[$key])) {
                $selected[$field_id] = $data[$key];
            }

            if ($element instanceof Engine_Form_Element_Heading) {
                $element->setIgnore(true);
            } else if (!isset($data[$key])) {
                $valid = $element->isValid(null, $data) && $valid;
            } else {
                $valid = $element->isValid($data[$key], $data) && $valid;
            }
        }
        $this->_processedValues = $selected;

        foreach ($this->getSubForms() as $key => $form) {
            $form->setTranslator($translator);
            if (isset($data[$key])) {
                $valid = $form->isValid($data[$key]) && $valid;
            } else {
                $valid = $form->isValid($data) && $valid;
            }
        }

        $this->_errorsExist = !$valid;
        return ($valid && $isValid);
    }

}
