<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Form_Admin_Import extends Engine_Form {

    public function init() {

        $this->setTitle('Upload a CSV File')
                ->setDescription("Add a CSV file to import Documents’ details corresponding to the entries in it, and then click on ‘Submit’ button. [Note: Choose the correct ‘Profile Type’ for which you are importing Documents’ details through CSV file.]")
                ->setAttrib('enctype', 'multipart/form-data')
                ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()));


        // Element: profile_type
        $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('document');
        if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
            $profileTypeField = $topStructure[0]->getChild();
            $options = $profileTypeField->getOptions();

            if (count($options) > 0) {
                $options = $profileTypeField->getElementParams('document');
                unset($options['options']['required']);
                unset($options['options']['allowEmpty']);
                unset($options['options']['order']);
                $options['options']['multiOptions'][''] = 'All (Excluding Profile Fields)';
                $this->addElement('Select', 'profile_type', array_merge($options['options'], array(
                    'tabindex' => 1, //$tabIndex++,
                    'value' => $this->_profileType,
                     'label' => 'Document Profile Type',
                    'onchange' => 'showHint(this.value)',
                )));
            } else if (count($options) == 0) {
                $this->addElement('Hidden', 'profile_type', array(
                    'order' => 999,
                    'value' => ''
                ));
            }
        }

        $this->addElement('File', 'filename', array(
            'label' => 'Import File',
            'required' => true,
        ));
        $this->filename->addValidator('Extension', false, 'csv,CSV');
        $this->filename->getDecorator('Description')->setOption('placement', 'append');

        $this->addElement('Radio', 'import_seperate', array(
            'label' => 'File Columns Separator',
            'description' => 'Select a separator from below which you are using for the columns of the CSV file.',
            'required' => true,
            'allowEmpty' => false,
            'multiOptions' => array(
                1 => "Pipe ('|')",
                0 => "Comma (',')"
            ),
        ));
        $this->import_seperate->getDecorator('Description')->setOptions(array('style' => 'color:#000 !important;margin-top:42px'));

        $this->addElement('Button', 'submit', array(
            'label' => 'Submit',
            'type' => 'submit',
            'onclick' => "javascript:showLightbox()",
            'decorators' => array(
                'ViewHelper',
            ),
        ));

        $this->addElement('Cancel', 'cancel', array(
            'label' => 'cancel',
            'link' => true,
            'prependText' => ' or ',
            'onclick' => "javascript:parent.Smoothbox.close()",
            'decorators' => array(
                'ViewHelper',
            ),
        ));

        $this->addDisplayGroup(array(
            'submit',
            'cancel',
                ), 'buttons', array(
            'decorators' => array(
                'FormElements',
                'DivDivDivWrapper'
            ),
        ));
    }

}
