<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 6590 2016-07-12 9:40:21Z SocialApps.tech $
 * @author     SocialApps.tech
 */
class Document_Form_Admin_Settings_Global extends Engine_Form {

    // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
    public $_SHOWELEMENTSBEFOREACTIVATE = array(
        "submit_lsetting", "environment_mode", "document_google_email", "document_client_id", "document_service_account_name", "document_private_key_url_path", "document_google_client_id", "document_google_client_secret_key"
    );

    public function init() {
        $settings = Engine_Api::_()->getApi('settings', 'core');
        $isDocumentActivate = $settings->getSetting('document.isActivate', 0);
        if (!empty($isDocumentActivate))
            $this->_SHOWELEMENTSBEFOREACTIVATE = array("submit_lsetting", "environment_mode");

        $this
                ->setTitle('Global Settings')
                ->setDescription('These settings affect all members in your community.');

        $document_lsettings = $settings->getSetting('document.lsettings');
        if (!empty($document_lsettings)) {
            $settings->setSetting('document.controllersettings', $document_lsettings);
        }

        $this->addElement('Text', 'document_lsettings', array(
            'label' => 'Enter License key',
            'required' => true,
            'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
            'value' => $settings->getSetting('document.lsettings'),
        ));

        if (Engine_Api::_()->hasModuleBootstrap('documentintegration')) {
            $this->addElement('Text', 'documentintegration_lsettings', array(
                'label' => 'Enter License key For Documents Extension',
                'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
                'value' => $settings->getSetting('documentintegration.lsettings'),
            ));
        }

        $this->addElement('Text', 'document_google_email', array(
            'label' => 'Google Email',
            'required' => true,
            'description' => 'Please enter your Google email id for the Google drive which you want to use for Documents. [ To know how to generate and configure this, please refer this faq: <a href="admin/document/settings/faq/show/1" target="_blank">faq</a> ]',
            'value' => $settings->getSetting('document.google.email', ''),
        ));

        $this->document_google_email->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

        $document_hide_old_fields = $settings->getSetting('document.hide.old.fields', 0);
        
        if (!$document_hide_old_fields ) {
            $this->addElement('Text', 'document_client_id', array(
                'label' => 'Old Client ID',
                'required' => true,
                'description' => 'Please enter your Client ID. [ To know how to generate and configure this, please refer this faq: <a href="admin/document/settings/faq/show/1" target="_blank">faq</a> ]',
                'value' => $settings->getSetting('document.client.id', ''),
            ));

            $this->document_client_id->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

            $this->addElement('Text', 'document_service_account_name', array(
                'label' => 'Service Account Name',
                'required' => true,
                'description' => 'Please enter you Google Service Account Name. [ To know how to generate and configure this, please refer this faq: <a href="admin/document/settings/faq/show/1" target="_blank">faq</a> ]',
                'value' => $settings->getSetting('document.service.account.name', ''),
            ));

            $this->document_service_account_name->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

            $this->addElement('Text', 'document_private_key_url_path', array(
                'label' => 'Private Key URL Path',
                'required' => true,
                'description' => 'Please enter the Private key URL path for .p12 file. [ Once you have generated your .p12 file for your Google Drive API, you can upload .p12 file through the <a href="admin/files" target="_blank">File & Media Manager</a> section of your website, copy the URL of uploaded .p12 file and enter in this field. To know how to generate this .p12 file please refer this <a href="admin/document/settings/faq/show/1" target="_blank">faq</a>. ]',
                'value' => $settings->getSetting('document.private.key.url.path', ''),
            ));

            $this->document_private_key_url_path->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));
        }

        $this->addElement('Text', 'document_google_client_id', array(
            'label' => 'Client ID',
            'required' => true,
            'description' => 'Please enter your Client ID. [ To know how to generate and configure this, please refer this faq: <a href="admin/document/settings/faq/show/1" target="_blank">faq</a> ]',
            'value' => $settings->getSetting('document.google.client.id', ''),
        ));

        $this->document_google_client_id->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));


        $this->addElement('Text', 'document_google_client_secret_key', array(
            'label' => 'Client Secret Key',
            'required' => true,
            'description' => 'Please enter your Client Secret Key. [ To know how to generate and configure this, please refer this faq: <a href="admin/document/settings/faq/show/1" target="_blank">faq</a> ]',
            'value' => $settings->getSetting('document.google.client.secret.key', ''),
        ));

        $this->document_google_client_secret_key->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));


//        $this->addElement('Text', 'document_google_client_redirect_url', array(
//            'label' => 'Redirect URL',
//            'required' => true,
//            'description' => 'Please enter redirect URL. [ To know how to generate and configure this, please refer this faq: <a href="admin/document/settings/faq/show/1" target="_blank">faq</a> ]',
//            'value' => $settings->getSetting('document.google.client.redirect.url', ''),
//        ));
        //  $this->document_google_client_redirect_url->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));



        if (APPLICATION_ENV == 'production') {
            $this->addElement('Checkbox', 'environment_mode', array(
                'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few documents of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
                'description' => 'System Mode',
                'value' => 1,
            ));
        } else {
            $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
        }

        $this->addElement('Button', 'submit_lsetting', array(
            'label' => 'Activate Your Plugin Now',
            'type' => 'submit',
            'ignore' => true
        ));

        $this->addElement('Radio', 'document_email_notifications', array(
            'label' => 'Email Notifications while new document uploaded',
            'description' => "Do you want to email nofications when any user upload any new document?",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.email.notifications', 1),
        ));

        $this->addElement('Radio', 'document_network', array(
            'label' => 'Browse by Networks',
            'description' => "Do you want to show documents according to viewer's network if he has selected any? (If set to no, all the documents will be shown.)",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'onclick' => 'showDefaultNetwork(this.value)',
            'value' => $settings->getSetting('document.network', 0),
        ));

        $this->addElement('Radio', 'document_default_show', array(
            'label' => 'Set Only My Networks as Default in search',
            'description' => 'Do you want to set "Only My Networks" option as default for Show field in the search form widget? (This widget appears on the documents browse and home documents, and enables users to search and filter documents.)',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'onclick' => 'showDefaultNetworkType(this.value)',
            'value' => $settings->getSetting('document.default.show', 0),
        ));

        $this->addElement('Radio', 'document_networks_type', array(
            'label' => 'Network selection for Documents',
            'description' => "You have chosen that viewers should only see Documents of their network(s). How should a Document's network(s) be decided?",
            'multiOptions' => array(
                0 => "Document Owner's network(s) [If selected, only members belonging to document owner's network(s) will see the Documents.]",
                1 => "Selected Networks [If selected, document owner will be able to choose the networks of which members will be able to see their Document.]"
            ),
            'value' => $settings->getSetting('document.networks.type', 0),
        ));

        $this->addElement('Radio', 'document_networkprofile_privacy', array(
            'label' => 'Display Profile Document only to Network Users',
            'description' => "Do you want to show the Document Profile document only to users of the same network. (If set to yes and \"Browse By Networks\" is enabled then users would not be able to view the profile document of those documents which does not belong to their networks.)",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('document.networkprofile.privacy', 0),
        ));

        $this->addElement('Radio', 'document_privacybase', array(
            'label' => 'Displays All Documents in Widgets',
            'description' => "Do you want to show all the documents to the users in the Widgets and Browse Documents of this plugin irrespective of privacy? [Note: If you select 'No', then only those documents will be shown in the Widgets and Browse Documents which are viewable to the current logged-in users. But this may slightly affect the loading speed of your website. To avoid such loading delay to the best possible extent, we are also using caching based display.)",
            'multiOptions' => array(
                0 => 'Yes',
                1 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('document.privacybase', 0),
        ));


        $this->addElement('Radio', 'document_show_editor', array(
            'label' => 'WYSIWYG Editor',
            'description' => 'Allow WYSIWYG editor for description of documents.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.show.editor', 1),
        ));

        $this->addElement('Radio', 'document_rating', array(
            'label' => 'Document Rating',
            'description' => 'Allow logged-in users to rate documents.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.rating', 1),
        ));

        $this->addElement('Radio', 'document_report', array(
            'label' => 'Report as inappropriate',
            'description' => 'Allow logged-in users to report documents as inappropriate.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.report', 1),
        ));

        $this->addElement('Radio', 'document_share', array(
            'label' => 'Document Sharing',
            'description' => 'Allow logged-in users to share documents within the site.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.share', 1),
        ));

        $this->addElement('Radio', 'document_button_share', array(
            'label' => 'Social Sharing Buttons',
            'description' => 'Do you want to show social sharing buttons on the main document document ?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.button.share', 1),
        ));

        $this->addElement('Radio', 'document_categorywithslug', array(
            'label' => 'Slug URL',
            'description' => "Do you want to replace blank-space in your category name by '-' in URL?",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $settings->getSetting('document.categorywithslug', 1),
        ));

//        $this->addElement('Radio', 'document_thumbs', array(
//            'label' => "Document Thumbnails",
//            'description' => "Do you want to save the thumbnails of documents on your site's server? (Note: If enabled, this setting will import the thumbnails of existing documents on site from Google Drive, when the documents are viewed. Changing this to 'No' will not affect those documents for which thumbnails are already on site's server.)",
//            'multiOptions' => array(
//                0 => "No, the source of thumbnail images will be at Google Drive.",
//                1 => "Yes, save the document thumbnail images on the site's server."
//            ),
//            'value' => $settings->getSetting('document.thumbs', 0),
//        ));

        $this->addElement('Radio', 'document_thumbnail', array(
            'label' => "Document Thumbnails",
            'description' => "Do you want to allow user to upload the document thumbnail? [Note: If you select 'no' then Google Drive thumbnail will be uploaded for the respective document.]",
            'multiOptions' => array(
                1 => "Yes",
                0 => "No"
            ),
            'value' => $settings->getSetting('document.thumbnail', 0),
        ));

        $this->addElement('Radio', 'document_uploaded_extension', array(
            'label' => "Document Extension",
            'description' => "Do you want to allow user to upload a document with any extension?",
            'multiOptions' => array(
                1 => "Yes, allow document with any extension.",
                0 => "No, limited number of extension."
            ),
            'value' => $settings->getSetting('document.uploaded.extension', 0),
            'onclick' => 'showDocumentExtension(this.value);'
        ));

        $this->addElement('Radio', 'document_circular_image', array(
            'label' => 'Member\'s Thumbnail Images in Circular',
            'description' => 'Do you want to display member\'s thumbnail images in circular shape ?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('document.circular.image', 1),
        ));

        $filter = new Engine_Filter_Html();
        $this->addElement('textarea', 'document_extension_type', array(
            'label' => 'Document Extension Type',
            'description' => 'Please enter the documents extension which you want to allow while uploading the documents.',
            'attribs' => array('rows' => 24, 'cols' => 80, 'style' => 'width:300px; max-width:553px;height:120px;'),
            'filters' => array(
                $filter,
                new Engine_Filter_Censor(),
            ),
            'value' => $settings->getSetting('document.extension.type', 'pdf, txt, ps, rtf, epub, odt, odp, ods, odg, odf, sxw, sxc, sxi, sxd, doc, ppt, pps, xls, docx, pptx, ppsx, xlsx, tif, tiff, jpg, jpeg, png, gif, mp4, mov'),
        ));
        $this->addElement('Text', 'language_phrases_document', array(
            'label' => 'Singular Document Title',
            'description' => 'Please enter the Singular Title for document. This text will come in places like feeds generated, widgets etc.',
            'allowEmpty' => FALSE,
            'validators' => array(
                array('NotEmpty', true),
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting("language.phrases.document", "document"),
        ));

        $this->addElement('Text', 'language_phrases_documents', array(
            'label' => 'Plural Document Title',
            'description' => 'Please enter the Plural Title for documents. This text will come in places like Main Navigation Menu, Document Navigation Menu, widgets etc.',
            'allowEmpty' => FALSE,
            'validators' => array(
                array('NotEmpty', true),
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting("language.phrases.documents", "documents"),
        ));
        $this->addElement('Text', 'document_manifestUrlP', array(
            'label' => "Document documents URL alternate text for 'documents'",
            'allowEmpty' => false,
            'required' => true,
            'description' => "Please enter the text below which you want to display in place of 'documents' in the URLs of this plugin.",
            'value' => $settings->getSetting('document.manifestUrlP', "documents"),
        ));

        $this->addElement('Text', 'document_manifestUrlS', array(
            'label' => "Documents documents URL alternate text for 'document'",
            'allowEmpty' => false,
            'required' => true,
            'description' => "Please enter the text below which you want to display in place of 'document' in the URLs of this plugin.",
            'value' => $settings->getSetting('document.manifestUrlS', "document"),
        ));

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $field = 'document_code_share';
        $this->addElement('Dummy', "$field", array(
            'label' => 'Social Share Widget Code',
            'description' => "<a class='smoothbox' href='" . $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'social-share', 'field' => "$field"), 'admin_default', true) . "'>Click here</a> to add your social share code.",
            'ignore' => true,
        ));
        $this->$field->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}
