<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Level.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Form_Admin_Settings_Level extends Authorization_Form_Admin_Level_Abstract {

    public function init() {
        parent::init();

        $this
                ->setTitle('Member Level Settings')
                ->setDescription("These settings are applied on a per member level basis. Start by selecting the member level you want to modify, then adjust the settings for that level below.");

        $this->addElement('Radio', 'view', array(
            'label' => 'Allow Viewing of Documents?',
            'description' => 'Do you want to let members view documents? If set to no, some other settings on this page may not apply.',
            'multiOptions' => array(
                2 => 'Yes, allow viewing of all documents, even private ones.',
                1 => 'Yes, allow viewing of documents.',
                0 => 'No, do not allow documents to be viewed.',
            ),
            'value' => ( $this->isModerator() ? 2 : 1 ),
        ));

        if (!$this->isModerator()) {
            unset($this->view->options[2]);
        }

        if (!$this->isPublic()) {
            $this->addElement('Radio', 'create', array(
                'label' => 'Allow Creation of Documents?',
                'description' => 'Do you want to let members create documents? If set to no, some other settings on this page may not apply. This is useful if you want members to be able to view documents, but only want certain levels to be able to create documents.',
                'multiOptions' => array(
                    1 => 'Yes, allow creation of documents.',
                    0 => 'No, do not allow documents to be created.'
                ),
                'value' => 1,
            ));

            $this->addElement('Radio', 'edit', array(
                'label' => 'Allow Editing of Documents?',
                'description' => 'Do you want to let members edit documents? If set to no, some other settings on this page may not apply.',
                'multiOptions' => array(
                    2 => 'Yes, allow members to edit all documents.',
                    1 => 'Yes, allow members to edit their own documents.',
                    0 => 'No, do not allow members to edit their documents.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if (!$this->isModerator()) {
                unset($this->edit->options[2]);
            }

            $this->addElement('Radio', 'delete', array(
                'label' => 'Allow Deletion of Documents?',
                'description' => 'Do you want to let members delete documents? If set to no, some other settings on this page may not apply.',
                'multiOptions' => array(
                    2 => 'Yes, allow members to delete all documents.',
                    1 => 'Yes, allow members to delete their own documents.',
                    0 => 'No, do not allow members to delete their documents.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if (!$this->isModerator()) {
                unset($this->delete->options[2]);
            }

            $this->addElement('Radio', 'approved', array(
                'label' => 'Documents Approval Moderation',
                'description' => 'Do you want new documents to be automatically approved?',
                'multiOptions' => array(
                    1 => 'Yes, automatically approve documents.',
                    0 => 'No, site admin approval will be required for all documents.'
                ),
                'value' => 1,
            ));

            $this->addElement('Radio', 'featured', array(
                'label' => 'Documents Featured Moderation',
                'description' => 'Do you want new documents to be automatically made as Featured?',
                'multiOptions' => array(
                    1 => 'Yes, automatically make new documents as featured.',
                    0 => 'No, site admin will make documents as featured.'
                ),
                'value' => 0,
            ));

            $this->addElement('Radio', 'sponsored', array(
                'label' => 'Documents Sponsored Moderation',
                'description' => 'Do you want new documents to be automatically made sponsored?',
                'multiOptions' => array(
                    1 => 'Yes, automatically make documents sponsored.',
                    0 => 'No, site admin will be making documents sponsored.'
                ),
                'value' => 0,
            ));

            $this->addElement('Radio', 'profile_doc', array(
                'label' => 'Allow Profile Document',
                'description' => "Do you want to let members of this level to make their documents as Profile Document?",
                'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
                ),
                'value' => 1,
            ));

            $this->addElement('Radio', 'profile_doc_show', array(
                'label' => 'Make Profile Document during Creation',
                'description' => "Do you want users to be able to make Profile Document while creation of the document?",
                'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
                ),
                'value' => 1,
            ));

            $this->addElement('Radio', 'comment', array(
                'label' => 'Allow Commenting on Documents?',
                'description' => 'Do you want to let members of this level to comment on documents?',
                'multiOptions' => array(
                    1 => 'Yes, allow members to comment on documents.',
                    0 => 'No, do not allow members to comment on documents.',
                ),
                'value' => 1,
            ));

            $availableLabels = array(
                'everyone' => 'Everyone',
                'registered' => 'All Registered Members',
                'owner_network' => 'Friends and Networks',
                'owner_member_member' => 'Friends of Friends',
                'owner_member' => 'Friends Only',
                'parent_member' => "Parent Member (Members / Guests of 'Directory / Pages' or  'Directory / Businesses' or 'Groups / Communities' or 'Advanced Events' plugin) Only",
                'owner' => 'Just Me'
            );
            $roles = array('everyone', 'registered', 'owner_network', 'owner_member_member', 'owner_member', 'parent_member', 'leaderowner');

            if ((Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "sitepage_page", 'item_module' => 'sitepage')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepagemember')) 
                || (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "sitebusiness_business", 'item_module' => 'sitebusiness')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember')) 
                || (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "sitegroup_group", 'item_module' => 'sitegroup')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroupmember'))
                || (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "siteevent_event", 'item_module' => 'siteevent')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent'))) {
                //No need to do anything
            } else {
                unset($availableLabels['parent_member']);
            }

            // Element: auth_view
            $this->addElement('MultiCheckbox', 'auth_view', array(
                'label' => 'Document View Privacy',
                'description' => 'Your members can choose from any of the options checked below when they decide who can see their document entries. (Note: If you do not check any options, everyone will be allowed to view documents.)',
                'multiOptions' => $availableLabels,
                'value' => $roles,
            ));

            $availableLabels = array( 
                'registered' => 'All Registered Members',
                'owner_network' => 'Friends and Networks',
                'owner_member_member' => 'Friends of Friends',
                'owner_member' => 'Friends Only',
                'parent_member' => "Parent Member (Members / Guests of 'Directory / Pages' or  'Directory / Businesses' or 'Groups / Communities' or 'Advanced Events' plugin) Only",
                'owner' => 'Just Me'
            );
            $roles = array('registered', 'owner_network', 'owner_member_member', 'owner_member', 'parent_member', 'owner');

            if ((Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "sitepage_page", 'item_module' => 'sitepage')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepagemember')) 
                || (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "sitebusiness_business", 'item_module' => 'sitebusiness')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember')) 
                || (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "sitegroup_group", 'item_module' => 'sitegroup')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroupmember'))
                || (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => "siteevent_event", 'item_module' => 'siteevent')) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent'))) {
                //No need to do anything
            } else {
                unset($availableLabels['parent_member']);
            }  

            // Element: auth_view
            $this->addElement('MultiCheckbox', 'auth_comment', array(
                'label' => 'Document Comment Options',
                'description' => 'Your members can choose from any of the options checked below when they decide who can post comments on their entries. If you do not check any options, everyone will be allowed to post comments on entries.',
                'multiOptions' => $availableLabels,
                'value' => $roles,
            ));

            $this->addElement('Text', 'entries', array(
                'label' => 'Maximum allowed documents',
                'description' => 'Enter the maximum number of documents allowed to be posted. This field must contain an integer, use zero for unlimited documents.',
                'value' => '0'
            ));

            $filesize = (int) ini_get('upload_max_filesize') * 1024;
            $description = Zend_Registry::get('Zend_Translate')->_('Enter the maximum document file size limit in KB to be allowed for this user level. (Valid values are from 1 to %s KB.)');
            $description = sprintf($description, $filesize);
            $this->addElement('Text', 'filesize', array(
                'label' => 'Maximum file size',
                'description' => $description,
                'value' => $filesize
            ));
        }

        $this->addElement('Radio', 'view_download', array(
            'label' => 'Document downloading (Viewer)',
            'description' => 'Do you want members to be able to download the documents posted by the members of this level?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => !$this->isPublic() ? 1 : 0,
        ));

        if (!$this->isPublic()) {
            if ($visibility != 'public' || !empty($option_show)) {
                $this->addElement('Radio', 'download_allow', array(
                    'label' => 'Document downloading (Creator)',
                    'description' => 'Do you want document creator to be able to download the document posted by him?',
                    'multiOptions' => array(
                        1 => 'Yes',
                        0 => 'No'
                    ),
                    'value' => 1,
                ));

                $this->addElement('Radio', 'download_show', array(
                    'description' => "Show ‘Allow Document Download’ option during document creation to give permission to download the document to other members. (Note : If enabled, this option will only be visible on ‘Upload New Document’ page but not on ‘Edit Document’ page.)",
                    'multiOptions' => array(
                        1 => 'Yes',
                        0 => 'No'
                    ),
                    'value' => 1,
                ));
            }
        }

        if (!$this->isPublic()) {

            $this->addElement('Radio', 'view_email', array(
                'label' => 'Email attachment Settings (Viewer)',
                'description' => 'Do you want members to be able to email the document as attachment posted by the members of this level?',
                'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
                ),
                'value' => 1,
            ));

            if ($visibility != 'public' || !empty($option_show)) {

                $this->addElement('Radio', 'email_allow', array(
                    'label' => 'Email attachment Settings (Creator)',
                    'description' => 'Do you want document creator to be able to email his own document as attachment?',
                    'multiOptions' => array(
                        1 => 'Yes',
                        0 => 'No'
                    ),
                    'value' => 1,
                ));

                $this->addElement('Radio', 'email_show', array(
                    'description' => 'Show ‘Allow Email Attachment’ option during document creation to give permission to email the document as attachment to other members. (Note : If enabled, this option will only be visible on ‘Upload New Document’ page but not on ‘Edit Document’ page.)',
                    'multiOptions' => array(
                        1 => 'Yes',
                        0 => 'No'
                    ),
                    'value' => 1,
                ));
            } else {
                $this->addElement('Dummy', 'visibility_hide_options', array(
                    'description' => "Some settings for downloading and emailing as attachments of documents are enableded by default as you have chosen public visibility for documents in 'Global Settings'.",
                ));
            }
        }
    }

}
