<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Profilemaps.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Model_DbTable_Profilemaps extends Engine_Db_Table {

    protected $_rowClass = "Document_Model_Profilemap";

    /**
     * Get Mapping array
     *
     */
    public function getMapping($profileTypeName = 'profile_type') {

        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), array('category_id', "$profileTypeName"));
        //FETCH DATA
        $mapping = $this->fetchAll($select);

        //RETURN DATA
        if (!empty($mapping)) {
            return $mapping->toArray();
        }

        return null;
    }

    /**
     * Get profile_type corresponding to category_id
     *
     * @param int category_id
     */
    public function getProfileType($category_id) {

        //FETCH DATA
        $profile_type = $this->select()
                ->from($this->info('name'), array('profile_type'))
                ->where('category_id = ?', $category_id)
                ->query()
                ->fetchColumn();

        //RETURN DATA
        if (!empty($profile_type)) {
            return $profile_type;
        }

        return 0;
    }

    /**
     * If category is edit then do mapping work
     *
     * @param object document
     */
    public function editCategoryMapping($document) {

        $document_id = $document->document_id;
        $select = $this->select()->from($this->info('name'), array('profile_type'))->where('category_id = ?', $document->category_id)->limit(1);
        $resultMaps = $this->fetchAll($select)->toArray();

        //CHECK THAT PREVIOUS PROFILE TYPE IS DIFFERENT OR SAME
        if (!empty($resultMaps) && !empty($resultMaps[0]['profile_type']) && $resultMaps[0]['profile_type'] != $document->profile_type) {

            //IF PROFILE TYPE IS DIFFERENT THAN FIRST DELETE ENTRIES RELEATED TO PREVIOUS TYPE FROM FIELD TABLE
            $fieldvalueTable = Engine_Api::_()->fields()->getTable('document', 'values');
            $fieldvalueTable->delete(array(
                'item_id = ?' => $document_id,
            ));

            $fieldsearchTable = Engine_Api::_()->fields()->getTable('document', 'search');
            $fieldsearchTable->delete(array(
                'item_id = ?' => $document_id,
            ));

            //PUT NEW PROFILE TYPE
            $fieldvalueTable->insert(array(
                'item_id' => $document_id,
                'field_id' => 1,
                'index' => 0,
                'value' => $resultMaps[0]['profile_type'],
            ));

            $document->profile_type = $resultMaps[0]['profile_type'];
            $document->save();
        } elseif (empty($resultMaps)) { //IF NEW ASSIGNED CATEGORY IS NOT MAPPED WITH ANY PROFILE TYPE
            $fieldvalueTable = Engine_Api::_()->fields()->getTable('document', 'values');
            $fieldvalueTable->delete(array(
                'item_id = ?' => $document_id,
            ));

            $fieldsearchTable = Engine_Api::_()->fields()->getTable('document', 'search');
            $fieldsearchTable->delete(array(
                'item_id = ?' => $document_id,
            ));

            //PUT NEW PROFILE TYPE
            $fieldvalueTable->insert(array(
                'item_id' => $document_id,
                'field_id' => 1,
                'index' => 0,
                'value' => 0,
            ));

            $document->profile_type = 0;
            $document->save();
        }
    }

//    /**
//     * Mapping work at page creation and edition
//     *
//     * @param object document
//     */
//    public function profileMapping($document) {
//        $select = $this->select()->from($this->info('name'), array('profile_type'))->where('category_id = ?', $document->category_id)->limit(1);
//        $result = $this->fetchAll($select)->toArray();
//        if (!empty($result)) {
//            if (!empty($result[0]['profile_type'])) {
//                $fieldvalueTable = Engine_Api::_()->fields()->getTable('document', 'values');
//                $fieldvalueTable->insert(array(
//                    'item_id' => $document->document_id,
//                    'field_id' => 1,
//                    'index' => 0,
//                    'value' => $result[0]['profile_type'],
//                ));
//            }
//
//            $document->profile_type = $result[0]['profile_type'];
//            $document->save();
//        }
//    }
}
