<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Plugin_Core extends Zend_Controller_Plugin_Abstract {

    //MOBILE PAGES WORK
    public function routeShutdown(Zend_Controller_Request_Abstract $request) {

        //IF MOBILE MODULE IS NOT ENABLED THEN RETURN
        if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('mobi'))
            return;

        //CHECK IF ADMIN
        if (substr($request->getPathInfo(), 1, 5) == "admin") {
            return;
        }

        $mobile = $request->getParam("mobile");
        $session = new Zend_Session_Namespace('mobile');

        if ($mobile == "1") {
            $mobile = true;
            $session->mobile = true;
        } elseif ($mobile == "0") {
            $mobile = false;
            $session->mobile = false;
        } else {
            if (isset($session->mobile)) {
                $mobile = $session->mobile;
            } else {
                //CHECK TO SEE IF MOBILE
                if (Engine_Api::_()->mobi()->isMobile()) {
                    $mobile = true;
                    $session->mobile = true;
                } else {
                    $mobile = false;
                    $session->mobile = false;
                }
            }
        }

        if (!$mobile) {
            return;
        }
        $module = $request->getModuleName();
        $controller = $request->getControllerName();
        $action = $request->getActionName();

        //MOBILE BROWSE DOCUMENT PAGE
        if ($module == "document" && $controller == "index" && $action == "browse") {
            $request->setActionName('mobi-browse');
        }

        //MOBILE DOCUMENT HOME PAGE
        if ($module == "document" && $controller == "index" && $action == "home") {
            $request->setActionName('mobi-home');
        }

        //MOBILE DOCUMENT HOME PAGE
        if ($module == "document" && $controller == "index" && $action == "view") {
            $request->setActionName('mobi-view');
        }

        //CREATE LAYOUT
        $layout = Zend_Layout::startMvc();

        //SET OPTIONS
        $layout->setViewBasePath(APPLICATION_PATH . "/application/modules/Mobi/layouts", 'Core_Layout_View')
                ->setViewSuffix('tpl')
                ->setLayout(null);
    }

    //SHOW DETAILS ON STATISTICS
    public function onStatistics($event) {
        //FETCH NUMBER OF DOCUMENTS
        $total_rows = Engine_Api::_()->getDbTable('documents', 'document')->onStatisticsData();

        if ($total_rows == 1)
            $event->addResponse($total_rows, 'document');
        else
            $event->addResponse($total_rows, 'documents');
    }

    //DELETE USERS BELONGINGS BEFORE THAT USER DELETION
    public function onUserDeleteBefore($event) {
        $payload = $event->getPayload();

        if ($payload instanceof User_Model_User) {

            //FETCH OWNER DOCUMETNS
            $owner_id = $payload->getIdentity();
            $documents = Engine_Api::_()->getDbtable('documents', 'document')->getOwnerDocuments($owner_id);

            foreach ($documents as $document) {

                //DELETE DOCUMENT BELONGINGS
                Engine_Api::_()->document()->deleteContent($document->document_id);
            }
        }
    }

    public function addActivity($event) {
        $front = Zend_Controller_Front::getInstance();
        $module = $front->getRequest()->getModuleName();
        $controller = $front->getRequest()->getControllerName();
        $action = $front->getRequest()->getActionName();

        if ((Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'group', 'item_module' => 'group', 'checked' => 'enabled'))) && ($module == 'group' || $module == 'advgroup') && ($action == 'create' || $action == 'edit') && ($controller == 'index' || $controller == 'group')) {

            //GET GROUP ID
            $payload = $event->getPayload();
            $group_id = $payload['object']->group_id;

            //GET GROUP OBJECT
            $group = Engine_Api::_()->getItem('group', $group_id);

            //PROCESS PRIVACY WORK
            $auth = Engine_Api::_()->authorization()->context;

            $roles = array('officer', 'member', 'registered', 'everyone');

            $gdcreate = array_search($_POST['gdcreate'], $roles);

            $officerList = $group->getOfficerList();

            foreach ($roles as $i => $role) {
                if ($role === 'officer') {
                    $role = $officerList;
                }
                $auth->setAllowed($group, $role, 'gdcreate', ($i <= $gdcreate));
            }
        }


        if ((Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'event', 'item_module' => 'event', 'checked' => 'enabled'))) && ($module == 'event' || $module == 'advevent' || $module == 'ynevent') && ($action == 'create' || $action == 'edit') && ($controller == 'index' || $controller == 'event')) {

            //GET EVENT ID
            $payload = $event->getPayload();
            $event_id = $payload['object']->event_id;

            //GET EVENT OBJECT
            $event = Engine_Api::_()->getItem('event', $event_id);

            //PROCESS PRIVACY WORK
            $auth = Engine_Api::_()->authorization()->context;

            $roles = array('owner', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered');

            $edcreate = array_search($_POST['edcreate'], $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($event, $role, 'edcreate', ($i <= $edcreate));
            }
        }
    }

}
