<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Plugin_Menus {

    //DOCUMENT VIEW PRIVACY CHECK
    public function canViewDocuments() {

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();

        //CHECK DOCUMENT VIEW PRIVACY
        if (!Engine_Api::_()->authorization()->isAllowed('document', $viewer, 'view')) {
            return false;
        }
        return true;
    }

    //DOCUMENT CREATION PRIVACY CHECK
    public function canCreateDocuments() {

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();

        $viewer_id = $viewer->getIdentity();

        if (!$viewer_id)
            return false;

        //CHECK DOCUMENT CREATION PRIVACY
        if (!Engine_Api::_()->authorization()->isAllowed('document', $viewer, 'create')) {
            return false;
        }
        return true;
    }

    //ADD DOCUMENT LISTING LINK
    public function onMenuInitialize_DocumentGutterList() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document') {
            return false;
        }

        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //USER IS ALLOWED TO VIEW OR NOT
        $can_view = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'view');
        if (empty($can_view)) {
            return false;
        }

        $itemTypeValue = $document->parent_type;
        $documentOwnerLeader = 0;
        if (strpos($document->parent_type, "sitereview_listing") !== false) {
            $contentitem = Engine_Api::_()->getItem('sitereview_listing', $document->parent_id);
            $itemTypeValue = $itemTypeValue . $contentitem->listingtype_id;
            $documentOwnerLeader = Engine_Api::_()->getApi('settings', 'core')->getSetting("document.leader.owner.$itemTypeValue", 1);
        } elseif ($itemTypeValue && $itemTypeValue != 'user' && Engine_Api::_()->hasItemType($document->parent_type)) {
            $contentitem = Engine_Api::_()->getItem($document->parent_type, $document->parent_id);
            $documentOwnerLeader = Engine_Api::_()->getApi('settings', 'core')->getSetting("document.leader.owner.$itemTypeValue", 1);
        }
        if (!$documentOwnerLeader)
            $itemTypeValue = 'user';

        if ($itemTypeValue == 'user') {
            //GET OWNER LINKED TITLE
            $owner_title = $document->getOwner()->getTitle();
            return array(
                'class' => 'buttonlink seaocore_icon_document',
                'route' => 'document_list',
                'label' => $owner_title . Zend_Registry::get('Zend_Translate')->_("'s Documents"),
                'params' => array(
                    'user_id' => $document->owner_id,
                ),
            );
        } else {
            //GET OWNER LINKED TITLE
            $owner_title = $contentitem->getTitle();
            return array(
                'class' => 'buttonlink seaocore_icon_document',
                'route' => 'document_list',
                'label' => $owner_title . Zend_Registry::get('Zend_Translate')->_("'s Documents"),
                'params' => array(
                    'user_id' => $document->owner_id,
                    'document_id' => $document->getIdentity()
                ),
            );
        }
    }

    //ADD DOCUMENT PUBLISH LINK
    public function onMenuInitialize_DocumentGutterPublish() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($document->draft) || empty($viewer_id)) {
            return false;
        }

        //USER IS ALLOWED FOR PUBLISH OR NOT
        $can_edit = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'document', 'edit');
        if (empty($can_edit) || ($can_edit == 1 && $viewer_id != $document->owner_id)) {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox icon_document_publish',
            'route' => 'document_publish',
            'params' => array(
                'document_id' => $document->getIdentity(),
            ),
        );
    }

    //ADD DOCUMENT EDIT LINK
    public function onMenuInitialize_DocumentGutterEdit($row) {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($viewer_id)) {
            return false;
        }

        //USER IS ALLOWED FOR EDIT OR NOT
        $can_edit = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'document', 'edit');
        if (empty($can_edit) || ($can_edit == 1 && $viewer_id != $document->owner_id)) {
            return false;
        }

        return array(
            'class' => 'buttonlink seaocore_icon_edit',
            'route' => 'document_edit',
            'params' => array(
                'document_id' => $document->getIdentity(),
            ),
        );
    }

    //ADD DOCUMENT SHARE LINK
    public function onMenuInitialize_DocumentGutterShare() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($viewer_id) || $document->draft == 1 || empty($document->approved) || $document->status != 1) {
            return false;
        }

        //SHARING IS ALLOWED OR NOT
        $can_share = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('document.share', 1);
        if (empty($can_share)) {
            return false;
        }

        return array(
            'class' => 'smoothbox buttonlink seaocore_icon_share',
            'route' => 'default',
            'params' => array(
                'module' => 'activity',
                'controller' => 'index',
                'action' => 'share',
                'type' => $document->getType(),
                'id' => $document->getIdentity(),
                'format' => 'smoothbox',
            ),
        );
    }

    //ADD DOCUMENT DOWNLOAD LINK
    public function onMenuInitialize_DocumentGutterDownload($row) {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document') {
            return false;
        }

        //GET USER LEVEL ID
        if ($viewer->getIdentity()) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //DOWNLOAD IS ALLOWED OR NOT FOR THIS LEVEL
        $view_download_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'view_download');
        if (empty($view_download_allow) || empty($document->download_allow)) {
            return false;
        }

        $coreApi = Engine_Api::_()->document();
        $document_client_id = $coreApi->getGoogleClientId();
        $getGoogleClientSecretKey = $coreApi->getGoogleClientSecretKey();
        $document_google_email = $coreApi->getGoogleEmail();
        $document_hide_old_fields = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.hide.old.fields', 0);
        if ($document_hide_old_fields) {
            $GDSEMedia = new GDSEMedia($document_client_id, null, null, $getGoogleClientSecretKey);
        } else {
            $document_service_account_name = $coreApi->getGoogleServiceAccountName();
            $document_private_key_url_path = $coreApi->getPrivateKeyUrl();
            if ($document_google_email && $document_client_id && $document_service_account_name && $document_private_key_url_path) {
                $GDSEMedia = new GDSEMedia($document_client_id, $document_service_account_name, $document_private_key_url_path);
            }
        }
        $file_proper = $GDSEMedia->files->get($document->google_file_id);
        $link = $file_proper['webContentLink'];
        if (empty($link)) {
            return false;
        }

        return array(
            'class' => 'buttonlink seaocore_download_icon',
            'uri' => $link,
            'target' => '_blank'
        );
    }

    //ADD DOCUMENT EMAIL LINK
    public function onMenuInitialize_DocumentGutterEmail($row) {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($viewer_id) || $document->status != 1) {
            return false;
        }

        //EMAIL IS ALLOWED OR NOT FOR THIS LEVEL
        $view_email_allow = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'document', 'view_email');
        if (empty($view_email_allow) || empty($document->email_allow)) {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox seaocore_email_icon',
            'route' => 'default',
            'params' => array(
                'module' => 'document',
                'controller' => 'index',
                'action' => 'email',
                'id' => $document->getIdentity(),
            ),
        );
    }

    //ADD DOCUMENT SUGGESTION LINK	
    public function onMenuInitialize_DocumentGutterSuggest($row) {

        $is_suggestion_enabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('suggestion');
        $is_suggestion_active = Engine_Api::_()->suggestion()->getModSettings('document', 'link');
        if (empty($is_suggestion_enabled) || empty($is_suggestion_active)) {
            return;
        }

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($viewer_id) || $document->status != 1 || empty($document->approved) || $document->draft == 1) {
            return false;
        }

        return array(
            'class' => 'buttonlink  notification_type_document_popup_suggestion smoothbox seaocore_icon_suggest',
            'route' => 'default',
            'params' => array(
                'module' => 'suggestion',
                'controller' => 'index',
                'action' => 'switch-popup',
                'modName' => 'document',
                'modContentId' => $document->getIdentity(),
                'modError' => 1,
                'format' => 'smoothbox',
            ),
        );
    }

    //ADD DOCUMENT REPORT LINK
    public function onMenuInitialize_DocumentGutterReport() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($viewer_id)) {
            return false;
        }

        //REPORTING IS ALLOWED OR NOT
        $report = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('document.report', 1);
        if (empty($report)) {
            return false;
        }

        return array(
            'class' => 'smoothbox buttonlink seaocore_report_icon',
            'route' => 'default',
            'params' => array(
                'module' => 'core',
                'controller' => 'report',
                'action' => 'create',
                'subject' => $document->getGuid(),
                'format' => 'smoothbox',
            ),
        );
    }

    //ADD DOCUMENT DELETE LINK
    public function onMenuInitialize_DocumentGutterDelete() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if ($document->getType() !== 'document' || empty($viewer_id)) {
            return false;
        }

        //USER IS ALLOWED FOR DELETE OR NOT
        $can_delete = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'document', 'delete');
        if (empty($can_delete) || ($can_delete == 1 && $viewer_id != $document->owner_id)) {
            return false;
        }

        return array(
            'class' => 'buttonlink seaocore_icon_delete',
            'route' => 'document_delete',
            'params' => array(
                'document_id' => $document->getIdentity(),
            ),
        );
    }

}
