<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Controller.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Document_Widget_DocumentViewDocumentsController extends Seaocore_Content_Widget_Abstract {

    public function indexAction() {
        //DON'T RENDER IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return $this->setNoRender();
        }

        //GET DOCUMENT SUBJECT
        $this->view->document = $document = Engine_Api::_()->core()->getSubject();
        if (empty($document)) {
            return $this->setNoRender();
        }

        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //GET WIDGET SETTINGS
        $this->view->documentViewerHeight = $this->_getParam('documentViewerHeight', 600);
        //$this->view->documentViewerWidth = $this->_getParam('documentViewerWidth', 730);
        //INCREMENT DOCUMENT VIEWS IF VIEWER IS NOT OWNER
        if (!$document->getOwner()->isSelf($viewer)) {
            $document->views++;
            $document->save();
        }

        //CHECK THAT VIEWER CAN RATE THE DOCUMENT OR NOT
        $this->view->can_rate = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.rating', 1);

        //GET CATEGORY TABLE
        $this->view->categoryTable = $categoryTable = Engine_Api::_()->getDbtable('categories', 'document');

        //GET CATEGORIES DETAIL
        $this->view->category_name = $this->view->subcategory_name = $this->view->subsubcategory_name = '';
        $categoriesNmae = $categoryTable->getCategory($document->category_id);
        if (!empty($categoriesNmae->category_name)) {
            $this->view->category_name = $categoriesNmae->category_name;
        }
        $subcategory_name = $categoryTable->getCategory($document->subcategory_id);
        if (!empty($subcategory_name->category_name)) {
            $this->view->subcategory_name = $subcategory_name->category_name;
        }
        //GET SUB-SUB-CATEGORY
        $subsubcategory_name = $categoryTable->getCategory($document->subsubcategory_id);
        if (!empty($subsubcategory_name->category_name)) {
            $this->view->subsubcategory_name = $subsubcategory_name->category_name;
        }
        //FIND DOCUMENT OWNER TAGS
        $this->view->documentTags = $document->tags()->getTagMaps();

        //GET RATING TABLE
        $tableRating = Engine_Api::_()->getDbTable('ratings', 'document');
        $this->view->rating_count = $tableRating->countRating($document->getIdentity());
        $this->view->document_rated = $tableRating->previousRated($document->getIdentity(), $viewer_id);

        $view = $this->view;
        $view->addHelperPath(APPLICATION_PATH . '/application/modules/Fields/View/Helper', 'Fields_View_Helper');
        $view->fieldStructure = Engine_Api::_()->fields()->getFieldsStructurePartial($document);
        $documentViewDocument = Zend_Registry::isRegistered('documentViewDocument') ? Zend_Registry::get('documentViewDocument') : null;
        if(empty($documentViewDocument))
            return $this->setNoRender();


        //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
        if ($document->draft == 0 && $document->approved == 1 && $document->status == 1 && $document->activity_feed == 0) {

            //GET DOCUMENT OWNER OBJECT
            $creator = Engine_Api::_()->getItem('user', $document->owner_id);

            //GET ACTIVITY TABLE
            $activityTable = Engine_Api::_()->getDbtable('actions', 'activity');

            $action = $activityTable->addActivity($creator, $document, 'document_new');

            //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
            if ($action != null) {
                $activityTable->attachActivity($action, $document);
                $document->activity_feed = 1;
                $document->save();
            }
        }
    }

}
