<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Controller.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Widget_ProfileDocumentsController extends Seaocore_Content_Widget_Abstract {

    protected $_childCount;

    public function indexAction() {
        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $this->view->widgetSettings = $this->view->allParams = $this->_getAllParams();
        //in_array function gives warning if we document option do not come form settings, so used default params
        $this->view->widgetSettings['documentOption'] = $this->_getParam('documentOption', array('title', 'owner', 'featured', 'sponsored', 'view', 'like', 'comment', 'rating', 'likeButton', 'facebook', 'twitter', 'linkedin', 'googleplus'));

        $this->view->layoutsViews = $layoutsViews = $this->_getParam('layoutsViews', array("1" => "1", "2" => "2"));
        $this->view->layoutsOrder = $layoutsOrder = $this->_getParam('layoutsOrder', 2);
        $this->view->countLayoutsViews = count($layoutsViews);
        $this->view->listView = 0;
        $this->view->gridView = 0;
        if (in_array("1", $layoutsViews)) {
            $this->view->listView = 1;
            if ($layoutsOrder == 1)
                $this->view->defaultView = 0;
        }
        if (in_array("2", $layoutsViews)) {
            $this->view->gridView = 1;
            if ($layoutsOrder == 2)
                $this->view->defaultView = 1;
        }

        $this->view->isajax = $this->_getParam('isajax', 0);
        if ($this->_getParam('isajax', 0)) {
            $this->getElement()->removeDecorator('Title');
            $this->getElement()->removeDecorator('Container');
        }
        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = Engine_Api::_()->user()->getViewer()->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //WHO CAN VIEW THE DOCUMENTS
        $can_view = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'view');
        if (empty($can_view)) {
            return $this->setNoRender();
        }

        //DON'T RENDER IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject()) {
            return $this->setNoRender();
        }

        //GET SUBJECT
        $subject = Engine_Api::_()->core()->getSubject();
        if (!$subject->authorization()->isAllowed($viewer, 'view')) {
            return $this->setNoRender();
        }

        //NUMBER OF DOCUMENTS IN LISTING
        $this->view->items_per_page = $total_documents = $this->_getParam('itemCount', 10);

        //CHECK THAT RATING IS VIEABLE OR NOT
        $this->view->show_rate = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.rating', 1);
        $this->view->widgetSettings['show_rate'] = $this->view->show_rate;

        //OWNER AND SUPER ADMIN CAN VIEW ALL PROFILE DOCUMENTS 
        $profile_owner_id = Engine_Api::_()->core()->getSubject()->getIdentity();
        $network_based_content = 1;
        if ($viewer_id == $profile_owner_id || $level_id == 1) {
            $network_based_content = 0;
        }

        //FETCH DOCUMENTS
        $this->view->paginator = Engine_Api::_()->getDbtable('documents', 'document')->getDocumentsPaginator(array(
            'orderby' => 'document_id',
            'draft' => '0',
            'approved' => '1',
            'status' => '1',
            'owner_id' => $profile_owner_id,
            'network_based_content' => $network_based_content
        ));

        $this->view->paginator->setItemCountPerPage($total_documents);
        $this->view->paginator->setCurrentPageNumber($this->_getParam('page', 1));

        if ($this->view->paginator->getTotalItemCount() <= 0) {
            return $this->setNoRender();
        }

        if ($this->_getParam('titleCount', false)) {
            $this->_childCount = $this->view->paginator->getTotalItemCount();
        }

        if (!$this->view->isajax) {
            $this->view->params = $this->_getAllParams();
            if ($this->_getParam('loaded_by_ajax', true)) {
                $this->view->loaded_by_ajax = true;
                if ($this->_getParam('is_ajax_load', false)) {
                    $this->view->is_ajax_load = true;
                    $this->view->loaded_by_ajax = false;
                    if (!$this->_getParam('onloadAdd', false))
                        $this->getElement()->removeDecorator('Title');
                    $this->getElement()->removeDecorator('Container');
                } else {
                    return;
                }
            }
            $this->view->showContent = true;
        } else {
            $this->view->showContent = true;
        }
    }

    public function getChildCount() {
        return $this->_childCount;
    }

}
