<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Eventdocument
 * @copyright  Copyright 20011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminManageController.php 2012-01-25 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Eventdocument_AdminManageController extends Core_Controller_Action_Admin {

  //ACTION FOR MANAGE THE DOCUMENTS
  public function indexAction() {
    //GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                    ->getNavigation('eventdocument_admin_main', array(), 'eventdocument_admin_main_manage');

    $eventdocument_admin_tab = '';

    //FORM GENERATION
    $this->view->formFilter = $formFilter = new Eventdocument_Form_Admin_Manage_Filter();
    $page = $this->_getParam('page', 1);

    //GET USER TABLE
    $tableUser = Engine_Api::_()->getItemTable('user')->info('name');

    //GET EVENT TABLE
    $tableEvent = Engine_Api::_()->getItemTable('event')->info('name');

    //GET DOCUMENT TABLE
    $tableDocument = Engine_Api::_()->getDbtable('documents', 'eventdocument');
    $tableDocumentName = $tableDocument->info('name');

    //MAKE QUERY
    $select = $tableDocument->select()
                    ->setIntegrityCheck(false)
                    ->from($tableDocumentName)
                    ->joinLeft($tableUser, "$tableDocumentName.owner_id = $tableUser.user_id", 'username')
                    ->joinLeft($tableEvent, "$tableDocumentName.event_id = $tableEvent.event_id", 'title AS event_title');

    //GET FORM VALUES
    $values = array();
    if ($formFilter->isValid($this->_getAllParams())) {
      $values = $formFilter->getValues();
    }

    foreach ($values as $key => $value) {
      if (null === $value) {
        unset($values[$key]);
      }
    }

    $values = array_merge(array(
                'order' => 'document_id',
                'order_direction' => 'DESC',
                    ), $values);

    $this->view->assign($values);

    $select->order((!empty($values['order']) ? $values['order'] : 'document_id' ) . ' ' . (!empty($values['order_direction']) ? $values['order_direction'] : 'DESC' ));

    //GET PAGINATOR
    $this->view->paginator = $paginator = Zend_Paginator::factory($select);
    $this->view->paginator->setItemCountPerPage(50);
    $this->view->paginator = $paginator->setCurrentPageNumber($page);
  }

  //ACTION FOR MAKE EVENT-DOCUMENT APPROVED/DIS-APPROVED
  public function approvedAction() {
    //GET DOCUMENT ID
    $document_id = $this->_getParam('id');

    //BEGIN TRANSACTION
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      //GET DOCUMENT OBJECT
      $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);

      if ($eventdocument->approved == 0) {
        $eventdocument->approved = 1;
      } else {
        $eventdocument->approved = 0;
      }

      //SAVE IN DATABASE
      $eventdocument->save();

      //COMMIT
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    //REDIRECT
    $this->_redirect('admin/eventdocument/manage');
  }

  //ACTION FOR MAKE EVENT-DOCUMENT FEATURED/UN-FEATURED
  public function featuredAction() {
    //GET DOCUMENT ID
    $document_id = $this->_getParam('id');

    //BEGIN TRANSACTION
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      //GET DOCUMENT OBJECT
      $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);

      if ($eventdocument->featured == 0) {
        $eventdocument->featured = 1;
      } else {
        $eventdocument->featured = 0;
      }

      //SAVE IN DATABASE
      $eventdocument->save();

      //COMMIT
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    //REDIRECT
    $this->_redirect('admin/eventdocument/manage');
  }

  //ACTION FOR DELETE THE EVENT-DOCUMENT
  public function deleteAction() {
    //SET LAYOUT
    $this->_helper->layout->setLayout('admin-simple');

    //GET DOCUMENT ID
    $this->view->document_id = $document_id = $this->_getParam('id');

    if ($this->getRequest()->isPost()) {

      //DELETE DOCUMENT FROM LOCAL STORAGE
      Engine_Api::_()->eventdocument()->deleteContent($document_id);

      $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('')
      ));
    }

    //RENDER SCRIPT
    $this->renderScript('admin-manage/delete.tpl');
  }

  //ACTION FOR MULTI DELETE DOCUMENTS
  public function multiDeleteAction() {
    if ($this->getRequest()->isPost()) {
      $values = $this->getRequest()->getPost();
      foreach ($values as $key => $value) {
        if ($key == 'delete_' . $value) {

          $document_id = (int) $value;

          //DELETE DOCUMENT BELONGINGS
          Engine_Api::_()->eventdocument()->deleteContent($document_id);
        }
      }
    }

    //REDIRECT
    return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
  }

}