<?php

/**
 * SocialEngine
 *
 * @category   Application_Theme
 * @package    Facelight
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2017-12-15 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Facelight_Api_Core extends Core_Api_Abstract {

    /**
     * This function return the complete path of image, from the photo id.
     *
     * @param id: The photo id.
     * @param type: The type of photo required.
     * @return Image path.
     */
    public function displayPhoto($id, $type = 'thumb.profile') {
        if (empty($id)) {
            return null;
        }
        $file = Engine_Api::_()->getItemTable('storage_file')->getFile($id, $type);
        if (!$file) {
            return null;
        }

        return $file->map();
    }

    /**
     * Plugin which return the error, if Siteadmin not using correct version for the plugin.
     *
     */
    public function isModulesSupport() {
        $isFacelightActivate = Engine_Api::_()->getApi('settings', 'core')->getSetting('facelight.isActivate', 0);
        if (empty($isFacelightActivate))
            return array();

        $modArray = array(
            'siteevent' => '4.8.8p3',
            'siteeventticket' => '4.8.8p3',
            'sitecontentcoverphoto' => '4.8.8p5',
            'siteusercoverphoto' => '4.8.8p4',
            'sitereview' => '4.8.8p1',
            'sitereviewlistingtype' => '4.8.8p1',
            'sitealbum' => '4.8.8p1',
            'sitemenu' => '4.8.8p3'
        );
        $finalModules = array();
        foreach ($modArray as $key => $value) {
            $isModEnabled = Engine_Api::_()->hasModuleBootstrap($key);
            if (!empty($isModEnabled)) {
                $getModVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule($key);
                $isModSupport = $this->checkVersion($getModVersion->version, $value);
                if (!$isModSupport) {
                    $finalModules[] = $getModVersion->title;
                }
            }
        }
        return $finalModules;
    }

    function checkVersion($databaseVersion, $checkDependancyVersion) {
        if (strcasecmp($databaseVersion, $checkDependancyVersion) == 0)
            return -1;
        $databaseVersionArr = explode(".", $databaseVersion);
        $checkDependancyVersionArr = explode('.', $checkDependancyVersion);
        $fValueCount = $count = count($databaseVersionArr);
        $sValueCount = count($checkDependancyVersionArr);
        if ($fValueCount > $sValueCount)
            $count = $sValueCount;
        for ($i = 0; $i < $count; $i++) {
            $fValue = $databaseVersionArr[$i];
            $sValue = $checkDependancyVersionArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                $result = $this->compareValues($fValue, $sValue);
                if ($result == -1) {
                    if (($i + 1) == $count) {
                        return $this->compareValues($fValueCount, $sValueCount);
                    } else
                        continue;
                }
                return $result;
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);
                $result = $this->compareValues($fsArr[0], $sValue);
                return $result == -1 ? 1 : $result;
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);
                $result = $this->compareValues($fValue, $ssArr[0]);
                return $result == -1 ? 0 : $result;
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                $result = $this->compareValues($fsArr[0], $ssArr[0]);
                if ($result != -1)
                    return $result;
                $result = $this->compareValues($fsArr[1], $ssArr[1]);
                return $result;
            }
        }
    }

    public function compareValues($firstVal, $secondVal) {
        $num = $firstVal - $secondVal;
        return ($num > 0) ? 1 : ($num < 0 ? 0 : -1);
    }

    /**
     * Get Widgetized PageId
     * @param $params
     */
    public function getWidgetizedPageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $page_id = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'page_id')
                ->where('name =?', $params['name'])
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    /**
     * Check Widget Exist
     * @param $params
     */
    public function checkWidgetExist($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $content_id = $tableNameContent->select()
                ->from($tableNameContent->info('name'), 'content_id')
                ->where('page_id =?', $this->getWidgetizedPageId(array('name' => 'core_index_index')))
                ->where('name =?', $params['name'])
                ->query()
                ->fetchColumn();
        return $content_id;
    }

    /**
     * Get Widgetized Page Layout Value
     * @param $params
     */
    public function getWidgetizedPageLayoutValue($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $select = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'layout');

        if (isset($params['name'])) {
            $select->where('name =?', $params['name']);
        }
        if (isset($params['page_id'])) {
            $select->where('page_id =?', $params['page_id']);
        }
        $layout = $select->query()
                ->fetchColumn();
        return $layout;
    }

    /**
     * Get language array
     *
     * @param string $page_url
     * @return array $localeMultiOptions
     */
    public function getLanguageArray() {

        //PREPARE LANGUAGE LIST
        $languageList = Zend_Registry::get('Zend_Translate')->getList();

        //PREPARE DEFAULT LANGUAGE
        $defaultLanguage = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.locale.locale', 'en');
        if (!in_array($defaultLanguage, $languageList)) {
            if ($defaultLanguage == 'auto' && isset($languageList['en'])) {
                $defaultLanguage = 'en';
            } else {
                $defaultLanguage = null;
            }
        }
        //INIT DEFAULT LOCAL
        $localeObject = Zend_Registry::get('Locale');
        $languages = Zend_Locale::getTranslationList('language', $localeObject);
        $territories = Zend_Locale::getTranslationList('territory', $localeObject);

        $localeMultiOptions = array();
        foreach ($languageList as $key) {
            $languageName = null;
            if (!empty($languages[$key])) {
                $languageName = $languages[$key];
            } else {
                $tmpLocale = new Zend_Locale($key);
                $region = $tmpLocale->getRegion();
                $language = $tmpLocale->getLanguage();
                if (!empty($languages[$language]) && !empty($territories[$region])) {
                    $languageName = $languages[$language] . ' (' . $territories[$region] . ')';
                }
            }

            if ($languageName) {
                $localeMultiOptions[$key] = $languageName;
            } else {
                $localeMultiOptions[$key] = Zend_Registry::get('Zend_Translate')->_('Unknown');
            }
        }
        $localeMultiOptions = array_merge(array(
            $defaultLanguage => $defaultLanguage
                ), $localeMultiOptions);
        return $localeMultiOptions;
    }

    public function getContentPageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $page_id = $tableNameContent->select()
                ->from($tableNameContent->info('name'), 'page_id')
                ->where('content_id =?', $params['content_id'])
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    /**
     * Get Widgetized PageId
     * @param $params
     */
    public function getBackupHomePageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $page_id = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'page_id')
                ->where('url =?', 'home')
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    public function getBackupOfHomePage() {

        $page_id = $this->getWidgetizedPageId(array('name' => 'core_index_index'));
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $tableNameContentName = $tableNameContent->info('name');
        $db = Engine_Db_Table::getDefaultAdapter();

        //CHECK PAGE EXIST OR NOT
        $home_backup_page_id = $this->getBackupHomePageId();

        //CREATE PAGE
        if (empty($home_backup_page_id)) {
            $db->query("INSERT IGNORE INTO `engine4_core_pages` ( `name`, `displayname`, `url`, `title`, `description`, `keywords`, `custom`, `fragment`, `layout`, `levels`, `provides`, `view_count`, `search`) VALUES (NULL, 'Landing Page - Backup of Landing Page on Installation of Facelight Theme', 'home', 'Backup of Landing Page on Installation of Facelight Theme Plugin', '', '', '0', '0', '', NULL, NULL, '0', '0');");
        }

        //GET EXISTING PAGE ID
        $home_backup_page_id = $this->getBackupHomePageId();

        $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = $home_backup_page_id");
        //GET MAIN CONTAINER WORK

        $select = $tableNameContent->select()
                ->from($tableNameContentName, '*')
                ->where('page_id =?', $page_id)
                ->where('name =?', 'main')
                ->where('type =?', 'container');

        $mainRow = $tableNameContent->fetchRow($select);

        if (!empty($mainRow)) {

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $home_backup_page_id,
                'parent_content_id' => null,
                'order' => $mainRow->order,
                'params' => $mainRow->params ? json_encode($mainRow->params) : ''
            ));
            $content_id = $db->lastInsertId('engine4_core_content');

            $results = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('name in (?)', array('left', 'middle', 'right'))
                    ->where('type =?', 'container')
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->query()
                    ->fetchAll();

            foreach ($results as $values) {
                $db->insert('engine4_core_content', array(
                    'type' => $values['type'],
                    'name' => $values['name'],
                    'page_id' => $home_backup_page_id,
                    'parent_content_id' => $content_id,
                    'order' => $values['order'],
                    'params' => $values['params']
                ));
            }

            //LEFT CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->where('name =?', 'left')
                    ->where('type =?', 'container');

            $leftRow = $tableNameContent->fetchRow($select);

            if (!empty($leftRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $leftRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'left')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END LEFT CONTAINER WIDGET
            //MIDDLE CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->where('name =?', 'middle')
                    ->where('type =?', 'container');

            $middleRow = $tableNameContent->fetchRow($select);

            if (!empty($middleRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $middleRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'middle')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END MIDDLE CONTAINER WIDGET
            //RIGHT CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->where('name =?', 'right')
                    ->where('type =?', 'container');

            $rightRow = $tableNameContent->fetchRow($select);

            if (!empty($rightRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $rightRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'right')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END RIGHT CONTAINER WIDGET
        }

        //TOP CONTAINER
        $select = $tableNameContent->select()
                ->from($tableNameContentName, '*')
                ->where('page_id =?', $page_id)
                ->where('name =?', 'top')
                ->where('type =?', 'container');

        $topRow = $tableNameContent->fetchRow($select);

        if (!empty($topRow)) {

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'top',
                'page_id' => $home_backup_page_id,
                'parent_content_id' => null,
                'order' => $topRow->order,
                //'params' => json_encode($topRow->params)
                'params' => $topRow->params ? json_encode($topRow->params) : ''
            ));
            $content_id = $db->lastInsertId('engine4_core_content');

            $results = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('name in (?)', array('left', 'middle', 'right'))
                    ->where('type =?', 'container')
                    ->where('parent_content_id =?', $topRow->content_id)
                    ->query()
                    ->fetchAll();

            foreach ($results as $values) {
                $db->insert('engine4_core_content', array(
                    'type' => 'container',
                    'name' => $values['name'],
                    'page_id' => $home_backup_page_id,
                    'parent_content_id' => $content_id,
                    'order' => $values['order'],
                    'params' => $values['params']
                ));
            }

            //MIDDLE CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $topRow->content_id)
                    ->where('name =?', 'middle')
                    ->where('type =?', 'container');

            $topMiddleRow = $tableNameContent->fetchRow($select);

            if (!empty($topMiddleRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $topMiddleRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'middle')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END MIDDLE CONTAINER WIDGET
        }


        //GET BOTTOM CONTAINER
        $select = $tableNameContent->select()
                ->from($tableNameContentName, '*')
                ->where('page_id =?', $page_id)
                ->where('name =?', 'bottom')
                ->where('type =?', 'container');

        $bottomRow = $tableNameContent->fetchRow($select);

        if (!empty($bottomRow)) {

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'bottom',
                'page_id' => $home_backup_page_id,
                'parent_content_id' => null,
                'order' => $bottomRow->order,
                'params' => $bottomRow->params ? json_encode($bottomRow->params) : ''
            ));
            $content_id = $db->lastInsertId('engine4_core_content');

            $results = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('name in (?)', array('left', 'middle', 'right'))
                    ->where('type =?', 'container')
                    ->where('parent_content_id =?', $bottomRow->content_id)
                    ->query()
                    ->fetchAll();

            foreach ($results as $values) {
                $db->insert('engine4_core_content', array(
                    'type' => 'container',
                    'name' => $values['name'],
                    'page_id' => $home_backup_page_id,
                    'parent_content_id' => $content_id,
                    'order' => $values['order'],
                    'params' => $values['params']
                ));
            }

            //MIDDLE CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $bottomRow->content_id)
                    ->where('name =?', 'middle')
                    ->where('type =?', 'container');

            $bottomMiddleRow = $tableNameContent->fetchRow($select);

            if (!empty($bottomMiddleRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $bottomMiddleRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'middle')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END MIDDLE CONTAINER WIDGET
        }
    }

    public function setDefaultLayout($obj) {
        Engine_Api::_()->facelight()->getBackupOfHomePage();
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;

        $db = Engine_Db_Table::getDefaultAdapter();
        $page_id = $db->select()
                ->from('engine4_core_pages', 'page_id')
                ->where('name = ?', 'user_index_home')
                ->limit(1)
                ->query()
                ->fetchColumn();
        $page_parent_id = $db->select()
                ->from('engine4_core_content', 'content_id')
                ->where('type = ?', 'container')
                ->where('name = ?', 'left')
                ->where('page_id =? ',$page_id)
                ->limit(1)
                ->query()
                ->fetchColumn();
        if (!empty($page_id) && !empty($page_parent_id) && !empty($obj)) {
        
        $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`name` = 'user.home-photo'  OR `engine4_core_content`.`name`='facelight.user-shortcuts' OR `engine4_core_content`.`name`='facelight.explore-links' OR `engine4_core_content`.`name`='user.home-links' OR `engine4_core_content`.`name`='facelight.home-links' OR `engine4_core_content`.`name`='facelight.home-photo' OR `engine4_core_content`.`name`='sitemember.profile-photo-sitemembers'");       
        $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.home-photo',
                'page_id' => $page_id,
                'parent_content_id' => $page_parent_id,
                'params' => '',
                'order' => 1,
            ));
        $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.user-shortcuts',
                'page_id' => $page_id,
                'parent_content_id' => $page_parent_id,
                'params' => '{"title":"Shortcuts","name":"facelight.user-shortcuts"}',
                'order' => 2,
            ));
        $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.explore-links',
                'page_id' => $page_id,
                'parent_content_id' => $page_parent_id,
                'params' => '{"parent":"0","title":"Explore","nomobile":"0","name":"facelight.explore-links"}',
                'order' => 3,
            ));

    }
        $db = Engine_Db_Table::getDefaultAdapter();
        $page_id = $db->select()
                ->from('engine4_core_pages', 'page_id')
                ->where('name = ?', 'core_index_index')
                ->limit(1)
                ->query()
                ->fetchColumn();
        if (!empty($page_id) && !empty($obj) && !empty($obj['facelight_landing_page_layout'])) {
            $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = $page_id");

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'top',
                'page_id' => $page_id,
                'order' => 1,
            ));
            $top_id = $db->lastInsertId();

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'parent_content_id' => $top_id,
                'page_id' => $page_id,
                'order' => 2,
            ));
            $top_middle_id = $db->lastInsertId();

            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.login-signup-tagline',
                'page_id' => $page_id,
                'parent_content_id' => $top_middle_id,
                'params' => '',
                'order' => 3,
            ));

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => 3,
            ));
            $main_id = $db->lastInsertId();

            // Insert main-middle
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 4,
            ));
            $main_middle_id = $db->lastInsertId();
        }

        $title = Engine_Api::_()->getApi('settings', 'core')->getSetting('core_general_site_title', $view->translate('_SITE_TITLE'));
        $strLength = strlen($title);
        $isSitemenuModEnabled = Engine_Api::_()->hasModuleBootstrap('sitemenu');
        $isAdvSearchModEnabled = Engine_Api::_()->hasModuleBootstrap('siteadvsearch');
        $page_id = $db->select()
                ->from('engine4_core_pages', 'page_id')
                ->where('name = ?', 'footer')
                ->limit(1)
                ->query()
                ->fetchColumn();
        if (!empty($page_id) && !empty($obj) && !empty($obj['facelight_landing_page_layout'])) {
            $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = $page_id");

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => 1,
            ));
            $main_id = $db->lastInsertId();
            
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.language',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 2,
            ));
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.menu-footer',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 3,
            ));
        }

        $page_id = $db->select()
                ->from('engine4_core_pages', 'page_id')
                ->where('name = ?', 'header')
                ->limit(1)
                ->query()
                ->fetchColumn();
        if (!empty($page_id) && !empty($obj) && !empty($obj['facelight_landing_page_layout'])) {
            $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = $page_id");
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => 1,
            ));
            $main_id = $db->lastInsertId();

            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'core.html-block',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 2,
                'params' => '{"title":"","data":"<script type=\"text\/javascript\"> \r\nif(typeof(window.jQuery) !=  \"undefined\") {\r\njQuery.noConflict();\r\n}\r\n<\/script>","nomobile":"0","name":"core.html-block"}'
            ));

            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'core.menu-logo',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 3,
                'params' => '{"title":"","name":"core.menu-logo","logo":"","nomobile":"0"}'
            ));

            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.signup-button',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 4,
                'params' => '{"title":"","name":"facelight.signup-button"}'
            ));

            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.login-or-signup',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 5,
                'params' => '{"title":"","name":"facelight.login-or-signup"}'
            ));
            
         if ($isAdvSearchModEnabled) {
                $db->insert('engine4_core_content', array(
                    'type' => 'widget',
                    'name' => 'siteadvsearch.search-box',
                    'page_id' => $page_id,
                    'parent_content_id' => $main_id,
                    'order' => 6,
                    'params' => '{"title":"","titleCount":true,"advsearch_search_box_width":"240","advsearch_search_box_width_for_nonloggedin":"275","nomobile":"0","name":"siteadvsearch.search-box"}'
                ));
            } else {
                $db->insert('engine4_core_content', array(
                    'type' => 'widget',
                    'name' => 'facelight.search-box',
                    'page_id' => $page_id,
                    'parent_content_id' => $main_id,
                    'order' => 6,
                    'params' => '{"facelight_on_logged_out":"0","facelight_search_width":"240","title":"","nomobile":"0","name":"facelight.search-box"}'
                ));
            }

            if ($isSitemenuModEnabled) {
                // $db->insert('engine4_core_content', array(
                //     'type' => 'widget',
                //     'name' => 'sitemenu.menu-main',
                //     'page_id' => $page_id,
                //     'parent_content_id' => $main_id,
                //     'order' => 7,
                //     'params' => '{"sitemenu_on_logged_out":"1","sitemenu_totalmenu":"2","sitemenu_truncation_limit_content":"20","sitemenu_truncation_limit_category":"20","sitemenu_is_more_link":"1","sitemenu_more_link_icon":"1","sitemenu_is_arrow":"1","sitemenu_separator_style":"3","sitemenu_show_cart":"1","sitemenu_show_in_main_options":"1","changeMyLocation":"0","sitemenu_is_fixed":"0","sitemenu_fixed_height":"0","sitemenu_show_extra_on":"0","sitemenu_style":"1","sitemenu_box_shadow":"1","sitemenu_menu_corners_style":"0","sitemenu_main_menu_height":"20","Dummy_label":null,"sitemenu_menu_link_color":"#ffffff","sitemenu_menu_background_color":"#000000","sitemenu_menu_hover_color":"#000000","sitemenu_menu_hover_background_color":"#ffffff","sitemenu_sub_link_color":"#000000","sitemenu_sub_background_color":"#ffffff","sitemenu_sub_hover_color":"#ffffff","sitemenu_totalmenu_mobile":"4","sitemenu_totalmenu_tablet":"6","title":"","nomobile":"0","name":"sitemenu.menu-main"}'
                // ));

                $db->insert('engine4_core_content', array(
                    'type' => 'widget',
                    'name' => 'sitemenu.menu-mini',
                    'page_id' => $page_id,
                    'parent_content_id' => $main_id,
                    'order' => 9,
                    'params' => '{"sitemenu_on_logged_out":"0","sitemenu_show_icon":"1","no_of_updates":"10","sitemenu_show_in_mini_options":"0","search_position":"1","changeMyLocation":"0","showLocationBasedContent":"0","sitemenu_mini_search_width":"275","sitemenu_location_box_width":"275","sitemenu_enable_login_lightbox":"1","sitemenu_enable_signup_lightbox":"1","title":"","nomobile":"0","name":"sitemenu.menu-mini"}'
                ));
            } else {
//                $db->insert('engine4_core_content', array(
//                    'type' => 'widget',
//                    'name' => 'facelight.browse-menu-main',
//                    'page_id' => $page_id,
//                    'parent_content_id' => $main_id,
//                    'order' => 7,
//                    'params' => '{"max":"3","title":"","nomobile":"0","name":"facelight.browse-menu-main"}'
//                ));

                $db->insert('engine4_core_content', array(
                    'type' => 'widget',
                    'name' => 'core.menu-mini',
                    'page_id' => $page_id,
                    'parent_content_id' => $main_id,
                    'order' => 9,
                    'params' => ''
                ));
            } 
        }
        $theme_id = $db->select()
                ->from('engine4_core_themes', 'theme_id')
                ->where('name = ?', 'facelight')
                ->limit(1)
                ->query()
                ->fetchColumn();
        if(empty($theme_id)){
            $db->query("UPDATE `engine4_core_themes` SET `active` = 0 WHERE `engine4_core_themes`.`active` = 1;");
            $db->insert('engine4_core_themes', array(
                'name' => 'facelight',
                'title' => 'FB Clone Theme',
                'description' => 'FB Clone Theme',
                'active' => 1,
            ));
        } else {
            $db->query("UPDATE `engine4_core_themes` SET `active` = 0 WHERE `engine4_core_themes`.`active` = 1;");
            $db->query("UPDATE `engine4_core_themes` SET `active` = 1 WHERE `engine4_core_themes`.`name` = 'facelight';");
        }
        $headerPageId = $db->select()
                ->from('engine4_core_pages', 'page_id')
                ->where('name = ?', 'header')
                ->limit(1)->query()->fetchColumn();

        if (!empty($headerPageId)) {
            $parentContentId = $db->select()
                            ->from('engine4_core_content', 'content_id')
                            ->where('page_id = ?', $headerPageId)
                            ->where('name = ?', 'main')
                            ->where('type =?', 'container')
                            ->limit(1)->query()->fetchColumn();
            $layoutScrollContentId = $db->select()
                            ->from('engine4_core_content', 'content_id')
                            ->where('page_id = ?', $headerPageId)
                            ->where('name = ?', 'facelight.layout-scroll')
                            ->where('type =?', 'widget')
                            ->limit(1)->query()->fetchColumn();

            if (!empty($parentContentId) && empty($layoutScrollContentId)) {
                $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'facelight.layout-scroll',
                'page_id' => $headerPageId,
                'parent_content_id' => $parentContentId,
                'order' => 4,
                'params' => '[]'
            ));
            }
        }    
        // Enable theme as well
        
    }
    /**
     * Does the user have new updates, returns the number or 0
     *
     * @param User_Model_User $user
     * @param $params
     * @return int The number of new updates the user has
     */
    public function getNewUpdatesCount(User_Model_User $user, $params = array()) {
        $notificationTable = Engine_Api::_()->getDbtable('notifications', 'seaocore');
        $notificationTableName = $notificationTable->info('name');

        $notificationsTable = Engine_Api::_()->getDbtable('notifications', 'activity');
        $notificationsTableName = $notificationsTable->info('name');

        $select = $notificationTable->select()
               ->from($notificationTableName, "COUNT($notificationTableName.notification_id) as count")
                ->where("$notificationsTableName.user_id = ?", $user->getIdentity())
                ->where("$notificationTableName.show = ?", 0)
                ->where("$notificationsTableName.read = ?", 0);

        if (isset($params['isNotification']) && !empty($params['isNotification']))
            $select->where("$notificationsTableName.type != 'friend_request'")
                    ->where("$notificationsTableName.type != 'message_new'")
                    ->where("$notificationsTableName.type != 'friend_follow_request'");
        elseif (isset($params['type']) && !empty($params['type'])) {
            $notificationType = $params['type'];
            $select->where("$notificationsTableName.type = 'friend_follow_request' OR $notificationsTableName.type = '" . $notificationType . "'");
        }
        $newUpdates = $select->query()->fetchAll();
        $newUpdatesCount = $newUpdates[0]['count'];
        return empty($newUpdatesCount) ? false : $newUpdatesCount;
    }

    public function tinymceEditorOptions() {
        $plugins = "directionality,advlist,autolink,lists,link,image,charmap,print,preview,hr,anchor,"
        . "pagebreak,searchreplace,wordcount,visualblocks,visualchars,code,fullscreen,insertdatetime,"
        . "media,nonbreaking,save,table,contextmenu,directionality,emoticons,paste,textcolor,imagetools,colorpicker,autosave";
        return array(
            'upload_url' => '',
            'menubar' => true,
            'forced_root_block' => false,
            'force_p_newlines' => false,
            'plugins' => $plugins,
            'toolbar1' => "ltr,rtl,undo,redo,removeformat,pastetext,|,code,link,media,image,emoticons,|,bullist,numlist,|,print,preview,fullscreen",
            'toolbar2' => "fontselect,fontsizeselect,bold,italic,underline,strikethrough,forecolor,backcolor,|,alignleft,aligncenter,alignright,alignjustify,|,outdent,indent,blockquote",
            'image_advtab' => true,
            /*  'plugins' => 'directionality,preview,table,code,layer,image,media,paste,fullscreen,searchreplace,link,textcolor,charmap,anchor,visualchars,contextmenu',
            'toolbar1' => "ltr,rtl,|,preview,code,|,cut,copy,paste,pastetext,pasteword,|,undo,redo,|,link,unlink,anchor,charmap,image,media,|,hr,removeformat,fullscreen,|,search,replace",
            'toolbar2' => "bold,italic,underline,strikethrough,|,bullist,numlist,|,outdent,indent,blockquote,|,alignleft,aligncenter,alignright,alignjustify,|,sub,sup,|,table",
            'toolbar3' => "formatselect,fontselect,fontsizeselect,|,forecolor,backcolor,|,insertlayer,moveforward,movebackward,absolute," */
            );
    } 


    public function getOldVersionImages($default){
        // Get available files
        $imgOptions = $default;
        $imageExtensions = array('gif', 'jpg', 'jpeg', 'png');

        $it = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
        foreach ($it as $file) {
            if ($file->isDot() || !$file->isFile())
                continue;
            $basename = basename($file->getFilename());
            if (!($pos = strrpos($basename, '.')))
                continue;
            $ext = strtolower(ltrim(substr($basename, $pos), '.'));
            if (!in_array($ext, $imageExtensions))
                continue;
            $imgOptions['public/admin/' . $basename] = $basename;
        }
        return $imgOptions;
    }


    public function getNewVersionImages($default){
        $params = array();
        $params['extension'] = array('gif', 'jpg', 'jpeg', 'png');
        $filesTable = Engine_Api::_()->getDbTable('files','core');
        $select = $filesTable->getFiles($params);
        $fileData = $filesTable->fetchAll($select);
        $imgOptions = $default;
        foreach ($fileData as $key => $value) {
            $imgOptions[$value->storage_path] =  $value->name;
        }
        return $imgOptions;
    }

    public function getImages($first = array(0 => 'No Image')){
        $coreVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core')->version;
        $checkVersion = Engine_Api::_()->seaocore()->checkVersion($coreVersion, '5.0.0');
        // changes in calling of function on the basis of core version
        if($checkVersion) {
          return $this->getNewVersionImages($first);
        } else {
          return $this->getOldVersionImages($first);
        }
    }
}
