<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Groupdocument
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2010-10-19 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Groupdocument_Api_Core extends Core_Api_Abstract {

  /**
   * Return document tabid
   *
   * @return tabid
   */
  public function getTabId() {
    $tab_id = '';
    $tablecontent = Engine_Api::_()->getDbtable('content', 'core');
    $select = $tablecontent->select()
                    ->where('name = ?', 'groupdocument.profile-groupdocuments')
                    ->limit(1);
    $row = $tablecontent->fetchRow($select);
    if ($row !== null) {
      $tab_id = $row->content_id;
    }

    return $tab_id;
  }

  /**
   * Send email to document and page owner if document has been deleted from scirbd
   * @param array $document : document item
   * @param string $group_title : group title
   */
  public function emailDocumentDelete($document, $group_title, $group_user_id) {

    if (empty($document)) {
      return;
    }

    if (empty($group_title)) {
      $group_title = "Group Title";
    }

		$slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($document->groupdocument_title))), '-');
    $document_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('user_id' => $document->owner_id, 'document_id' => $document->document_id, 'slug' => $slug), 'groupdocument_detail_view') . ">$document->groupdocument_title</a>";

    $edit_document_link = 'http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'group_id' => $document->group_id), 'groupdocument_edit');

    $delete_document_link = 'http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'group_id' => $document->group_id), 'groupdocument_delete');

    $group_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('id' => $document->group_id), 'group_profile') . ">$group_title</a>";

    $userTable = Engine_Api::_()->getItemTable('user');
    $document_owner_email_id = $userTable->select()
                    ->from($userTable, 'email')
                    ->where('`user_id` = ?', $group_user_id)
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);

    if (!empty($document_owner_email_id)) {
      Engine_Api::_()->getApi('mail', 'core')->sendSystem($document_owner_email_id, 'notify_docowner_groupdocument_delete', array(
          'document_title_with_link' => $document_title_with_link,
          'group_title_with_link' => $group_title_with_link,
          'delete_document_link' => $delete_document_link,
          'edit_document_link' => $edit_document_link,
          'queue' => true
      ));
    }

    $group_owner_id = Engine_Api::_()->groupdocument()->groupUserId($document->group_id);
    $userTable = Engine_Api::_()->getItemTable('user');
    $group_owner_email_id = $userTable->select()
                    ->from($userTable, 'email')
                    ->where('`user_id` = ?', $group_owner_id)
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);

    if (!empty($group_owner_email_id)) {
      Engine_Api::_()->getApi('mail', 'core')->sendSystem($group_owner_email_id, 'notify_groupowner_groupdocument_delete', array(
          'document_title_with_link' => $document_title_with_link,
          'group_title_with_link' => $group_title_with_link,
          'delete_document_link' => $delete_document_link,
          'queue' => true
      ));
    }
  }

  /**
   * Delete the groupdocument and ratings
   * 
   * @param int $document_id
   */
  public function deleteContent($document_id) {

    //GET THE DOCUMENT OBJECT
    $groupdocument = Engine_Api::_()->getItem('groupdocument_document', $document_id);

    if (empty($groupdocument)) {
      return;
    }

    include_once APPLICATION_PATH . '/application/modules/Groupdocument/Api/Scribdgroup.php';

    $this->scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->groupdocument_api_key;
    $this->scribd_secret = Engine_Api::_()->getApi('settings', 'core')->groupdocument_secret_key;
    $this->scribdgroup = new Scribdgroup($this->scribd_api_key, $this->scribd_secret);

    //DELETE DOCUMENT FROM SCRIBD
    if (!empty($groupdocument->doc_id)) {
      $this->scribdgroup->my_user_id = $groupdocument->owner_id;
      $this->scribdgroup->delete($groupdocument->doc_id);
    }

    //DELETE ENTRY FROM engine4_document_fields_search TABLE CORRESPONDIG TO item_id
    $searchTable = Engine_Api::_()->getItem('groupdocument_search', $document_id);
    if (!empty($searchTable)) {
      $searchTable->delete();
    }

    Engine_Api::_()->getDbtable('ratings', 'groupdocument')->delete(array('document_id = ?' => $document_id));

    //DELETE DOCUMENT FROM LOCAL SERVER
    $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
    $storageversion = $storagemodule->version;
    if ($storageversion < '4.1.1' && file_exists($groupdocument->storage_path) && !empty($groupdocument->storage_path)) {
      unlink($groupdocument->storage_path);
    }

    //DELETE DOCUMENT AND OTHER BELONGINGS
    $groupdocument->delete();
  }

  /**
   * Delete document from server
   * @param int $document_id : document id
   */
  public function deleteServerDocument($document_id) {

    $document = Engine_Api::_()->getItem('groupdocument_document', $document_id);

    $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
    $storageversion = $storagemodule->version;
    if ($storageversion < '4.1.1' && file_exists($document->storage_path) && !empty($document->storage_path)) {
      unlink($document->storage_path);
    }

    if (!empty($document->filename_id)) {
      $storage = Engine_Api::_()->getItem('storage_file', $document->filename_id);
      $fileName = $storage->name;
      $storage->delete();

      $document->storage_path = $fileName;
      $document->filename_id = 0;
      $document->save();
    }
  }

  /**
   * Get Truncation String
   *
   * @param string $text
   * @param int $limit
   * @return truncate string
   */
  public function truncateText($text, $limit) {
    $tmpBody = strip_tags($text);
    return ( Engine_String::strlen($tmpBody) > $limit ? Engine_String::substr($tmpBody, 0, $limit) . '..' : $tmpBody );
  }

  /**
   * Get group owner id
   *
   * @param int $group_id 
   * @return group owner id
   */
  public function groupUserID($group_id) {
    $groupTable = Engine_Api::_()->getItemTable('group');
    $group_user_id = $groupTable->select()
                    ->from($groupTable->info('name'), 'user_id')
                    ->where('group_id = ?', $group_id)
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);
    return $group_user_id;
  }

}