<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Groupdocument
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 6590 2010-10-19 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Groupdocument_Form_Admin_Global extends Engine_Form {

  public function init() {
    $this
            ->setTitle('Global Settings')
            ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'groupdocument_controllersettings', array(
        'label' => 'Enter License key',
        'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialEngineAddOns from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.controllersettings'),
    ));

    //GET SCRIBD KEYS IF OTHER DOCUMENT PLUGIN IS ALREADY INSTALLED AND HAVING THESE KEYS.
    $coreApi = Engine_Api::_()->getApi('settings', 'core');
    $scribd_api_key = $coreApi->getSetting('groupdocument.api.key');
    $scribd_secret_key = $coreApi->getSetting('groupdocument.secret.key');
    if (empty($scribd_api_key) && empty($scribd_secret_key)) {
      Engine_Api::_()->seaocore()->getScribdApiKeys('groupdocument');
    }

    $this->addElement('Text', 'groupdocument_api_key', array(
        'label' => 'Scribd API Key',
        'required' => true,
        'description' => 'The Scribd API Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.api.key', ''),
    ));

    $this->addElement('Text', 'groupdocument_secret_key', array(
        'label' => 'Scribd Secret Key',
        'required' => true,
        'description' => 'The Scribd Secret Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.secret.key', ''),
    ));


    if( APPLICATION_ENV == 'production' ) {
      $this->addElement('Checkbox', 'environment_mode', array(
          'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few pages of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
          'description' => 'System Mode',
          'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }


    $this->addElement('Button', 'submit_lsetting', array(
        'label' => 'Activate Your Plugin Now',
        'type' => 'submit',
        'ignore' => true
    ));

    $this->addElement('Radio', 'groupdocument_default_visibility', array(
        'label' => 'Visibility for Group Documents',
        'description' => 'Group documents visible only on this website will be private and available only on your website, whereas the ones which will be public on Scribd.com will be available to everyone on Scribd.(Note : This setting will only apply to new group documents created and not to the existing group documents on the site.)',
        'multiOptions' => array(
            'public' => 'Public on Scribd.com',
            'private' => 'Only on this website'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.default.visibility', 'private'),
    ));

    $this->addElement('Radio', 'groupdocument_visibility_option', array(
        'description' => 'Show visibility option to users. Allow users to choose whether their group documents will be public or private,i.e., available only on your website, or also on Scribd.com.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.visibility.option', 1),
    ));

    $this->addElement('Radio', 'groupdocument_carousel', array(
        'label' => 'Featured Documents Carousel',
        'description' => 'Do you want to show the carousel for featured documents in groups in the Documents tab of groups ?',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.carousel', 1),
    ));

    $this->addElement('Text', 'groupdocument_number_carousel', array(
        'label' => 'Documents in Featured Carousel',
        'description' => 'How many documents should be shown in the carousel for featured documents (value cannot be empty or zero) ?',
        'required' => true,
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.number.carousel', 15),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

    $this->addElement('Radio', 'groupdocument_featured', array(
        'label' => 'Making Group Documents Featured',
        'description' => 'Allow group owners to make documents in their groups as featured.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.featured', 1),
    ));

    $this->addElement('Radio', 'groupdocument_show_editor', array(
        'label' => 'WYSIWYG Editor',
        'description' => 'Allow WYSIWYG editor for description of group documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.show.editor', 1),
    ));

    $filesize = (int) ini_get('upload_max_filesize') * 1024;
    $show_description = Zend_Registry::get('Zend_Translate')->_('Enter the maximum group document file size in KB. Valid values are from 1 to %s KB.');
    $show_description = sprintf($show_description, $filesize);
    $this->addElement('Text', 'groupdocument_filesize', array(
        'label' => 'Maximum file size',
        'description' => $show_description,
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.filesize', 2048),
    ));

    $this->addElement('Radio', 'groupdocument_scribd_viewer', array(
        'label' => 'Default Document Viewer Type',
        'description' => 'Select the default viewer type for documents on your site. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
        'multiOptions' => array(
						1 => 'Flash Reader',
            0 => 'HTML5 Reader'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.scribd.viewer', 1),
    ));

    $this->addElement('Radio', 'groupdocument_fullscreen_button', array(
        'label' => 'Fullscreen option in Flash Reader',
        'description' => "Do you want the 'Fullscreen' option to be available in the Flash Reader?",
        'multiOptions' => array(
						0 => 'Yes',
            1 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.fullscreen.button', 0),
    ));

    $this->addElement('Radio', 'groupdocument_flash_mode', array(
        'label' => 'Default View Mode in Flash Reader',
        'description' => 'Choose the default view mode of Flash Reader for viewing documents. Users will be able to change the mode in the viewer.',
        'multiOptions' => array(
						'list' => 'List',
            'book' => 'Book',
            'slide' => 'Slide',
						'tile' => 'Tile'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.flash.mode', 'list'),
    ));

    $this->addElement('Radio', 'groupdocument_disable_button', array(
        'label' => 'Disabled links in Reader',
        'description' => 'Do you want the disabled links in the Document Viewer like Download, etc to be hidden?',
        'multiOptions' => array(
						1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.disable.button', 0),
    ));

    $this->addElement('Radio', 'groupdocument_rating', array(
        'label' => 'Group Document Rating',
        'description' => 'Allow logged-in users to give rating to group documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.rating', 1),
    ));

    $this->addElement('Radio', 'groupdocument_report', array(
        'label' => 'Report as inappropriate',
        'description' => 'Allow logged-in users to report group documents as inappropriate.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.report', 1),
    ));

    $this->addElement('Radio', 'groupdocument_share', array(
        'label' => 'Social Sharing Buttons',
        'description' => 'Do you want to show social sharing buttons on the main group document page ?',
        'multiOptions' => array(
            1 => ' 	Yes, show the social sharing buttons on the main group document page.',
            0 => ' 	No, do not show the social sharing buttons on the main group document page.'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.share', 1),
    ));

		$social_share_default_code = '<div class="addthis_toolbox addthis_default_style ">
		<a class="addthis_button_preferred_1"></a>
		<a class="addthis_button_preferred_2"></a>
		<a class="addthis_button_preferred_3"></a>
		<a class="addthis_button_preferred_4"></a>
		<a class="addthis_button_preferred_5"></a>
		<a class="addthis_button_compact"></a>
		<a class="addthis_counter addthis_bubble_style"></a>
		</div>
		<script type="text/javascript">
		var addthis_config = {
							services_compact: "facebook, twitter, linkedin, google, digg, more",
							services_exclude: "print, email"
		}
		</script>
		<script type="text/javascript" src="https://s7.addthis.com/js/250/addthis_widget.js"></script>';

    $this->addElement('Textarea', 'groupdocument_code_share', array(
        'description' => "Personalize the code for social sharing buttons by adding your own code generated from: <a href='http://www.addthis.com/' target='_blank'>http://www.addthis.com/</a>. If you do not want to show these buttons, then you can simply empty this field.",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.code.share', $social_share_default_code),
    ));
		$this->groupdocument_code_share->addDecorator('Description', array('placement' => 'PREPEND','class' => 'description', 'escape' => false));

    $this->addElement('Text', 'groupdocument_viewer_height', array(
        'label' => 'Document Viewer Height',
        'description' => 'What should be the height in pixels of the document viewer on document view page ?',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.viewer.height', 600),
    ));

    $this->addElement('Text', 'groupdocument_viewer_width', array(
        'label' => 'Document Viewer Width',
        'description' => 'What should be the width in pixels of the document viewer on document view page ?',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.viewer.width', 730),
    ));

    $this->addElement('Checkbox', 'groupdocument_licensing_option', array(
        'label' => 'Selecting this will allow users to choose the license to be associated with their group documents.',
        'description' => 'Show license option to users',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.licensing.option', 1),
    ));

    $this->addElement('Select', 'groupdocument_licensing_scribd', array(
        'label' => 'License associated with group documents',
        'description' => 'Choose the license to be associated with the group documents on your site. The license will be shown on your site, as well as on Scribd.com.',
        'multiOptions' => array(
            'ns' => 'Unspecified - no licensing information associated',
            'by' => 'By attribution (by)',
            'by-nc' => 'By attribution, non-commercial (by-nc)',
            'by-nc-nd' => 'By attribution, non-commercial, non-derivative (by-nc-nd)',
            'by-nc-sa' => 'By attribution, non-commercial, share alike (by-nc-sa)',
            'by-nd' => 'By attribution, non-derivative (by-nd)',
            'by-sa' => 'By attribution, share alike (by-sa)',
            'pd' => 'Public domain',
            'c' => 'Copyright - all rights reserved',
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.licensing.scribd', 'ns'),
    ));
    $this->groupdocument_licensing_scribd->getDecorator('Description')->setOption('placement', 'append');

    $this->addElement('Checkbox', 'groupdocument_include_full_text', array(
        'label' => "If this option is checked, the full text for a group document will be visible if downloading is enabled for that group document and if the iPaper viewer is not visible because of javascript being disabled on user's browser. Also, full text on the page allows search engines to index content, and increases SEO.",
        'description' => 'Include full text on pages',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.include.full.text', 1),
    ));

    $this->addElement('Radio', 'groupdocument_visitor_fulltext', array(
        'label' => '',
        'description' => ' Do you want full texts for group documents to be included on group document pages for non-logged-in users also? (Choosing "Yes" over here will enable full text on your group document pages to be indexed by search engines.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.visitor.fulltext', 1),
    ));

    $this->addElement('Checkbox', 'groupdocument_save_local_server', array(
        'label' => "Save group documents on your site's server",
        'description' => 'Save group documents on server',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.save.local.server', 1),
    ));

    $this->addElement('Radio', 'groupdocument_download_allow', array(
        'label' => 'Group Document downloading',
        'description' => 'Enable downloading of group documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.download.allow', 1),
    ));

    $this->addElement('Radio', 'groupdocument_download_show', array(
        'description' => 'Show option to users during group document creation to allow downloading of their group documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.download.show', 1),
    ));

    $this->addElement('Select', 'groupdocument_download_format', array(
        'label' => 'Download Format',
        'description' => 'Select the format in which the downloadable group documents will be downloaded in.',
        'multiOptions' => array(
            'pdf' => 'PDF',
            'original' => 'Original Group Document Format',
            'txt' => 'Plain Text'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.download.format', 'pdf'),
    ));

    $this->addElement('Radio', 'groupdocument_secure_allow', array(
        'label' => 'Secure iPaper Settings',
        'description' => 'Secure group document iPaper cannot be embedded on other sites. Note that this is a permanent setting for a group document during its first upload. Thus any change in this setting will only work for new group document uploads.(Note : This setting will only apply to new group documents created and not to the existing group documents on the site. )',
        'multiOptions' => array(
            1 => 'Make iPaper group documents secure. Do not allow embedding on other sites. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
            0 => 'Do not make iPaper group documents secure. Allow embedding on other sites.'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.secure.allow', 0),
    ));

    $this->addElement('Radio', 'groupdocument_secure_show', array(
        'description' => 'Show security option to users. Allow users to choose if their group documents should be secure or not.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.secure.show', 1),
    ));

    $this->addElement('Radio', 'groupdocument_email_allow', array(
        'label' => 'Email attachment Settings',
        'description' => 'Enable emailing as attachments for group documents on your site.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.email.allow', 1),
    ));

    $this->addElement('Radio', 'groupdocument_email_show', array(
        'description' => 'Allow members to choose during group document creation if their group documents could be emailed as attachments or not.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.email.show', 1),
    ));

    $this->addElement('Radio', 'groupdocument_title_truncation', array(
        'label' => 'Show Full Title Without Truncation',
        'description' => 'Do you want to show the full group document title without truncation on various pages like widgets, group profile etc..',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.title.truncation', 0),
    ));

    $this->addElement('Button', 'submit', array(
        'label' => 'Save Changes',
        'type' => 'submit',
        'ignore' => true
    ));
  }

}
