<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Groupdocument
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Groupdocuments.php 6590 2010-10-19 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Groupdocument_Model_DbTable_Documents extends Engine_Db_Table {

  protected $_name = 'groupdocument_documents';
  protected $_rowClass = 'Groupdocument_Model_Document';

  /**
   * Get groupdocument detail
   * @param array $params : contain desirable groupdocument info
   * @return  object of groupdocument
   */
  public function getGroupdocumentsPaginator($params = array(), $customParams = null) {
    $paginator = Zend_Paginator::factory($this->getGroupdocumentsSelect($params, $customParams));
    if (!empty($params['page'])) {
      $paginator->setCurrentPageNumber($params['page']);
    }
    if (!empty($params['limit'])) {
      $paginator->setItemCountPerPage($params['limit']);
    }
    return $paginator;
  }

  /**
   * Get groupdocuments 
   * @param array $params : contain desirable groupdocument info
   * @return  array of groupdocuments
   */
  public function getGroupdocumentsSelect($params = array(), $customParams = null) {

    $tableDocument = Engine_Api::_()->getDbtable('documents', 'groupdocument');
    $tableDocumentName = $tableDocument->info('name');

    $select = $tableDocument->select();

    if (!empty($params['orderby'])) {
      $select = $select->order($tableDocumentName . '.' . $params['orderby'] . ' DESC');
    }

    if (!empty($params['orderby']) && $params['orderby'] != 'document_id') {
      $select = $select->order($tableDocumentName . '.document_id DESC');
    }

    $searchTable = Engine_Api::_()->fields()->getTable('groupdocument_document', 'search')->info('name');
    $select = $select
                    ->setIntegrityCheck(false)
                    ->from($tableDocumentName, array('document_id', 'owner_id', 'group_id', 'groupdocument_title', 'groupdocument_description', 'doc_id', 'thumbnail', 'creation_date', 'rating', 'comment_count', 'like_count', 'views', 'featured', 'search', 'draft', 'featured', 'approved', 'status'))
                    ->group("$tableDocumentName.document_id");

    if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
      $select->where($tableDocumentName . '.owner_id = ?', $params['user_id']);
    }

    if (!empty($params['user']) && $params['user'] instanceof User_Model_User) {
      $select->where($tableDocumentName . '.owner_id = ?', $params['user_id']->getIdentity());
    }

    if (!empty($params['users'])) {
      $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
      $select->where($tableDocumentName . '.owner_id in (?)', new Zend_Db_Expr($str));
    }

    if (isset($params['owner_id'])) {
      $select->where($tableDocumentName . '.owner_id = ?', $params['owner_id']);
    }

    if (isset($params['draft'])) {
      $select->where($tableDocumentName . '.draft = ?', $params['draft']);
    }

    if (isset($params['approved'])) {
      $select->where($tableDocumentName . '.approved = ?', $params['approved']);
    }

    if (isset($params['group_id'])) {
      $select->where($tableDocumentName . '.group_id = ?', $params['group_id']);
    }

    if (isset($params['featured'])) {
      $select->where($tableDocumentName . '.featured = ?', $params['featured']);
    }

    if (isset($params['status'])) {
      $select->where($tableDocumentName . '.status = ?', $params['status']);
    }

    if (!empty($params['search'])) {
      $select->where($tableDocumentName . ".fulltext LIKE ? OR " . $tableDocumentName . ".groupdocument_title LIKE ? OR " . $tableDocumentName . ".groupdocument_description LIKE ?", '%' . $params['search'] . '%');
    }

    if (!empty($params['visible'])) {
      $select->where($tableDocumentName . ".search = ?", $params['visible']);
    }

    if (!empty($params['show_document']) && empty($params['search']) && empty($params['featured'])) {
      $select->where($tableDocumentName . ".draft = ?", 0)
              ->where($tableDocumentName . ".approved = ?", 1)
              ->where($tableDocumentName . ".status = ?", 1)
							->where($tableDocumentName . ".search = ?", 1)
              ->orwhere($tableDocumentName . ".owner_id = ?", $params['document_owner_id']);
    }

    if (!empty($params['show_document']) && (!empty($params['search']) || !empty($params['featured']))) {
      $select->where("($tableDocumentName.draft = 0 AND $tableDocumentName.approved = 1 AND $tableDocumentName.status = 1 AND $tableDocumentName.search = 1)  OR ($tableDocumentName.owner_id = " . $params['document_owner_id'] . ")");
    }

    if (isset($params['group_id'])) {
      $select->where($tableDocumentName . '.group_id = ?', $params['group_id']);
    }

    return $select;
  }

  /**
   * Documents from same group
   * @param int $document_id : groupdocument id
   * @param int $group_id : group id
   * @return same group documents
   */
  public function sameGroupDocuments($group_id, $document_id) {

    $selectUserDocs = $this->select()
                    ->from($this->info('name'), array('groupdocument_title', 'rating', 'owner_id', 'thumbnail', 'groupdocument_description',
                        'views', 'creation_date', 'modified_date', 'comment_count', 'like_count', 'document_id'))
                    ->where('group_id = ?', $group_id)
                    ->where('document_id != ?', $document_id)
                    ->where('approved = ?', 1)
                    ->where('draft = ?', 0)
                    ->where('status = ?', 1)
										->where('search = ?', 1)
                    ->order('creation_date DESC')
                    ->limit(4);
    return $this->fetchAll($selectUserDocs);
  }

  /**
   * Featured documents
   * @param int $group_id : group id
   * @return  featured documents
   */
  public function featuredDocuments($group_id) {

    //NUMBER OF DOCUMENTS IN CAROUSEL
    $show_featured = Engine_Api::_()->getApi('settings', 'core')->getSetting('groupdocument.number.carousel', 15);

    $select = $this->select()
                    ->from($this->info('name'), array('groupdocument_title', 'rating', 'owner_id', 'thumbnail', 'groupdocument_description',
                        'views', 'creation_date', 'modified_date', 'comment_count', 'like_count', 'document_id'))
                    ->where('group_id = ?', $group_id)
                    ->where('draft = ?', 0)
                    ->where('approved = ?', 1)
                    ->where('status = ?', 1)
										->where('search = ?', 1)
                    ->where('featured = ?', 1)
                    ->order('document_id DESC')
                    ->limit($show_featured);
    return $this->fetchAll($select);
  }

  /**
   * Documents of same group for scribd conversion
   * @param int $group_id : group id
   * @return documents of status zero
   */
  public function updateDocs($group_id) {

    $selectDocs = $this->select()
                    ->from($this->info('name'), array('document_id', 'owner_id', 'doc_id', 'fulltext', 'thumbnail', 'status', 'activity_feed'))
                    ->where('status = ?', 0)
                    ->where('group_id = ?', $group_id)
                    ->order('document_id DESC')
                    ->limit(5);
    return $this->fetchAll($selectDocs);
  }

  /**
   * Return document data
   *
   * @param array params
   * @return Zend_Db_Table_Select
   */
  public function widgetDocumentsData($params = array()) {

    $select = $this->select()
                    ->from($this->info('name'), array('document_id', 'group_id', 'owner_id', 'groupdocument_title', 'creation_date', 'thumbnail', 'rating', 'comment_count', 'like_count', 'views', 'featured'))
                    ->where('draft = ?', 0)
                    ->where('approved = ?', 1)
                    ->where('status = ?', 1)
                    ->where('search = ?', 1);

    if (isset($params['zero_count']) && !empty($params['zero_count'])) {
      $select = $select->where($params['zero_count'] . '!= ?', 0);
    }

    if (isset($params['featured']) && !empty($params['featured'])) {
      $select = $select->where('featured = ?', 1);
    }
    
    if (isset($params['group_id']) && !empty($params['group_id'])) {
      $select = $select->where('group_id = ?', $params['group_id']);
    }    

    if (isset($params['orderby']) && !empty($params['orderby'])) {
      $select = $select->order($params['orderby']);
    }
    else {
      $select->order('document_id DESC');
    }

    if (isset($params['limit']) && !empty($params['limit'])) {
      $select = $select->limit($params['limit']);
    }

    return $this->fetchAll($select);
  }

  /**
   * Return documents of same group
   *
   * @param int $group_id
   * @param int $owner_id
   * @return Zend_Db_Table_Select
   */
	public function getGroupDocuments($group_id, $owner_id) {
		
		//MAKE QUERY
		$select = $this->select()->from($this->info('name'), 'document_id');

		if(!empty($group_id)) {
			$select = $select->where('group_id = ?', $group_id);
		}

		if(!empty($owner_id)) {
			$select = $select->where('owner_id = ?', $owner_id);
		}

		//RETURN RESULTS
		return $this->fetchAll($select);
	}
}