<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Instaclone
 * @copyright  Copyright 2015-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminLayoutController.php 2018-05-15 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Instaclone_AdminLandingPageController extends Core_Controller_Action_Admin
{
  public function rightLayoutAction()
  {

    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('instaclone_admin_main', array(), 'instaclone_admin_landingpage_text_banner');

    //MAKE FORM
    $this->view->form = $form = new Instaclone_Form_Admin_Settings_Landingpage_Landing();

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $values = $form->getValues();

    foreach( $values as $key => $value ) {
      if ( $coreSettings->hasSetting( $key, $value ) ) {
          $coreSettings->removeSetting($key);
      }
      $coreSettings->setSetting($key, $value);
    }
    $form->addNotice('Your changes have been saved.');

  }

  public function leftLayoutAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('instaclone_admin_main', array(), 'instaclone_admin_landingpage_slider');

    $tableSimages = Engine_Api::_()->getDbtable('simages', 'instaclone');
    $select = $tableSimages->select()->where('saved = ?', 1);
    $select->order('order ASC');
    // $select->order('simage_id DESC');

    $this->view->list = Zend_Paginator::factory($select);
    $items_per_page = 10;
    $this->view->list->setItemCountPerPage($items_per_page);
    $this->view->list = $this->view->list->setCurrentPageNumber($this->_getParam('page'));

  }

  public function saveValues($form)
  {
    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $values = $form->getValues();
    foreach( $values as $key => $value ) {
      $coreSettings->setSetting($key, $value);
    }
    $form->addNotice('Your changes have been saved.');
  }

  public function setPhoto($photo, $parent_id = null, $parent_type = null) {
    if ($photo instanceof Zend_Form_Element_File) {
        $file = $photo->getFileName();
    } else if (is_array($photo) && !empty($photo['tmp_name'])) {
        $file = $photo['tmp_name'];
    } else if (is_string($photo) && file_exists($photo)) {
        $file = $photo;
    } else {
        throw new Engine_Exception('invalid argument passed to setPhoto');
    }

    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

    $thumb_file = $path . '/in_' . $name;
    $image = Engine_Image::factory();

    $image->open($file)
                  ->resize(64, 64)
                  ->write($thumb_file)
                  ->destroy();
    try {
        $thumbFileRow = Engine_Api::_()->storage()->create($thumb_file, array(
            'parent_type' => $parent_type,
            'parent_id' => $parent_id
        )); 
        // Remove temp file
        @unlink($thumb_file); 
    } catch (Exception $e) {
        
    }

    $file_id = $thumbFileRow->file_id;
    return $file_id;
  }

  public function uploadAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('instaclone_admin_main', array(), 'instaclone_admin_landingpage_slider');

    //MAKE FORM
    $this->view->form = $form = new Instaclone_Form_Admin_Settings_Landingpage_SlideImage();

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $values = $form->getValues();
    if(empty($values['file'][0]) ) {
      $form->file->setErrors(array("File 'photo' is not uploaded. Please select photo"));
          return;
    }
    $simagesTable = Engine_Api::_()->getDbTable('simages','instaclone');
    $simages = $simagesTable->fetchAll($simagesTable->select()->where('saved = ?', 0));
    foreach ($simages as $key => $simage) {
      if(!in_array($simage->getIdentity(), $values['file'])){
        $simage->delete();
      } else {
        $simage->enabled = 1;
        $simage->saved = 1;
        $simage->save();
      }
    }

    $this->_redirect('admin/instaclone/slider-images');
  }


  public function imageUploadAction()
  {
    if( !$this->_helper->requireUser()->checkRequire() )
    {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
      return;
    }

    if( !$this->getRequest()->isPost() )
    {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
      return;
    }

    $values = $this->getRequest()->getPost();

    if (empty($_FILES['file'])) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('No file');
      return;
    }

    $db = Engine_Api::_()->getDbTable('simages','instaclone')->getAdapter();
    $db->beginTransaction();

    try {
      $viewer = Engine_Api::_()->user()->getViewer();

      $simagesTable = Engine_Api::_()->getDbTable('simages','instaclone');
      $photo = $simagesTable->createRow();
      $photo->title = $_FILES['file']['name'];
      $photo->enabled = 0;
      $photo->order = 0;
      $photo->saved = 0;
      $photo->save();


      $photo->setPhoto($_FILES['file']);

      $this->view->status = true;
      $this->view->name = $_FILES['file']['name'];
      $this->view->photo_id = $photo->simage_id;

      $db->commit();

      $this->sendJson([
        'id' => $photo->simage_id,
        'fileName' => $_FILES['file']['name']
      ]);
    }

    catch( Exception $e )
    {
      $db->rollBack();
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
      // throw $e;
      return;
    }
  }


  //ACTION FOR MAKE SLIDESHOW ENABLE/DIS-ABLE
    public function enabledAction() {
        //GET SLIDESHOW ID
        $id = $this->_getParam('id');
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            //GET SLIDESHOW OBJECT
          $table = Engine_Api::_()->getDbtable('simages', 'instaclone');
          $simage = $table->fetchRow($table->select()->where('simage_id = ?', $id));
          if ($simage->enabled == 0) {
              $simage->enabled = 1;
          } else {
              $simage->enabled = 0;
          }
          $simage->save();
          $db->commit();
        } catch (Exception $e) {
          $db->rollBack();
          throw $e;
        }
        $this->_redirect('admin/instaclone/landing-page/left-layout');
    }

    //ACTION FOR DELETE SLIDESHOW
    public function deleteAction() {
        //LAYOUT
        $this->_helper->layout->setLayout('admin-simple');

        //GET SLIDESHOW ID
        $this->view->id = $id = $this->_getParam('id');

        if ($this->getRequest()->isPost()) {
          $table = Engine_Api::_()->getDbtable('simages', 'instaclone');

          $result = $table->fetchRow($table->select()->where('simage_id = ?', $id));
          $result->delete();
          $this->_forward('success', 'utility', 'core', array(
              'smoothboxClose' => 10,
              'parentRefresh' => 10,
              'messages' => array('')
          ));
        }
        $this->renderScript('admin-landing-page/delete.tpl');
    }

    //ACTION FOR DELETE SLIDESHOW AND THEIR BELONGINGS
    public function multiDeleteAction() {
        if ($this->getRequest()->isPost()) {

          $values = $this->getRequest()->getPost();
          $table = Engine_Api::_()->getDbtable('simages', 'instaclone');
          //IF ADMIN CLICK ON DELETE SELECTED BUTTON
          foreach ($values as $key => $value) {
              if ($key == 'delete_' . $value) {
                  $id = (int) $value;
                  $result = $table->fetchRow($table->select()->where('simage_id = ?', $id));
                  $result->delete();
              }
          }
        }
        $this->_redirect('admin/instaclone/landing-page/left-layout');
    }


    public function orderAction() {
        if (!empty($_POST)) {
            foreach ($_POST as $key => $value) {
                if (strstr($key, "content_")) {
                    $keyArray = explode("content_", $key);

                    if (!empty($keyArray))
                        $image_id = end($keyArray);

                    if (!empty($image_id)) {
                        $obj = Engine_Api::_()->getItem('instaclone_simage', $image_id);
                        $obj->order = $value;
                        $obj->save();
                    }
                }
            }
        }
    }

    public function editImageAction() {
        $simage_id = $this->_getParam('simage_id');
        $simage = Engine_Api::_()->getItem('instaclone_simage', $simage_id);
        $this->_helper->layout->setLayout('default-simple');
        $form = $this->view->form = new Instaclone_Form_Admin_Settings_Landingpage_Edit();
        $title = $simage->title;
        $form->title->setValue($title);
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

            $simage->title = $_POST['title'];
            $simage->save();
            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'))
            ));
        }
    }


}
