<?php
/**
 * SocialEngine
 *
 * @category   Application_Core
 * @package    PrimeMessenger
 * @copyright  Copyright 2017-2018 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: Membership.php 10088 2017-06-12 13:34:37Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
use PrimeMessenger\Primemessenger\ChatRoom;
use PrimeMessenger\Primemessenger\ChatMessage;
require_once APPLICATION_PATH . '/application/modules/Primemessenger/getid3/getid3.php';

class Primemessenger_Model_DbTable_Conversations extends Messages_Model_DbTable_Conversations
{
    protected $_name = 'messages_conversations';

    public function send(Core_Model_Item_Abstract $user, $recipients, $title, $body, $attachment = null)
    {
        $conversation = parent::send($user, $recipients, $title, $body, $attachment);
        try {
            foreach($recipients as $recipientId) {
                $messageData = $this->_translateMessage($user, $recipientId, $title, $body, $attachment);
                if($messageData){
                    $chatMessage = new ChatMessage();
                    $chatMessage->create($messageData);
                }
            }

        } catch (Exception $e) {
            echo $e;die;
        }

        return $conversation;
    }


    private function _translateMessage($user, $recipientId, $title, $body, $attachment) {
        $data = array();

        // Get attachment data
        if (!empty($attachment)) {
            if (!empty($attachment->file_id)) {
                $data['file'] = Engine_Api::_()->storage()->get($attachment->file_id);
            }
        }

        $data['userId'] = (string) $recipientId;
        if(!$data['file']){
           $data['body'] = $body;  
        }
        $data['ownerId'] = (string) $user->user_id;
        return $data;
    }

    private function getAudioVideoDuration($file)
    {
        // Copy remote file locally to scan with getID3()
        if ($fpRemote = fopen($file, 'rb')) {
            $localtempfilename = tempnam('/tmp', 'getID3');
            if ($fpLocal = fopen($localtempfilename, 'wb')) {
                while ($buffer = fread($fpRemote, 8192)) {
                    fwrite($fpLocal, $buffer);
                }
                fclose($fpLocal);
                // Initialize getID3 engine
                $getID3 = new getID3;
                $fileInfo = $getID3->analyze($localtempfilename);
                $duration = $this->convertTimeIntoSeconds($fileInfo['playtime_string']);
 
                // Delete temporary file
                unlink($localtempfilename);
            }
            fclose($fpRemote);
            return $duration;
        }
    }

    private function convertTimeIntoSeconds($time)
    {
        $time = explode(':', $time);
        if (count($time) == 1) {
            $timeInSeconds = $time[0];
        } elseif(count($time) == 2) {
            $timeInSeconds = $time[0] * 60 + $time[1];
        } elseif(count($time) == 3) {
            $timeInSeconds = $time[0] * 3600 + $time[1] * 60 + $time[2];
        }
        return $timeInSeconds;
    }

    private function _getFileUrl($resource, $type = 'main') {
        if ($resource instanceof Core_Model_Item_Abstract) {
            $filePath = $resource->getPhotoUrl();
        } else {
            $filePath = $resource;
        }

        if (!$filePath) {
            return;
        }

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        if (!preg_match('/http:\/\//', $filePath) && !preg_match('/https:\/\//', $filePath)) {
            $filePath = str_replace($view->baseUrl(), "",  $filePath);
            $path = $view->serverUrl() . $view->baseUrl() . '/' . $filePath;
        } else {
            $path = $filePath;
        }

        return $path;
    }
}