<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ChatWhispers.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class PrimeMessenger_Migrate_Chat_ChatWhispers extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_chat_whispers';
    protected $_warningMessage = array();
    protected $_priority = 500;
    protected $_jsonFileName = 'chat-messages';
    protected $_chatRoomData = null;

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'chat_whispers';
      $this->lastChatRoomsMessageId = $this->getFromDb()->select()
        ->from($this->getfromPrefix() . 'chat_messages', 'message_id')
        ->order('message_id DESC')
        ->query()
        ->fetchColumn();
    }
    
    protected function _setChatRoomData(){
        
        if($this->_chatRoomData){
            return;
        }
        
        $path = realpath(dirname(__FILE__) . '/../../data/chat-rooms.json');
        
        try{
        $chatRoomData = json_decode(file_get_contents($path) , true);
        }
        catch (Exception $e) {
                return $this->_error($e);
        }
        $this->_chatRoomData = $chatRoomData;
    }
    

    protected function _translateRow(array $data, array &$jsonData) {

        $this->_setChatRoomData();

        // If Message have no body then not migrate..
        if(!$data['body']){
               return;
        }

        $recipients = array_values(array_filter([$data['sender_id'] ,$data['recipient_id']]));
        $roomId = $this->getRoomId($recipients);
        
        $newData = array();
        $newData['messageId'] = $this->getMessageId($data);
        $newData['roomId'] = $roomId;
        $newData['body'] = $data['body'];
        $newData['ownerId'] = $data['sender_id'];
        $newData['createdAt'] = $data['date'];
        $newData['recipients'] = $recipients;
        $newData['attachmentType'] = 'text';
        $newData['attachmentData'] = [];
                
        $jsonData[] =  $newData;
    }
    
   public function getRoomId($recipients){
       $chatRoomDataContainer = $this->_chatRoomData;
       foreach($chatRoomDataContainer as $chatRoomData){
         $isRoomExist = $this->array_equal($recipients , $chatRoomData['members']);
         if($isRoomExist){
           return $chatRoomData['roomId'];
         }
       }
       $this->_setChatRoomData();
   }
   
   public function getMessageId($data){
       $lastChatRoomsMessageId = $this->lastChatRoomsMessageId ? $this->lastChatRoomsMessageId : 0;
       $messageId = $lastChatRoomsMessageId + $data['whisper_id'];
        return $messageId;
   }
   
   public function array_equal($a, $b, $strict=false) {
    if (count($a) !== count($b)) {
        return false;
    }
    sort($a);
    sort($b);
    return ($strict && $a === $b) || $a == $b;
  }

}

