<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ChatWhispersRoom.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class PrimeMessenger_Migrate_Chat_ChatWhispersRoom extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_chat_whispers';
    protected $_warningMessage = array();
    protected $_priority = 600;
    protected $_jsonFileName = 'chat-rooms';
    protected $_initialRoomId = null;
    protected $_nextRoomId = null;
    protected $_prevdata = [];

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'chat_whispers';
        
        $this->_initialRoomId = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'chat_rooms', 'room_id')
                ->order('room_id DESC')
                ->query()
                ->fetchColumn()+1;
    }

    protected function _translateRow(array $data, array &$jsonData) {        
        $members = array_values(array_filter([$data['recipient_id'] , $data['sender_id']]));
       
        if($this->checkRoomExist($members)){
            return; 
        }
        
        $this->_nextRoomId = !$this->_nextRoomId ? $this->_initialRoomId  : $this->_nextRoomId+1;
        
        $result = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'chat_whispers', array('whisper_id' ,'date'))
                ->where('sender_id IN (?)', $members)
                ->where('recipient_id IN (?)', $members)
                ->order('whisper_id DESC')
                ->query()
                ->fetchAll();

        $updatedAt = $result[0]['date'];
        
        $newData = array();
        $newData['roomId'] = $this->_nextRoomId;
        $newData['memberCount'] = 2;
        $newData['ownerId'] = $data['sender_id'];
        $newData['resourceType'] = 'user';
        $newData['members'] = $members;
        $newData['createdAt'] = $data['date'];
        $newData['updatedAt'] = $updatedAt;
                
        $this->setPreviousData($newData);
        $jsonData[] =  $newData;
    }
    
    public function setPreviousData($newData){
       $_prevdata = $this->_prevdata;
       array_push($_prevdata , $newData);
       $this->_prevdata = $_prevdata;
       return $this->_prevdata;
    }
    
   public function checkRoomExist($members){
       $_prevdataContainer = $this->_prevdata;
       foreach($_prevdataContainer as $_prevdata){
         $isRoomExist = $this->array_equal($members , $_prevdata['members']);
         if($isRoomExist){
           return true;
         }
       }
       return false;
   }
   
   public function array_equal($a, $b, $strict=false) {
    if (count($a) !== count($b)) {
        return false;
    }
    sort($a);
    sort($b);
    return ($strict && $a === $b) || $a == $b;
  }

}