<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    DbAbstract.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
abstract class PrimeMessenger_Migrate_DbAbstract extends PrimeMessenger_Migrate_Abstract {
    protected $_fromDb;
    protected $_fromPrefix;
    protected $_fromTable;
    protected $_fromJoins;
    protected $_fromTableExists;
    protected $_fromWhere;
    protected $_fromOrderBy = null;
    protected $_fromGroupBy = null;
    protected $_batchCount;
    protected $_selectCount = 6;
    protected $_runCount = 0;
    protected $_isComplete = false;
    protected $_successCount = 0;
    protected $_failureCount = 0;
    protected $_totalFromRecords;
    protected $_dataRecursiveMerge = false;
    protected $_jsonFileName;
    public function __sleep() {
        return array_merge(parent::__sleep(), array(
            '_fromDb', '_fromPrefix', '__fromTable', '_fromJoins', '_fromTableExists', '_fromWhere',
            '_selectCount', '_runCount', '_successCount', '_failureCount', '_totalFromRecords'
        ));
    }
    public function setFromDb(Zend_Db_Adapter_Abstract $fromDb) {
        $this->_fromDb = $fromDb;
        return $this;
    }
    /**
     * @return Zend_Db_Adapter_Abstract
     */
    public function getFromDb() {
        if (null === $this->_fromDb) {
            throw new Engine_Exception('No from database');
        }
        return $this->_fromDb;
    }
    public function getFromPrefix() {
        if (null === $this->_fromPrefix) {
            throw new Engine_Exception('No prefix');
        }
        return $this->_fromPrefix;
    }
    public function setFromPrefix($fromPrefix) {
        $this->_fromPrefix = $fromPrefix;
        return $this;
    }
    public function setFromTable($fromTable) {
        $this->_fromTable = $fromTable;
        return $this;
    }
    public function getFromTable() {
        if (null === $this->_fromTable) {
            throw new Engine_Exception('No from table');
        }
        return $this->_fromTable;
    }
    public function getFromTableExists() {
        if (null === $this->_fromTable) {
            return false;
        }
        if (null === $this->_fromTableExists) {
            $this->_fromTableExists = $this->_tableExists($this->getFromDb(), $this->getFromTable());
        }
        return $this->_fromTableExists;
    }
    public function setBatchCount($batchCount) {
        $this->_batchCount = (int) $batchCount;
        return $this;
    }
    public function getBatchCount() {
        return $this->_batchCount;
    }
    public function setSelectCount($selectCount) {
        $this->_selectCount = (int) $selectCount;
        return $this;
    }
    public function getSelectCount() {
        if (!is_int($this->_selectCount) || $this->_selectCount <= 0) {
            $this->_selectCount = 100;
        }
        return $this->_selectCount;
    }
    public function getRunCount() {
        return $this->_runCount;
    }
    public function getTotalFromRecords() {
        return $this->_totalFromRecords;
    }
    public function isComplete() {
        return (bool) $this->_isComplete;
    }
    public function init() {
        $this->_initPre();
        $this->_init();
        $this->_initPost();
        // Try to get total rows now
        try {
            if (null === $this->_totalFromRecords) {
                if (null !== $this->_fromTable) {
                    $this->_totalFromRecords = (int) $this->getFromDb()->select()
                                    ->from($this->getFromTable(), new Zend_Db_Expr('COUNT(*)'))
                                    ->query()
                                    ->fetchColumn(0);
                }
            }
        } catch (Exception $e) {
            // Silence
        }
    }
    public function run() {
        $this->_message('(START)', 2);
        try {
            $this->_runPre();
            $this->_run();
            $this->_runPost();
        } catch (Exception $e) {
            $this->_error($e->getMessage(), 0);
        }
        $this->_message('(END)', 2);
    }
    protected function _run() {
        // We're done
        if ($this->_isComplete) {
            return;
        }
        // Get from db/table, check if it exists
        try {
            $fromDb = $this->getFromDb();
            $fromTable = $this->getFromTable();
        } catch (Exception $e) {
            return $this->_error($e);
        }
        $fromTables = array_keys((array) $this->_fromJoins);
        $fromTables[] = $fromTable;
        $fromTables = array_filter($fromTables);
        if (!$fromTables || empty($fromTables) || !is_array($fromTables) || count($fromTables) < 1) {
            $this->_error('No from table specified.', 0);
            return;
        }
        if (!$this->_tableExists($fromDb, $fromTables)) {
            $msg = '@@@@@One of the source tables does not exist (%s). This usually means you did not have the plugin installed.$$$key$$$' . join('_', $fromTables);
            if (count($this->_warningMessage) > 0)
                $msg = "@@@@@" . $this->_warningMessage['value'] . '$$$key$$$' . $this->_warningMessage['key'];
            $this->_warning(sprintf($msg, join(', ', $fromTables)), 0);
            return;
        }
        $this->_isComplete = false;
        // Select query
        $select = $fromDb->select();
        $select->from($fromTable);
        if ($this->_fromJoins && is_array($this->_fromJoins)) {
            foreach ($this->_fromJoins as $table => $condition) {
                $select->joinLeft($table, $condition);
            }
        }
        if ($this->_fromWhere && is_array($this->_fromWhere)) {
            foreach ($this->_fromWhere as $cond => $value) {
                $select->where($cond, $value);
            }
        }
        $this->_message($select->__toString(), 2);
        $tmpSelect = clone $select;
        if (!empty($this->_fromOrderBy) && is_array($this->_fromOrderBy) && isset($this->_fromOrderBy[0]) && isset($this->_fromOrderBy[1]) && is_array($this->_fromOrderBy[0])) {
            if (!in_array(strtolower($this->_fromOrderBy[1]), array('asc', 'desc'))) {
                $this->_fromOrderBy[1] = 'ASC';
            }
            $select->order($this->_fromOrderBy[0], $this->_fromOrderBy[1]);
        }
        $dataSet = $tmpSelect
                ->query(Zend_Db::FETCH_ASSOC)
                ->fetchAll();
        // Translate data for every row
        $newData = array();
        foreach ($dataSet as $rawData) {
            try {
                $this->_translateRow($rawData, $newData);
            } catch (Exception $e) {
                return $this->_error($e);
            }
        }
        // Create json files
        try {
            set_time_limit(0);
            ini_set('max_execution_time', 600);
            $this->_createJsonFile($newData);
        } catch (Exception $e) {
            return $this->_error($e);
        }
        // If we're in batch mode, strip success and failure messages and re-add
        if (null !== $this->getBatchCount()) {
            foreach ($this->_messages as $index => $message) {
                if (strpos($message, 'Success - ') !== false || strpos($message, 'Failure - ') !== false) {
                    unset($this->_messages[$index]);
                }
            }
            $this->_messages = array_values($this->_messages);
        }
        $this->_isComplete = true;
        $this->_message(sprintf('Success - %1$d records have been added in migration queue.', $this->_totalFromRecords), 1);
    }
    protected function _tableExists(Zend_Db_Adapter_Abstract $db, $table) {
        if (is_array($table)) {
            $exists = true;
            foreach ($table as $singleTable) {
                $exists &= $this->_tableExists($db, $singleTable);
            }
            return $exists;
        }
        $sql = 'SHOW TABLES LIKE ' . $db->quote($table);
        $ret = $db->query($sql)->fetchColumn();
        if (!$ret) {
            return false;
        } else {
            return true;
        }
    }
}