<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    MessagesMessages.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
require_once APPLICATION_PATH . '/application/modules/Primemessenger/getid3/getid3.php';

class PrimeMessenger_Migrate_Messages_MessagesMessages extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_messages_messages';
    protected $_warningMessage = array();
    protected $_priority = 300;
    protected $_jsonFileName = 'message';
    protected $messages= array();
    protected $roomMergingData = array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'messages_messages';
    }

    protected function _translateRow(array $rawData, array &$newData) {
        $attachmentType = 'text';
        $attachmentData = array();
    
        // If Message have no body then not migrate..
        if(!$rawData['body']){
           return;
        }

        // Get message messages_recipients
        $recipients = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'messages_recipients', 'user_id')
                ->where('conversation_id = ?', $rawData['conversation_id'])
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);
        $recipients = array_values(array_filter($recipients));

        $recipients = array_unique($recipients);
        
        if(count($recipients)<2){
            return;
        }

        // Get attachment data
        if (!empty($rawData['attachment_type']) && !empty($rawData['attachment_id'])) {

            $isItem = Engine_Api::_()->hasItemType($rawData['attachment_type']);

            if(!$isItem){
                return;
            }

            $attachment = Engine_Api::_()->getItem($rawData['attachment_type'], $rawData['attachment_id']);
            if ($attachment instanceof Core_Model_Link) {
                $attachmentType = 'link';
                $attachmentId = $this->getGuid();
                $attachmentData = array(
                    "_id" =>  $attachmentId,
                    'title' => $attachment->title,
                    'description' => $attachment->description,
                    'thumbnailUrl' => !empty($attachment->photo_id) ? $this->_getFileUrl($attachment, 'normal') : null,
                    'url' => $attachment->uri,
                    'resourceId' => (string) $rawData['message_id'],
                    'resourceType' => 'message'
                );

                $this->_createJsonFile([$attachmentData], 'link');
            } else if ($attachment instanceof Video_Model_Video && !$attachment->file_id) {
                $attachmentType = 'link';
                $attachmentId = $this->getGuid();
                $attachmentData = array(
                    "_id" =>  $attachmentId,
                    'title' => $attachment->title,
                    'description' => $attachment->description,
                    'thumbnailUrl' => !empty($attachment->photo_id) ? $this->_getFileUrl($attachment, 'normal') : null,
                    'resourceId' => (string) $rawData['message_id'],
                    'resourceType' => 'message'
                );
                if ($attachment->type = 'youtube') {
                    $attachmentData['url'] = 'www.youtube.com/embed/' . $attachment->code;
                } else {
                    $attachmentData['url'] = 'player.vimeo.com/video/embed/' . $attachment->code;
                }

                $this->_createJsonFile([$attachmentData], 'link');
            } else if (!empty($attachment->file_id)) {
                $storageFile = Engine_Api::_()->storage()->get($attachment->file_id);
                $attachmentType = $storageFile->mime_major;
                $attachmentId = $this->getGuid();

                if ($attachmentType == 'application') {
                    $attachmentType = 'audio';
                }
                
                $isFileExist = $this->remoteFileExists($this->_getFileUrl($storageFile->getHref()));
                if(!$isFileExist){
                   return;
                }

                $attachmentData = array(
                    '_id' => $attachmentId,
                    'name' => $storageFile->name,
                    'mimeType' => $storageFile->mime_major . '/' . $storageFile->mime_minor,
                    'size' => $storageFile->size,
                    'extension' => $storageFile->extension,
                    'fileUrl' => $this->_getFileUrl($storageFile->getHref()),
                    'thumbnailUrl' => $this->_getFileUrl($attachment, 'normal'),
                    'attachmentType' => $attachmentType,
                    'resourceId' => (string) $rawData['message_id'],
                    'resourceType' => 'message'
                );

                if (in_array($attachmentType, ['audio', 'video'])) {
                    $attachmentData['duration'] = $this->getAudioVideoDuration($attachmentData['fileUrl']);
                }
                $this->_createJsonFile([$attachmentData], 'File');
            }
        }

        $recipients = $this->getModifiedRecipients($recipients,$rawData['user_id'],$rawData['date']);

        $roomId = $this->getExistingRoomId($recipients);

        if($roomId){
            $path = $this->_dataPath . '/' . $this->_jsonFileName . '.json';
            $roomMergingRecords = $this->roomMergingData[$roomId]["mergeRooms"];
            array_push($roomMergingRecords, $rawData['conversation_id']);
            $this->roomMergingData[$roomId]["mergeRooms"] = $roomMergingRecords;
        }
        else{
            $this->roomMergingData = $this->roomMergingData ? $this->roomMergingData : [];
            $this->roomMergingData =  array($rawData['conversation_id'] => ["mergeRooms"=> []]) + $this->roomMergingData;
        }
        
        $data = array();
        $data['_id'] = (string) $rawData['message_id'];
        $data['chatId'] = $roomId ? (string) $roomId : (string) $rawData['conversation_id'] ;
        $data['attachmentType'] = $attachmentType;
        $data['contentType'] = 0;
        $data['status'] = "success";
        
        if($attachmentType == "text"){
           $data['body'] = htmlentities($rawData['body']);
        }

        $data['ownerId'] = (string) $rawData['user_id'];
        $timeStamp = strtotime($rawData['date']);
        
        // For fixing 0000-00-00 date in database . 
        if($timeStamp<0 || $timeStamp == false){
          $createdAt = date("c");
        }
        else{
          $createdAt = date(DATE_ISO8601, $timeStamp);
        }

        $data['recipients'] = array_unique($recipients);
        
        // For Last Message Id . . 
        if( $this->roomMergingData[$data['chatId']]["lastMessageId"] && $this->needToUpdateLastMessageId($this->roomMergingData[$data['chatId']]["lastMessageId"],$rawData['message_id'],$createdAt)){
           $this->roomMergingData[$data['chatId']]["lastMessageId"] = (string) $rawData['message_id'];
        }

        if(!$this->roomMergingData[$data['chatId']]["lastMessageId"]){
           $this->roomMergingData[$data['chatId']]["lastMessageId"] = (string) $rawData['message_id'];
        }
        $this->messages[$rawData['message_id']] = $data;
        $newData[] = $data;
    }

    public function _runPost(){
        $path = $this->_dataPath . '/rooms_merging_records.json';
        file_put_contents($path, json_encode($this->roomMergingData));
    }

    private function getAudioVideoDuration($file)
    {
        // Copy remote file locally to scan with getID3()
        if ($fpRemote = fopen($file, 'rb')) {
            $localtempfilename = tempnam('/tmp', 'getID3');
            if ($fpLocal = fopen($localtempfilename, 'wb')) {
                while ($buffer = fread($fpRemote, 8192)) {
                    fwrite($fpLocal, $buffer);
                }
                fclose($fpLocal);
                // Initialize getID3 engine
                $getID3 = new getID3;
                $fileInfo = $getID3->analyze($localtempfilename);
                $duration = $this->convertTimeIntoMiliSecond($fileInfo['playtime_seconds']);
 
                // Delete temporary file
                unlink($localtempfilename);
            }
            fclose($fpRemote);
            return $duration;
        }
    }


    public function remoteFileExists($url) {
        $curl = curl_init($url);

        //don't fetch the actual page, you only want to check the connection is ok
        curl_setopt($curl, CURLOPT_NOBODY, true);

        //do request
        $result = curl_exec($curl);

        $ret = false;

        //if request did not fail
        if ($result !== false) {
        //if request was ok, check response code
        $statusCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);  

        if ($statusCode == 200) {
            $ret = true;   
        }
        }

        curl_close($curl);

        return $ret;
    }

    private function getExistingRoomId($recipients) {
        foreach($this->messages as $messageKey => $message) {
            if (count($message['recipients']) == count($recipients)) {
                $count = 0;
                $newMessRecipients = array_column($message['recipients'], 'recipientId');
                foreach($recipients as $recipient) {
                    if (in_array($recipient["recipientId"], $newMessRecipients)) {
                        $count++;
                    }
                }
                if ($count == count($recipients)) {
                    return $message["chatId"];
                }
            }
        }
        return;
    }

    private function needToUpdateLastMessageId($lastMessageId,$messageId,$messageCreatedAt) {
        $lastMessageCreatedAt = $this->messages[$lastMessageId]["createdAt"]['$date'];
        if($messageCreatedAt > $lastMessageCreatedAt){
            return true;
        }
        return false;

    }

    private function getModifiedRecipients($recipients,$ownerId,$createdAt) {
        $modRecipients = [];
        foreach($recipients as $recipientKey => $recipientId) {
            $modRecipientValue = [
               "id" => $this->getGuid(),
               "recipientId"=> (string) $recipientId,"status"=>3,
               "createdAt"=>['$date' => $this->getFormatedDate($createdAt)]
            ];
            array_push($modRecipients,$modRecipientValue);
        }
        return $modRecipients;
    }

    private function convertTimeIntoMiliSecond($time)
    {
        return intval(floatval($time)*1000);
    }

    private function getGuid()
    {
        if (function_exists('com_create_guid') === true)
        {
            return trim(com_create_guid(), '{}');
        }

        return sprintf('%04X%04X-%04X-%04X-%04X-%04X%04X%04X', mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(16384, 20479), mt_rand(32768, 49151), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535));
    }

    private function getFormatedDate($date)
    {
        $timeStamp = strtotime($date);
        
        // For fixing 0000-00-00 date in database . 
        if($timeStamp<0 || $timeStamp == false){
          $formatedDate = date("c");
        }
        else{
          $formatedDate = date(DATE_ISO8601, $timeStamp);
        }
        return $formatedDate;
    }

    public function br2nl($input)
    {   $output = preg_replace('/<br(\s+)?\/?>/i', "\n", $input);
        return preg_replace("/&#?[a-z0-9]+;/i","",$output);;
    }

}