<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    MessagesConversations.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class PrimeMessenger_Migrate_MessagesConversations extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_messages_conversations';
    protected $_warningMessage = array();
    protected $_priority = 200;
    protected $_jsonFileName = 'chat-rooms';
    protected $chats= array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'messages_conversations';
    }

    protected function _translateRow(array $rawData, array &$newData) {
        // Get chat members
        $members = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'messages_recipients', 'user_id')
                ->where('conversation_id = ?', $rawData['conversation_id'])
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);

        //Get Creation date
        $creationDate = null;
        if ($rawData['recipients'] > 1) {
            $creationDate = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'messages_messages', 'date')
                    ->where('conversation_id = ?', $rawData['conversation_id'])
                    ->order(array('message_id ASC'))
                    ->query()
                    ->fetchColumn();
        }

        // If a room with same members already exist, then merge this chatroom with previous chatroom and update this chatroom.
        $roomId = $this->getExistingRoomId($members);
        if ($roomId) {
            // Create a file to keep rooms merging records
            $this->_createJsonFile(array($rawData['conversation_id'] => $roomId), 'rooms_merging_records');
            foreach($newData as $index => $data) {
                if ($data['roomId'] == $roomId) {

                    if ($rawData['modified'] > $data['updatedAt']) {
                        $data['updatedAt'] = $rawData['modified']
                    ;
                    }

                    $newData[$index] = $data;
                    return ;
                }
            }
        }
        $this->_createJsonFile(array($rawData['conversation_id'] => $rawData['conversation_id']), 'rooms_merging_records');

        $data = array();
        $data['roomId'] = $rawData['conversation_id'];
        $data['title'] = $rawData['title'] ? $rawData['title'] : 'Untitled';
        $data['memberCount'] = $rawData['recipients'] + 1;
        $data['ownerId'] = $rawData['user_id'];
        $data['resourceType'] = 'user';
        $data['members'] = $members;
        $data['createdAt'] = $creationDate;
        $data['updatedAt'] = $rawData['modified'];

        $this->chats[$rawData['conversation_id']] = $data;
        $newData[] = $data;
    }

    private function getExistingRoomId($members) {
        foreach($this->chats as $chatKey => $chat) {
            if (count($chat['members']) == count($members)) {
                $count = 0;
                foreach($members as $member) {
                    if (in_array($member, $chat['members'])) {
                        $count++;
                    }
                }
                if ($count == count($members)) {
                    return $chatKey;
                }
            }
        }
        return;
    }
}
