<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Users.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class PrimeMessenger_Migrate_Users extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_users';
    protected $_warningMessage = array();
    protected $_priority = 100;
    protected $_jsonFileName = 'customer';
    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'users';
        $this->defaultPassword = str_replace("$2y$","$2a$",password_hash("123456", PASSWORD_DEFAULT));
    }

    public function _runPre(){
        $path = $this->_dataPath . '/users_chat.json';
        $json = file_get_contents($path);
        $this->userChatRecords = json_decode($json, true);
    }

    protected function _translateRow(array $rawData, array &$newData) {
        $newUser = array();
        $newUser['_id'] = (string) $rawData['user_id'];
        $newUser['email'] = trim($rawData['email']);
        $newUser['language'] = $rawData['language'];

        $user = Engine_Api::_()->getItem('user', $rawData['user_id']);
        $newUser['displayName'] = html_entity_decode(strtolower($user->getTitle()));
        $newUser['profileImageUrl'] = $this->_getFileUrl($user, 'profile');
        $newUser['profileUrl'] = $this->_getHref($user);
        $userMembershipTableName = $this->getfromPrefix() . 'user_membership';
        $userTableName = $this->getfromPrefix() . 'users';

        // Get user's friends
        $friends = $this->getFromDb()->select()
                ->from($userMembershipTableName,'user_id')
                ->join($userTableName, "`{$userTableName}`.`user_id` = `{$userMembershipTableName}`.`user_id`", '*')
                ->where('resource_id = ?', $rawData['user_id'])
                ->where('active = ?', '1')
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);
        $newUser['friends'] = $this->getModifiedFriendsArray($friends);

        // Get blocked users
        $blockedUsers = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'user_block', 'blocked_user_id')
                ->where('user_id = ?', $rawData['user_id'])
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);
        $newUser['blocks'] = $this->getModifiedBlockedArray($blockedUsers);
        $newUser['isOnline'] = false;
        $newUser['visibility'] = true;
        $newUser['notification'] = true;
        $newUser['createdAt'] = ['$date' => date("c")];
        $newUser['updatedAt'] = ['$date' => date("c")];
        $newUser['lastSeen'] = ['$date' => date("c")];
        $newUser['password'] = $this->defaultPassword;
        $newUser['chatId'] = $this->userChatRecords[$newUser['_id']] ? $this->userChatRecords[$newUser['_id']] : [];
        $newData[] = $newUser;
    }

    public function getModifiedFriendsArray($friends) {
        $modifiedFriendsArray = [];
        foreach ($friends as $friend) {
        $user = Engine_Api::_()->getItem('user', $friend);
            if(isset($user['email']) && $friend){
               array_push($modifiedFriendsArray, (string) $friend);
            }
        }
        return $modifiedFriendsArray;
    }

    public function getModifiedBlockedArray($blocklist) {
        $modifiedBlockArray = [];
        foreach ($blocklist as $block) {
        $user = Engine_Api::_()->getItem('user', $block);
            if(isset($user['email']) && $block){
               array_push($modifiedBlockArray, (string) $block);
            }
        }
        return $modifiedBlockArray;
    }
}
