<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Form_Admin_Global extends Engine_Form {

  public function init() {
    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $this
        ->setTitle('Global Settings')
        ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'recipe_lsettings', array(
            'label' => 'Enter License key',
            'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please ccontact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
            'value' => $coreSettings->getSetting('recipe.lsettings'),
    ));

    if( APPLICATION_ENV == 'production' ) {
      $this->addElement('Checkbox', 'environment_mode', array(
              'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few pages of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
              'description' => 'System Mode',
              'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    // Add submit button
    $this->addElement('Button', 'submit_lsetting', array(
            'label' => 'Activate Your Plugin Now',
            'type' => 'submit',
            'ignore' => true
    ));


    // VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'recipe_location', array(
            'label' => 'Maps Integration',
            'description' => 'Do you want Maps Integration to be enabled for recipe items? (With this enabled, items having location information could also be seen on Map. Pages like the Recipe Home and Browse Recipe also enable you to see the items plotted on Map.)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'onclick' => 'showMapOptions(this.value)',
            'value' => $coreSettings->getSetting('recipe.location', 1),
    ));

    // VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'recipe_map_sponsored', array(
            'label' => 'Sponsored Recipes with a Bouncing Animation',
            'description' => 'Do you want the sponsored recipes to be shown with a bouncing animation in the Map?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.map.sponsored', 1),
    ));

    $this->addElement('Text', 'recipe_map_city', array(
            'label' => 'Centre Location for Map at Recipes Home  and Browse Recipes',
            'description' => 'Enter the location which you want to be shown at centre of the map which is shown on Recipes Home  and Browse Recipes when Map View is chosen to view Recipes.(To show the whole world on the map, enter the word "World" below.)',
            'required' => true,
            'value' => $coreSettings->getSetting('recipe.map.city', "World"),
    ));
    
    $this->addElement('Select', 'recipe_map_zoom', array(
            'label' => "Default Zoom Level for Map at Recipes Home  and Browse Recipes",
            'description' => 'Select the default zoom level for the map which is shown on Recipes Home  and Browse Recipes when Map View is chosen to view Recipes. (Note that as higher zoom level you will select, the more number of surrounding cities/locations you will be able to see.)',
            'multiOptions' => array(
                    '1' => "1",
                    "2" => "2",
                    "4" => "4",
                    "6" => "6",
                    "8" => "8",
                    "10" => "10",
                    "12" => "12",
                    "14" => "14",
                    "16" => "16"
            ),
            'value' => $coreSettings->getSetting('recipe.map.zoom', 1),
            'disableTranslator' => 'true'
    ));



    // VALUE FOR ENABLE/DISABLE REPORT
    $this->addElement('Radio', 'recipe_report', array(
            'label' => 'Report as Inappropriate',
            'description' => 'Do you want to allow logged-in members to be able to report recipes as inappropriate? (Members will also be able to mention the reason why they find the recipe inappropriate.)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.report', 1),
    ));

    // VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'recipe_share', array(
            'label' => 'Community Sharing',
            'description' => 'Do you want to allow members to share recipes within your community?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.share', 1),
    ));

    // VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'recipe_socialshare', array(
            'label' => 'Social Sharing',
            'description' => 'Do you want social sharing to be enabled for the recipes? (Social sharing buttons will be shown on the main recipe pages.)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.socialshare', 1),
    ));

    // VALUE FOR ENABLE / DISABLE RATING
    $this->addElement('Radio', 'recipe_rating', array(
            'label' => 'Rating',
            'description' => 'Do you want logged-in members to be able to rate recipes?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.rating', 1),
    ));
    // VALUE FOR ENABLE / DISABLE PRINTER
    $this->addElement('Radio', 'recipe_printer', array(
            'label' => 'Printing',
            'description' => 'Do you want users to be able to print recipe information?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.printer', 1),
    ));

    // VALUE FOR ENABLE / DISABLE TELL-A-FRIEND
    $this->addElement('Radio', 'recipe_tellafriend', array(
            'label' => 'Tell a friend',
            'description' => 'Do you want to show the "Tell a friend" link on the main recipe pages? (Using this feature, users will be able to email a recipe to their friends )',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.tellafriend', 1),
    ));
    // VALUE FOR CAPTCHA
    $this->addElement('Radio', 'recipe_captcha_post', array(
            'label' => 'CAPTCHA For Tell a friend',
            'description' => 'Do you want visitors to enter validation code in Tell a friend form?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.captcha.post', 1),
    ));

    $this->addElement('Radio', 'recipe_description_allow', array(
        'label' => 'Allow Description',
        'description' =>  'Do you want to allow listing owners to write description for their listings?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('recipe.description.allow', 1),
        'onclick' => 'showDescription(this.value)'
    ));

    // VALUE FOR CAPTCHA
    $this->addElement('Radio', 'recipe_requried_description', array(
            'label' => 'Description Required',
            'description' => 'Do you want to make Description a mandatory field for recipes?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.requried.description', 1),
    ));

    // VALUE FOR Page Dispute Link.
    $this->addElement('Radio', 'recipe_network', array(
            'label' => 'Browse by Networks',
            'description' => "Do you want to show recipes according to viewer's network if he has selected any? (If set to no, all the recipes will be shown.)",
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'onclick' => 'showDefaultNetwork(this.value)',
            'value' => $coreSettings->getSetting('recipe.network', 0),
    ));

    //    // VALUE FOR Page Dispute Link.
    $this->addElement('Radio', 'recipe_default_show', array(
            'label' => 'Set Only My Networks as Default in search',
            'description' => 'Do you want to set "Only My Networks" option as default for Show field in the search form widget? (This widget appears on the recipes browse and home pages, and enables users to search and filter recipes.)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.default.show', 0),
    ));




    // VALUE FOR ENABLE /DISABLE Proximity Search
    $this->addElement('Radio', 'recipe_proximitysearch', array(
            'label' => 'Proximity Search',
            'description' => 'Do you want proximity search to be enabled for recipes? (Proximity search will enable users to search for recipes within a certain distance from a location. Proximity search will work only if you have created a custom Location type field in Recipe Questions.)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'onclick' => 'showlocationKM(this.value)',
            'value' => $coreSettings->getSetting('recipe.proximitysearch', 1),
    ));

    // VALUE FOR ENABLE /DISABLE Proximity Search IN Kilometer
    $this->addElement('Radio', 'recipe_proximity_search_kilometer', array(
            'label' => 'Proximity Search Metric',
            'description' => 'What metric do you want to be used for proximity search?',
            'multiOptions' => array(
                    0 => 'Miles',
                    1 => 'Kilometers'
            ),
            'value' => $coreSettings->getSetting('recipe.proximity.search.kilometer', 0),
    ));


    // VALUE FOR COMMENT
    $this->addElement('Radio', 'recipe_checkcomment_widgets', array(
            'label' => 'Comments',
            'description' => 'Do you want comments to be enabled for recipes on the Info pages?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.checkcomment.widgets', 1),
    ));


    // VALUE FOR CAPTCHA
    $this->addElement('Radio', 'recipe_sponsored_image', array(
            'label' => 'Sponsored Label',
            'description' => 'Do you want to show the "SPONSORED" label on the main pages of sponsored recipes above the recipe profile picture ?',
            'onclick' => 'showsponsored(this.value)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.sponsored.image', 1),
    ));

    // COLOR VALUE FOR SPONSORED
    $this->addElement('Text', 'recipe_sponsored_color', array(
            'decorators' => array(array('ViewScript', array(
                                    'viewScript' => '_formImagerainbowSponsred.tpl',
                                    'class' => 'form element'
                    )))
    ));




    // VALUE FOR CAPTCHA
    $this->addElement('Radio', 'recipe_feature_image', array(
            'label' => 'Featured Label',
            'description' => 'Do you want to show the "FEATURED" label on the main pages of featured recipes below the recipe profile picture ?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'onclick' => 'showfeatured(this.value)',
            'value' => $coreSettings->getSetting('recipe.feature.image', 1),
    ));
    // COLOR VALUE FOR FEATURED
    $this->addElement('Text', 'recipe_featured_color', array(
            'decorators' => array(array('ViewScript', array(
                                    'viewScript' => '_formImagerainbowFeatured.tpl',
                                    'class' => 'form element'
                    )))
    ));


    // Order of browse page
    $this->addElement('Radio', 'recipe_browseorder', array(
            'label' => 'Default ordering on Browse Recipes',
            'description' => 'Select the default ordering of recipes on the browse recipes page.',
            'multiOptions' => array(
                    1 => 'All recipes in descending order of creation.',
                    2 => 'All recipes in descending order of views.',
                    3 => 'All recipes in alphabetical order.',
                    4 => 'Sponsored recipes followed by others in descending order of creation.',
                    5 => 'Featured recipes followed by others in descending order of creation.',
                    6 => 'Sponsored & Featured recipes followed by Sponsored recipes followed by Featured recipes followed by others in descending order of creation.',
                    7 => 'Featured & Sponsored recipes followed by Featured recipes followed by Sponsored recipes followed by others in descending order of creation.',
            ),
            'value' => $coreSettings->getSetting('recipe.browseorder', 1),
    ));

    // VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'recipe_closeicon', array(
            'label' => 'Open / Close Recipe Listings',
            'description' => 'Do you want users to be able to make their recipe listings closed / open?',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
             'onclick' => 'showOpenOptions(this.value)',
            'value' => $coreSettings->getSetting('recipe.closeicon', 0),
    ));

    // VALUE FOR CAPTCHA
    $this->addElement('Radio', 'recipe_status_show', array(
            'label' => 'Open / Closed status in Search',
            'description' => 'Do you want the Status field (Open / Closed) in the search form widget? (This widget appears on the recipes browse and home pages, and enables users to search and filter recipes.)',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.status.show', 0),
    ));






    // VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'recipe_start_end_month', array(
            'label' => 'Recipe Season',
            'description' => 'Do you want users to be able to choose season for their recipes? If enabled, users will be able to select the start and end months for the season of their recipes.',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No'
            ),
            'value' => $coreSettings->getSetting('recipe.start.end.month', 1),
    ));
















    // VALUE FOR RECIPE LISING PAGE
    $this->addElement('Text', 'recipe_page', array(
            'label' => 'Recipes Per Page',
            'description' => 'How many recipes will be shown per page on the Browse Recipes page?',
            'allowEmpty' => false,
            'maxlength' => '3',
            'required' => true,
            'filters' => array(
                    new Engine_Filter_Censor(),
                    'StripTags',
                    new Engine_Filter_StringLength(array('max' => '3'))
            ),
            'value' => $coreSettings->getSetting('recipe.page', 10),
    ));

    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $field = 'recipe_code_share';
    $this->addElement('Dummy', "$field", array(
        'label' => 'Social Share Widget Code',
        'description' => "<a class='smoothbox' href='". $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'social-share', 'field' => "$field"), 'admin_default', true) ."'>Click here</a> to add your social share code.",
        'ignore' => true,
    ));
    $this->$field->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

    // VALUE FOR TURNCATION
    $this->addElement('Text', 'recipe_title_turncationsponsored', array(
            'label' => 'Title Truncation Limit For Sponsored ',
            'allowEmpty' => false,
            'maxlength' => '3',
            'required' => true,
            'description' => 'What maximum limit should be applied to the number of characters in the titles of items in the Sponsored widgets? (Enter a number between 1 and 999. Titles having more characters than this limit will be truncated. Complete titles will be shown on mouseover.)',
            'value' => $coreSettings->getSetting('recipe.title.turncationsponsored', 18),
    ));


    // VALUE FOR TURNCATION
    $this->addElement('Text', 'recipe_title_turncation', array(
            'label' => 'Title Truncation Limit',
            'allowEmpty' => false,
            'maxlength' => '3',
            'required' => true,
            'description' => 'What maximum limit should be applied to the number of characters in the titles of items in the widgets? (Enter a number between 1 and 999. Titles having more characters than this limit will be truncated. Complete titles will be shown on mouseover.)',
            'value' => $coreSettings->getSetting('recipe.title.turncation', 18),
    ));


    // Add submit button
    $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
    ));
  }

}
