<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Form_Create extends Engine_Form {

  public $_error = array();

  public function init() {

    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $this->setTitle('Post New Recipe')
        ->setDescription('Compose your new recipe below, then click "Post Recipe" to publish the recipe.')
        ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
        ->setAttrib('name', 'recipes_create');

    // TITLE
    $this->addElement('Text', 'title', array(
            'label' => 'Recipe Title',
            'allowEmpty' => false,
            'required' => true,
            'filters' => array(
                    'StripTags',
                    new Engine_Filter_Censor(),
            //new Engine_Filter_StringLength(array('max' => '63')),
        )));

    $user = Engine_Api::_()->user()->getViewer();
    $user_level = Engine_Api::_()->user()->getViewer()->level_id;

    // init to
    $this->addElement('Text', 'tags', array(
            'label' => 'Tags (Keywords)',
            'autocomplete' => 'off',
            'description' => 'Separate tags with commas.',
            'filters' => array(
                    new Engine_Filter_Censor(),
            ),
    ));

		$duration_array1 = array('0' => '', '01' => 'January','02' => 'Fabruary','03' =>'March','04' =>'April','05' =>'May','06' =>'June','07' =>'July','08' =>'August','09' =>'September','10' =>'October','11' =>'November','12' =>'December');

    if ($coreSettings->getSetting('recipe.start.end.month', 1)) {
		$this->addElement('Select', 'start_month', array(
			'label' => 'Season Starting Month',
      'required' => false,
			'description' => 'Please select the starting month for the season of this recipe.',
			'multiOptions' => $duration_array1,
			'value' => 0,
		));

		$this->addElement('Select', 'end_month', array(
			'label' => 'Season Ending Month',
      'required' => false,
			'description' => 'Please select the ending month for the season of this recipe.',
			'multiOptions' => $duration_array1,
			'value' => 0,
		));
    }

    $this->tags->getDecorator("Description")->setOption("placement", "append");

    // prepare categories
//    $categories = Engine_Api::_()->recipe()->getCategories();
//    if (count($categories) != 0) {
//      $categories_prepared[0] = "";
//      foreach ($categories as $category) {
//        $categories_prepared[$category->category_id] = $category->category_name;
//      }
//
//      // category field
//      $this->addElement('Select', 'category_id', array(
//              'label' => 'Category',
//              'multiOptions' => $categories_prepared
//      ));
//    }
    // prepare categories
    $categories = Engine_Api::_()->recipe()->getCategories();
    if (count($categories) != 0) {
      $categories_prepared[0] = "";
      foreach ($categories as $category) {
        $categories_prepared[$category->category_id] = $category->category_name;
      }

      $this->addElement('Select', 'category_id', array(
              'label' => 'Category',
              'multiOptions' => $categories_prepared,
              'onchange' => "subcategory(this.value, '', '');",
      ));
    }

    $this->addElement('Select', 'subcategory_id', array(
            'RegisterInArrayValidator' => false,
            'allowEmpty' => true,
            'required' => false,
            'decorators' => array(array('ViewScript', array(
                                    'viewScript' => '_formSubcategory.tpl',
                                    'class' => 'form element')))
    ));

    if($coreSettings->getSetting('recipe.description.allow', 1)) {
			if ($coreSettings->getSetting('recipe.requried.description', 1)) {
				// body
				$this->addElement('textarea', 'body', array(
								'label' => 'Description',
								'required' => true,
								'allowEmpty' => false,
								'attribs' => array('rows' => 24, 'cols' => 180, 'style' => 'width:300px; max-width:400px;height:120px;'),
								'filters' => array(
												'StripTags',
												new Engine_Filter_HtmlSpecialChars(),
												new Engine_Filter_EnableLinks(),
												new Engine_Filter_Censor(),
								),
				));
			} else {
				// body
				$this->addElement('textarea', 'body', array(
								'label' => 'Description',
								'attribs' => array('rows' => 24, 'cols' => 180, 'style' => 'width:300px; max-width:400px;height:120px;'),
								'filters' => array(
												'StripTags',
												new Engine_Filter_HtmlSpecialChars(),
												new Engine_Filter_EnableLinks(),
												new Engine_Filter_Censor(),
								),
				));
			}
    }
    $allowed_upload = Engine_Api::_()->authorization()->getPermission($user_level, 'recipe', 'photo');
    if ($allowed_upload) {
      $this->addElement('File', 'photo', array(
              'label' => 'Main Photo'
      ));
      $this->photo->addValidator('Extension', false, 'jpg,jpeg,png,gif');
    }


    // Add subforms
    if (!$this->_item) {
      $customFields = new Recipe_Form_Custom_Fields();
    } else {
      $customFields = new Recipe_Form_Custom_Fields(array(
                  'item' => $this->getItem()
          ));
    }

    $this->addSubForms(array(
            'fields' => $customFields
    ));

    $this->addElement('Select', 'draft', array(
            'label' => 'Status',
            'multiOptions' => array("1" => "Published", "0" => "Saved As Draft"),
            'description' => 'If this entry is published, it cannot be switched back to draft mode.'
    ));
    $this->draft->getDecorator('Description')->setOption('placement', 'append');
    // Init search
    $this->addElement('Checkbox', 'search', array(
            'label' => "Show this recipe in search results",
            'value' => 1,
    ));

    // Privacy
    $availableLabels = array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me',
    );

    // View
    $view_options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('recipe', $user, 'auth_view');
    $view_options = array_intersect_key($availableLabels, array_flip($view_options));

    if (count($view_options) >= 1) {
      $this->addElement('Select', 'auth_view', array(
              'label' => 'Privacy',
              'description' => 'Who may see this recipe?',
              'multiOptions' => $view_options,
              'value' => key($view_options),
      ));
      $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
    }

    // Comment
    $comment_options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('recipe', $user, 'auth_comment');
    $comment_options = array_intersect_key($availableLabels, array_flip($comment_options));

    if (count($comment_options) >= 1) {
      $this->addElement('Select', 'auth_comment', array(
              'label' => 'Comment Privacy',
              'description' => 'Who may post comments on this recipe?',
              'multiOptions' => $comment_options,
              'value' => key($comment_options),
      ));
      $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
    }
    // Photo
    $availableLabels = array(
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me',
    );
    $photo_options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('recipe', $user, 'auth_photo');
    $photo_options = array_intersect_key($availableLabels, array_flip($photo_options));

    if (count($photo_options) >= 1) {
      $this->addElement('Select', 'auth_photo', array(
              'label' => 'Photo Privacy',
              'description' => 'Who may post photos on this recipe?',
              'multiOptions' => $photo_options,
              'value' => key($photo_options),
      ));
      $this->auth_photo->getDecorator('Description')->setOption('placement', 'append');
    }

    $videoEnable = Engine_Api::_()->recipe()->enableVideoPlugin();
    if ($videoEnable) {
      // Video
      $availableLabels = array(
              'registered' => 'All Registered Members',
              'owner_network' => 'Friends and Networks',
              'owner_member_member' => 'Friends of Friends',
              'owner_member' => 'Friends Only',
              'owner' => 'Just Me',
      );
      $video_options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('recipe', $user, 'auth_video');
      $video_options = array_intersect_key($availableLabels, array_flip($video_options));

      if (count($video_options) >= 1) {
        $this->addElement('Select', 'auth_video', array(
                'label' => 'Video Privacy',
                'description' => 'Who may post videos on this recipe?',
                'multiOptions' => $video_options,
                'value' => key($video_options),
        ));
        $this->auth_video->getDecorator('Description')->setOption('placement', 'append');
      }
    }

    // Element: execute
    $this->addElement('Button', 'execute', array(
            'label' => 'Post Recipe',
            'type' => 'submit',
            'ignore' => true,
            'decorators' => array(
                    'ViewHelper',
            ),
    ));

    // Element: cancel
    $this->addElement('Cancel', 'cancel', array(
            'label' => 'cancel',
            'link' => true,
            'prependText' => ' or ',
            'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'recipe_general', true),
            'decorators' => array(
                    'ViewHelper',
            ),
    ));

    // DisplayGroup: buttons
    $this->addDisplayGroup(array(
            'execute',
            'cancel',
        ), 'buttons', array(
            'decorators' => array(
                    'FormElements',
                    'DivDivDivWrapper'
            ),
    ));
  }

}