<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Recipes.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Model_DbTable_Recipes extends Engine_Db_Table {

  protected $_rowClass = "Recipe_Model_Recipe";

  public function getTagCloud($limit = 100, $count_only = 0) {
    $tableTagmaps = 'engine4_core_tagmaps';
    $tableTags = 'engine4_core_tags';
    $tableRecipeName = $this->info('name');

    $select = $this->select()
            ->setIntegrityCheck(false)
            ->from($tableRecipeName, 'title')
            ->joinInner($tableTagmaps, "$tableRecipeName.recipe_id = $tableTagmaps.resource_id", array('COUNT(engine4_core_tagmaps.resource_id) AS Frequency'))
            ->joinInner($tableTags, "$tableTags.tag_id = $tableTagmaps.tag_id", array('text', 'tag_id'))
            ->where($tableRecipeName . '.approved = ?', "1")
            ->where($tableRecipeName . '.draft = ?', "1")
            ->where($tableTagmaps . '.resource_type = ?', 'recipe')
            ->group("$tableTags.text")
            ->order("Frequency DESC");
    $select->where($tableRecipeName . ".search = ?", 1);
    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {

        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$tableRecipeName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity())
        ;
      }
    }
    // End Network work
    $stusShow = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.status.show', 1);
    if ($stusShow == 0) {
      $select = $select
              ->where($tableRecipeName . '.closed = ?', '0');
    }

		if(!empty($count_only)) {
			$total_results = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
			return Count($total_results);
		}

		$select = $select->limit($limit);

    return $select->query()->fetchAll();
  }

  public function getItemOfDay() {
    $today = date('Y-m-d');

    $recipeName = $this->info('name');

    $itemofthedaytable = Engine_Api::_()->getDbtable('itemofthedays', 'recipe');
    $itemofthedayName = $itemofthedaytable->info('name');

    $select = $this->select();
    $select = $select
            ->setIntegrityCheck(false)
            ->from($recipeName)
            ->join($itemofthedayName, $recipeName . '.recipe_id = ' . $itemofthedayName . '.recipe_id', array('date'))
            ->where($itemofthedayName . '.date <=?', $today)
            ->where($itemofthedayName . '.endtime >=?', $today)
            ->order('RAND()');

    //Here we can fetch the result form the table
    return $row = $this->fetchRow($select);
  }

  public function getRecentviewRecipe() {
    $recipeName = $this->info('name');

    $viewtable = Engine_Api::_()->getDbtable('vieweds', 'recipe');
    $viewName = $viewtable->info('name');

    $select = $this->select();
    $select = $select
            ->setIntegrityCheck(false)
            ->from($recipeName)
            ->join($viewName, $recipeName . '.recipe_id = ' . $viewName . '.recipe_id', array('date'))
            ->where($recipeName . '.closed = ?', '0')
            ->where($recipeName . '.approved = ?', '1')
            ->where($recipeName . '.draft = ?', '1')
            ->group($viewName . '.recipe_id')
            ->order($viewName . '.date DESC');
    $select->where($recipeName . ".search = ?", 1);
    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {

        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$recipeName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity())
        ;
      }
    }
    // End Network work
    $select = $select->limit((int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recently.view', 3));
    return $row = $this->fetchAll($select);
  }

  public function getRecipeSelectSql($params=array()) {
    $tableName = $this->info('name');
    $select = $this->select()
            ->where("{$tableName}.search = ?", 1)
            ->where("{$tableName}.closed = ?", '0')
            ->where("{$tableName}.approved = ?", '1')          
            ->where("{$tableName}.draft = ?", '1');
   
    if (isset($params['limit']) && !empty($params['limit']))
      $select->limit($params['limit']);
    return $select;
  }

}