<?php
 /**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Post.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Model_Post extends Core_Model_Item_Abstract
{
  protected $_parent_type = 'recipe_topic';

  protected $_owner_type = 'user';
  
  public function getHref($params = array())
  {
    $params = array_merge(array(
      'route' => 'recipe_extended',
      'controller' => 'topic',
      'action' => 'view',
      'recipe_id' => $this->recipe_id,
      'topic_id' => $this->getParentTopic()->getIdentity(),
      'post_id' => $this->getIdentity(),
    ), $params);
    $route = @$params['route'];
    unset($params['route']);
    return Zend_Controller_Front::getInstance()->getRouter()->assemble($params, $route, true);
  }

  public function getDescription()
  {
    // Remove bbcode
    $desc = preg_replace('/\[[^\[\]]+?\]/', '', $this->body);
    return Engine_String::substr($desc, 0, 255);
  }

  public function getPostIndex()
  {
    $table = $this->getTable();
    $select = new Zend_Db_Select($table->getAdapter());
    $select
      ->from($table->info('name'), new Zend_Db_Expr('COUNT(post_id) as count'))
      ->where('topic_id = ?', $this->topic_id)
      ->where('post_id < ?', $this->getIdentity())
      ->order('post_id ASC');

    $data = $select->query()->fetch();
    
    return (int) $data['count'];
  }

  public function getParentrecipe()
  {
    return Engine_Api::_()->getItem('recipe', $this->recipe_id);
  }

  public function getParentTopic()
  {
    return Engine_Api::_()->getItem('recipe_topic', $this->topic_id);
  }

  public function getPoster()
  {
    return Engine_Api::_()->getItem('user', $this->user_id);
  }

  public function getAuthorizationItem()
  {
    return $this->getParent('recipe');
  }

  // Internal hooks
  protected function _insert()
  {
    if( $this->_disableHooks ) return;
    
    if( !$this->recipe_id )
    {
      throw new Exception('Cannot create post without recipe_id');
    }
    
    if( !$this->topic_id )
    {
      throw new Exception('Cannot create post without topic_id');
    }

    // Update topic
    $table = Engine_Api::_()->getDbtable('topics', 'recipe');
    $select = $table->select()->where('topic_id = ?', $this->topic_id)->limit(1);
    $topic = $table->fetchRow($select);

    $topic->lastpost_id = $this->post_id;
    $topic->lastposter_id = $this->user_id;
    $topic->modified_date = date('Y-m-d H:i:s');
    $topic->post_count++;
    $topic->save();
    
    parent::_insert();
  }

  protected function _delete()
  {
    if( $this->_disableHooks ) return;
    
    // Update topic
    $table = Engine_Api::_()->getDbtable('topics', 'recipe');
    $select = $table->select()->where('topic_id = ?', $this->topic_id)->limit(1);
    $topic = $table->fetchRow($select);
    $topic->post_count--;

    if( $topic->post_count == 0 ) {
      $topic->delete();
    } else {
      $topic->save();
    }
    parent::_delete();
  }
}