<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Recipe.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Model_Recipe extends Core_Model_Item_Abstract {

  // Properties
  protected $_parent_type = 'user';
  protected $_searchTriggers = array('title', 'body', 'search', 'draft', 'approved', 'closed');
  protected $_parent_is_owner = true;

  public function isSearchable() {

    return ( (!isset($this->search) || $this->search) && !empty($this->_searchTriggers) && is_array($this->_searchTriggers) && empty($this->closed) && $this->approved && !empty($this->draft));
  }

  public function getMediaType() {
    return 'recipe';
  }

  public function getHref($params = array()) {
    $slug = $this->getSlug();
    $params = array_merge(array(
        'route' => 'recipe_entry_view',
        'reset' => true,
        'user_id' => $this->owner_id,
        'recipe_id' => $this->recipe_id,
        'slug' => $slug,
            ), $params);
    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);
    return Zend_Controller_Front::getInstance()->getRouter()
                    ->assemble($params, $route, $reset);
  }

  public function getDescription() {
    // @todo decide how we want to handle multibyte string functions
    $tmpBody = strip_tags($this->body);
    return ( Engine_String::strlen($tmpBody) > 255 ? Engine_String::substr($tmpBody, 0, 255) . '...' : $tmpBody );
  }

  public function getKeywords($separator = ' ') {
    $keywords = array();
    foreach ($this->tags()->getTagMaps() as $tagmap) {
      $tag = $tagmap->getTag();
      $keywords[] = $tag->getTitle();
    }

    if (null == $separator) {
      return $keywords;
    }

    return join($separator, $keywords);
  }

  public function setPhoto($photo) {
    if ($photo instanceof Zend_Form_Element_File) {
      $file = $photo->getFileName();
    } else if (is_array($photo) && !empty($photo['tmp_name'])) {
      $file = $photo['tmp_name'];
    } else if (is_string($photo) && file_exists($photo)) {
      $file = $photo;
    } else {
      throw new Recipe_Model_Exception('invalid argument passed to setPhoto');
    }

    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
        'parent_type' => 'recipe',
        'parent_id' => $this->getIdentity()
    );

    // Save
    $storage = Engine_Api::_()->storage();

    // Resize image (main)
    $image = Engine_Image::factory();
    $image->open($file)
            ->resize(720, 720)
            ->write($path . '/m_' . $name)
            ->destroy();

    // Resize image (profile)
    $image = Engine_Image::factory();
    $image->open($file)
            ->resize(200, 400)
            ->write($path . '/p_' . $name)
            ->destroy();

    // Resize image (normal)
    $image = Engine_Image::factory();
    $image->open($file)
            ->resize(140, 160)
            ->write($path . '/in_' . $name)
            ->destroy();

    // Resize image (icon)
    $image = Engine_Image::factory();
    $image->open($file);

    $size = min($image->height, $image->width);
    $x = ($image->width - $size) / 2;
    $y = ($image->height - $size) / 2;

    $image->resample($x, $y, $size, $size, 48, 48)
            ->write($path . '/is_' . $name)
            ->destroy();

    // Store
    $iMain = $storage->create($path . '/m_' . $name, $params);
    $iProfile = $storage->create($path . '/p_' . $name, $params);
    $iIconNormal = $storage->create($path . '/in_' . $name, $params);
    $iSquare = $storage->create($path . '/is_' . $name, $params);

    $iMain->bridge($iProfile, 'thumb.profile');
    $iMain->bridge($iIconNormal, 'thumb.normal');
    $iMain->bridge($iSquare, 'thumb.icon');

    // Remove temp files
    @unlink($path . '/p_' . $name);
    @unlink($path . '/m_' . $name);
    @unlink($path . '/in_' . $name);
    @unlink($path . '/is_' . $name);


    // Add to album
    $viewer = Engine_Api::_()->user()->getViewer();
    $photoTable = Engine_Api::_()->getItemTable('recipe_photo');
    $recipeAlbum = $this->getSingletonAlbum();
    $photoItem = $photoTable->createRow();
    $photoItem->setFromArray(array(
        'recipe_id' => $this->getIdentity(),
        'album_id' => $recipeAlbum->getIdentity(),
        'user_id' => $viewer->getIdentity(),
        'file_id' => $iMain->getIdentity(),
        'collection_id' => $recipeAlbum->getIdentity(),
    ));
    $photoItem->save();

    // Update row
    $this->modified_date = date('Y-m-d H:i:s');
    $this->photo_id = $photoItem->file_id;
    $this->save();

    return $this;
  }

  public function getPhoto($photo_id) {
    $photoTable = Engine_Api::_()->getItemTable('recipe_photo');
    $select = $photoTable->select()
            ->where('file_id = ?', $photo_id)
            ->limit(1);

    $photo = $photoTable->fetchRow($select);
    return $photo;
  }

  public function getSingletonAlbum() {
    $table = Engine_Api::_()->getItemTable('recipe_album');
    $select = $table->select()
            ->where('recipe_id = ?', $this->getIdentity())
            ->order('album_id ASC')
            ->limit(1);

    $album = $table->fetchRow($select);

    if (null == $album) {
      $album = $table->createRow();
      $album->setFromArray(array(
          'title' => $this->getTitle(),
          'recipe_id' => $this->getIdentity()
      ));
      $album->save();
    }

    return $album;
  }

  public function comments() {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
  }

  public function likes() {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
  }

  public function tags() {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('tags', 'core'));
  }

  protected function _insert() {
    if (null == $this->search) {
      $this->search = 1;
    }

    parent::_insert();
  }

  public function setFeatured() {
    $this->featured = !$this->featured;
    $this->save();
  }

  public function setSponsored() {
    $this->sponsored = !$this->sponsored;
    $this->save();
  }

  public function deleteRecipe() {
    $recipe_id = $this->recipe_id;
    $db = Engine_Db_Table::getDefaultAdapter();

    $db->beginTransaction();
    try {
      //DELETE RECIPE FROM DATABASE AND SCRIBD
      Engine_Api::_()->fields()->getTable('recipe', 'search')->delete(array('item_id =?' => $recipe_id));
      Engine_Api::_()->fields()->getTable('recipe', 'values')->delete(array('item_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('ratings', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('reviews', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('clasfvideos', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('albums', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('photos', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('itemofthedays', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('vieweds', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('writes', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('posts', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('topics', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('locations', 'recipe')->delete(array('recipe_id =?' => $recipe_id));
      Engine_Api::_()->getDbtable('allow', 'authorization')->delete(array('resource_id =?' => $recipe_id, 'resource_type =?' => 'recipe'));
      Engine_Api::_()->getDbtable('actions', 'activity')->delete(array('object_type =?' => 'recipe', 'object_id =?' => $recipe_id));
      $this->delete();
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
  }

  public function setRating($rating, $total) {
    $rating = ($this->rating + $rating) / $total;
    $this->rating = $rating;
    $this->rate_count++;
    $this->save();
    return $this;
  }

}