<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_MobiController extends Core_Controller_Action_Standard {

  protected $_navigation;

  // SET THE VALUE FOR ALL ACTION DEFAULT
  public function init() {

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;

    $ajaxContext = $this->_helper->getHelper('AjaxContext');
    $ajaxContext
        ->addActionContext('rate', 'json')
        ->addActionContext('validation', 'html')
        ->initContext();

    $id = $this->_getParam('recipe_id', $this->_getParam('id', null));

    if ($id) {
      $recipe = Engine_Api::_()->getItem('recipe', $id);
      if ($recipe) {
        Engine_Api::_()->core()->setSubject($recipe);
      }
    }
  }

  // NONE USER SPECIFIC METHODS
  public function indexAction() {

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();


    $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
    $coreversion = $coremodule->version;
    if ($coreversion < '4.1.0') {
      $this->_helper->content->render();
    } else {
      $this->_helper->content
          ->setNoRender()
          ->setEnabled()
      ;
    }
  }

  // NONE USER SPECIFIC METHODS
  public function homeAction() {

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();
    $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
    $coreversion = $coremodule->version;
    if ($coreversion < '4.1.0') {
      $this->_helper->content->render();
    } else {
      $this->_helper->content
          ->setNoRender()
          ->setEnabled()
      ;
    }
  }

  public function viewAction() {

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;

    // get viewr details
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    $recipe_id = $this->_getParam('recipe_id');
    $recipe = Engine_Api::_()->getItem('recipe', $this->_getParam('recipe_id'));

//    $recipetable = Engine_Api::_()->getDbtable('vieweds', 'recipe');
//    $recipeName = $recipetable->info('name');
//    $select = $recipetable->select()->from($recipeName, 'viewed_id')->where('recipe_id = ?', $recipe_id)->where('viewer_id = ?', $viewer_id);
//    $reciperesult = $recipetable->fetchRow($select);

    if (empty($recipe)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

//    $count = count($reciperesult);

    if ((empty($recipe->draft) || empty($recipe->approved)) && $recipe->owner_id != $viewer_id && !$this->_helper->requireAuth()->setAuthParams($recipe, null, 'edit')->isValid()) {
      return $this->_forward('requireauth', 'error', 'core');
    }


    // check permission for view
    if (!$this->_helper->requireAuth()->setAuthParams($recipe, null, 'view')->isValid())
      return;

    if ($recipe) {

      // set the viewr counting
      $recipe->view_count++;
      $recipe->save();

      Engine_Api::_()->getDbtable('vieweds', 'recipe')->setVieweds($recipe_id, $viewer_id);
      $subject = Engine_Api::_()->core()->getSubject();
      $owner = Engine_Api::_()->getItem('user', $recipe->owner_id);

      // Check to see if profile styles is allowed
      $style_perm = Engine_Api::_()->getDbtable('permissions', 'authorization')->getAllowed('user', $owner->level_id, 'style');

      if ($style_perm) {

        // Get styles
        $table = Engine_Api::_()->getDbtable('styles', 'core');

        $select = $table->select()
                ->where('type = ?', $subject->getType())
                ->where('id = ?', $subject->getIdentity())
                ->limit();

        $row = $table->fetchRow($select);
        if (null != $row && !empty($row->style)) {
          $this->view->headStyle()->appendStyle($row->style);
        }
      }
    }

    if (null != ($tab = $this->_getParam('tab'))) {
      // provide widgties page
      $friend_tab_function = <<<EOF
                                        var content_id = "$tab";
                                        this.onload = function()
                                        {
                                                tabContainerSwitch($('main_tabs').getElement('.tab_' + content_id));
                                        }
EOF;
      $this->view->headScript()->appendScript($friend_tab_function);
    }
    $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
    $coreversion = $coremodule->version;
    if ($coreversion < '4.1.0') {
      $this->_helper->content->render();
    } else {
      $this->_helper->content
          ->setNoRender()
          ->setEnabled()
      ;
    }
  }

}