<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: ReviewController.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_ReviewController extends Core_Controller_Action_Standard {

  public function init() {

    if (Engine_Api::_()->core()->hasSubject())
      return;
    if (0 != ($recipe_id = (int) $this->_getParam('recipe_id')) &&
        null != ($recipe = Engine_Api::_()->getItem('recipe', $recipe_id))) {
      Engine_Api::_()->core()->setSubject($recipe);
    }
  }

  // POST NEW REVIEW
  public function createAction() {

    if (!$this->_helper->requireUser()->isValid())
      return;

    if (!$this->_helper->requireSubject('recipe')->isValid())
      return;

    // GET LISITING
    $this->view->recipe = $recipe = Engine_Api::_()->core()->getSubject();

    $content_id = $this->_getParam('content_id');

    // Make form
    $this->view->form = $form = new Recipe_Form_Review_Create();

    // Process form
    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();

      try {
        $viewer = Engine_Api::_()->user()->getViewer();

        $values = $form->getValues();
        $values['owner_id'] = $viewer->getIdentity();
        $values['recipe_id'] = $recipe->getIdentity();

        // Create topic
        $reviewTable = Engine_Api::_()->getDbtable('reviews', 'recipe');
        $review = $reviewTable->createRow();
        $review->setFromArray($values);
        $review->save();
        // Add activity

        $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
        $subject = Engine_Api::_()->core()->getSubject();
        $subjectOwner = $subject->getOwner('user');

        // Activity
        $action = $activityApi->addActivity($viewer, $subject, 'review_recipe', '', array(
                    'title' => $subject->getTitle(),
            ));
        if ($action != null) {
          Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $review);
        }

        $db->commit();
        $url = $this->_helper->url->url(array('recipe_id' => $recipe->getIdentity(), 'user_id' => $recipe->owner_id, 'slug' => $recipe->getSlug(), 'tab' => $content_id), 'recipe_entry_view', true);

        $this->_forward('success', 'utility', 'core', array(
                'parentRefresh' => 3,
                'parentRedirect' => $url,
                'parentRedirectTime' => 1,
                'messages' => array('Your Review has been posted successfully.')
        ));
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
    }
  }

  // EDIT REVIEW
  public function editAction() {

    if (!$this->_helper->requireUser()->isValid())
      return;

    if (!$this->_helper->requireSubject('recipe')->isValid())
      return;

    $this->view->recipe = $recipe = Engine_Api::_()->core()->getSubject();

    $id = $this->_getParam('id');
    $content_id = $this->_getParam('content_id');
    $review = Engine_Api::_()->getItem('recipe_reviews', $id);

    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

    if ($review->owner_id != $viewer_id) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    // Make form
    $this->view->form = $form = new Recipe_Form_Review_Create();
    $form->populate($review->toarray());
    $form->setTitle('Edit your Review');
    $form->submit->setLabel('Save Changes');

    // Process form
    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      try {
        $viewer = Engine_Api::_()->user()->getViewer();
        $values = $form->getValues();
        $values['owner_id'] = $viewer->getIdentity();
        $values['recipe_id'] = $recipe->getIdentity();
        $values['modified_date'] = date('Y-m-d H:i:s');

        // Create topic
        $review->setFromArray($values);
        $review->save();
        $db->commit();
        $content_id = $this->_getParam('content_id');
        // Redirect to the post
        $url = $this->_helper->url->url(array('recipe_id' => $recipe->getIdentity(), 'user_id' => $recipe->owner_id, 'slug' => $recipe->getSlug(), 'tab' => $content_id), 'recipe_entry_view', true);
        $this->_forward('success', 'utility', 'core', array(
                'parentRefresh' => 3,
                'parentRedirect' => $url,
                'parentRedirectTime' => 1,
                'messages' => array('Your Review has been edited successfully.')
        ));
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
    }
  }

  // DELETE REVIEW
  public function deleteAction() {

    if (!$this->_helper->requireUser()->isValid())
      return;

    if (!$this->_helper->requireSubject('recipe')->isValid())
      return;

    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();
    $id = $this->_getParam('id');

    $review = Engine_Api::_()->getItem('recipe_reviews', $id);

    if (!($review->owner_id == $viewer_id || $viewer->level_id == 1)) {
      return $this->_forward('requireauth', 'error', 'core');
    }
    if ($this->getRequest()->isPost()) {

      $this->view->recipe = $recipe = Engine_Api::_()->core()->getSubject();
      $content_id = $this->_getParam('content_id');
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      try {
        //DELETE REVIEW FROM DATABASE
        $review->delete();
        $db->commit();
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
      // Redirect to the post
      $url = $this->_helper->url->url(array('recipe_id' => $recipe->getIdentity(), 'user_id' => $recipe->owner_id, 'slug' => $recipe->getSlug(), 'tab' => $content_id), 'recipe_entry_view', true);
     
      $this->_forward('success', 'utility', 'core', array(
              'parentRefresh' => 3,
              'parentRedirect' => $url,
              'parentRedirectTime' => 1,
              'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your review has been deleted successfully.'))
      ));
    } else {
      $this->renderScript('review/delete.tpl');
    }
  }

}