<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: TopicController.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_TopicController extends Core_Controller_Action_Standard {

  public function init() {
    if (Engine_Api::_()->core()->hasSubject())
      return;

    if (0 != ($topic_id = (int) $this->_getParam('topic_id')) &&
        null != ($topic = Engine_Api::_()->getItem('recipe_topic', $topic_id))) {
      Engine_Api::_()->core()->setSubject($topic);
    } else if (0 != ($recipe_id = (int) $this->_getParam('recipe_id')) &&
        null != ($recipe = Engine_Api::_()->getItem('recipe', $recipe_id))) {
      Engine_Api::_()->core()->setSubject($recipe);
    }
  }

  public function indexAction() {
    if (!$this->_helper->requireSubject('recipe')->isValid())
      return;

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;

    $this->view->recipe = $recipe = Engine_Api::_()->core()->getSubject();
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();
    // $table = Engine_Api::_()->getDbtable('topics', 'recipe');
//    $select = $table->select()
//            ->where('recipe_id = ?', $recipe->getIdentity())
//            ->order('sticky DESC')
//            ->order('modified_date DESC');

    $this->view->paginator = $paginator = Engine_Api::_()->getDbtable('topics', 'recipe')->getRecipeTopices($recipe->getIdentity()); //Zend_Paginator::factory($select);
    $this->view->can_post = $can_post = $this->_helper->requireAuth->setAuthParams('recipe', null, 'comment')->checkRequire();
    $paginator->setCurrentPageNumber($this->_getParam('page'));
  }

  public function viewAction() {
    if (!$this->_helper->requireSubject('recipe_topic')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;

    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->topic = $topic = Engine_Api::_()->core()->getSubject();
    $this->view->recipe = $recipe = $topic->getParentRecipe();

    $this->view->canPost = $canPost = $recipe->authorization()->isAllowed($viewer, 'comment');

    if (!$viewer || !$viewer->getIdentity() || $viewer->getIdentity() != $topic->user_id) {
      $topic->view_count = new Zend_Db_Expr('view_count + 1');
      $topic->save();
    }

    // Check watching
    $isWatching = null;
    if ($viewer->getIdentity()) {

      $topicWatchesTable = Engine_Api::_()->getDbtable('topicWatches', 'recipe');
      $isWatching = $topicWatchesTable->isWatching($recipe->getIdentity(), $topic->getIdentity(), $viewer->getIdentity());
      if (false == $isWatching) {
        $isWatching = null;
      } else {
        $isWatching = (bool) $isWatching;
      }
    }
    $this->view->isWatching = $isWatching;

    // @todo implement scan to post
    $this->view->post_id = $post_id = (int) $this->_getParam('post');

    $table = Engine_Api::_()->getDbtable('posts', 'recipe');
    $select = $table->select()
            ->where('recipe_id = ?', $recipe->getIdentity())
            ->where('topic_id = ?', $topic->getIdentity())
            ->order('creation_date ASC');

    $this->view->paginator = $paginator = Zend_Paginator::factory($select);

    // Skip to page of specified post
    if (0 != ($post_id = (int) $this->_getParam('post_id')) &&
        null != ($post = Engine_Api::_()->getItem('recipe_post', $post_id))) {
      $icpp = $paginator->getItemCountPerPage();
      $page = ceil(($post->getPostIndex() + 1) / $icpp);
      $paginator->setCurrentPageNumber($page);
    }

    // Use specified page
    else if (0 != ($page = (int) $this->_getParam('page'))) {
      $paginator->setCurrentPageNumber($this->_getParam('page'));
    }

    if ($canPost && !$topic->closed) {
      $this->view->form = $form = new Recipe_Form_Post_Create();
      $form->populate(array(
              'topic_id' => $topic->getIdentity(),
              'ref' => $topic->getHref(),
              'watch' => ( false == $isWatching ? '0' : '1' ),
      ));
    }
  }

  public function createAction() {
    if (!$this->_helper->requireUser()->isValid())
      return;
    if (!$this->_helper->requireSubject('recipe')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'comment')->isValid())
      return;

    $this->view->recipe = $recipe = Engine_Api::_()->core()->getSubject('recipe');
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();

    // Make form
    $this->view->form = $form = new Recipe_Form_Topic_Create();

    // Check method/data
    if (!$this->getRequest()->isPost()) {
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Process
    $values = $form->getValues();
    $values['user_id'] = $viewer->getIdentity();
    $values['recipe_id'] = $recipe->getIdentity();

    $topicTable = Engine_Api::_()->getDbtable('topics', 'recipe');
    $topicWatchesTable = Engine_Api::_()->getDbtable('topicWatches', 'recipe');
    $postTable = Engine_Api::_()->getDbtable('posts', 'recipe');

    $db = $recipe->getTable()->getAdapter();
    $db->beginTransaction();

    try {
      // Create topic
      $topic = $topicTable->createRow();
      $topic->setFromArray($values);
      $topic->save();

      // Create post
      $values['topic_id'] = $topic->topic_id;

      $post = $postTable->createRow();
      $post->setFromArray($values);
      $post->save();

      // Create topic watch
      $topicWatchesTable->insert(array(
              'resource_id' => $recipe->getIdentity(),
              'topic_id' => $topic->getIdentity(),
              'user_id' => $viewer->getIdentity(),
              'watch' => (bool) $values['watch'],
      ));

      // Add activity
      $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
      $action = $activityApi->addActivity($viewer, $topic, 'recipe_topic_create');

      if ($action) {
        $action->attach($topic);
      }
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    // Redirect to the post
    $this->_redirectCustom($post);
  }

  public function postAction() {
    if (!$this->_helper->requireUser()->isValid())
      return;
    if (!$this->_helper->requireSubject('recipe_topic')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'comment')->isValid())
      return;

    $this->view->topic = $topic = Engine_Api::_()->core()->getSubject();
    $this->view->recipe = $recipe = $topic->getParentRecipe();

    if ($topic->closed) {
      $this->view->status = false;
      $this->view->message = Zend_Registry::get('Zend_Translate')->_('This has been closed for posting.');
      return;
    }

    // Make form
    $this->view->form = $form = new Recipe_Form_Post_Create();

    // Check method/data
    if (!$this->getRequest()->isPost()) {
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Process
    $viewer = Engine_Api::_()->user()->getViewer();
    $topicOwner = $topic->getOwner();
    $isOwnTopic = $viewer->isSelf($topicOwner);

    $postTable = Engine_Api::_()->getDbtable('posts', 'recipe');
    $topicWatchesTable = Engine_Api::_()->getDbtable('topicWatches', 'recipe');
    $userTable = Engine_Api::_()->getItemTable('user');
    $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
    $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');

    $values = $form->getValues();
    $values['user_id'] = $viewer->getIdentity();
    $values['recipe_id'] = $recipe->getIdentity();
    $values['topic_id'] = $topic->getIdentity();

    $watch = (bool) $values['watch'];
    $isWatching = $topicWatchesTable->isWatching($recipe->getIdentity(), $topic->getIdentity(), $viewer->getIdentity());

    $db = $recipe->getTable()->getAdapter();
    $db->beginTransaction();

    try {
      // Create post
      $post = $postTable->createRow();
      $post->setFromArray($values);
      $post->save();

      // Watch
      if (false == $isWatching) {
        $topicWatchesTable->insert(array(
                'resource_id' => $recipe->getIdentity(),
                'topic_id' => $topic->getIdentity(),
                'user_id' => $viewer->getIdentity(),
                'watch' => (bool) $watch,
        ));
      } else if ($watch != $isWatching) {
        $topicWatchesTable->update(array(
                'watch' => (bool) $watch,
            ), array(
                'resource_id = ?' => $recipe->getIdentity(),
                'topic_id = ?' => $topic->getIdentity(),
                'user_id = ?' => $viewer->getIdentity(),
        ));
      }

      // Activity
      $action = $activityApi->addActivity($viewer, $topic, 'recipe_topic_reply');
      if ($action) {
        $action->attach($post, Activity_Model_Action::ATTACH_DESCRIPTION);
      }

      // Notifications
      $notifyUserIds = $topicWatchesTable->getNotifyUserIds($values);
//      $notifyUserIds = $topicWatchesTable->select()
//              ->from($topicWatchesTable->info('name'), 'user_id')
//              ->where('resource_id = ?', $recipe->getIdentity())
//              ->where('topic_id = ?', $topic->getIdentity())
//              ->where('watch = ?', 1)
//              ->query()
//              ->fetchAll(Zend_Db::FETCH_COLUMN);


      foreach ($userTable->find($notifyUserIds) as $notifyUser) {
        // Don't notify self
        if ($notifyUser->isSelf($viewer)) {
          continue;
        }

        if ($notifyUser->isSelf($topicOwner)) {
          $type = 'recipe_discussion_response';
        } else {
          $type = 'recipe_discussion_reply';
        }

        $notifyApi->addNotification($notifyUser, $viewer, $topic, $type, array(
                'message' => $this->view->BBCode($post->body),
        ));
      }
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    // Redirect to the post
    $this->_redirectCustom($post);
  }

  public function stickyAction() {
    if (!$this->_helper->requireSubject('recipe_topic')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'edit')->isValid())
      return;

    $topic = Engine_Api::_()->core()->getSubject('recipe_topic');
    $table = $topic->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $topic = Engine_Api::_()->core()->getSubject();
      $topic->sticky = ( null == $this->_getParam('sticky') ? !$topic->sticky : (bool) $this->_getParam('sticky') );
      $topic->save();

      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    $this->_redirectCustom($topic);
  }

  public function closeAction() {
    if (!$this->_helper->requireSubject('recipe_topic')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'edit')->isValid())
      return;

    $topic = Engine_Api::_()->core()->getSubject();
    $table = $topic->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $topic = Engine_Api::_()->core()->getSubject();
      $topic->closed = ( null == $this->_getParam('closed') ? !$topic->closed : (bool) $this->_getParam('closed') );
      $topic->save();
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    $this->_redirectCustom($topic);
  }

  public function renameAction() {
    if (!$this->_helper->requireSubject('recipe_topic')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'edit')->isValid())
      return;

    $topic = Engine_Api::_()->core()->getSubject();
    $this->view->form = $form = new Recipe_Form_Topic_Rename();

    if (!$this->getRequest()->isPost()) {
      $form->title->setValue(htmlspecialchars_decode($topic->title));
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $table = $topic->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      $title = htmlspecialchars($form->getValue('title'));
      $topic = Engine_Api::_()->core()->getSubject();
      $topic->title = $title;
      $topic->save();
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    return $this->_forward('success', 'utility', 'core', array(
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Topic renamed.')),
            'layout' => 'default-simple',
            'parentRefresh' => true,
    ));
  }

  public function deleteAction() {
    if (!$this->_helper->requireSubject('recipe_topic')->isValid())
      return;
    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'edit')->isValid())
      return;

    $topic = Engine_Api::_()->core()->getSubject();

    $this->view->form = $form = new Recipe_Form_Topic_Delete();

    if (!$this->getRequest()->isPost()) {
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $table = $topic->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      $topic = Engine_Api::_()->core()->getSubject();
      $recipe = $topic->getParent('recipe');
      $topic->delete();
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    return $this->_forward('success', 'utility', 'core', array(
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Topic deleted.')),
            'layout' => 'default-simple',
            'parentRedirect' => Engine_Api::_()->recipe()->getHref($recipe->recipe_id, $recipe->owner_id, $recipe->getSlug()),
    ));
  }

  public function watchAction() {
    $topic = Engine_Api::_()->core()->getSubject();
    $recipe = Engine_Api::_()->getItem('recipe', $topic->recipe_id);
    $viewer = Engine_Api::_()->user()->getViewer();
    if (!$this->_helper->requireAuth()->setAuthParams($recipe, null, 'view')->isValid()) {
      return;
    }

    $watch = $this->_getParam('watch', true);
    $topicWatchesTable = Engine_Api::_()->getDbtable('topicWatches', 'recipe');
    $db = $topicWatchesTable->getAdapter();
    $db->beginTransaction();
    try {
      $resultWatch = $topicWatchesTable
              ->select()
              ->from($topicWatchesTable->info('name'), 'watch')
              ->where('resource_id = ?', $recipe->getIdentity())
              ->where('topic_id = ?', $topic->getIdentity())
              ->where('user_id = ?', $viewer->getIdentity())
              ->limit(1)
              ->query()
              ->fetchAll();
      if (empty($resultWatch))
        $isWatching = 0;
      else
        $isWatching=1;
      if (false == $isWatching) {
        $topicWatchesTable->insert(array(
                'resource_id' => $recipe->getIdentity(),
                'topic_id' => $topic->getIdentity(),
                'user_id' => $viewer->getIdentity(),
                'watch' => (bool) $watch,
        ));
      } else{
        $topicWatchesTable->update(array(
                'watch' => (bool) $watch,
            ), array(
                'resource_id = ?' => $recipe->getIdentity(),
                'topic_id = ?' => $topic->getIdentity(),
                'user_id = ?' => $viewer->getIdentity(),
        ));
      }
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    $this->_redirectCustom($topic);
  }

}