<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteautoaction
 * @copyright  Copyright 2014-2015 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 2014-08-06 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteautoaction_Form_Admin_Create extends Engine_Form {

    /**
     * @var array|null
     */
    protected $levelId;

    /**
     * @var int
     */
    protected $order = 0;

    /**
     * @var array|null
     */
    protected $applyTo;

    /**
     * @var array|null
     */
    protected $actionType;

    /**
     * @var array|null
     */
    protected $resourceIds;

    /**
     * @var string|null
     */
    protected $resourceType;

    /**
     * @var array|null
     */
    protected $filteredValues;

    /**
     * @var array|null
     */
    protected $actionJoin;

    /**
     * @var array|null
     */
    protected $actionCount;

    public function init() {
        $this->addPrefixPath(
            'Fields_Form_Element',
            APPLICATION_PATH . '/application/modules/Fields/Form/Element',
            'element'
        );

        $this->addElement('MultiCheckbox', 'resource_ids', array(

            'label' => 'Select your content',
            'order' => $this->order++,
            'required' => true,
        ));

        $memberLevels = Engine_Api::_()->getDbtable('levels', 'authorization')->getLevelsAssoc();
        unset($memberLevels[Engine_Api::_()->getDbtable('levels', 'authorization')->getPublicLevel()->level_id]);
        $this->addElement('Multiselect', 'level_id', array(
            'label' => 'Select Member Level',
            'description' => 'Select Member Level for which you want to perform this auto action i.e. this action will be automatically performed for the members of the selected Member Level',
            'multiOptions' => $memberLevels,
            'order' => $this->order++,
            'required' => true,
        ));

        $this->addCustomFields();

        $allMultiOptions = array('new' => 'New Signup', 'existing' => 'Existings Users');
        $multiOptions = $allMultiOptions;
        $this->addElement('MultiCheckbox', 'apply_to', array(
            'label' => 'User Type',
            'description' => 'Select users for whom you want to perform this auto action, i.e. this action will be automatically performed for the selected type of users.',
            'multiOptions' => $multiOptions,
            'order' => $this->order++,
            'required' => true,
        ));

        $this->addElement('MultiCheckbox', 'action_type', array(
            'label' => 'Which action you want to perform for selected content?',
            'required' => true,
            'order' => $this->order++,
        ));

        $this->addElement('Radio', 'action_join', array(
            'label' => 'Enable Automatic Membership',
            'description' => '',
            'value' => 1,
            'order' => $this->order++,
            // 'required' => true,
        ));

        /*$this->addElement('Text', 'action_count', [
            'label' => 'Action Count',
            'description' => 'How many auto actions you want to perform. <br>[Note : Enter 0 for unlimited autoactions.]',
            'value' => 0,
            'order' => $this->order++,
            // 'required' => true,
        ]);
        $this->action_count->getDecorator('description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));*/

        $this->addElement('Button', 'submit', array(
            'label' => 'Save',
            'type' => 'submit',
            'order' => 10000
        ));
    }

    public function saveValues() {
        $actionTable = Engine_Api::_()->getDbTable('actions', 'siteautoaction');
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            foreach ($this->resourceIds as $resourceId) {
                $row = $actionTable->createRow();
                $row->resource_id = $resourceId;
                $row->resource_type = $this->resourceType;
                $row->level_id = $this->levelId;
                $row->apply_to = $this->applyTo;
                $row->action_type = $this->actionType;
                $row->action_join = $this->actionJoin;
                $row->action_count = $this->actionCount;
                $row->save();
                $this->saveOptionValues($this->filteredValues, $row);
                if (in_array('existing', $this->applyTo)) {
                    $this->performActions($row, $this->filteredValues);
                }
            }
            $db->commit();
        } catch (Exception $ex) {
            $db->rollBack();
            throw $ex;
        }
    }

    public function performActions($action, $values) {
        $userActionTable = Engine_Api::_()->getDbTable('userActions','siteautoaction');
        $users = Engine_Api::_()->siteautoaction()->getUsers($action, $values);

        foreach ($users as $user) {
            if (!empty($values) && $user->match_count !== count($values)) {
                continue;
            }

            try {
                $row = $userActionTable->createRow();
                $row->user_id = $user->user_id;
                $row->action_id = $action->action_id;
                $row->save();
            } catch (Exception $ex) {

            }
        }

        Engine_Api::_()->getDbtable('jobs', 'core')->addJob('perform_actions', array(
            'action_id' => $action->action_id
        ));
    }

    public function actionExists() {
        $values = $this->getValues();
        if(empty($values['action_join'])) {
            $values['action_join'] = 1;
        }
        $this->resourceIds = $this->pluckValue($values, 'resource_ids');
        $this->resourceType = $this->pluckValue($values, 'resource_type');
        $this->levelId = $this->pluckValue($values, 'level_id');
        $this->applyTo = $this->pluckValue($values, 'apply_to');
        $this->actionType = $this->pluckValue($values, 'action_type');
        $this->actionJoin = $this->pluckValue($values, 'action_join');
        $this->actionCount = $this->pluckValue($values, 'action_count');

        $actionIds = $this->getMachedActionIds($values);
        if (empty(array_filter($actionIds))) {
            return false;
        }

        $actionTable = Engine_Api::_()->getDbTable('actions', 'siteautoaction');
        $actionSelect = $actionTable->select()->where('action_id IN (?)', array_filter($actionIds))
            ->where('resource_type = ?', $this->resourceType)
            ->where('resource_id IN (?)', $this->resourceIds);
        $results = $actionTable->fetchAll($actionSelect);
        if (!count($results)) {
            return false;
        }

        foreach ($results as $result) {
            if (empty($levelId = array_diff($this->levelId, $result->level_id))) {
                return true;
            }
        }
        $this->levelId = $levelId;
        return false;
    }

    private function addCustomFields() {
        $struct = Engine_Api::_()->fields()->getFieldsStructureFull('user');

        foreach ($struct as $fskey => $map) {
            $field = $map->getChild();

            // Skip fields hidden on signup
            if (isset($field->show) && !$field->show && $this->_isCreation) {
                continue;
            }

            // Add field and load options if necessary
            $params = $field->getElementParams('user');

            //$key = 'field_' . $field->field_id;
            $key = $map->getKey();

            if (!@is_array($params['options']['attribs'])) {
                $params['options']['attribs'] = array();
            }

            // Heading
            if ($params['type'] == 'Heading') {
                $params['options']['value'] = Zend_Registry::get('Zend_Translate')->_($params['options']['label']);
                unset($params['options']['label']);
            }

            // Order
            // @todo this might cause problems, however it will prevent multiple orders causing elements to not show up
            $params['options']['order'] = $this->order++;

            $inflectedType = Engine_Api::_()->fields()->inflectFieldType($params['type']);
            unset($params['options']['alias']);
            unset($params['options']['publish']);
            unset($params['options']['required']);
            $this->addElement($inflectedType, $key, $params['options']);

            $element = $this->getElement($key);

            if (method_exists($element, 'setFieldMeta')) {
                $element->setFieldMeta($field);
            }

            // Set attributes for hiding/showing fields using javscript
            $classes = 'field_container field_' . $map->child_id . ' option_' . $map->option_id . ' parent_' . $map->field_id;
            $element->setAttrib('class', $classes);

            //
            if ($field->canHaveDependents()) {
                $element->setAttrib('onchange', 'changeFields(this)');
            }

            // Set custom error message
            if ($field->error) {
                $element->addErrorMessage($field->error);
            }

            if ($field->isHeading()) {
                $element->removeDecorator('Label')
                    ->removeDecorator('HtmlTag')
                    ->getDecorator('HtmlTag2')->setOption('class', 'form-wrapper-heading');
            }
            if ($element->getDecorator('Description')) {
                $element->getDecorator('Description')->setOption('placement', 'append');
            }
            if ($field->alias == 'profile_type') {
                $element->setDescription('Select Profile Type for which you want to perform this auto action i.e. this action will be automatically performed for the members of the selected Profile Type.');
                $element->getDecorator('Description')->setOption('placement', 'prepend');
            }

            if (!($element instanceof Engine_Form_Element_Radio || $element instanceof Engine_Form_Element_Select)) {
                $this->removeElement($key);
            }
        }
    }

    private function pluckValue(&$array, $key) {
        if ($key === 'resource_type') {
            $array[$key] = strpos($array[$key], 'sitereview_listing') !== false ? 'sitereview_listing' : $array[$key];
        }
        $value = isset($array[$key]) ? $array[$key] : null;
        unset($array[$key]);
        return $value;
    }

    private function saveOptionValues($values, $action) {
        $optionTable = Engine_Api::_()->getDbTable('actionOptions', 'siteautoaction');
        foreach ($values as $key => $value) {
            if (empty($value)) {
                continue;
            }

            $row = $optionTable->createRow();
            $row->action_id = $action->action_id;
            $row->field_id = $key;
            $row->value = $value;
            $row->save();
        }
    }

    private function getMachedActionIds($values)
    {
        $this->filteredValues = $this->filterValues($values);
        $optionTable = Engine_Api::_()->getDbTable('actionOptions', 'siteautoaction');
        $select = $optionTable->select()
            ->from($optionTable->info('name'), array("action_id", "count(action_id) as total_matches"))
            ->group('action_id');
        $totalActions = $optionTable->fetchAll($select);

        $select->orWhere("field_id IN('" . join("','", array_keys($this->filteredValues)) . "') and value IN('" .
            join("','", array_values($this->filteredValues)) . "')");

        $matchedActions = $optionTable->fetchAll($select);

        $actionIds = array();
        foreach ($totalActions as $action) {
            foreach ($matchedActions as $matchedAction) {
                if ($matchedAction->action_id == $action->action_id) {
                    $actionIds[] = count($this->filteredValues) === $matchedAction->total_matches ?
                        $matchedAction->total_matches === $action->total_matches ? $matchedAction->action_id :
                        null : null;
                    break;
                }
            }
        }

        return $actionIds;
    }

    private function filterValues($values) {
        unset($values['search']);
        $keys = array_keys($values);
        $replaceKeys = array();
        foreach ($keys as $key) {
            $flag = explode('_', $key);
            $replaceKeys[$key] = array_pop($flag);
        }

        return array_filter(array_combine(array_merge($values, $replaceKeys), $values));
    }
}
