<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteautoaction
 * @copyright  Copyright 2014-2015 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2014-08-06 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteautoaction_Plugin_Core
{
    public function onUserSignupAfter($event)
    {
        $user = $event->getPayload();

        // dump(!($user instanceof User_Model_User));
        if (!($user instanceof User_Model_User)) {
            return;
        }

        if (!$user->isEnabled()) {
            Engine_Api::_()->getDbtable('userSettings', 'seaocore')->setSetting($user, 'pending_auto_actions', true);
            return;
        }

        $this->performAutoActions($user);
    }

    public function onUserEnable($event)
    {
        $payload = $event->getPayload();
        $user = $payload['user'];

        if (!($user instanceof User_Model_User) || !Engine_Api::_()->getDbtable('settings', 'user')
            ->getSetting($user, "pending_auto_actions")) {
            return;
        }

        Engine_Api::_()->getDbtable('userSettings', 'seaocore')->setSetting($user, 'pending_auto_actions', null);
        $this->performAutoActions($user);
    }

    public function onItemDeleteBefore($event) {
        $item = $event->getPayload();

        Engine_Api::_()->getDbTable('actions','siteautoaction')->delete(array(
            'resource_id = ?' => $item->getIdentity(),
            'resource_type = ?' => $item->getType()
        ));
    }

    private function performAutoActions($user)
    {
        $userValues = Engine_Api::_()->fields()->getTable('user', 'values')->getValues($user);
        if (empty($userValues)) {
            return;
        }

        $optionTable = Engine_Api::_()->getDbTable('actionOptions', 'siteautoaction');
        $optionTableName = $optionTable->info('name');
        $select = $optionTable->select()
            ->from(
                $optionTableName,
                array("{$optionTableName}.action_id" ,"count({$optionTableName}.action_id) as total_matches")
            )
            ->group('action_id');
        $totalactions = $optionTable->fetchAll($select);

        foreach ($userValues as $userValue) {
            $select->orWhere("{$optionTableName}.field_id = $userValue->field_id "
                . "and {$optionTableName}.value = '$userValue->value'");
        }
        $matchedactions = $optionTable->fetchAll($select);

        $actionIds = array();
        foreach($totalactions as $action) {
            foreach($matchedactions as $matchaction) {
                if ($matchaction->action_id == $action->action_id) { 
                    $actionIds[] = $matchaction->total_matches === $action->total_matches ?
                        $matchaction->action_id : null;
                    break;
                }
            }
        }
        if (empty($actionIds)) { 
            return;
        }
        
        $userActionTable = Engine_Api::_()->getDbTable('userActions','siteautoaction');
        $actionTable = Engine_Api::_()->getDbTable('actions','siteautoaction');
        $actionSelect = $actionTable->select()->where('action_id IN (?)', $actionIds);
        foreach ($actionTable->fetchAll($actionSelect) as $action) {
            if (!$action->enabled || !in_array('new', $action->apply_to)) {
                continue;
            }

            try {
                $row = $userActionTable->createRow();
                $row->user_id = $user->user_id;
                $row->action_id = $action->action_id;
                $row->save();
            } catch (Exception $ex) {
                // Listen Silently...
            }
        }

        Engine_Api::_()->getDbtable('jobs', 'core')->addJob('perform_actions', array(
            'user_id' => $user->getIdentity(),
        ));
    }
}
