<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteautoaction
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    PerformAction.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteautoaction_Plugin_Job_PerformAction extends Core_Plugin_Job_Abstract {

    protected function _execute() {
        // Prepare tables
        $userActionTable = Engine_Api::_()->getDbTable('userActions', 'siteautoaction');

        // Prepare
        $isComplete = $break = false;
        $total = $this->getParam('total');
        $limit = $this->getParam('limit', 5);
        $userId = $this->getParam('user_id', 0);
        $position = $this->getParam('position', 0);
        $progress = $this->getParam('progress', 0);
        $actionId = $this->getParam('action_id', 0);

        // Populate total
        if (null === $total) {
            $select = $userActionTable->select()
                ->from($userActionTable->info('name'), new Zend_Db_Expr('COUNT(*)'));

            if ($userId) {
                $select->where('user_id = ?', $userId);
            }
            if ($actionId) {
                $select->where('action_id = ?', $actionId);
            }

            $total = $select->query()->fetchColumn(0);
            $this->setParam('total', $total);
            if (!$progress) {
                $this->setParam('progress', 0);
            }
            if (!$position) {
                $this->setParam('position', 0);
            }
        }

        // Complete if nothing to do
        if ($total <= 0) {
            $this->_setWasIdle();
            $this->_setIsComplete(true);
            return;
        }


        // Execute
        $count = 0;

        while (!$break && $count <= $limit) {
            $select = $userActionTable->select()
                ->where('user_action_id >= ?', (int) $position + 1)
                ->order('user_action_id ASC')
                ->limit(1);
            if ($userId) {
                $select->where('user_id = ?', $userId);
            }
            if ($actionId) {
                $select->where('action_id = ?', $actionId);
            }

            $userAction = $userActionTable->fetchRow($select);

            // Nothing left
            if (!$userAction) {
                $break = true;
                $isComplete = true;
                continue;
            }

            $position = $userAction->user_action_id;
            $count++;
            $progress++;
            try {
                $action = Engine_Api::_()->getItem('siteautoaction_action', $userAction->action_id);
                Engine_Api::_()->siteautoaction()->performActions(
                    Engine_Api::_()->getItem($action->resource_type, $action->resource_id),
                    Engine_Api::_()->getItem('user', $userAction->user_id),
                    $action->action_type,
                    $action
                );

                //Cleanup
                $userActionTable->delete(array('user_action_id = ?' => $userAction->user_action_id));
            } catch (Exception $e) {
                $this->_addMessage($e->getMessage());
            }

            // Cleanup
            unset($userAction);
        }

        // Cleanup
        $this->setParam('position', $position);
        $this->setParam('progress', $progress);
        $this->_setIsComplete($isComplete);
    }
}
