<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Allure
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Add.php 2015-06-04 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebanner_Form_Admin_Slideshow_SlideCTA extends Engine_Form {

	protected $_isArray = true;
	protected $_number = 1;
	protected $_params = array();
  protected $_fontIconsList = array();

	public function setParams($params) {
		$this->_params = $params;
		return $this;
	}

	public function setNumber($number) {
		$this->_number = $number;
		return $this;
	}

  public function setFontIconsList($fontIconsList)
  {
    $this->_fontIconsList = $fontIconsList;
    return $this;
  }

	public function init() {
		$this->clearDecorators()
			->addDecorator('FormElements');

		//VALUE FOR LOGO PREVIEW.
		$this->addElement('Dummy', 'heading', array(
			'label' => 'CTA Button ' . $this->_number . ':',
		));
		// Init name
		$this->addElement('Text', 'title', array(
			'label' => 'Label',
			'description' => 'Add a label to the button.',
			'maxlength' => '100',
			'filters' => array(
				//new Engine_Filter_HtmlSpecialChars(),
				'StripTags',
				new Engine_Filter_Censor(),
				new Engine_Filter_StringLength(array('max' => '100')),
			),
		));
		$this->addElement('Text', 'url', array(
			'label' => 'URL',
			'description' => 'Specify a URL to which CTA button should redirect users.',
			'maxlength' => '256',
			'filters' => array(
				//new Engine_Filter_HtmlSpecialChars(),
				'StripTags',
			),
		));
    if( $this->_fontIconsList ) {
      $this->addElement('Select', 'button_icon', array(
        'label' => 'Font Icon',
        'description' => "Select the font icon for the button? Below listed icons are Fontawesome icons.",
        'multiOptions' => $this->_fontIconsList,
        'value' => isset($this->_params['button_icon']) ? $this->_params['button_icon'] : '',
      ));
    } else {
      $this->addElement('Text', 'button_icon', array(
        'label' => 'Font Icon',
        'description' => "Enter the Fontawesome icon class. [Note: you can add the Fontawesome class in this format: ex: 'fa-plus']",
        'maxlength' => '100',
        'filters' => array(
          //new Engine_Filter_HtmlSpecialChars(),
          'StripTags',
        ),
        'value' => isset($this->_params['button_icon']) ? $this->_params['button_icon'] : '',
      ));
    }
    $this->addElement('Text', 'button_border_radius', array(
			'label' => 'Border Radius (in px)',
			'description' => "Border Radius (Please enter radius in pixels, e.g. you can add the value as ‘5’ for showing sharp edges, ‘10’ for showing blunt edges and ‘25’ for showing round edges.)",
			'maxlength' => '100',
			'filters' => array(
				//new Engine_Filter_HtmlSpecialChars(),
				'StripTags',
			),
			'value' => isset($this->_params['button_border_radius']) ? $this->_params['button_border_radius'] : '',
		));

		$this->addElement('Select', 'button_style', array(
			'label' => 'Button Style',
			'description' => "Select the style of the button?",
			'multiOptions' => array(
				'fill' => 'Fill',
				'transparent' => 'Transparent',
				'gradient' => 'Fill Gradient',
			),
			'onchange' => 'changeCTAButtonType(' . $this->_number . ',this.value)',
			'value' => isset($this->_params['button_style']) ? $this->_params['button_style'] : 'fill',
		));

		$this->addElement('Text', 'background_color', array(
			'label' => 'Background Color',
			'decorators' => array(array('ViewScript', array(
				'viewScript' => '_formColorElement.tpl',
				'class' => '',
				'id' => 'cta_' . $this->_number . '-background_color',
				'name' => 'cta_' . $this->_number . '[background_color]',
				'label' => 'Background Color',
				'value' => isset($this->_params['background_color']) ? $this->_params['background_color'] : '',
			))),
		));

		$this->addElement('Text', 'gradient_background_color', array(
			'label' => 'Button Gradient Background Color',
			'value' => isset($this->_params['gradient_background_color']) ? $this->_params['gradient_background_color'] : '',
		));
		$this->addElement('Text', 'hover_background_color', array(
			'label' => 'Mouseover Background Color',
			'decorators' => array(array('ViewScript', array(
				'viewScript' => '_formColorElement.tpl',
				'class' => '',
				'id' => 'cta_' . $this->_number . '-hover_background_color',
				'name' => 'cta_' . $this->_number . '[hover_background_color]',
				'label' => 'Mouseover Background Color',
				'value' => isset($this->_params['hover_background_color']) ? $this->_params['hover_background_color'] : '',
			))),
		));
		$this->addElement('Text', 'gradient_hover_background_color', array(
			'label' => 'Mouseover Gradient Background Color',
			'value' => isset($this->_params['gradient_hover_background_color']) ? $this->_params['gradient_hover_background_color'] : '',
		));
		$this->addElement('Text', 'font_color', array(
			'label' => 'Font Color',
			'decorators' => array(array('ViewScript', array(
				'viewScript' => '_formColorElement.tpl',
				'class' => '',
				'id' => 'cta_' . $this->_number . '-font_color',
				'name' => 'cta_' . $this->_number . '[font_color]',
				'label' => 'Font Color',
				'value' => isset($this->_params['font_color']) ? $this->_params['font_color'] : '',
			))),
		));
		$this->addElement('Text', 'hover_font_color', array(
			'label' => 'Mouseover Font Color',
			'decorators' => array(array('ViewScript', array(
				'viewScript' => '_formColorElement.tpl',
				'class' => '',
				'id' => 'cta_' . $this->_number . '-hover_font_color',
				'name' => 'cta_' . $this->_number . '[hover_font_color]',
				'label' => 'Mouseover Font Color',
				'value' => isset($this->_params['hover_font_color']) ? $this->_params['hover_font_color'] : '',
			))),
		));

		$this->addElement('Text', 'border_color', array(
			'label' => 'Border Color',
			'decorators' => array(array('ViewScript', array(
				'viewScript' => '_formColorElement.tpl',
				'class' => '',
				'id' => 'cta_' . $this->_number . '-border_color',
				'name' => 'cta_' . $this->_number . '[border_color]',
				'label' => 'Border Color',
				'value' => isset($this->_params['border_color']) ? $this->_params['border_color'] : '',
			))),
		));
		$this->addElement('Text', 'hover_border_color', array(
			'label' => 'Mouseover Border Color',
			'decorators' => array(array('ViewScript', array(
				'viewScript' => '_formColorElement.tpl',
				'class' => '',
				'id' => 'cta_' . $this->_number . '-hover_border_color',
				'name' => 'cta_' . $this->_number . '[hover_border_color]',
				'label' => 'Mouseover Border Color',
				'value' => isset($this->_params['hover_border_color']) ? $this->_params['hover_border_color'] : '',
			))),
		));

		$this->addElement('Select', 'target', array(
			'label' => 'Button Target',
			'description' => "Select the type of target for CTA button i.e. whether you want to open the URL linked to CTA button in the same window, new window or in a Lightbox Viewer (you can use Lightbox Viewer in case of videos)?",
			'multiOptions' => array(
				'' => 'Same Window/Tab',
				'_blank' => 'New Window/Tab',
				'SmoothBoxSeao' => 'Open in LightBox',
			),
		));
	}

}