<?php

class Sitebanner_AdminSlideShowController extends Core_Controller_Action_Admin
{

  public function init()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitebanner_admin_main', array(), 'sitebanner_admin_main_manage');
  }

  public function indexAction()
  {

    $table = Engine_Api::_()->getDbTable('slideshows', 'sitebanner');
    $this->view->params = $params = array(
      'limit' => $this->_getParam('limit', 10),
      'page' => $this->_getParam('page', 1),
    );
    $this->view->paginator = $table->getSlideshowsPaginator($params);
  }

  public function createAction()
  {
    $this->view->form = $form = new Sitebanner_Form_Admin_Slideshow_Create();
    // Check stuff
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Save
    $values = $form->getValues();
    $table = Engine_Api::_()->getDbTable('slideshows', 'sitebanner');
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $slideshow = $table->createRow();
      $slideshow->setFromArray($values);
      $slideshow->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => true,
      'parentRefresh' => true,
      'format' => 'smoothbox',
      'messages' => array(Zend_Registry::get('Zend_Translate')->_("Slideshow Created Sucessfully!"))
    ));
  }

  public function editAction()
  {
    $this->view->slideshow_id = $slideshowId = $this->_getParam('id');
    $this->view->slideshow = $slideshow = Engine_Api::_()->getDbtable('slideshows', 'sitebanner')->getSlideshow($slideshowId);
    if( !$slideshow ) {
      throw new Core_Model_Exception('missing slideshow');
    }
    $this->view->form = $form = new Sitebanner_Form_Admin_Slideshow_Edit();
    // Check stuff
    if( !$this->getRequest()->isPost() ) {
      $form->populate($slideshow->toArray());
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Save
    $values = $form->getValues();

    $table = Engine_Api::_()->getDbTable('slideshows', 'sitebanner');
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $slideshow->setFromArray($values);
      $slideshow->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => true,
      'parentRefresh' => true,
      'format' => 'smoothbox',
      'messages' => array(Zend_Registry::get('Zend_Translate')->_("Save Changes Sucessfully!"))
    ));
  }

  public function manageAction()
  {
    $this->view->slideshow_id = $slideshowId = $this->_getParam('id');
    $slideshow = Engine_Api::_()->getDbtable('slideshows', 'sitebanner')->getSlideshow($slideshowId);

    if( !$slideshow ) {
      throw new Core_Model_Exception('missing slideshow');
    }
    $this->view->slideshow = $slideshow;
  }

  public function deleteAction()
  {
    $this->view->slideshow_id = $slideshowId = $this->_getParam('id');
    $slideshow = Engine_Api::_()->getDbtable('slideshows', 'sitebanner')->getSlideshow($slideshowId);

    if( !$slideshow ) {
      throw new Core_Model_Exception('missing slideshow');
    }

    // Get form
    $this->view->form = $form = new Sitebanner_Form_Admin_Slideshow_Delete();

    // Check stuff
    if( !$this->getRequest()->isPost() || !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }


    $slideshow->delete();
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => true,
      'parentRefresh' => true,
      'format' => 'smoothbox',
      'messages' => array(Zend_Registry::get('Zend_Translate')->_("Banner Deleted"))
    ));
  }



  public function createSlideAction()
  {
    $this->view->slideshow_id = $slideshowId = $this->_getParam('id');
    $slideshow = Engine_Api::_()->getDbtable('slideshows', 'sitebanner')->getSlideshow($slideshowId);
    if( !$slideshow ) {
      throw new Core_Model_Exception('missing slideshow');
    }
    $this->view->slideshow = $slideshow;
    $this->view->form = $form = new Sitebanner_Form_Admin_Slideshow_SlideAdd();
    // Check stuff
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Save
    $values = $form->getValues();
    $table = Engine_Api::_()->getDbTable('slides', 'sitebanner');
    $params = array();
    $background_type = $values['background_type'];
    $background_image = $values['background_image'];
    foreach( $values as $key => $value ) {
      if( strpos($key, 'style_') === 0 || strpos($key, 'cta_') === 0 || strpos($key, 'params_') === 0 ) {
        $params[$key] = $value;
        unset($values[$key]);
      }
    }
    if( $background_type == 'color' ) {
      $values['background'] = $values['background_color'];
    }
    if( $background_type == 'gradient' ) {
      $values['background'] = $values['background_gradient'];
    }
    $values['params'] = $this->setFrameImageRatio($params);
    $values['slideshow_id'] = $slideshow->getIdentity();
    unset($values['background_color']);
    unset($values['background_gradient']);
    unset($values['background_image']);
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $slide = $table->createRow();
      $slide->setFromArray($values);
      $slide->save();
      // Set photo
      if( !empty($background_image) && $values['background_type'] == 'image' ) {
        $slide->setBackgroundImage($form->background_image);
      }
      if( !empty($values['photo']) ) {
        $slide->setPhoto($form->photo);
      }
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }
    // redirect to manage page for now
    $this->_helper->redirector->gotoRoute(array('module' => 'sitebanner', 'controller' => 'slide-show', 'action' => 'manage', 'id' => $slideshowId), 'admin_default', true);
  }

  public function editSlideAction()
  {
    $this->view->slide_id = $slideId = $this->_getParam('id');
    $this->view->slide = $slide = Engine_Api::_()->getDbtable('slides', 'sitebanner')->getSlide($slideId);
    if( !$slide ) {
      throw new Core_Model_Exception('missing slide');
    }

    $this->view->slideshow_id = $slideshowId = $slide->slideshow_id;
    $slideshow = Engine_Api::_()->getDbtable('slideshows', 'sitebanner')->getSlideshow($slideshowId);
    if( !$slideshow ) {
      throw new Core_Model_Exception('missing slideshow');
    }
    $this->view->slideshow = $slideshow;
    // Make safe
    $slideData = $slide->toArray();
    if( in_array($slideData['background_type'], array('color', 'gradient')) ) {
      $type = $slideData['background_type'];
      $slideData['background_' . $type] = $slideData['background'];
    }
    if( is_array($slideData['params']) ) {
      $slideData = array_merge($slideData, $slideData['params']);
    }
    $this->view->form = $form = new Sitebanner_Form_Admin_Slideshow_SlideEdit(array('initParams' => $slideData));

    // Check stuff
    if( !$this->getRequest()->isPost() ) {
      $form->populate($slideData);
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Save
    $values = $form->getValues();
    $background_type = $values['background_type'];
    $background_image = $values['background_image'];
    foreach( $values as $key => $value ) {
      if( strpos($key, 'style_') === 0 || strpos($key, 'cta_') === 0 || strpos($key, 'params_') === 0) {
        $params[$key] = $value;
        unset($values[$key]);
      }
    }
    if( $background_type == 'color' ) {
      $values['background'] = $values['background_color'];
    }
    if( $background_type == 'gradient' ) {
      $values['background'] = $values['background_gradient'];
    }
   
    $values['params'] = $this->setFrameImageRatio($params);
    unset($values['background_color']);
    unset($values['background_gradient']);
    unset($values['background_image']);
    $table = Engine_Api::_()->getDbTable('slides', 'sitebanner');

    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $slide->setFromArray($values);
      $slide->save();
      // Set photo
      if( !empty($background_image) && $background_type == 'image' ) {
        $slide->setBackgroundImage($form->background_image);
      }
      if( !empty($values['photo']) ) {
        $slide->setPhoto($form->photo);
      }
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }
    // redirect to manage page for now
    $this->_helper->redirector->gotoRoute(array('module' => 'sitebanner', 'controller' => 'slide-show', 'action' => 'manage', 'id' => $slide->slideshow_id), 'admin_default', true);
  }

  public function deleteSlideAction()
  {
    $this->view->slide_id = $slideId = $this->_getParam('id');
    $this->view->slide = $slide = Engine_Api::_()->getDbtable('slides', 'sitebanner')->getSlide($slideId);
    if( !$slide ) {
      throw new Core_Model_Exception('missing slide');
    }

    // Get form
    $this->view->form = $form = new Sitebanner_Form_Admin_Slideshow_SlideDelete();

    // Check stuff
    if( !$this->getRequest()->isPost() || !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    $slide->delete();
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => true,
      'parentRefresh' => true,
      'format' => 'smoothbox',
      'messages' => array(Zend_Registry::get('Zend_Translate')->_("Slide Deleted"))
    ));
  }

  public function viewSlideAction()
  {
    
  }

  public function setOrderAction()
  {
    if( empty($_POST) || empty($_POST['order']) ) {
      return;
    }
    foreach( $_POST['order'] as $key => $value ) {
      if( strstr($key, "content_") ) {
        $keyArray = explode("content_", $key);
        $slideId = end($keyArray);

        if( empty($slideId) ) {
          continue;
        }
        $slide = Engine_Api::_()->getDbtable('slides', 'sitebanner')->getSlide($slideId);
        if( !$slide ) {
          continue;
        }
        $slide->order = $value;
        $slide->save();
      }
    }
  }

  private function setFrameImageRatio($params)
  {
    $frames = array(
      'desktop' => array(500, 404),
      'lp' => array(501, 288),
      'ipad' => array(216, 300),
      'mob' => array(199, 400)
    );

    if( !empty($params['params_photo_frame']) && (!empty($params['style_photo_width']) || !empty($params['style_photo_height'])) ) {
      $framesType = str_replace('_frame_', '', explode(' ', $params['params_photo_frame'])[0]);

      $data = $frames[$framesType];
      if( !empty($params['style_photo_width']) ) {
        $params['style_photo_height'] = round($params['style_photo_width'] * $data[1] / $data[0], 2);
      } elseif( !empty($params['style_photo_height']) ) {
        $params['style_photo_width'] = round($params['style_photo_height'] * $data[0] / $data[1], 2);
      }
    }
    return $params;
  }

}