<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Form_Admin_Global extends Engine_Form {
    
    // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
    public $_SHOWELEMENTSBEFOREACTIVATE = array(
        "submit_lsetting", "environment_mode"
    );
    
  public function init() {
    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $this
            ->setTitle('Global Settings')
            ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'sitebusiness_lsettings', array(
        'label' => 'Enter License key',
        'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
        'value' => $coreSettings->getSetting('sitebusiness.lsettings'),
    ));

    if( APPLICATION_ENV == 'production' ) {
      $this->addElement('Checkbox', 'environment_mode', array(
          'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few businesses of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
          'description' => 'System Mode',
//          'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    //Add submit button
    $this->addElement('Button', 'submit_lsetting', array(
        'label' => 'Activate Your Plugin Now',
        'type' => 'submit',
        'ignore' => true
    ));


    $this->addElement('Text', 'language_phrases_business', array(
        'label' => 'Singular Business Title',
        'description' => 'Please enter the Singular Title for business. This text will come in places like feeds generated, widgets etc.',
        'allowEmpty' => FALSE,
        'validators' => array(
            array('NotEmpty', true),
        ),
        'value'=> Engine_Api::_()->getApi('settings', 'core')->getSetting( "language.phrases.business", "business"),

    ));
    
    $this->addElement('Text', 'language_phrases_businesses', array(
        'label' => 'Plural Business Title',
        'description' => 'Please enter the Plural Title for businesses. This text will come in places like Main Navigation Menu, Business Navigation Menu, widgets etc.',
        'allowEmpty' => FALSE,
        'validators' => array(
            array('NotEmpty', true),
        ),
      'value'=> Engine_Api::_()->getApi('settings', 'core')->getSetting( "language.phrases.businesses", "businesses"),
    ));



    $this->addElement('Text', 'sitebusiness_manifestUrlP', array(
        'label' => 'Businesses URL alternate text for "businessitems"',
        'allowEmpty' => false,
        'required' => true,
        'description' => 'Please enter the text below which you want to display in place of "businessitems" in the URLs of this plugin.',
        'value' => $coreSettings->getSetting('sitebusiness.manifestUrlP', "businessitems"),
    ));

    $this->addElement('Text', 'sitebusiness_manifestUrlS', array(
        'label' => 'Businesses URL alternate text for "businessitem"',
        'allowEmpty' => false,
        'required' => true,
        'description' => 'Please enter the text below which you want to display in place of "businessitem" in the URLs of this plugin.',
        'value' => $coreSettings->getSetting('sitebusiness.manifestUrlS', "businessitem"),
    ));

    //VALUE FOR ENABLE/DISABLE PACKAGE
    $this->addElement('Radio', 'sitebusiness_package_enable', array(
        'label' => 'Packages',
        'description' => 'Do you want Packages to be activated for Directory Items / Businesses? Packages can vary based on the features available to the businesses created under them. If enabled, users will have to select a package in the first step while creating a new business. Business admins will be able to change their package later. To manage business packages, go to Manage Business Packages section. (Note: If packages are enabled, then feature settings for businesses will depend on packages, and member levels based feature settings will be off. If packages are disabled, then feature settings for businesses could be configured for member levels.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showpackageOption(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.package.enable', 1),
    ));
    
    $this->addElement('Radio', 'sitebusiness_package_view', array(
           'label' => 'Package View',
           'description' => 'Select the view type of packages that will be shown in the first step of business creation.',
           'multiOptions' => array(
               1 => 'Vertical',
               0 => 'Horizontal'
           ),
           'value' => $coreSettings->getSetting('sitebusiness.package.view', 1),
    ));
     
     $packageInfoArray = array('price' => 'Price', 'billing_cycle' => 'Billing Cycle', 'duration' => 'Duration', 'featured' => 'Featured', 'sponsored' => 'Sponsored', 'tellafriend' => 'Tell a friend', 'print' => 'Print', 'overview' => 'Rich Overview', 'map' => 'Map', 'insights' => 'Insights', 'contactdetails' => 'Contact Details', 'sendanupdate' => 'Send an Update', 'apps' => 'Apps available', 'description' => 'Description');

    if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesstwitter')) {
        $packageInfoArray = array_merge($packageInfoArray, array('twitterupdates' => 'Display Twitter Updates'));
    }

    if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('communityad')) {
        $packageInfoArray = array_merge($packageInfoArray, array('ads' => 'Ads Display'));
    }

    $this->addElement('MultiCheckbox', 'sitebusiness_package_information', array(
        'label' => 'Package Information',
        'description' => 'Select the information options that you want to be available in package details.',
        'multiOptions' => $packageInfoArray,
        'value' => $coreSettings->getSetting('sitebusiness.package.information', array_keys($packageInfoArray)),
    ));
    
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $localeObject = Zend_Registry::get('Locale');
    $currencyCode = $coreSettings->getSetting('payment.currency', 'USD');
    $currencyName = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $currencyCode);
    $this->addElement('Dummy', 'sitebusiness_currency', array(
        'label' => 'Currency',
        'description' => "<b>" . $currencyName . "</b> <br class='clear' /> <a href='" . $view->url(array('module' => 'payment', 'controller' => 'settings'), 'admin_default', true)."' target='_blank'>" . Zend_Registry::get('Zend_Translate')->_('edit currency') . "</a>",
    ));
    $this->getElement('sitebusiness_currency')->getDecorator('Description')->setOptions(array('placement', 'APPEND', 'escape' => false));

    $this->addElement('Radio', 'sitebusiness_payment_benefit', array(
        'label' => 'Payment Status for Directory Item / Business Activation',
        'description' => "Do you want to activate directory items / businesses immediately after payment, before the payment passes the gateways' fraud checks? This may take any time from 20 minutes to 4 days, depending on the circumstances and the gateway. (Note: If you want to manually activate businesses, then you can set this while creating a business package.)",
        'multiOptions' => array(
            'all' => 'Activate business immediately.',
            'some' => 'Activate if member has an existing successful transaction, wait if this is their first.',
            'none' => 'Wait until the gateway signals that the payment has completed successfully.',
        ),
        'value' => $coreSettings->getSetting('sitebusiness.payment.benefit', 'all'),
    ));

    $this->addElement('Radio', 'sitebusiness_manageadmin', array(
        'label' => 'Business Admins',
        'description' => 'Do you want there to be multiple admins for directory items / businesses on your site? (If enabled, then every Business will be able to have multiple administrators who will be able to manage that Business. Business Admins will have the authority to add other users as administrators of their Business.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.manageadmin', 1),
    ));
if(!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemenu')){
    $this->addElement('Radio', 'sitebusiness_show_menu', array(
        'label' => 'Businesses Link',
        'description' => 'Select the location of the main link for Businesses.',
        'multiOptions' => array(
            3 => 'Main Navigation Menu',
            2 => 'Mini Navigation Menu',
            1 => 'Footer Menu',
            0 => 'Member Home Business Left side Navigation'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.show.menu', 3),
    ));
}
    //VALUE FOR ENABLE/DISABLE REPORT
    $this->addElement('Radio', 'sitebusiness_report', array(
        'label' => 'Report as Inappropriate',
        'description' => 'Do you want to allow logged-in members to be able to report businesses as inappropriate? (Members will also be able to mention the reason why they find the business inappropriate.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.report', 1),
    ));

    //VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'sitebusiness_share', array(
        'label' => 'Community Sharing',
        'description' => 'Do you want to allow members to share directory items / businesses within your community?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.share', 1),
    ));

    //VALUE FOR ENABLE /DISABLE SHARE
    $this->addElement('Radio', 'sitebusiness_socialshare', array(
        'label' => 'Social Sharing',
        'description' => 'Do you want social sharing to be enabled for directory items / businesses? (If enabled, social sharing buttons will be shown on the Profile Business of directory items / businesses.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.socialshare', 1),
    ));

    //VALUE FOR CAPTCHA
    $this->addElement('Radio', 'sitebusiness_captcha_post', array(
        'label' => 'CAPTCHA For Tell a friend',
        'description' => 'Do you want visitors to enter a validation code in Tell a friend form?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.captcha.post', 1),
    ));

    //VALUE FOR ENABLE /DISABLE LOCATION FIELD
    $this->addElement('Radio', 'sitebusiness_locationfield', array(
        'label' => 'Location Field',
        'description' => 'Do you want the Location field to be enabled for directory items / businesses?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showlocationOption(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.locationfield', 1),
    ));

    
    $this->addElement('Radio', 'sitebusiness_multiple_location', array(
        'label' => 'Allow Multiple Locations',
        'description' => 'Do you want to allow business admins to enter multiple locations for their Businesses? (If you select ‘Yes’, then users will be able to add multiple locations for their Businesses from their Business Dashboards.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.multiple.location', 0),
    ));

    //VALUE FOR ENABLE /DISABLE MAP
    $this->addElement('Radio', 'sitebusiness_location', array(
        'label' => 'Maps Integration',
        'description' => ' Do you want Maps Integration to be enabled for directory items / businesses? (With this enabled, items / businesses having location information could also be seen on Map. The "Businesses Home" and "Browse Businesses" also enable you to see the items plotted on Map.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showMapOptions(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.location', 1),
    ));

    //VALUE FOR ENABLE /DISABLE Bouncing Animation
    $this->addElement('Radio', 'sitebusiness_map_sponsored', array(
        'label' => 'Sponsored Items with a Bouncing Animation',
        'description' => 'Do you want the sponsored directory items / businesses to be shown with a bouncing animation in the Map?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.map.sponsored', 1),
    ));

    $this->addElement('Text', 'sitebusiness_map_city', array(
        'label' => 'Centre Location for Map at Businesses Home and Browse Businesses',
        'description' => 'Enter the location which you want to be shown at centre of the map which is shown on Businesses Home and Browse Businesses when Map View is chosen to view Directory/Businesses.(To show the whole world on the map, enter the word "World" below.)',
        'required' => true,
        'value' => $coreSettings->getSetting('sitebusiness.map.city', "World"),
    ));

    $this->addElement('Select', 'sitebusiness_map_zoom', array(
        'label' => "Default Zoom Level for Map at Businesses Home and Browse Businesses",
        'description' => 'Select the default zoom level for the map which is shown on Businesses Home and Browse Businesses when Map View is chosen to view Directory/Businesses. (Note that as higher zoom level you will select, the more number of surrounding cities/locations you will be able to see.)',
        'multiOptions' => array(
            '1' => "1",
            "2" => "2",
            "4" => "4",
            "6" => "6",
            "8" => "8",
            "10" => "10",
            "12" => "12",
            "14" => "14",
            "16" => "16"
        ),
        'value' => $coreSettings->getSetting('sitebusiness.map.zoom', 1),
        'disableTranslator' => 'true'
    ));

    //VALUE FOR ENABLE /DISABLE Proximity Search
    $this->addElement('Radio', 'sitebusiness_proximitysearch', array(
        'label' => 'Proximity Search',
        'description' => 'Do you want proximity search to be enabled for directory items / businesses? (Proximity search will enable users to search for items / businesses within a certain distance from a location.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showlocationKM(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.proximitysearch', 1),
    ));

    //VALUE FOR ENABLE /DISABLE Proximity Search IN Kilometer
    $this->addElement('Radio', 'sitebusiness_proximity_search_kilometer', array(
        'label' => 'Proximity Search Metric',
        'description' => 'What metric do you want to be used for proximity search?',
        'multiOptions' => array(
            0 => 'Miles',
            1 => 'Kilometers'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.proximity.search.kilometer', 0),
    ));
    
    $this->addElement('Radio', 'sitebusiness_multiple_location', array(
        'label' => 'Allow Multiple Locations',
        'description' => 'Do you want to allow business admins to enter multiple locations for their Businesses? (If you select ‘Yes’, then users will be able to add multiple locations for their Businesses from their Business Dashboards.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.multiple.location', 0),
    ));
    
    //VALUE FOR COMMENT
    $this->addElement('Radio', 'sitebusiness_checkcomment_widgets', array(
        'label' => 'Comments',
        'description' => 'Do you want comments to be enabled for directory items / businesses? (If enabled, then users will be able to comment on items / businesses on their Info tabs.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.checkcomment.widgets', 1),
    ));

    //VALUE FOR CAPTCHA
    $this->addElement('Radio', 'sitebusiness_sponsored_image', array(
        'label' => 'Sponsored Label',
        'description' => 'Do you want to show "SPONSORED" label on the main profile of sponsored directory items / businesses above the profile picture?',
        'onclick' => 'showsponsored(this.value)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.sponsored.image', 1),
    ));

    //COLOR VALUE FOR SPONSORED
    $this->addElement('Text', 'sitebusiness_sponsored_color', array(
        'decorators' => array(array('ViewScript', array(
                    'viewScript' => '_formImagerainbowSponsred.tpl',
                    'class' => 'form element'
            )))
    ));

    //VALUE FOR CAPTCHA
    $this->addElement('Radio', 'sitebusiness_feature_image', array(
        'label' => 'Featured Label',
        'description' => 'Do you want to show "FEATURED" label on the main profile of featured directory items / businesses below the profile picture?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showfeatured(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.feature.image', 1),
    ));

    //COLOR VALUE FOR FEATURED
    $this->addElement('Text', 'sitebusiness_featured_color', array(
        'decorators' => array(array('ViewScript', array(
                    'viewScript' => '_formImagerainbowFeatured.tpl',
                    'class' => 'form element'
            )))
    ));

    //VALUE FOR CAPTCHA
    $this->addElement('Radio', 'sitebusiness_fs_markers', array(
        'label' => 'Featured & Sponsored Markers',
        'description' => 'On Businesses Home, Browse Businesses and My Businesses how do you want a Business to be indicated as featured and sponsored ?',
        'multiOptions' => array(
            1 => 'Using Labels (See FAQ for customizing the labels)',
            0 => 'Using Icons (See FAQ for customizing the icons)',
        ),
        'value' => $coreSettings->getSetting('sitebusiness.fs.markers', 1),
    ));

    $this->addElement('Radio', 'sitebusiness_network', array(
        'label' => 'Browse by Networks',
        'description' => "Do you want to show directory items / businesses according to viewer's network if he has selected any? (If set to no, all the items / businesses will be shown.)",
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showDefaultNetwork(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.network', 0),
    ));

    //VALUE FOR Business Dispute Link.
    $this->addElement('Radio', 'sitebusiness_default_show', array(
        'label' => 'Set Only My Networks as Default in search',
        'description' => 'Do you want to set "Only My Networks" option as default for Show field in the search form widget? (This widget appears on the businesses browse and home businesses, and enables users to search and filter businesses.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showDefaultNetworkType(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.default.show', 0),
    ));

    $this->addElement('Radio', 'sitebusiness_networks_type', array(
        'label' => 'Network selection for Businesses',
        'description' => "You have chosen that viewers should only see Businesses of their network(s). How should a Business's network(s) be decided?",
        'multiOptions' => array(
            0 => "Business Owner's network(s) [If selected, only members belonging to business owner's network(s) will see the Businesses.]",
            1 => "Selected Networks [If selected, business admins will be able to choose the networks of which members will be able to see their Business.]"
        ),
        'value' => $coreSettings->getSetting('sitebusiness.networks.type', 0),
    ));
    
    $this->addElement('Radio', 'sitebusiness_networkprofile_privacy', array(
        'label' => 'Display Profile Business only to Network Users',
        'description' => "Do you want to show the Directory Item / Business Profile business only to users of the same network. (If set to yes and \"Browse By Networks\" is enabled then users would not be able to view the profile business of those businesses which does not belong to their networks.)",
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        // 'onclick' => 'showviewablewarning(this.value);',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.networkprofile.privacy', 0),
    ));
    $this->addElement('Radio', 'sitebusiness_privacybase', array(
        'label' => 'Display of All Businesses in widgets',
        'description' => "Do you want to show all the businesses to the user in the widgets and browse businesses of this plugin irrespective of privacy? [Note: If you select 'No', then only those businesses will be shown in the widgets and browse businesses which are viewable to the current logged-in user. But this may slightly affect the loading speed of your website. To avoid such loading delay to the best possible extent, we are also using caching based display.)",
        'multiOptions' => array(
            0 => 'Yes',
            1 => 'No'
        ),
        // 'onclick' => 'showviewablewarning(this.value);',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.privacybase', 0),
    ));

    //Order of browse business
    $this->addElement('Radio', 'sitebusiness_browseorder', array(
        'label' => 'Default ordering on Browse Businesses',
        'description' => 'Select the default ordering of businesses on the browse businesses.',
        'multiOptions' => array(
            1 => 'All businesses in descending order of creation.',
            2 => 'All businesses in descending order of views.',
            3 => 'All businesses in alphabetical order.',
            4 => 'Sponsored businesses followed by others in descending order of creation.',
            5 => 'Featured businesses followed by others in descending order of creation.',
            6 => 'Sponsored & Featured businesses followed by Sponsored businesses followed by Featured businesses followed by others in descending order of creation.',
            7 => 'Featured & Sponsored businesses followed by Featured businesses followed by Sponsored businesses followed by others in descending order of creation.',
        ),
        'value' => $coreSettings->getSetting('sitebusiness.browseorder', 1),
    ));

    $this->addElement('Radio', 'sitebusiness_addfavourite_show', array(
        'label' => 'Linking Businesses',
        'description' => 'Do you want members to be able to Link their Businesses to other Businesses? (Linking is useful to show related Businesses. For example, a Chef\'s Business can be linked to the Restaurant\'s Business where he works, or a Store\'s Business can be linked to the Businesses of the Brands that it sells. If enabled, a "Link to your Business" link will appear on Businesses.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.addfavourite.show', 1),
    ));

    $this->addElement('Radio', 'sitebusiness_layoutcreate', array(
        'label' => 'Edit Business Layout',
        'description' => 'Do you want to enable business admins to alter the block positions / add new available blocks on the directory item / business profile? (If enabled, then business admins will also be able to add HTML blocks on their directory item / business profile.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.layoutcreate', 0),
    ));

    $this->addElement('Radio', 'sitebusiness_category_edit', array(
        'label' => 'Edit Business Category',
        'description' => 'Do you want to allow business admins to edit category of their businesses?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showcategoryblock(this.value);',
        'value' => $coreSettings->getSetting('sitebusiness.category.edit', 0),
    ));

    //$description = Zend_Registry::get('Zend_Translate')->_('Do you want to show categories, subcategories and 3%s level categories with slug in the url.');
    //$description = sprintf($description, "<sup>rd</sup>");
    $this->addElement('Radio', 'sitebusiness_categorywithslug', array(
        'label' => 'Slug URL',
        'description' => 'Do you want to replace blank-space in your category name by "-" in URL?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.categorywithslug', 1),
    ));

    //$this->sitebusiness_categorywithslug->getDecorator('Description')->setOptions(array('placement'=> 'PREPEND', 'escape' => false));

    $this->addElement('Radio', 'sitebusiness_claimlink', array(
        'label' => 'Claim a Business Listing',
        'description' => 'Do you want users to be able to file claims for directory items / businesses ? (Claims filed by users can be managed from the Manage Claims section.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'onclick' => 'showclaim(this.value)',
        'value' => $coreSettings->getSetting('sitebusiness.claimlink', 1),
    ));

    if(!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemenu')){
      $this->addElement('Radio', 'sitebusiness_claim_show_menu', array(
          'label' => 'Claim a Business link',
          'description' => 'Select the position for the "Claim a Business" link.',
          'multiOptions' => array(
              2 => 'Show this link on Businesses Navigation Menu.',
              1 => 'Show this link on Footer Menu.',
              0 => 'Do not show this link.'
          ),
          'value' => $coreSettings->getSetting('sitebusiness.claim.show.menu', 2),
      ));
    }
    $this->addElement('Radio', 'sitebusiness_claim_email', array(
        'label' => 'Notification for Business Claim',
        'description' => 'Do you want to receive e-mail notification when a member claims a business?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.claim.email', 1),
    ));

    $this->addElement( 'Radio' , 'sitebusiness_automatically_like' , array (
      'label' => 'Automatic Like',
      'description' => "Do you want members to automatically Like a business they create?",
      'multiOptions' => array (
        1 => 'Yes' ,
        0 => 'No'
      ) ,
      'value' => $coreSettings->getSetting( 'sitebusiness.automatically.like' , 1),
    )) ;

		$this->addElement('Radio', 'sitebusiness_hide_left_container', array(
				'label' => 'Hide Left / Right Column on Business Profile',
				'description' => sprintf(Zend_Registry::get('Zend_Translate')->_('When you have "Advertisements / Community Ads" enabled to be shown on Business Profile from "%1$sAd Settings%2$s" section, then do you want the left / right column on Business Profile to be hidden when users click on the Business tabs other than Updates, Info and Overview?'), "<a href='" . $view->url(array('module' => 'sitebusiness', 'controller' => 'settings', 'action' =>'adsettings'), 'admin_default', true)."' target='_blank'>", '</a>'),
				'multiOptions' => array(
						1 => 'Yes',
						0 => 'No'
				),
				'value' => $coreSettings->getSetting( 'sitebusiness.hide.left.container', 0),
		));
		$this->sitebusiness_hide_left_container->addDecorator('Description', array('placement' => Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false)); 

		$this->addElement('Radio', 'sitebusiness_show_tabs_without_content', array(
				'label' => 'Show Tabs with no Respective Content',
				'description' => 'When there are content types in a Business (like Albums, Videos, etc.) with no respective content, then do you want their tabs to appear on Business profile to users who do not have permission to add that content?',
				'multiOptions' => array(
						1 => 'Yes',
						0 => 'No'
				),
				'value' => $coreSettings->getSetting( 'sitebusiness.show.tabs.without.content', 0),
		));

		$this->addElement('Radio', 'sitebusiness_slding_effect', array(
				'label' => 'Enable Sliding Effect on Tabs',
				'description' => 'Do you want to enable sliding effect when tabs on Business Profile are clicked?',
				'multiOptions' => array(
						1 => 'Yes',
						0 => 'No'
				),
				'value' => $coreSettings->getSetting( 'sitebusiness.slding.effect', 1),
		));

    $this->addElement('Radio', 'sitebusiness_mylike_show', array(
        'label' => 'Businesses I Like Link',
        'description' => 'Do you want to show the "Businesses I Like" link to users? This link appears on "My Businesses" and enables users to see the list of Businesses that they have Liked.',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.mylike.show', 1),
    ));

    $this->addElement('Text', 'sitebusiness_business', array(
        'label' => 'Directory Items / Businesses Per Page',
        'description' => 'How many directory items / businesses will be shown per page in "Browse Businesses" and "My Businesses" businesses?',
        'allowEmpty' => false,
        'maxlength' => '3',
        'required' => true,
        'filters' => array(
            new Engine_Filter_Censor(),
            'StripTags',
            new Engine_Filter_StringLength(array('max' => '3'))
        ),
        'value' => $coreSettings->getSetting('sitebusiness.business', 24),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));
    
    $this->addElement('Radio', 'sitebusiness_redirection', array(
        'label' => 'Redirection of Businesses link',
        'description' => 'Please select the redirection page for Businesses, when user click on "Businesses" link at Main Navigation Menu.',
        "multiOptions" => array(
            'home' => 'Businesses Home',
            'index' => 'Browse Businesses'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.redirection', 'home'),
    ));     

    $this->addElement('Text', 'sitebusiness_showmore', array(
        'label' => 'Tabs / Links',
        'allowEmpty' => false,
        'maxlength' => '3',
        'required' => true,
        'description' => 'How many tabs / links do you want to show on directory item / business profile by default? (Note that if there are more tabs / links than the limit entered by you then a "More" tab / link will appear, clicking on which will show the remaining hidden tabs / links. Tabs are available in the tabbed layout, and links in the non-tabbed layout. To choose the layout for Businesses on your site, visit the "Business Layout" section.)',
        'value' => $coreSettings->getSetting('sitebusiness.showmore', 8),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

    $this->addElement('Text', 'sitebusinesseshow_navigation_tabs', array(
        'label' => 'Tabs in Businesses navigation bar',
        'allowEmpty' => false,
        'maxlength' => '3',
        'required' => true,
        'description' => 'How many tabs do you want to show on Businesses main navigation bar by default? (Note: If number of tabs exceeds the limit entered by you then a "More" tab will appear, clicking on which will show the remaining hidden tabs. To choose the tab to be shown in this navigation menu, and their sequence, please visit: "Layout" > "Menu Editor")',
        'value' => $coreSettings->getSetting('sitebusinesseshow.navigation.tabs', 8),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

    $this->addElement('Radio', 'sitebusiness_postedby', array(
        'label' => 'Posted By',
        'description' => "Do you want to enable Posted by option for the Businesses on your site? (Selecting Yes here will display the member's name who has created the business.)",
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.postedby', 1),
    ));

    $advfeedmodule = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('advancedactivity');
    $adddescription = '';
    if (!$advfeedmodule)
		$adddescription = "and requires it to be installed and enabled on your site. Please install this plugin after downloading it from your Client Area on SocialEngineAddOns. You may purchase this plugin <a href='http://www.socialengineaddons.com/socialengine-advanced-activity-feeds-wall-plugin' target='_blank'>over here</a>";
    $this->addElement('Radio', 'sitebusiness_postfbbusiness', array(
        'label' => 'Allow Facebook Page Linking',
        'description' => "Do you want to allow users to link their Facebook Pages with their Businesses on your website? If you select 'Yes' over here, then users will see a new block in the 'Marketing' section of their Business Dashboard which will enable them to enter the URL of their Facebook Page. With this, the updates made by users on their Business on your site will also be published on their Facebook Page. Also, the Facebook Like Box for the Facebook Page will be displayed on Business Profile. The Facebook Like Box will:<br /><br /><ul style='margin-left: 20px;'><li>Show the recent posts from the Facebook Page.</li><li>Show how many people already like the Facebook Page.</li><li>Enable visitors to Like the Facebook Page from your site.</li></ul><br /><br />If you do not want to show the Facebook Like Box on Businesses with linked Facebook Pages, then simply remove the widget from the 'Layout Editor'. With linked Facebook Page, if Business Admins select 'Publish this on Facebook' option while posting 
their updates, then these updates will be published on their Facebook Profile as well as Facebook Page. (Note: Publishing updates on Facebook Pages via this linking is dependent on the <a href='http://www.socialengineaddons.com/socialengine-advanced-activity-feeds-wall-plugin' target='_blank'> Advanced Activity Feeds / Wall Plugin</a> ".$adddescription.".)",
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.postfbbusiness', 1),
    ));
		$this->sitebusiness_postfbbusiness->addDecorator('Description', array('placement' => 'PREPEND','class' => 'description', 'escape' => false));

		$publish_fb_places = array('0' => 1, '1' => 2);
    $publish_fb_places = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.publish.facebook', serialize($publish_fb_places));
    if(!empty($publish_fb_places) && !is_array($publish_fb_places)) {
      $publish_fb_places = unserialize($publish_fb_places);
    }
    $this->addElement('MultiCheckbox', 'sitebusiness_publish_facebook', array(
        'label' => 'Publishing Updates on Facebook',
        'description' => "Choose the places on Facebook where users will be able to publish their updates that they post on Businesses of your site.",
        'multiOptions' => array(            
            '1' => 'Publish this post on Facebook Page linked with this Business. [Note: This setting will only work if you choose \'Yes\' option for the setting "Allow Facebook Page Linking".]',
            '2' => 'Publish this post on my Facebook Timeline',
        ),
        'value' => $publish_fb_places
    )); 
    
    $this->addElement('Radio', 'sitebusiness_tinymceditor', array(
        'label' => 'Tinymce Editor',
        'description' => 'Allow TinyMCE editor for discussion message of Businesses.',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $coreSettings->getSetting('sitebusiness.tinymceditor', 1),
    ));

    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $field = 'sitebusiness_code_share';
    $this->addElement('Dummy', "$field", array(
        'label' => 'Social Share Widget Code',
        'description' => "<a class='smoothbox' href='". $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'social-share', 'field' => "$field"), 'admin_default', true) ."'>Click here</a> to add your social share code.",
        'ignore' => true,
    ));
    $this->$field->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

    $this->addElement('Textarea', 'sitebusiness_defaultbusinesscreate_email', array(
      'label' => 'Alerted by Email',
      'description' => 'Please enter comma-separated list, or one-email-per-line. Email is sent to the below email ids when members create new Businesses.',
      'value' => $coreSettings->getSetting('sitebusiness.defaultbusinesscreate.email', Engine_API::_()->seaocore()->getSuperAdminEmailAddress()),
    ));

    $this->addElement('Text', 'sitebusiness_title_truncation', array(
        'label' => 'Title Truncation Limit',
        'allowEmpty' => false,
        'maxlength' => '3',
        'required' => true,
        'description' => 'What maximum limit should be applied to the number of characters in the title of items in the widgets? (Enter a number between 1 and 999. Titles having more characters than this limit will be truncated. Complete titles will be shown on mouseover.)',
        'value' => $coreSettings->getSetting('sitebusiness.title.truncation', 18),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

		if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepage') && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroup')) {
    $description = 'Do you want to have a common CSS (/application/modules/Sitepage/externals/styles/common_style_page_business_group.css) on your website for Directory / Pages Plugin and Directory / Businesses Plugin and  Groups / Communities Plugin? (Note: As these 3 are similar plugins, it is recommended to have a common CSS loaded for 3 plugins for good webpage performance. You might select the No option here if you have different custom styling for these 3 plugins on your website.)';
		}
		elseif(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepage')) {
    $description = 'Do you want to have a common CSS (/application/modules/Sitepage/externals/styles/common_style_page_business.css) on your website for Directory / Pages Plugin and Directory / Businesses Plugin? (Note: As these are both similar plugins, it is recommended to have a common CSS loaded for both plugins for good webpage performance. You might select the No option here if you have different custom styling for these 2 plugins on your website.)';
		} 
		elseif(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroup')) {
    $description = 'Do you want to have a common CSS (/application/modules/Sitebusiness/externals/styles/common_style_business_group.css) on your website for Groups / Communities Plugin and Directory / Businesses Plugin? (Note: As these are both similar plugins, it is recommended to have a common CSS loaded for both plugins for good webpage performance. You might select the No option here if you have different custom styling for these 2 plugins on your website.)';

		}
		if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepage') || Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroup')) {
		
			// VALUE FOR ENABLE /DISABLE SHARE
			$this->addElement('Radio', 'seaocore_common_css', array(
				'label' => 'Common CSS',
				'description' => $description,
				'multiOptions' => array(
					1 => 'Yes',
					0 => 'No'
				),
				'value' => $coreSettings->getSetting('seaocore.common.css', 0),
			));
		}
		
    $this->addElement('Button', 'submit', array(
        'label' => 'Save Changes',
        'type' => 'submit',
        'ignore' => true
    ));
  }

}
