<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Album.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Form_Photo_Album extends Engine_Form {

    public function init() {

        $business_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('business_id');
        $albumvalues['album_id'] = Engine_Api::_()->getItemTable('sitebusiness_album')->getDefaultAlbum($business_id)->album_id;
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SITEBUSINESS ITEM
        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            $can_edit = 0;
        } else {
            $can_edit = 1;
        }
        //END MANAGE-ADMIN CHECK

        if ($sitebusiness->owner_id == $viewer_id || $can_edit == 1) {
            $defaultalbum_id = 0;
        } else {
            $defaultalbum_id = $albumvalues['album_id'];
        }

        $user_level = Engine_Api::_()->user()->getViewer()->level_id;
        $user = Engine_Api::_()->user()->getViewer();

        $this
                ->setTitle('Add New Photos')
                ->setDescription('Browse and choose photos on your system to add to this album.')
                ->setAttrib('id', 'form-upload')
                ->setAttrib('name', 'albums_create')
                ->setAttrib('class', 'global_form sitebusiness_form_upload')
                ->setAttrib('enctype', 'multipart/form-data')
                ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
        ;

        $this->addElement('Select', 'album', array(
            'label' => 'Choose Album',
            'multiOptions' => array('0' => 'Create A New Album'),
            'onchange' => "updateTextFields()",
        ));

        //SET ALBUMS PARAMS
        $paramsAlbum = array();
        $paramsAlbum['business_id'] = $business_id;
        $paramsAlbum['getSpecialField'] = 1;

        $all_albums = Engine_Api::_()->getDbtable('albums', 'sitebusiness')->getAlbums($paramsAlbum);
        $album_options = Array();
        foreach ($all_albums as $all_album) {
            $album_options[$all_album->album_id] = htmlspecialchars_decode($all_album->getTitle());
        }

        $this->album->addMultiOptions($album_options);

        $this->addElement('Text', 'title', array(
            'label' => 'Album Title',
            'maxlength' => '256',
            'filters' => array(
                'StripTags',
                new Engine_Filter_Censor(),
                new Engine_Filter_StringLength(array('max' => '256')),
            )
        ));

        $this->addElement('Hidden', 'business_id', array(
            'value' => $business_id,
            'order' => 333
        ));

        $this->addElement('Hidden', 'default_album_id', array(
            'value' => $defaultalbum_id,
            'order' => 334
        ));

        // Privacy
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.manageadmin', 1))
            $ownerTitle = "Business Admins";
        else
            $ownerTitle = "Just Me";

        $user = Engine_Api::_()->user()->getViewer();

//     $availableLabels = array(
//         'registered' => 'All Registered Members',
//         'owner_network' => 'Friends and Networks',
//         'owner_member_member' => 'Friends of Friends',
//         'owner_member' => 'Friends Only',
//         'owner' => $ownerTitle
//     );

        $allowMemberInLevel = Engine_Api::_()->authorization()->getPermission($user_level, 'sitebusiness_business', 'smecreate');
        $allowMemberInthisPackage = false;
        $allowMemberInthisPackage = Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember");
        $sitebusinessMemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');

        $availableLabels = array(
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'like_member' => 'Who Liked This Business',
        );
        if (!empty($sitebusinessMemberEnabled) && $allowMemberInthisPackage) {
            $availableLabels['member'] = 'Business Members Only';
        } elseif (!empty($sitebusinessMemberEnabled) && $allowMemberInLevel) {
            $availableLabels['member'] = 'Business Members Only';
        }
        $availableLabels['owner'] = $ownerTitle;



        $tagOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitebusiness_album', $user, 'auth_tag');

        $tagOptions = array_intersect_key($availableLabels, array_flip($tagOptions));
        if (!empty($tagOptions) && count($tagOptions) >= 1) {
            if (count($tagOptions) == 1) {
                $this->addElement('hidden', 'auth_tag', array('order' => 335,'value' => key($tagOptions)));
            } else {
                $this->addElement('Select', 'auth_tag', array(
                    'label' => 'Tag Post Privacy',
                    'description' => 'Who may tag photos in this album?',
                    'multiOptions' => $tagOptions,
                    'value' => key($tagOptions),
                ));
                $this->auth_tag->getDecorator('Description')->setOption('placement', 'append');
            }
        }

        // Init search
        $this->addElement('Checkbox', 'search', array(
            'label' => Zend_Registry::get('Zend_Translate')->_("Show this album in search results"),
            'value' => 1,
            'disableTranslator' => true
        ));

        $uploadUrl = Zend_Controller_Front::getInstance()->getRouter()->assemble(array()) . '?ul=1';
        $deleteUrl = $this->getView()->url(array('action' => 'remove'), 'sitebusiness_imagephoto_specific');
        $request = Zend_Controller_Front::getInstance()->getRequest();
        $vars = array(
            'album_id' => $request->getParam('album_id'),
            'business_id' => $request->getParam('business_id'),
        );
        $this->addElement('SeaoFancyUpload', 'file', array(
            'url' =>  $uploadUrl,
            'deleteUrl' =>  $deleteUrl,
            'accept' => 'image/*',
            'data' => array(
                'vars' => $vars
            )
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Photos',
            'type' => 'submit',
        ));
    }

    public function clearAlbum() {

        $this->getElement('album')->setValue(0);
    }

    public function saveValues() {

        $set_cover = false;
        $values = $this->getValues();
        $viewer = Engine_Api::_()->user()->getViewer();

        $params = Array();
        $getPackageAlbum = Engine_Api::_()->sitebusiness()->getPackageAuthInfo('sitebusinessalbum');
        if ((empty($values['owner_id']))) {
            $params['owner_id'] = Engine_Api::_()->user()->getViewer()->user_id;
        } else {
            $params['owner_id'] = Engine_Api::_()->user()->getViewer()->user_id;
            throw new Zend_Exception("Non-user album owners not yet implemented");
        }
        if ((empty($values['album'])) && (empty($values['default_album_id'])) && !empty($getPackageAlbum)) {
            $params['title'] = $values['title'];
            if (empty($params['title'])) {
                $params['title'] = "Untitled Album";
            }
            $params['search'] = $values['search'];

            $default_album_id = Engine_Api::_()->getItemTable('sitebusiness_album')->getDefaultAlbum($values['business_id'])->album_id;

            if (empty($default_album_id)) {
                $params['default_value'] = 1;
            } else {
                $params['default_value'] = 0;
            }

            $params['business_id'] = $values['business_id'];
            $album = Engine_Api::_()->getDbtable('albums', 'sitebusiness')->createRow();
            $album->setFromArray($params);
            $album->view_count = 1;
            $album->save();
            $set_cover = true;

            $auth = Engine_Api::_()->authorization()->context;
            //$roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered');

            $sitebusinessmemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');
            if (!empty($sitebusinessmemberEnabled)) {
                $roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
            } else {
                $roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
            }

            if (empty($values['auth_tag'])) {
                $values['auth_tag'] = key($form->auth_tag->options);
                if (empty($values['auth_tag'])) {
                    $values['auth_tag'] = 'registered';
                }
            }

            $tagMax = array_search($values['auth_tag'], $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($album, $role, 'tag', ($i <= $tagMax));
            }

            //COMMENT PRIVACY
            $auth = Engine_Api::_()->authorization()->context;
            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
            $auth_comment = "everyone";
            $commentMax = array_search($auth_comment, $roles);
            foreach ($roles as $i => $role) {
                $auth->setAllowed($album, $role, 'comment', ($i <= $commentMax));
            }
        } else {
            if (!empty($values['album'])) {
                $album = Engine_Api::_()->getItem('sitebusiness_album', $values['album']);
            } else {
                $album = Engine_Api::_()->getItem('sitebusiness_album', $values['default_album_id']);
            }
        }
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);
        $content_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusiness.photos-sitebusiness', $album->business_id, $layout);
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        if (count($values['file'] > 0)) {
            $api = Engine_Api::_()->getDbtable('actions', 'activity');
            $sendFB_Activity = 0;
            $activityFeedType = null;
            if (Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness) && Engine_Api::_()->sitebusiness()->isFeedTypeBusinessEnable()) {
                $activityFeedType = 'sitebusinessalbum_admin_photo_new';
                $sendFB_Activity = 1;
            } elseif ($sitebusiness->all_post || Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness)) {
                $activityFeedType = 'sitebusinessalbum_photo_new';
                $sendFB_Activity = 1;
            }

            if ($activityFeedType) {
                $action = $api->addActivity(Engine_Api::_()->user()->getViewer(), $sitebusiness, $activityFeedType, null, array('child_id' => $album->getIdentity(), 'count' => count($values['file'])));
                Engine_Api::_()->getApi('subCore', 'sitebusiness')->deleteFeedStream($action);
            }

            //BUSINESS ALBUMS CREATE NOTIFICATION AND EMAIL WORK
            if (!empty($action)) {
                $sitebusinessVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitebusiness')->version;
                if (!empty(Engine_Api::_()->seaocore()->checkVersion($sitebusinessVersion, '4.2.9p3'))) {
                    Engine_Api::_()->sitebusiness()->sendNotificationEmail($album, $action, 'sitebusinessalbum_create', 'SITEBUSINESSALBUM_CREATENOTIFICATION_EMAIL', 'Businessevent Invite', count($values['file']));

                    $isBusinessAdmins = Engine_Api::_()->getDbtable('manageadmins', 'sitebusiness')->isBusinessAdmins($viewer->getIdentity(), $album->business_id);
                    if (!empty($isBusinessAdmins)) {
                        //NOTIFICATION FOR ALL FOLLWERS.
                        Engine_Api::_()->sitebusiness()->sendNotificationToFollowers($album, $action, 'sitebusinessalbum_create', count($values['file']));
                    }
                }
            }

            if ($sendFB_Activity == 1) {
                //SENDING ACTIVITY FEED TO FACEBOOK.
                $enable_Facebooksefeed = $enable_fboldversion = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('facebooksefeed');
                if (!empty($enable_Facebooksefeed)) {
                    $facebooksefeedmodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('facebooksefeed');
                    $facebooksefeedmoduleversion = $facebooksefeedmodule->version;
                    if ((Engine_Api::_()->seaocore()->checkVersion($facebooksefeedmoduleversion, '4.1.6p2')) == 1) {
                        $album_array = array();
                        $album_array['type'] = 'sitebusinessalbum_photo_new';
                        $album_array['object'] = $album;
                        $album_array['file_ids'] = $this->getValues();
                        Engine_Api::_()->facebooksefeed()->sendFacebookFeed($album_array);
                    }
                }
            }
        }

        $count = 0;
        foreach ($values['file'] as $photo_id) {
            $photo = Engine_Api::_()->getItem("sitebusiness_photo", $photo_id);
            if (!($photo instanceof Core_Model_Item_Abstract) || !$photo->getIdentity())
                continue;
            if ($set_cover) {
                $album->photo_id = $photo_id;
                $album->save();
                $set_cover = false;
            }
            $photo->album_id = $album->album_id;
            $photo->collection_id = $album->album_id;
            $photo->save();

            if ($action instanceof Activity_Model_Action && $count < 8) {
                $api->attachActivity($action, $photo, Activity_Model_Action::ATTACH_MULTI);
            }
            $count++;
        }
        return $album;
    }

}
