<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Contentbusinesses.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Model_DbTable_Contentbusinesses extends Engine_Db_Table implements Engine_Content_Storage_Interface {

  protected $_rowClass = "Sitebusiness_Model_Contentbusiness";

  public function loadMetaData(Engine_Content $contentAdapter, $name) {
  	
    $select = $this->select()->where('name = ?', $name)->orWhere('contentbusiness_id = ?', $name);
    $business = $this->fetchRow($select);

    if (!is_object($business)) {
      //throw?
      return null;
    }

    return $business->toArray();
  }

  public function loadContent(Engine_Content $contentAdapter, $name) {
  	
    $sitebusiness_id = Engine_Api::_()->core()->getSubject()->getIdentity();

    if (is_array($name)) {
      $name = join('_', $name);
    }
    if (!is_string($name) && !is_numeric($name)) {
      throw new Exception('not string');
    }
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    $select = $this->select()->where('business_id = ?', $sitebusiness_id)->where('name = ?', $name)->orWhere('contentbusiness_id = ?', $name);
    $business = $this->fetchRow($select);

    if (is_object($business)) {
			$contentTable = Engine_Api::_()->getDbtable('content', 'sitebusiness');
			$select = $contentTable->select()
							->where('contentbusiness_id = ?', $business->contentbusiness_id)
							->order('order ASC');
			$content = $contentTable->fetchAll($select);

			$structure = $this->prepareContentArea($content);
			$element = new Engine_Content_Element_Container(array(
									'class' => 'layout_business_' . $business->name,
									'elements' => $structure
							));
    } else {
      $business_id = Engine_Api::_()->sitebusiness()->getWidgetizedBusiness()->page_id;
			$contentTable = Engine_Api::_()->getDbtable('admincontent', 'sitebusiness');
			$select = $contentTable->select()
							->where('business_id = ?', $business_id)
							->order('order ASC');
			$content = $contentTable->fetchAll($select);
			$structure = Engine_Api::_()->getDbtable('admincontent', 'sitebusiness')->prepareContentArea($content);
			$element = new Engine_Content_Element_Container(array(
									'class' => 'layout_business_sitebusiness_index_view',
									'elements' => $structure
							));
    }

    return $element;
  }

  public function prepareContentArea($content, $current = null) {

    $parent_content_id = null;
    if (null !== $current) {
      $parent_content_id = $current->content_id;
    }

    $children = $content->getRowsMatching('parent_content_id', $parent_content_id);
    if (empty($children) && null === $parent_content_id) {
      $children = $content->getRowsMatching('parent_content_id', 0);
    }

    $struct = array();
    foreach ($children as $child) {
      $elStruct = $this->createElementParams($child);
      $elStruct['elements'] = $this->prepareContentArea($content, $child);
      $struct[] = $elStruct;
    }
    $Modules = array("offer" => "sitebusinessoffer", "form" => "sitebusinessform", "invite" => "sitebusinessinvite", "sdcreate" => "sitebusinessdocument", "sncreate" => "sitebusinessnote", "splcreate" => "sitebusinesspoll", "secreate" => "sitebusinessevent", "svcreate" => "sitebusinessvideo", "spcreate" => "sitebusinessalbum", "sdicreate" => "sitebusinessdiscussion", "smcreate" => "sitebusinessmusic");
    $subject = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    foreach ($struct as $keys => $valuess) {
      $unsetFlage = false;
      $explode_modulename_array = explode('.', $valuess['name']);
      $explode_modulename = $explode_modulename_array[0];
      $search_Key = "";
      $search_Key = array_search($explode_modulename, $Modules);
      if ($explode_modulename == 'sitebusiness') {
        if ($valuess['name'] == 'sitebusiness.photos-sitebusiness' || $valuess['name'] == 'sitebusiness.photorecent-sitebusiness' || $valuess['name'] == 'sitebusiness.albums-sitebusiness') {
          $explode_modulename = 'sitebusinessalbum';
          $search_Key = 'spcreate';
        }
        if ($valuess['name'] == 'sitebusiness.discussion-sitebusiness') {
          $explode_modulename = 'sitebusinessdiscussion';
          $search_Key = 'sdicreate';
        }
        if ($valuess['name'] == 'sitebusiness.overview-sitebusiness') {
          $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'overview');
          if (empty($isManageAdmin)) {
            $unsetFlage = true;
          }
        }
        if ($valuess['name'] == 'sitebusiness.location-sitebusiness') {
          $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'map');
          if (empty($isManageAdmin)) {
            $unsetFlage = true;
          }
        }
      }
      if (!empty($search_Key)) {
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
          if (!Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", $explode_modulename)) {
            $unsetFlage = true;
          }
        } else {
          $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, $search_Key);
          if (empty($isBusinessOwnerAllow)) {
            $unsetFlage = true;
          }
        }
      }
      if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('communityad')) {
        if ($valuess['name'] == 'sitebusiness.thumbphoto-sitebusiness') {
          unset($struct[$keys]);
        }
      }

      if ($unsetFlage)
        unset($struct[$keys]);
    }
    return $struct;
  }

  public function createElementParams($row) {
  	
    $data = array(
        'identity' => $row->content_id,
        'type' => $row->type,
        'name' => $row->name,
        'order' => $row->order,
				'widget_admin' => $row->widget_admin,
    );
    $params = (array) $row->params;
    if (isset($params['title']))
      $data['title'] = $params['title'];
    $data['params'] = $params;

    return $data;
  }

  public function deleteBusiness(Sitebusiness_Model_Business $business) {

    Engine_Api::_()->getDbtable('content', 'sitebusiness')->delete(array('contentbusiness_id = ?' => $business->contentbusiness_id));
    $business->delete();
    return $this;
  }
  
  /**
   * Gets contentbusiness_id,description,keywords
   *
   * @param int $business_id
   * @return contentbusiness_id,description,keywords
   */     
  public function getContentBusinessId($business_id) {
  	
  	$selectBusinessAdmin = $this->select()
            ->from($this->info('name'), array('contentbusiness_id', 'description', 'keywords'))
            ->where('name = ?', 'sitebusiness_index_view')
            ->where('business_id =?', $business_id)
            ->limit(1);
    return $this->fetchRow($selectBusinessAdmin);
  }

}

?>