<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Manageadmins.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Model_DbTable_Manageadmins extends Engine_Db_Table {

  protected $_rowClass = "Sitebusiness_Model_Manageadmin";

	/**
   * Return manage admins
   *
   * @param int $business_id
   */
  public function getManageAdminUser($business_id) {

    $usertable = Engine_Api::_()->getDbtable('users', 'user');
    $userName = $usertable->info('name');
    $manageName = $this->info('name');
    $manageHistoriesQuery = $this->select()
            ->setIntegrityCheck(false)
            ->from($manageName)
            ->joinleft($userName, $manageName . '.business_id = ' . $userName . '.user_id', array('displayname', 'photo_id'))
            ->where('business_id = ?', $business_id);
    return Zend_Paginator::factory($manageHistoriesQuery);
  }

	/**
   * Return manage admin ids
   *
   * @param int $business_id
   */
	public function getManageAdmin($business_id, $user_id = null) {

    $select = $this->select()
                    ->from($this->info('name'))
                    ->where('business_id = ?', $business_id);
    if (!empty($user_id)) {
			$select->where('user_id <> ?', $user_id);
    }
    return $this->fetchAll($select);
	}

	/**
   * Return manage admin businesses_id
   *
   * @param int $viewer_id
   */
	public function getManageAdminBusinesses($viewer_id) {

		$select = $this->select()
						->from($this->info('name'), 'business_id')
						->where('user_id = ?', $viewer_id);
		return $this->fetchAll($select);
	}

	/**
   * Return linked businesses result
   *
   * @param int $business_id
   */
  public function linkedBusinesses($business_id) {

    $manageAdminName = $this->info('name');
    $select = $this->select()->from($manageAdminName, 'user_id')->where('business_id = ?', $business_id);
    return $user_idarray = $this->fetchAll($select)->toArray();
	}

	/**
   * Return featured manage admins
   *
   * @param int $business_id
   */
	public function featuredAdmins($business_id) {

		$select = $this->select()
						->where('featured = ?', 1)
						->where('business_id = ?', $business_id);

		if (!Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
      return Zend_Paginator::factory($select);
    }

		return $this->fetchAll($select);
	}

	/**
   * Return business admin.
   *
   * @param int $user_id
   * @param int $business_id
   */
	public function isBusinessAdmins($user_id, $business_id) {

    $select = $this->select()
						->from($this->info('name'))
						->where('user_id = ?', $user_id)
						->where('business_id = ?', $business_id);
    return $this->fetchRow($select);
	}
	
	/**
   * Return manage admin ids array
   *
   * @param int $business_id
   */
	public function getManageAdminIds($business_id, $param = null) {

		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    $select = $this->select()
							->from($this->info('name'), array('user_id'));
		if(!empty($param) && $param == 'businessintergration') { 
			$select->where('user_id <> ?', $viewer_id);
		}
		$user_ids = $select->where('business_id = ?', $business_id)
											->query()
											->fetchAll(Zend_Db::FETCH_COLUMN);
    return $user_ids;
	}
	  
  public function getCountUserAsAdmin($params = array()) {
 
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $businessTable = Engine_Api::_()->getDbTable('business', 'sitebusiness');
    $businessTableName = $businessTable->info('name');
    
    $manageAdminTableName = $this->info('name');

    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($manageAdminTableName, array("COUNT(engine4_sitebusiness_manageadmins.business_id) AS adminCount"))
                    ->joinLeft($businessTableName, "$businessTableName.business_id = $manageAdminTableName.business_id", array())
       ->where("$manageAdminTableName.user_id = ?", $viewer_id)
       ->where("$businessTableName.owner_id != ?", $viewer_id)     
       ->group("$businessTableName.business_id");

    return $select->query()->fetchColumn();
  }
  

}
?>