<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: DashboardController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_DashboardController extends Core_Controller_Action_Standard {

    //SET THE VALUE FOR ALL ACTION DEFAULT
    public function init() {

        if (!$this->_helper->requireAuth()->setAuthParams('sitebusiness_business', null, 'view')->isValid())
            return;

        $ajaxContext = $this->_helper->getHelper('AjaxContext');
        $ajaxContext
                ->addActionContext('rate', 'json')
                ->addActionContext('validation', 'html')
                ->initContext();

        $business_url = $this->_getParam('business_url', $this->_getParam('business_url', null));
        $business_id = $this->_getParam('business_id', $this->_getParam('business_id', null));

        if ($business_url) {
            $business_id = Engine_Api::_()->sitebusiness()->getBusinessId($business_url);
        }

        if ($business_id) {
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
            if ($sitebusiness) {
                Engine_Api::_()->core()->setSubject($sitebusiness);
            }
        }

        //FOR UPDATE EXPIRATION
        if ((Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.task.updateexpiredbusinesses') + 900) <= time()) {
            Engine_Api::_()->sitebusiness()->updateExpiredBusinesses();
        }
    }

    //ACTION FOR SHOWING THE APPS AT DASHBOARD
    public function appAction() {

        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        //VERSION CHECK APPLIED FOR - PACKAGE WORK
        $this->view->siteeventVersion = false;
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent')) {
            if (Engine_Api::_()->sitebusiness()->checkVersion(Engine_Api::_()->getDbtable('modules', 'core')->getModule('siteevent')->version, '4.8.8')) {
                $this->view->siteeventVersion = true;
            }
        }

        $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);

        //GET THE LOGGEDIN USER INFORMATION
        $this->view->viewer_id = $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET THE SITEBUSINESS ID FROM THE URL
        $this->view->business_id = $business_id = $this->_getParam('business_id');

        //SET THE SUBJECT OF SITEBUSINESS
        $this->view->subject = $subject = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        //VERSION CHECK APPLIED FOR - PACKAGE WORK
        $this->view->siteeventVersion = false;
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent')) {
            $siteeventModule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('siteevent');
            $siteeventVersion = $siteeventModule->version;
            if (!empty(Engine_Api::_()->seaocore()->checkVersion($siteeventVersion, '4.8.8p1'))) {
                $this->view->siteeventVersion = true;
            }
        }

        $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessalbum')) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessalbum")) {
                    $this->view->allowed_upload_photo = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'spcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->allowed_upload_photo = 1;
                }
            }
            //START THE BUSINESS ALBUM WORK
            $this->view->default_album_id = Engine_Api::_()->getItemTable('sitebusiness_album')->getDefaultAlbum($business_id)->album_id;
            //END THE BUSINESS ALBUM WORK

            $this->view->albumtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusiness.photos-sitebusiness', $business_id, $layout);
        }

        //PASS THE BUSINESS ID IN THE CORRESPONDING TPL FILE
        $this->view->sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        $this->view->sitebusinesses_view_menu = 16;

        //START THE BUSINESS POLL WORK
        $sitebusinessPollEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesspoll');
        if ($sitebusinessPollEnabled) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinesspoll")) {
                    $this->view->can_create_poll = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'splcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_poll = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->polltab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinesspoll.profile-sitebusinesspolls', $business_id, $layout);
        }
        //END THE BUSINESS POLL WORK
        //START THE BUSINESS DOCUMENT WORK
        $sitebusinessDocumentEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdocument');
        if ($sitebusinessDocumentEnabled || (Engine_Api::_()->hasModuleBootstrap('document') && Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessdocument")) {
                    $this->view->can_create_doc = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sdcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_doc = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            if ($sitebusinessDocumentEnabled) {
                $this->view->documenttab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessdocument.profile-sitebusinessdocuments', $business_id, $layout);
            } else {
                $this->view->documenttab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('document.contenttype-documents', $business_id, $layout);
            }
        }
        //END THE BUSINESS DOCUMENT WORK
        //START THE BUSINESS INVITE WORK
        $this->view->can_invite = 0;
        $sitebusinessInviteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessinvite');
        if ($sitebusinessInviteEnabled) {

            //START MANAGE-ADMIN CHECK
            $this->view->can_invite = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'invite');
            //END MANAGE-ADMIN CHECK
        }
        //END THE BUSINESS INVITE WORK
        //START THE BUSINESS VIDEO WORK
        $sitebusinessVideoEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessvideo');
        if ($sitebusinessVideoEnabled || (Engine_Api::_()->hasModuleBootstrap('sitevideo') && Engine_Api::_()->getDbtable('modules', 'sitevideo')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessvideo")) {
                    $this->view->can_create_video = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'svcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_video = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            if ($sitebusinessVideoEnabled) {
                $this->view->videotab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessvideo.profile-sitebusinessvideos', $business_id, $layout);
            } else {
                $this->view->videotab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitevideo.contenttype-videos', $business_id, $layout);
            }
        }
        //END THE BUSINESS VIDEO WORK
        //START THE BUSINESS EVENT WORK
        $sitebusinesseventEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessevent');
        if ($sitebusinesseventEnabled || (Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessevent")) {
                    $this->view->can_create_event = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'secreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_event = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            if ($sitebusinesseventEnabled) {
                $this->view->eventtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessevent.profile-sitebusinessevents', $business_id, $layout);
            } else {
                $this->view->eventtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('siteevent.contenttype-events', $business_id, $layout);
            }
        }
        //END THE BUSINESS EVENT WORK
        //START THE BUSINESS NOTE WORK
        $sitebusinessNoteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessnote');
        if ($sitebusinessNoteEnabled) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessnote")) {
                    $this->view->can_create_notes = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sncreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_notes = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->notetab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessnote.profile-sitebusinessnotes', $business_id, $layout);
        }
        //END THE BUSINESS NOTE WORK
        //START THE BUSINESS REVEIW WORK
        $sitebusinessReviewEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessreview');
        if ($sitebusinessReviewEnabled) {
            $hasPosted = Engine_Api::_()->getDbTable('reviews', 'sitebusinessreview')->canPostReview($subject->business_id, $viewer_id);
            if (empty($hasPosted) && !empty($viewer_id)) {
                $this->view->can_create_review = 1;
            } else {
                $this->view->can_create_review = 0;
            }

            $this->view->reviewtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessreview.profile-sitebusinessreviews', $business_id, $layout);
        }
        //END THE BUSINESS REVEIW WORK
        //START THE BUSINESS DISCUSSION WORK
        $sitebusinessDiscussionEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdiscussion');
        if ($sitebusinessDiscussionEnabled) {

            //START MANAGE-ADMIN CHECK
            $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'sdicreate');
            if (!empty($isManageAdmin)) {
                $this->view->can_create_discussion = 1;
            }
            //END MANAGE-ADMIN CHECK
            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (!Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessdiscussion")) {
                    $this->view->can_create_discussion = 0;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->discussiontab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusiness.discussion-sitebusiness', $business_id, $layout);
        }
        //END THE BUSINESS DISCUSSION WORK
        //START THE BUSINESS FORM WORK
        $sitebusinessFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessform');
        if ($sitebusinessFormEnabled) {

            //START MANAGE-ADMIN CHECK
            $this->view->can_form = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'form');
            //END MANAGE-ADMIN CHECK

            $business_id = $this->_getParam('business_id');
            $quetion = Engine_Api::_()->getDbtable('businessquetions', 'sitebusinessform');
            $select_quetion = $quetion->select()->where('business_id = ?', $business_id);
            $result_quetion = $quetion->fetchRow($select_quetion);
            $this->view->option_id = $result_quetion->option_id;

            $this->view->formtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessform.sitebusiness-viewform', $business_id, $layout);
        }
        //END THE BUSINESS FORM WORK
        //START THE BUSINESS OFFER WORK
        $this->view->moduleEnable = $sitebusinessOfferEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessoffer');
        if ($sitebusinessOfferEnabled) {

            //START MANAGE-ADMIN CHECK
            $this->view->can_offer = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'offer');
            //END MANAGE-ADMIN CHECK

            $this->view->offertab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessoffer.profile-sitebusinessoffers', $business_id, $layout);
        }
        //END THE BUSINESS OFFER WORK
        //START THE BUSINESS MUSIC WORK
        $sitebusinessMusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmusic');
        if ($sitebusinessMusicEnabled) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessmusic")) {
                    $this->view->can_create_musics = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'smcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_musics = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->musictab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessmusic.profile-sitebusinessmusic', $business_id, $layout);
        }
        //END THE BUSINESS MUSIC WORK

        //START THE BUSINESS CROWDFUNDING WORK
        $sitecrowdfundingEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitecrowdfunding');
        if ($sitecrowdfundingEnabled && (Engine_Api::_()->hasModuleBootstrap('sitecrowdfundingintegration') && Engine_Api::_()->getDbtable('modules', 'sitecrowdfunding')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitecrowdfunding")) {
                    $this->view->can_create_project = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sprcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_project = 1;
                }
            }
            //PACKAGE BASE PRIYACY END
            $this->view->projecttab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitecrowdfunding.contenttype-projects', $business_id, $layout);

        }
        //END THE BUSINESS CROWDFUNDING WORK

        $this->view->is_ajax = $this->_getParam('is_ajax', '');
    }

    //ACTION FOR CONTACT INFORMATION
    public function announcementsAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        //GET BUSINESS ID
        $this->view->business_id = $business_id = $this->_getParam('business_id');

        //GET SITEBUSINESS ITEM
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //END MANAGE-ADMIN CHECK
        //GET REQUEST IS AJAX OR NOT
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //SHOW SELECTED TAB
        $this->view->sitebusinesses_view_menu = 30;

        $this->view->announcements = Engine_Api::_()->getDbtable('announcements', 'sitebusiness')->announcements(array('business_id' => $business_id, 'hideExpired' => 0), array('announcement_id', 'title', 'body', 'startdate', 'expirydate', 'status'));
    }

    //ACTION FOR CONTACT INFORMATION
    public function notificationSettingsAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        //GET THE LOGGEDIN USER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET BUSINESS ID
        $this->view->business_id = $business_id = $this->_getParam('business_id');

        //GET SITEBUSINESS ITEM
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }


        //END MANAGE-ADMIN CHECK
        //GET REQUEST IS AJAX OR NOT
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //SHOW SELECTED TAB
        $this->view->sitebusinesses_view_menu = 31;

        //SET FORM
        $this->view->form = $form = new Sitebusiness_Form_NotificationSettings();

        $ManageAdminsTable = Engine_Api::_()->getDbtable('manageadmins', 'sitebusiness');
        $ManageAdminsTableName = $ManageAdminsTable->info('name');

        $select = $ManageAdminsTable->select()
                ->from($ManageAdminsTableName)
                ->where($ManageAdminsTableName . '.business_id = ?', $business_id)
                ->where($ManageAdminsTableName . '.user_id = ?', $viewer_id);
        $results = $ManageAdminsTable->fetchRow($select);


        //POPULATE FORM
        $this->view->email = $value['email'] = $results["email"];
        $value['action_email'] = json_decode($results['action_email']);

        $this->view->notification = $value['notification'] = $results["notification"];
        $value['action_notification'] = unserialize($results['action_notification']);

        $form->populate($value);
        //CHECK FORM VALIDATION
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

            //GET FORM VALUES
            $values = $form->getValues();
            if (isset($values['email'])) {
                $ManageAdminsTable->update(array('email' => $values['email'], 'action_email' => json_encode($values['action_email'])), array('business_id =?' => $business_id, 'user_id =?' => $viewer_id));

                if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember')) {

                    if (in_array('posted', $values['action_email']))
                        $email['emailposted'] = 1;
                    else
                        $email['emailposted'] = 0;

                    if (in_array('created', $values['action_email']))
                        $email['emailcreated'] = 1;
                    else
                        $email['emailcreated'] = 0;

                    Engine_Api::_()->getDbtable('membership', 'sitebusiness')->update(array('email' => $values['email'], 'action_email' => json_encode($email)), array('business_id =?' => $business_id, 'resource_id =?' => $business_id, 'user_id =?' => $viewer_id));
                }
            }

            if (isset($values['notification'])) {
                $ManageAdminsTable->update(array('notification' => $values['notification'], 'action_notification' => serialize($values['action_notification'])), array('business_id =?' => $business_id, 'user_id =?' => $viewer_id));

                if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember')) {

                    if (in_array('posted', $values['action_notification']))
                        $notification['notificationposted'] = 1;
                    else
                        $notification['notificationposted'] = 0;

                    if (in_array('created', $values['action_notification']))
                        $notification['notificationcreated'] = 1;
                    else
                        $notification['notificationcreated'] = 0;

                    if (in_array('follow', $values['action_notification']))
                        $notification['notificationfollow'] = 1;
                    else
                        $notification['notificationfollow'] = 0;

                    if (in_array('like', $values['action_notification']))
                        $notification['notificationlike'] = 1;
                    else
                        $notification['notificationlike'] = 0;

                    if (in_array('comment', $values['action_notification']))
                        $notification['notificationcomment'] = 1;
                    else
                        $notification['notificationcomment'] = 0;

                    if (in_array('join', $values['action_notification']))
                        $notification['notificationjoin'] = 1;
                    else
                        $notification['notificationjoin'] = 0;

                    Engine_Api::_()->getDbtable('membership', 'sitebusiness')->update(array('notification' => $values['notification'], 'action_notification' => json_encode($notification)), array('business_id =?' => $business_id, 'resource_id =?' => $business_id, 'user_id =?' => $viewer_id));
                }
            }

            if (empty($results) && $viewer == 1) {
                $form->addError(Zend_Registry::get('Zend_Translate')->_('Your changes will not be reflected as you are not an admin of this business. Please go to the Admin Panel >> Manage >> Members to login to the Business Admin’s account to save your changes.'));
                return;
            } else {
                //SHOW SUCCESS MESSAGE
                $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
            }
        } else {
            $this->view->is_ajax = $this->_getParam('is_ajax', '');
        }
    }

    //ACTION FOR CONTACT INFORMATION
    public function contactAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        //GET BUSINESS ID
        $this->view->business_id = $business_id = $this->_getParam('business_id');

        //GET SITEBUSINESS ITEM
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'contact');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        //GET REQUEST IS AJAX OR NOT
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //SHOW SELECTED TAB
        $this->view->sitebusinesses_view_menu = 20;

        //SET FORM
        $this->view->form = $form = new Sitebusiness_Form_Contactinfo(array('businessowner' => Engine_Api::_()->user()->getUser($sitebusiness->owner_id)));

        //POPULATE FORM
        $value['email'] = $sitebusiness->email;
        $value['phone'] = $sitebusiness->phone;
        $value['website'] = $sitebusiness->website;
        $form->populate($value);

        //CHECK FORM VALIDATION
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            //GET FORM VALUES
            $values = $form->getValues();
            if (isset($values['email'])) {
                $email_id = $values['email'];

                //CHECK EMAIL VALIDATION
                $validator = new Zend_Validate_EmailAddress();
                $validator->getHostnameValidator()->setValidateTld(false);
                if (!empty($email_id)) {
                    if (!$validator->isValid($email_id)) {
                        $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter a valid email address.'));
                        return;
                    } else {
                        $sitebusiness->email = $email_id;
                    }
                } else {
                    $sitebusiness->email = $email_id;
                }
            }

            //CHECK PHONE OPTION IS THERE OR NOT
            if (isset($values['phone'])) {
                $sitebusiness->phone = $values['phone'];
            }

            //CHECK WEBSITE OPTION IS THERE OR NOT
            if (isset($values['website'])) {
                $sitebusiness->website = $values['website'];
            }

            //SAVE VALUES
            $sitebusiness->save();

            //SHOW SUCCESS MESSAGE
            $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
        } else {
            $this->view->is_ajax = $this->_getParam('is_ajax', '');
        }
    }

    //ACTION FOR EDIT STYLE
    public function editStyleAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        //GET BUSINESS ID AND BUSINESS OBJECT
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        if (empty($sitebusiness)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        $this->view->sitebusinesses_view_menu = 3;
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        //GET FORM
        $this->view->form = $form = new Sitebusiness_Form_Style();

        //GET CURRENT ROW
        $tableStyle = Engine_Api::_()->getDbtable('styles', 'core');

        $row = $tableStyle->fetchRow(array('type = ?' => 'sitebusiness_business', 'id = ? ' => $business_id));
        $style = $sitebusiness->getBusinessStyle();

        //POPULATE
        if (!$this->getRequest()->isPost()) {
            $form->populate(array(
                'style' => ( null == $row ? '' : $row->style )
            ));
            return;
        }

        //Whoops, form was not valid
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        //GET STYLE
        $style = $form->getValue('style');
        $style = strip_tags($style);

        $forbiddenStuff = array(
            '-moz-binding',
            'expression',
            'javascript:',
            'behaviour:',
            'vbscript:',
            'mocha:',
            'livescript:',
        );

        $style = str_replace($forbiddenStuff, '', $style);

        //SAVE IN DATABASE
        if (null == $row) {
            $row = $tableStyle->createRow();
            $row->type = 'sitebusiness_business';
            $row->id = $business_id;
        }
        $row->style = $style;
        $row->save();
        $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved.'));
    }

    //ACTION FOR ALL LOCATION
    public function allLocationAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //LOCAITON ENABLE OR NOT
        if (!Engine_Api::_()->sitebusiness()->enableLocation()) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        $this->view->sitebusinesses_view_menu = 4;

        //GET BUSINESS ID, BUSINESS OBJECT AND THEN CHECK BUSINESS VALIDATION
        $this->view->business_id = $business_id = $this->_getParam('business_id');

        //$location_id = $this->_getParam('location_id');
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        if (empty($sitebusiness)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'map');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        if (!empty($sitebusiness->location)) {
            $mainLocationId = Engine_Api::_()->getDbtable('locations', 'sitebusiness')->getLocationId($sitebusiness->business_id, $sitebusiness->location);
            $this->view->mainLocationObject = Engine_Api::_()->getItem('sitebusiness_location', $mainLocationId);
            $value['mainlocationId'] = $mainLocationId;
        }
        $value['id'] = $sitebusiness->getIdentity();
        $value['mapshow'] = 'Map Tab';
        $business = $this->_getParam('business');

        $this->view->location = $paginator = Engine_Api::_()->getDbtable('locations', 'sitebusiness')->getLocation($value);

        $paginator->setItemCountPerPage(10);
        $this->view->paginator = $paginator->setCurrentPageNumber($business);
    }

    //ACTION FOR EDIT LOCATION
    public function editLocationAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //LOCAITON ENABLE OR NOT
        if (!Engine_Api::_()->sitebusiness()->enableLocation()) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        $this->view->sitebusinesses_view_menu = 4;

        //GET BUSINESS ID, BUSINESS OBJECT AND THEN CHECK BUSINESS VALIDATION
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        if (empty($sitebusiness)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'map');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK

        $location_id = $this->_getParam('location_id');

        $locationTable = Engine_Api::_()->getDbtable('locations', 'sitebusiness');

//    $multipleLocation = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.multiple.location', 0);

        $locationFieldEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.locationfield', 1);

        if (empty($location_id)) {
            $location_id = Engine_Api::_()->getDbtable('locations', 'sitebusiness')->getLocationId($business_id, $sitebusiness->location);
        }
        if ($locationFieldEnable && $location_id) {
            $params['location_id'] = $location_id;
            $params['id'] = $business_id;
            $this->view->location = $location = Engine_Api::_()->getDbtable('locations', 'sitebusiness')->getLocation($params);
        }

        //Get form
        if (!empty($location)) {
            $this->view->form = $form = new Sitebusiness_Form_Location(array(
                'item' => $sitebusiness,
                'location' => $location->location
            ));

            if (!$this->getRequest()->isPost()) {
                $form->populate($location->toarray());
                return;
            }

            //FORM VALIDAITON
            if (!$form->isValid($this->getRequest()->getPost())) {
                return;
            }

            //FORM VALIDAITON
            if ($form->isValid($this->getRequest()->getPost())) {
                $values = $form->getValues();
                unset($values['submit']);
                unset($values['location']);
                unset($values['locationParams']);
                $locationTable->update($values, array('business_id =?' => $business_id, 'location_id =?' => $location_id));
            }
            $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved.'));
        }

        $this->view->location = $location = Engine_Api::_()->getDbtable('locations', 'sitebusiness')->getLocation($params);
    }

    //ACTION FOR EDIT ADDRESS
    public function addLocationAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET BUSINESS ID, BUSINESS OBJECT AND THEN CHECK BUSINESS VALIDATION
        $tab_selected_id = $this->_getParam('tab');
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        if (empty($sitebusiness)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'map');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK

        $this->view->form = $form = new Sitebusiness_Form_Address(array('item' => $sitebusiness));
        $form->setTitle('Add Location');
        $form->setDescription('Add your location below, then click "Save Location" to save your location.');

        //POPULATE FORM
        if (!$this->getRequest()->isPost()) {
            return;
        }

        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $values = $form->getValues();
        if (empty($values['location'])) {
            $itemError = Zend_Registry::get('Zend_Translate')->_("Please enter the location.");
            $form->addError($itemError);
            return;
        }

        if (empty($values['locationParams'])) {
            $itemError = Zend_Registry::get('Zend_Translate')->_("Please select location from the auto-suggest.");
            $form->addError($itemError);
            return;
        }

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {

            if (!empty($values['main_location'])) {
                $sitebusiness->location = $values['location'];
                $sitebusiness->save();
            }

            $location = array();
            unset($values['submit']);
            $location = $values['location'];
            $locationName = $values['locationname'];
            if (!empty($location)) {
                $sitebusiness->setLocation($location, $locationName);
            }
            $db->commit();
            if (!empty($tab_selected_id)) {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRedirect' => $this->_helper->url->url(array('business_url' => Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id), 'tab' => $tab_selected_id), 'sitebusiness_entry_view', true),
                    'parentRedirectTime' => '2',
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your business location has been added successfully.'))
                ));
            } else {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRefresh' => 100,
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your business location has been added successfully.'))
                ));
            }
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    //ACTION FOR LEAVE THE JOIN MEMBER.
    public function deleteLocationAction() {

        $business_id = $this->_getParam('business_id');
        $tab_selected_id = $this->_getParam('tab');
        $location_id = $this->_getParam('location_id');
        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        $location = Engine_Api::_()->getItem('sitebusiness_location', $location_id);
        if ($this->getRequest()->isPost()) {
            if ($location->location == $sitebusiness->location) {
                $sitebusiness->location = '';
                $sitebusiness->save();
            }

            if (!empty($business_id)) {
                Engine_Api::_()->getDbtable('locations', 'sitebusiness')->delete(array('location_id =?' => $location_id, 'business_id =?' => $business_id));
            }

            if (!empty($tab_selected_id)) {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRedirect' => $this->_helper->url->url(array('business_url' => Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id), 'tab' => $tab_selected_id), 'sitebusiness_entry_view', true),
                    'parentRedirectTime' => '2',
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have successfully delete location for this business.'))
                ));
            } else {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRefresh' => 100,
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have successfully delete location for this business.'))
                ));
            }
        }
    }

    //ACTION FOR EDIT ADDRESS
    public function editAddressAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET BUSINESS ID, BUSINESS OBJECT AND THEN CHECK BUSINESS VALIDATION
        $tab_selected_id = $this->_getParam('tab');
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $location_id = $this->_getParam('location_id');
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        $multipleLocation = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.multiple.location', 0);

        $location = Engine_Api::_()->getItem('sitebusiness_location', $location_id);

        if (empty($sitebusiness)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'map');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK

        $this->view->form = $form = new Sitebusiness_Form_Address(array('item' => $sitebusiness));
        $form->setTitle('Edit Location');
        $form->setDescription('Edit your location below, then click "Save Location" to save your location.');

        if (!empty($multipleLocation) && $location->location == $sitebusiness->location) {
            $form->main_location->setValue(1);
        }

        //POPULATE FORM
        if (!$this->getRequest()->isPost()) {
            if (!empty($multipleLocation)) {
                $form->populate($location->toArray());
            } else {
                $form->populate($sitebusiness->toArray());
            }
            return;
        }

        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $values = $form->getValues();

        if (empty($values['location']) && !empty($multipleLocation)) {
            $itemError = Zend_Registry::get('Zend_Translate')->_("Please enter the location.");
            $form->addError($itemError);
            return;
        }

        if (empty($values['locationParams'])) {
            $itemError = Zend_Registry::get('Zend_Translate')->_("Please select location from the auto-suggest.");
            $form->addError($itemError);
            return;
        }

        $locationTable = Engine_Api::_()->getDbtable('locations', 'sitebusiness');
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {

            if (!empty($multipleLocation)) {
                if (!empty($values['main_location'])) {
                    $sitebusiness->location = $values['location'];
                    $sitebusiness->save();
                } elseif ($sitebusiness->location == $location->location) {
                    $sitebusiness->location = '';
                    $sitebusiness->save();
                }
                if ($location->location != $values['location']) {
                    $locationTable->delete(array('location_id =?' => $location_id));
                    $sitebusiness->setLocation($values['location']);
                }
            } else {
                if (!empty($values['location']) && $values['location'] != $sitebusiness->location) {
                    $locationTable->delete(array('location_id =?' => $location_id));
                    $sitebusiness->location = $values['location'];
                    $sitebusiness->setLocation($values['location']);
                    $sitebusiness->save();
                }
            }

            $location = '';
            $locationName = '';
            unset($values['submit']);
            $location = $values['location'];

            if (isset($values['locationname']))
                $locationName = $values['locationname'];


            if (!empty($location)) {
                // $sitebusiness->setLocation();

                if (!empty($multipleLocation)) {
                    $locationTable->update(array('location' => $location, 'locationname' => $locationName), array('business_id =?' => $business_id, 'location_id =?' => $location_id));
                } else {
                    $locationTable->update(array('location' => $location), array('business_id =?' => $business_id, 'location_id =?' => $location_id));
                }
            } else {
                $locationTable->delete(array('business_id =?' => $business_id, 'location_id =?' => $location_id));
            }

            $db->commit();
            if (!empty($tab_selected_id)) {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRedirect' => $this->_helper->url->url(array('business_url' => Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id), 'tab' => $tab_selected_id), 'sitebusiness_entry_view', true),
                    'parentRedirectTime' => '2',
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your business location has been modified successfully.'))
                ));
            } elseif (!empty($multipleLocation)) {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRedirect' => $this->_helper->url->url(array('action' => 'all-location', 'business_id' => $business_id), 'sitebusiness_dashboard', true),
                    'parentRedirectTime' => '2',
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your business location has been modified successfully.'))
                ));
            } else {
                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 500,
                    'parentRefresh' => 100,
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your business location has been modified successfully.'))
                ));
            }
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    //ACTION FOR FEATURED OWNER
    public function featuredOwnersAction() {

        //USER VALIDAITON
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        $this->view->sitebusinesses_view_menu = 17;

        //GET BUSINESS ID AND BUSINESS OBJECT
        $this->view->business_id = $business_id = $this->_getParam('business_id', null);
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //EDIT PRIVACY
        $editPrivacy = 0;
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (!empty($isManageAdmin)) {
            $editPrivacy = 1;
        }

        $manageAdminAllowed = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.manageadmin', 1);
        if (empty($editPrivacy) || empty($manageAdminAllowed)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //GET FEATURED ADMINS
        $this->view->featuredhistories = Engine_Api::_()->getDbtable('manageadmins', 'sitebusiness')->featuredAdmins($business_id);

        $this->view->is_ajax = $this->_getParam('is_ajax', '');
    }

    //ACTION FOR MAKING FAVOURITE
    public function favouriteAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GETTING VIEWER ID
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET THE SUBJECT
        $getBusinessId = $this->_getParam('business_id', $this->_getParam('id', null));
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->core()->getSubject();
        $business_id = $sitebusiness->business_id;

        //CALLING THE FUNCTION AND PASS THE VALUES OF BUSINESS ID AND USER ID.
        $this->view->userListings = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getBusinesses($business_id, $viewer_id);

        //CHECK POST.
        if ($this->getRequest()->isPost()) {

            //GET VALUE FROM THE FORM.
            $values = $this->getRequest()->getPost();
            $selected_business_id = $values['business_id'];
            if (!empty($selected_business_id)) {

                $favouritesTable = Engine_Api::_()->getDbtable('favourites', 'sitebusiness');
                $row = $favouritesTable->createRow();
                $row->business_id = $selected_business_id;
                $row->business_id_for = $getBusinessId;
                $row->owner_id = $viewer_id;
                $row->save();

                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 100,
                    'parentRefresh' => 100,
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your Business has been successfully linked.'))
                ));
            }
        }
        //RENDER THE SCRIPT.
        $this->renderScript('dashboard/favourite.tpl');
    }

    //ACTION FOR DELETING THE FAVOURITE
    public function favouriteDeleteAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GETTING THE VIEWER ID.
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET THE SUBJECT AND CHECK AUTH.
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->core()->getSubject();
        $business_id = $sitebusiness->business_id;

        //CALLING THE FUNCTION.
        $this->view->userListings = Engine_Api::_()->getDbtable('favourites', 'sitebusiness')->deleteLink($business_id, $viewer_id);

        //CHECK POST.
        if ($this->getRequest()->isPost()) {

            $values = $this->getRequest()->getPost();
            $business_id_for = $business_id;
            $business_id = $values['business_id'];
            if (!empty($business_id)) {

                //DELETE THE RESULT FORM THE TABLE.
                $sitebusinessTable = Engine_Api::_()->getDbtable('favourites', 'sitebusiness');
                $sitebusinessTable->delete(array('business_id =?' => $business_id, 'business_id_for =?' => $business_id_for));

                $this->_forward('success', 'utility', 'core', array(
                    'smoothboxClose' => 100,
                    'parentRefresh' => 100,
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your Business has been successfully unlinked.'))
                ));
            }
        }
        //RENDER THE SCRIPT.
        $this->renderScript('dashboard/favourite-delete.tpl');
        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        //VERSION CHECK APPLIED FOR - PACKAGE WORK
        $this->view->siteeventVersion = false;
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent')) {
            if (Engine_Api::_()->sitebusiness()->checkVersion(Engine_Api::_()->getDbtable('modules', 'core')->getModule('siteevent')->version, '4.8.8')) {
                $this->view->siteeventVersion = true;
            }
        }
    }

    //ACTION FOR FOURSQUARE CODE
    public function foursquareAction() {
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {
            //NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        //GET BUSINESS ID AND SITEBUSINESS OBJECT
        $siteabusiness = Engine_Api::_()->getItem('sitebusiness_business', $this->_getParam('business_id'));

        //GENERATE FORM
        $this->view->form = $form = new Sitebusiness_Form_Foursquare();

        //POPULATE THE FORM
        $form->populate($siteabusiness->toArray());

        if (!$this->getRequest()->isPost())
            return;

        //SAVE THE FOURSQUARE CODE IN DATABASE
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $db = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getAdapter();
            $db->beginTransaction();
            try {
                $siteabusiness->foursquare_text = $_POST['foursquare_text'];
                $siteabusiness->save();
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                throw $e;
            }

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => false,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_('Text saved successfully.'))
            ));
        }
    }

    //ACTION: GET-STARTED
    public function getStartedAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        //VIEWER INFORMATION
        $this->view->viewer_id = $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET BUSINESS ID AND BUSINESS SUBJECT
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $this->view->subject = $subject = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //GET PHOTO ID
        $this->view->photo_id = $subject->photo_id;

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        //VERSION CHECK APPLIED FOR - PACKAGE WORK
        $this->view->siteeventVersion = false;
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent')) {
            $siteeventModule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('siteevent');
            $siteeventVersion = $siteeventModule->version;
            if (!empty(Engine_Api::_()->seaocore()->checkVersion($siteeventVersion, '4.8.8p1'))) {
                $this->view->siteeventVersion = true;
            }
        }

        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //OVERVIEW PRIVACY
        $this->view->overviewPrivacy = 0;
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'overview');
        if (!empty($isManageAdmin)) {
            $this->view->overviewPrivacy = 1;
        }

        $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);

        //START BUSINESS ALBUM WORK
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessalbum')) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessalbum")) {
                    $this->view->allowed_upload_photo = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'spcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->allowed_upload_photo = 1;
                }
            }
            //START THE BUSINESS ALBUM WORK
            $this->view->default_album_id = Engine_Api::_()->getItemTable('sitebusiness_album')->getDefaultAlbum($business_id)->album_id;
            //END THE BUSINESS ALBUM WORK

            $this->view->albumtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusiness.photos-sitebusiness', $business_id, $layout);
        }
        //END BUSINESS ALBUM WORK
        //GET BUSINESS OBJECT
        $this->view->sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        $this->view->sitebusinesses_view_menu = 12;

        //START THE BUSINESS POLL WORK
        $sitebusinessPollEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesspoll');
        if ($sitebusinessPollEnabled) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinesspoll")) {
                    $this->view->can_create_poll = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'splcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_poll = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->polltab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinesspoll.profile-sitebusinesspolls', $business_id, $layout);
        }
        //END THE BUSINESS POLL WORK
        //START THE BUSINESS DOCUMENT WORK
        $sitebusinessDocumentEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdocument');
        if ($sitebusinessDocumentEnabled || (Engine_Api::_()->hasModuleBootstrap('document') && Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessdocument")) {
                    $this->view->can_create_doc = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sdcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_doc = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            if ($sitebusinessDocumentEnabled) {
                $this->view->documenttab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessdocument.profile-sitebusinessdocuments', $business_id, $layout);
            } else {
                $this->view->documenttab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('document.contenttype-documents', $business_id, $layout);
            }
        }
        //END THE BUSINESS DOCUMENT WORK
        //START THE BUSINESS INVITE WORK
        $this->view->can_invite = 0;
        $sitebusinessInviteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessinvite');
        if ($sitebusinessInviteEnabled) {

            //START MANAGE-ADMIN CHECK
            $this->view->can_invite = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'invite');
            //END MANAGE-ADMIN CHECK
        }
        //END THE BUSINESS INVITE WORK
        //START THE BUSINESS VIDEO WORK
        $sitebusinessVideoEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessvideo');
        if ($sitebusinessVideoEnabled || (Engine_Api::_()->hasModuleBootstrap('sitevideo') && Engine_Api::_()->getDbtable('modules', 'sitevideo')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessvideo")) {
                    $this->view->can_create_video = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'svcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_video = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            if ($sitebusinessVideoEnabled) {
                $this->view->videotab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessvideo.profile-sitebusinessvideos', $business_id, $layout);
            } else {
                $this->view->videotab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitevideo.contenttype-videos', $business_id, $layout);
            }
        }
        //END THE BUSINESS VIDEO WORK
        $sitebusinesseventEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessevent');
        //START THE BUSINESS EVENT WORK
        if ($sitebusinesseventEnabled || (Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessevent")) {
                    $this->view->can_create_event = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'secreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_event = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            if ($sitebusinesseventEnabled) {
                $this->view->eventtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessevent.profile-sitebusinessevents', $business_id, $layout);
            } else {
                $this->view->eventtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('siteevent.contenttype-events', $business_id, $layout);
            }
        }
        //END THE BUSINESS EVENT WORK
        //START THE BUSINESS NOTE WORK
        $sitebusinessNoteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessnote');
        if ($sitebusinessNoteEnabled) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessnote")) {
                    $this->view->can_create_notes = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sncreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_notes = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->notetab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessnote.profile-sitebusinessnotes', $business_id, $layout);
        }
        //END THE BUSINESS NOTE WORK
        //START THE BUSINESS REVEIW WORK
        $sitebusinessReviewEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessreview');
        if ($sitebusinessReviewEnabled) {
            $hasPosted = Engine_Api::_()->getDbTable('reviews', 'sitebusinessreview')->canPostReview($subject->business_id, $viewer_id);
            if (empty($hasPosted) && !empty($viewer_id)) {
                $this->view->can_create_review = 1;
            } else {
                $this->view->can_create_review = 0;
            }

            $this->view->reviewtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessreview.profile-sitebusinessreviews', $business_id, $layout);
        }
        //END THE BUSINESS REVEIW WORK
        //START THE BUSINESS DISCUSSION WORK
        $sitebusinessDiscussionEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdiscussion');
        if ($sitebusinessDiscussionEnabled) {

            //START MANAGE-ADMIN CHECK
            $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'sdicreate');
            if (!empty($isManageAdmin)) {
                $this->view->can_create_discussion = 1;
            }
            //END MANAGE-ADMIN CHECK
            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (!Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessdiscussion")) {
                    $this->view->can_create_discussion = 0;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->discussiontab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusiness.discussion-sitebusiness', $business_id, $layout);
        }
        //END THE BUSINESS DISCUSSION WORK
        //START THE BUSINESS OFFER WORK
        $this->view->moduleEnable = $sitebusinessOfferEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessoffer');
        if ($sitebusinessOfferEnabled) {

            //START MANAGE-ADMIN CHECK
            $this->view->can_offer = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'offer');
            //END MANAGE-ADMIN CHECK

            $this->view->offertab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessoffer.profile-sitebusinessoffers', $business_id, $layout);
        }
        //END THE BUSINESS OFFER WORK
        //START THE BUSINESS FORM WORK
        $sitebusinessFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessform');
        if ($sitebusinessFormEnabled) {

            //START MANAGE-ADMIN CHECK
            $this->view->can_form = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'form');
            //END MANAGE-ADMIN CHECK

            $business_id = $this->_getParam('business_id');
            $quetion = Engine_Api::_()->getDbtable('businessquetions', 'sitebusinessform');
            $select_quetion = $quetion->select()->where('business_id = ?', $business_id);
            $result_quetion = $quetion->fetchRow($select_quetion);
            $this->view->option_id = $result_quetion->option_id;

            $this->view->formtab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessform.sitebusiness-viewform', $business_id, $layout);
        }
        //END THE BUSINESS FORM WORK
        //START THE BUSINESS MUSIC WORK
        $sitebusinessMusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmusic');
        if ($sitebusinessMusicEnabled) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitebusinessmusic")) {
                    $this->view->can_create_musics = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'smcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_musics = 1;
                }
            }
            //PACKAGE BASE PRIYACY END

            $this->view->musictab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusinessmusic.profile-sitebusinessmusic', $business_id, $layout);
        }
        //END THE BUSINESS MUSIC WORK
        //START THE PAGE CROWDFUNDING WORK
        $sitecrowdfundingEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitecrowdfunding');
        if ($sitecrowdfundingEnabled && (Engine_Api::_()->hasModuleBootstrap('sitecrowdfundingintegration') && Engine_Api::_()->getDbtable('modules', 'sitecrowdfunding')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {

            //PACKAGE BASE PRIYACY START
            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                if (Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", "sitecrowdfunding")) {
                    $this->view->can_create_project = 1;
                }
            } else {
                $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sprcreate');
                if (!empty($isBusinessOwnerAllow)) {
                    $this->view->can_create_project = 1;
                }
            }
            //PACKAGE BASE PRIYACY END
            $this->view->projecttab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitecrowdfunding.contenttype-projects', $business_id, $layout);

        }
        //END THE PAGE CROWDFUNDING WORK

        //$this->view->updatestab_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('activity.feed', $business_id, $layout);
    }

    //ACTION FOR HIDE THE PHOTO
    public function hidePhotoAction() {

        //SET LAYOUT
        $this->_helper->layout->setLayout('default-simple');

        //GET AJAX VALUE
        $is_ajax = $this->_getParam('isajax', '');

        //IF REQUEST IS NOT AJAX THEN ONLY SHOW FORM
        if (empty($is_ajax)) {
            $this->view->form = $form = new Sitebusiness_Form_Hidephoto();
        } else {
            Engine_Api::_()->getDbtable('photos', 'sitebusiness')->update(array('photo_hide' => 1), array('photo_id = ?' => $this->_getParam('hide_photo_id', null)));
            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
            ));
        }
    }

    //ACTION FOR SHOW MARKETING BUSINESS
    public function marketingAction() {

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        //GET VIEWER IDENTITY
        $this->view->viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET BUSINESS ID AND SITEBUSINESS OBJECT
        $this->view->business_id = $business_id = $this->_getParam('business_id', null);
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $this->view->enableFoursquare = 1;
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'foursquare');
        if (empty($isManageAdmin)) {
            $this->view->enableFoursquare = 0;
        }

        $this->view->enabletwitter = $sitebusinesstwitterEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesstwitter');
        if ($sitebusinesstwitterEnabled) {
            $this->view->enabletwitter = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'twitter');
        }


        $this->view->enableInvite = 1;
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'invite');
        if (empty($isManageAdmin)) {
            $this->view->enableInvite = 0;
        }

        $this->view->enableSendUpdate = 1;
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'sendupdate');
        if (empty($isManageAdmin)) {
            $this->view->enableSendUpdate = 0;
        }

        $sitebusinessLikeboxEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesslikebox');
        if (!empty($sitebusinessLikeboxEnabled))
            $this->view->enableLikeBox = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'likebox');
        //END MANAGE-ADMIN CHECK

        $this->view->sitebusinesses_view_menu = 20;
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);
        $this->view->fblikebox_id = Engine_Api::_()->sitebusiness()->GetTabIdinfo('sitebusiness.fblikebox-sitebusiness', $business_id, $layout);
    }

    //ACTION FOR CREATING OVERVIEW
    public function overviewAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        //GET BUSINESS ID, BUSINESS OBJECT AND BUSINESS VALIDAITON
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        if (empty($sitebusiness)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'overview');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK

        $overview = '';
        if (!empty($sitebusiness->overview)) {
            $overview = $sitebusiness->overview;
        }

        //FORM GENERATION
        $this->view->form = $form = new Sitebusiness_Form_Overview();

        if (!$this->getRequest()->isPost()) {

            $saved = $this->_getParam('saved');
            if (!empty($saved))
                $this->view->success = Zend_Registry::get('Zend_Translate')->_('Your business has been successfully created. You can enhance your business from this dashboard by creating other components.');
        }

        if ($this->getRequest()->isPost()) {

            $overview = $_POST['body'];
            $sitebusiness->overview = $overview;
            $sitebusiness->save();
            $this->view->form = $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved.'));
        }
        $values['body'] = $overview;
        $form->populate($values);
        $this->view->sitebusinesses_view_menu = 2;
    }

    //ACTION FOR CHANGING THE BUSINESS PROFILE PICTURE
    public function profilePictureAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        //GET BUSINESS ID
        $this->view->business_id = $business_id = $this->_getParam('business_id');

        //GET SITEBUSINESS ITEM
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //GET SELECTED TAB
        $this->view->sitebusinesses_view_menu = 22;

        //GET REQUEST IS ISAJAX OR NOT
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //GET FORM
        $this->view->form = $form = new Sitebusiness_Form_Photo();

        //CHECK FORM VALIDATION
        if (!$this->getRequest()->isPost()) {
            return;
        }

        //CHECK FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        //UPLOAD PHOTO
        if ($form->Filedata->getValue() !== null) {
            //GET DB
            $db = $sitebusiness->getTable()->getAdapter();
            $db->beginTransaction();
            //PROCESS
            try {

                //SET PHOTO
                $sitebusiness->setPhoto($form->Filedata);

                //SET ALBUMS PARAMS
                $paramsAlbum = array();
                $paramsAlbum['business_id'] = $business_id;
                $paramsAlbum['default_value'] = 1;
                $paramsAlbum['limit'] = 1;

                //FETCH PHOTO ID
                $photo_id = Engine_Api::_()->getItemTable('sitebusiness_album')->getDefaultAlbum($sitebusiness->business_id)->photo_id;
                if ($photo_id == 0) {
                    Engine_Api::_()->getItemTable('sitebusiness_album')->update(array('photo_id' => $sitebusiness->photo_id, 'owner_id' => $sitebusiness->owner_id), array('business_id = ?' => $sitebusiness->business_id, 'default_value = ?' => 1));
                }
                $db->commit();
            } catch (Engine_Image_Adapter_Exception $e) {
                $db->rollBack();
                $form->addError(Zend_Registry::get('Zend_Translate')->_('The uploaded file is not supported or is corrupt.'));
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
        } else if ($form->getValue('coordinates') !== '') {
            $storage = Engine_Api::_()->storage();
            $iProfile = $storage->get($sitebusiness->photo_id, 'thumb.profile');
            $iSquare = $storage->get($sitebusiness->photo_id, 'thumb.icon');
            $pName = $iProfile->getStorageService()->temporary($iProfile);
            $iName = dirname($pName) . '/nis_' . basename($pName);
            list($x, $y, $w, $h) = explode(':', $form->getValue('coordinates'));
            $image = Engine_Image::factory();
            $image->open($pName)
                    ->resample($x + .1, $y + .1, $w - .1, $h - .1, 48, 48)
                    ->write($iName)
                    ->destroy();
            $iSquare->store($iName);
            @unlink($iName);
        }

        return $this->_helper->redirector->gotoRoute(array('action' => 'profile-picture', 'business_id' => $business_id), 'sitebusiness_dashboard', true);
    }

    //ACTION FOR FILL THE DATA OF PROFILE TYPE
    public function profileTypeAction() {

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitebusiness_main');

        //GET BUSINESS ID AND SITEBUSINESS OBJECT
        $this->view->business_id = $business_id = $this->_getParam('business_id', null);
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->core()->getSubject();
        ;

        //GET PROFILE TYPE
        $profile_type_exist = $sitebusiness->profile_type;

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //END MANAGE-ADMIN CHECK
        $this->view->sitebusinesses_view_menu = 10;

        //PROFILE FIELDS FORM DATA
        $aliasedFields = $sitebusiness->fields()->getFieldsObjectsByAlias();
        $this->view->topLevelId = $topLevelId = 0;
        $this->view->topLevelValue = $topLevelValue = null;
        if (isset($aliasedFields['profile_type'])) {
            $aliasedFieldValue = $aliasedFields['profile_type']->getValue($sitebusiness);
            $topLevelId = $aliasedFields['profile_type']->field_id;
            $topLevelValue = ( is_object($aliasedFieldValue) ? $aliasedFieldValue->value : null );
            if (!$topLevelId || !$topLevelValue) {
                $topLevelId = null;
                $topLevelValue = null;
            }
            $this->view->topLevelId = $topLevelId;
            $this->view->topLevelValue = $topLevelValue;
        }

        //GET FORM
        $form = $this->view->form = new Fields_Form_Standard(array(
            'item' => Engine_Api::_()->core()->getSubject(),
            'topLevelId' => $topLevelId,
            'topLevelValue' => $topLevelValue,
        ));
        $form->submit->setLabel('Save Info');
        $form->setTitle('Edit Business Profile Info');
        if (empty($profile_type_exist)) {
            $form->setDescription('Profile information enables you to add additional information about your business depending on its category. This non-generic additional information will help others know more specific details about your business. First select a relevant Profile Type for your business, and then fill the corresponding profile information fields.');
        } else {
            $form->setDescription('Profile information enables you to add additional information about your business depending on its category. This non-generic additional information will help others know more specific details about your business.');
        }

        //SAVE DATA IF POSTED
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $form->saveValues();
            $values = $this->getRequest()->getPost();

            $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved.'));

            $business_id = $this->_getParam('business_id', null);

            if (isset($values['0_0_1']) && !empty($values['0_0_1'])) {
                $profile_type = $values['0_0_1'];
                $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
                $sitebusiness->profile_type = $profile_type;
                $sitebusiness->save();
            }
        }

        //IF PACKAGE INABLE
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {

            $profileField_level = Engine_Api::_()->sitebusiness()->getPackageProfileLevel($business_id);
            if (empty($profileField_level)) {
                return $this->_forward('requireauth', 'error', 'core');
            }
            if ($profileField_level == 2) {
                $fieldsProfile = array("0_0_1", "submit");

                //PROFILE SELECT WORK
                if (empty($sitebusiness->profile_type)) {
                    $profileType = $form->getElement('0_0_1')
                            ->getMultiOptions();

                    $profileTypePackage = Engine_Api::_()->sitebusiness()->getSelectedProfilePackage($business_id);

                    $profileTypeFinal = array_intersect_key($profileType, $profileTypePackage);

                    //ONLY SET SELECTED PROFILE TYPE
                    $profileType = $form->getElement('0_0_1')
                            ->setMultiOptions($profileTypeFinal);
                    if (count($profileTypeFinal) <= 1) {
                        $form->removeElement("0_0_1");
                        $form->removeElement("submit");
                        $error = Zend_Registry::get('Zend_Translate')->_("There are no profile fields available.");
                        $form->addError($error);
                    }
                }

                $field_id = array();
                $fieldsProfile_2 = Engine_Api::_()->sitebusiness()->getProfileFields($business_id);
                $fieldsProfile = array_merge($fieldsProfile, $fieldsProfile_2);

                //PROFILE FIELD IS SELECTED BUT THERE ARE NOT ANY PROFILE FIELDS
                if (!empty($sitebusiness->profile_type)) {
                    $profile_field_flage = true;
                    foreach ($fieldsProfile_2 as $k => $v) {
                        $explodeField = explode("_", $v);
                        if ($explodeField['1'] == $sitebusiness->profile_type) {
                            $profile_field_flage = false;
                            break;
                        }
                    }

                    if ($profile_field_flage) {
                        $form->removeElement("submit");
                        $error = Zend_Registry::get('Zend_Translate')->_("There are no profile fields available.");
                        $form->addError($error);
                    }
                }

                foreach ($fieldsProfile_2 as $k => $v) {
                    $explodeField = explode("_", $v);
                    $field_id[] = $explodeField['2'];
                }

                $elements = $form->getElements();
                $orderIndex = 1;
                foreach ($elements as $key => $value) {
                    $explode = explode("_", $key);
                    if ($explode['0'] != "1" && $explode['0'] != "submit") {
                        if (in_array($explode['0'], $field_id)) {
                            $field_id[] = $explode['2'];
                            $fieldsProfile[] = $key;
                            continue;
                        }
                    }

                    if (!in_array($key, $fieldsProfile)) {
                        $form->removeElement($key);
                        $form->addElement('Hidden', $key, array(
                            "value" => "",
                            "order" => ++$orderIndex,
                        ));
                    }
                }
            }
        }//END PACKAGE WORK
        else {
            //START LEVEL CHECKS
            $business_owner = Engine_Api::_()->getItem('user', $sitebusiness->owner_id);
            $can_profile = Engine_Api::_()->authorization()->getPermission($business_owner->level_id, "sitebusiness_business", "profile");
            if (empty($can_profile)) {
                return $this->_forward('requireauth', 'error', 'core');
            }

            if ($can_profile == 2) {
                $fieldsProfile = array("0_0_1", "submit");

                //PROFILE SELECT WORK
                if (empty($sitebusiness->profile_type)) {
                    $profileType = $form->getElement('0_0_1')
                            ->getMultiOptions();

                    $profileTypePackage = Engine_Api::_()->sitebusiness()->getSelectedProfileLevel($business_owner->level_id);

                    $profileTypeFinal = array_intersect_key($profileType, $profileTypePackage);

                    //ONLY SET SELECTED PROFILE TYPE
                    $profileType = $form->getElement('0_0_1')
                            ->setMultiOptions($profileTypeFinal);
                    if (count($profileTypeFinal) <= 1) {
                        $form->removeElement("0_0_1");
                        $form->removeElement("submit");
                        $error = Zend_Registry::get('Zend_Translate')->_("There are no profile fields available.");
                        $form->addError($error);
                    }
                }
                $fieldsProfile_2 = Engine_Api::_()->sitebusiness()->getLevelProfileFields($business_owner->level_id);
                $fieldsProfile = array_merge($fieldsProfile, $fieldsProfile_2);


                //PROFILE FIELD IS SELECTED BUT THERE ARE NOT ANY PROFILE FIELDS
                if (!empty($sitebusiness->profile_type)) {
                    $profile_field_flage = true;
                    foreach ($fieldsProfile_2 as $k => $v) {
                        $explodeField = explode("_", $v);
                        if ($explodeField['1'] == $sitebusiness->profile_type) {
                            $profile_field_flage = false;
                            break;
                        }
                    }

                    if ($profile_field_flage) {
                        $form->removeElement("submit");
                        $error = Zend_Registry::get('Zend_Translate')->_("There are no profile fields available.");
                        $form->addError($error);
                    }
                }

                foreach ($fieldsProfile_2 as $k => $v) {
                    $explodeField = explode("_", $v);
                    $field_id[] = $explodeField['2'];
                }
                $elements = $form->getElements();
                $orderIndex = 1;
                foreach ($elements as $key => $value) {

                    $explode = explode("_", $key);
                    if ($explode['0'] != "1" && $explode['0'] != "submit") {
                        if (in_array($explode['0'], $field_id)) {
                            $field_id[] = $explode['2'];
                            $fieldsProfile[] = $key;
                            continue;
                        }
                    }
                    if (!in_array($key, $fieldsProfile)) {
                        $form->removeElement($key);
                        $form->addElement('Hidden', $key, array(
                            "value" => "",
                            "order" => ++$orderIndex,
                        ));
                    }
                }
            }//END LEVEL WORK
        }
    }

    //ACTION FOR REMOVE THE PHOTO
    public function removePhotoAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main', array(), 'sitebusiness_main_manage');

        //GET SITEBUSINESS ITEM
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $this->_getParam('business_id'));

        //CHECK FORM SUBMIT
        if (isset($_POST['submit']) && $_POST['submit'] == 'submit') {
            $sitebusiness->photo_id = 0;
            $sitebusiness->save();
            return $this->_helper->redirector->gotoRoute(array('action' => 'profile-picture', 'business_id' => $sitebusiness->business_id), 'sitebusiness_dashboard', true);
        }
    }

    //ACTION FOR UNHIDE THE PHOTO
    public function unhidePhotoAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SET LAYOUT
        $this->_helper->layout->setLayout('default-simple');

        //UNHIDE PHOTO FORM
        $this->view->form = $form = new Sitebusiness_Form_Unhidephoto();

        //CHECK FORM VALIDAITON
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            Engine_Api::_()->getDbtable('photos', 'sitebusiness')->update(array('photo_hide' => 0), array('business_id = ?' => $this->_getParam('business_id', null), 'photo_hide = ?' => 1));
            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => true,
                'parentRefresh' => true,
                'format' => 'smoothbox',
                'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your photos have been restored.'))
            ));
        }
    }

    //ACTION FOR UPLOADING THE OVERVIEWS PHOTOS FROM THE EDITOR
    public function uploadPhotoAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //LAYOUT
        $this->_helper->layout->disableLayout();
        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }

        //BUSINESS ID
        $business_id = $this->_getParam('business_id');

        $special = $this->_getParam('special', 'overview');
        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $can_edit = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');

        if ($special == 'overview') {
            $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'overview');
            if (empty($can_edit)) {
                return $this->_forward('requireauth', 'error', 'core');
            }

            if (empty($isManageAdmin)) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        } else {
            $photoCreate = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'spcreate');
            if (empty($can_edit) && empty($photoCreate)) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        }
        //END MANAGE-ADMIN CHECK
        //END MANAGE-ADMIN CHECK
        //IF NOT POST OR FORM NOT VALID, RETURN
        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }
        $fileName = Engine_Api::_()->seaocore()->tinymceEditorPhotoUploadedFileName();
        //IF NOT POST OR FORM NOT VALID, RETURN
        if (!isset($_FILES[$fileName]) || !is_uploaded_file($_FILES[$fileName]['tmp_name'])) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
            return;
        }

        //PROCESS
        $db = Engine_Api::_()->getDbtable('photos', 'sitebusiness')->getAdapter();
        $db->beginTransaction();
        try {
            //CREATE PHOTO
            $tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitebusiness');
            $photo = $tablePhoto->createRow();
            $photo->setFromArray(array(
                'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(),
                'business_id' => $business_id
            ));
            $photo->save();
            $photo->setPhoto($_FILES[$fileName]);

            $this->view->status = true;
            $this->view->name = $_FILES[$fileName]['name'];
            $this->view->photo_id = $photo->photo_id;
            $this->view->photo_url = $photo->getPhotoUrl();

            $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
            $album = $tableAlbum->getSpecialAlbum($sitebusiness, $special);
            $tablePhotoName = $tablePhoto->info('name');
            $photoSelect = $tablePhoto->select()->from($tablePhotoName, 'order')->where('album_id = ?', $album->album_id)->order('order DESC')->limit(1);
            $photo_rowinfo = $tablePhoto->fetchRow($photoSelect);
            $photo->collection_id = $album->album_id;
            $photo->album_id = $album->album_id;
            $order = 0;
            if (!empty($photo_rowinfo)) {
                $order = $photo_rowinfo->order + 1;
            }
            $photo->order = $order;
            $photo->save();

            if (!$album->photo_id) {
                $album->photo_id = $photo->file_id;
                $album->save();
            }
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
            return;
        }
    }

    //ACTION FOR Twitter CODE
    public function twitterAction() {
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {
            //NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        //GET BUSINESS ID AND SITEBUSINESS OBJECT
        $siteabusiness = Engine_Api::_()->getItem('sitebusiness_business', $this->_getParam('business_id'));

        //GENERATE FORM
        $this->view->form = $form = new Sitebusiness_Form_Twitter();

        //POPULATE THE FORM
        $form->populate($siteabusiness->toArray());

        if (!$this->getRequest()->isPost())
            return;

        //SAVE THE Twitter CODE IN DATABASE
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $db = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getAdapter();
            $db->beginTransaction();
            try {
                $siteabusiness->twitter_user_name = $_POST['twitter_user_name'];
                $siteabusiness->save();
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                throw $e;
            }
        }

        $this->_forward('success', 'utility', 'core', array(
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your account has been added successfully! You can view your recent tweets on profile of your business.')),
            'parentRefresh' => false,
            'format' => 'smoothbox',
            'smoothboxClose' => 1500,
        ));
    }

    //ACTION FOR Twitter CODE
    public function facebookAction() {
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {
            //NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        //GET BUSINESS ID AND SITEBUSINESS OBJECT
        $siteabusiness = Engine_Api::_()->getItem('sitebusiness_business', $this->_getParam('business_id'));

        //GENERATE FORM
        $this->view->form = $form = new Sitebusiness_Form_Facebook();

        //POPULATE THE FORM
        $form->populate($siteabusiness->toArray());

        if (!$this->getRequest()->isPost())
            return;

        //SAVE THE Twitter CODE IN DATABASE
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $db = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getAdapter();
            $db->beginTransaction();
            try {
                $siteabusiness->fbpage_url = $_POST['fbpage_url'];
                $siteabusiness->save();
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                throw $e;
            }
        }

        $this->_forward('success', 'utility', 'core', array(
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your Facebook Page has been successfully linked.')),
            'parentRefresh' => false,
            'format' => 'smoothbox',
            'smoothboxClose' => 1500,
        ));
    }

    public function manageMemberCategoryAction() {

        //CHECK PERMISSION FOR VIEW.
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION.
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        $this->view->sitebusinesses_view_menu = 40;

        //GETTING THE OBJECT AND BUSINESS ID.
        $this->view->business_id = $business_id = $this->_getParam('business_id', null);
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

        //EDIT PRIVACY
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');

        $manageAdminAllowed = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.manageadmin', 1);
        $manageMemberSettings = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessmember.category.settings', 1);

        if (empty($isManageAdmin) || empty($manageAdminAllowed)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        if ($manageMemberSettings == 3) {
            $is_admincreated = array("0" => 0, "1" => 1);
            $business_id = array("0" => 0, "1" => $business_id);
        } elseif ($manageMemberSettings == 2) {
            $is_admincreated = array("0" => 0);
            $business_id = array("1" => $business_id);
        }

        $rolesTable = Engine_Api::_()->getDbtable('roles', 'sitebusinessmember');
        $rolesTableName = $rolesTable->info('name');

        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            $row = $rolesTable->createRow();
            $row->is_admincreated = 0;
            $row->role_name = $values['category_name'];
            $row->business_category_id = $sitebusiness->category_id;
            $row->business_id = $sitebusiness->business_id;
            $row->save();
        }

        $select = $rolesTable->select()
                ->from($rolesTableName)
                ->where($rolesTableName . '.is_admincreated IN (?)', (array) $is_admincreated)
                ->where($rolesTableName . '.business_id IN (?)', (array) $business_id)
                ->where($rolesTableName . '.business_category_id = ? ', $sitebusiness->category_id)
                ->order('role_id DESC');
        $this->view->manageRolesHistories = $rolesTable->fetchALL($select);
    }

    public function editRoleAction() {

        $role_id = (int) $this->_getParam('role_id');
        $business_id = (int) $this->_getParam('business_id');

        $role = Engine_Api::_()->getItem('sitebusinessmember_roles', $role_id);

        $this->view->form = $form = new Sitebusiness_Form_EditRole();
        $form->populate($role->toArray());

        $rolesTable = Engine_Api::_()->getDbtable('roles', 'sitebusinessmember');

        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        // Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $values = $form->getValues();
            $role->setFromArray($values);
            $role->save();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 500,
            'parentRedirect' => $this->_helper->url->url(array('business_url' => Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id), 'action' => 'manage-member-category', 'business_id' => $business_id), 'sitebusiness_dashboard', true),
            'parentRedirectTime' => '2',
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Roles has been edited successfully.'))
        ));
    }

    //THIS ACTION FOR DELETE MANAGE ADMIN AND CALLING FROM THE CORE.JS FILE.
    public function deleteMemberCategoryAction() {

        $role_id = (int) $this->_getParam('category_id');
        $business_id = (int) $this->_getParam('business_id');
        $rolesTable = Engine_Api::_()->getDbtable('roles', 'sitebusinessmember');
        $rolesTable->delete(array('role_id = ?' => $role_id, 'business_id = ?' => $business_id));
    }

    public function resetPositionCoverPhotoAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;
        //GET BUSINESS ID
        $business_id = $this->_getParam("business_id");
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        ////START MANAGE-ADMIN CHECK
        $this->view->can_edit = $can_edit = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($can_edit))
            return;
        $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
        $album = $tableAlbum->getSpecialAlbum($sitebusiness, 'cover');
        $album->cover_params = $this->_getParam('position', array('top' => '0', 'left' => 0));
        $album->save();
    }

    public function getAlbumsPhotosAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;
        $sitebusinessalbumEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessalbum');
        if (!$sitebusinessalbumEnabled) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //GET BUSINESS ID
        $business_id = $this->_getParam("business_id");
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        ////START MANAGE-ADMIN CHECK
        $this->view->can_edit = $can_edit = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($can_edit))
            return;
        //FETCH ALBUMS
        $this->view->recentAdded = $recentAdded = $this->_getParam("recent", false);
        $this->view->album_id = $album_id = $this->_getParam("album_id");
        if ($album_id) {
            $this->view->album = $album = Engine_Api::_()->getItem('sitebusiness_album', $album_id);
            $this->view->paginator = $paginator = $album->getCollectiblesPaginator();
            $paginator->setItemCountPerPage(10000);
        } elseif ($recentAdded) {
            $paginator = Engine_Api::_()->getDbtable('photos', 'sitebusiness')->getPhotos(array('business_id' => $business_id, 'orderby' => 'photo_id DESC', 'start' => 0, 'end' => 100));
        } else {
            $paramsAlbum['business_id'] = $business_id;
            $paginator = Engine_Api::_()->getDbtable('albums', 'sitebusiness')->getAlbums($paramsAlbum);
        }
        $this->view->paginator = $paginator;
    }

    public function uploadCoverPhotoAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //LAYOUT
        $this->_helper->layout->setLayout('default-simple');
        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }

        //BUSINESS ID
        $business_id = $this->_getParam('business_id');

        $special = $this->_getParam('special', 'cover');
        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //GET FORM
        $this->view->form = $form = new Sitebusiness_Form_Photo_Cover();

        //CHECK FORM VALIDATION
        $file = '';
        $notNeedToCreate = false;
        $photo_id = $this->_getParam('photo_id');
        if ($photo_id) {
            $photo = Engine_Api::_()->getItem('sitebusiness_photo', $photo_id);
            $album = Engine_Api::_()->getItem('sitebusiness_album', $photo->album_id);
            if ($album && $album->type == 'cover') {
                $notNeedToCreate = true;
            }
            if ($photo->file_id && !$notNeedToCreate)
                $file = Engine_Api::_()->getItemTable('storage_file')->getFile($photo->file_id);
        }

        if (empty($photo_id) || empty($photo)) {
            if (!$this->getRequest()->isPost()) {
                return;
            }

            //CHECK FORM VALIDATION
            if (!$form->isValid($this->getRequest()->getPost())) {
                return;
            }
        }
        //UPLOAD PHOTO
        if ($form->Filedata->getValue() !== null || $photo || ($notNeedToCreate && $file)) {
            //PROCESS
            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            try {
                //CREATE PHOTO
                $tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitebusiness');
                if (!$notNeedToCreate) {
                    $photo = $tablePhoto->createRow();
                    $photo->setFromArray(array(
                        'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(),
                        'business_id' => $business_id
                    ));
                    $photo->save();
                    if ($file) {
                        $photo->setPhoto($file);
                    } else {
                        $photo->setPhoto($form->Filedata, true);
                    }


                    $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
                    $album = $tableAlbum->getSpecialAlbum($sitebusiness, $special);

                    $tablePhotoName = $tablePhoto->info('name');
                    $photoSelect = $tablePhoto->select()->from($tablePhotoName, 'order')->where('album_id = ?', $album->album_id)->order('order DESC')->limit(1);
                    $photo_rowinfo = $tablePhoto->fetchRow($photoSelect);
                    $photo->collection_id = $album->album_id;
                    $photo->album_id = $album->album_id;
                    $order = 0;
                    if (!empty($photo_rowinfo)) {
                        $order = $photo_rowinfo->order + 1;
                    }
                    $photo->order = $order;
                    $photo->save();
                }

                $album->cover_params = $this->_getParam('position', array('top' => '0', 'left' => 0));
                $album->save();
                if (!$album->photo_id) {
                    $album->photo_id = $photo->file_id;
                    $album->save();
                }
                $sitebusiness->business_cover = $photo->photo_id;
                $sitebusiness->save();
                //ADD ACTIVITY
                $viewer = Engine_Api::_()->user()->getViewer();
                $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
                $activityFeedType = null;
                if (Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness) && Engine_Api::_()->sitebusiness()->isFeedTypeBusinessEnable())
                    $activityFeedType = 'sitebusiness_admin_cover_update';
                elseif ($sitebusiness->all_post || Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness))
                    $activityFeedType = 'sitebusiness_cover_update';


                if ($activityFeedType) {
                    $action = $activityApi->addActivity($viewer, $sitebusiness, $activityFeedType);
                }
                if ($action) {
                    Engine_Api::_()->getApi('subCore', 'sitebusiness')->deleteFeedStream($action);
                    if ($photo)
                        Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $photo);
                }

                $this->view->status = true;
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                $this->view->status = false;
                $this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
                return;
            }
        }
    }

    public function removeCoverPhotoAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        $business_id = $this->_getParam('business_id');
        if ($this->getRequest()->isPost()) {
            $special = $this->_getParam('special', 'cover');
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
            $sitebusiness->business_cover = 0;
            $sitebusiness->save();
            $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
            $album = $tableAlbum->getSpecialAlbum($sitebusiness, $special);
            $album->cover_params = array('top' => '0', 'left' => 0);
            $album->save();

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
            ));
        }
    }


        //ACTION TO CHOOSE THE PROJECT FOR THE DONATION TYPE BACKING
    public function chooseProjectAction() {

         //ONLY LOGGED IN USER CAN EDIT THE STYLE
        if (!$this->_helper->requireUser()->isValid())
            return;
        //DO NOT SHOW THE PROJECTS TAB IF ADMIN HAVE PLACED ON THE BUSINESS PROFILE PAGE
        $adminSelectedProject = Engine_Api::_()->sitecrowdfunding()->adminSelectedProject('sitebusiness_index_view');
        if(!empty($adminSelectedProject)) {
            return false;
        }
        $this->view->is_ajax = $this->_getParam('is_ajax', '');

         //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        //GET PAGE ID AND OBJECT
        $this->view->business_id = $business_id = $this->_getParam('business_id');
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        $this->view->parent_type = $sitebusiness->getType();
        $this->view->owner_id = $sitebusiness->getOwner()->getIdentity();
        //SET PAGE SUBJECT
        if (!$sitebusiness->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forwardCustom('requireauth', 'error', 'core');
        }
        $this->view->form = $form = new Sitecrowdfunding_Form_ChooseProjectContentModule(array('item' => $sitebusiness));
        //CHECK METHOD
        if (!$this->getRequest()->isPost()) {
            return;
        }
        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $values = $form->getValues();

        foreach ($values as $key => $value) {
            if (Engine_Api::_()->getApi('settings', 'core')->hasSetting($key)) {
                Engine_Api::_()->getApi('settings', 'core')->removeSetting($key);
            }
            if (is_null($value)) {
                $value = "";
            }
            Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
        }
        $form->addNotice($this->view->translate('Your changes have been saved successfully.'));
    }

}
