<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_ProfileController extends Seaocore_Controller_Action_Standard {

  //ACTION FOR SENDING A MESSGE TO BUSINESS OWNER
  public function messageOwnerAction() {

    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET VIEWER DETAIL
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //GET BUSINESS ID AND BUSINESS OBJECT
    $business_id = $this->_getParam("business_id");
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    //BUSINESS OWNER CAN'T SEND MESSAGE TO HIMSELF
    if ($viewer_id == $sitebusiness->owner_id) {
      return $this->_forwardCustom('requireauth', 'error', 'core');
    }

    //FORM GENERATION
    $this->view->form = $form = new Messages_Form_Compose();
    $form->setTitle('Contact Business Owner');
    $form->setDescription('Create your message with the form given below. Your message will be sent to the admins of this Business.');
    $form->removeElement('to');

    //GET ADMINS ID FOR SENDING MESSAGE
    $manageAdminData = Engine_Api::_()->getDbtable('manageadmins', 'sitebusiness')->getManageAdmin($business_id);
    $manageAdminData = $manageAdminData->toArray();
    $ids = '';
    if (!empty($manageAdminData)) {
      foreach ($manageAdminData as $key => $user_ids) {
        $user_id = $user_ids['user_id'];
        if ($viewer_id != $user_id) {
          $ids = $ids . $user_id . ',';
        }
      }
    }
    $ids = trim($ids, ',');
    $form->toValues->setValue($ids);

    if (!$this->getRequest()->isPost()) {
      return;
    }

    $db = Engine_Api::_()->getDbtable('messages', 'messages')->getAdapter();
    $db->beginTransaction();

    try {
      $values = $this->getRequest()->getPost();

      $form->populate($values);

      $is_error = 0;
      if (empty($values['title'])) {
        $is_error = 1;
      }

      //SENDING MESSAGE
      if ($is_error == 1) {
        $error = $this->view->translate('Subject is required field !');
        $error = Zend_Registry::get('Zend_Translate')->_($error);

        $form->getDecorator('errors')->setOption('escape', false);
        $form->addError($error);
        return;
      }

      $recipients = preg_split('/[,. ]+/', $values['toValues']);

      //LIMIT RECIPIENTS IF IT IS NOT A SPECIAL LIST OF MEMBERS
      $recipients = array_slice($recipients, 0, 1000);

      //CLEAN THE RECIPIENTS FOR REPEATING IDS
      //THIS CAN HAPPEN IF RECIPIENTS IS SELECTED AND THEN A FRIEND LIST IS SELECTED
      $recipients = array_unique($recipients);

      $recipientsUsers = Engine_Api::_()->getItemMulti('user', $recipients);

      $sitebusiness_title = $sitebusiness->title;
      $business_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('business_url' => Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id)), 'sitebusiness_entry_view') . ">$sitebusiness_title</a>";

      $conversation = Engine_Api::_()->getItemTable('messages_conversation')->send(
              $viewer, $recipients, $values['title'], $values['body'] . "<br><br>" . $this->view->translate("This message corresponds to the Business:") . $business_title_with_link
      );

      foreach ($recipientsUsers as $user) {
        if ($user->getIdentity() == $viewer->getIdentity()) {
          continue;
        }
        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification(
                $user, $viewer, $conversation, 'message_new'
        );
      }

      //INCREMENT MESSAGES COUNTER
      Engine_Api::_()->getDbtable('statistics', 'core')->increment('messages.creations');

      $db->commit();

      return $this->_forwardCustom('success', 'utility', 'core', array(
                  'smoothboxClose' => true,
                  'parentRefresh' => false,
                  'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message has been sent successfully.'))
              ));
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
  }

  //ACTION FOR TELL TO THE FRIEND FOR THIS BUSINESS
  public function tellAFriendAction() {

    //DEFAULT LAYOUT
    $sitemobile = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemobile');
    if ($sitemobile && !Engine_Api::_()->sitemobile()->checkMode('mobile-mode'))
			$this->_helper->layout->setLayout('default-simple');

    //GET VIEWER DETAIL
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewr_id = $viewer->getIdentity();

    //GET BUSINESS ID AND BUSINESS OBJECT
    $business_id = $this->_getParam('business_id', $this->_getParam('id', null));
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    if (empty($sitebusiness))
      return $this->_forwardCustom('notfound', 'error', 'core');
    //AUTHORIZATION CHECK FOR TELL A FRIEND
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'tfriend');
    if (empty($isManageAdmin)) {
      return $this->_forwardCustom('requireauth', 'error', 'core');
    }

    //FORM GENERATION
    $this->view->form = $form = new Sitebusiness_Form_TellAFriend();
 
     if (Engine_Api::_()->seaocore()->isSitemobileApp()) {
      Zend_Registry::set('setFixedCreationForm', true);
      Zend_Registry::set('setFixedCreationHeaderTitle', str_replace(' New ', ' ', $form->getTitle()));
      Zend_Registry::set('setFixedCreationHeaderSubmit', 'Send');
      $this->view->form->setAttrib('id', 'form_sitebusiness_tellAFriend');
      Zend_Registry::set('setFixedCreationFormId', '#form_sitebusiness_tellAFriend');
			$this->view->form->removeElement('sitebusiness_send');
      $this->view->form->removeElement('sitebusiness_cancel');
      $this->view->form->removeDisplayGroup('sitebusiness_buttons');
      $form->setTitle('');
    }
    
    if (!empty($viewr_id)) {
      $value['sender_email'] = $viewer->email;
      $value['sender_name'] = $viewer->displayname;
      $form->populate($value);
    }
    
    //IF THE MODE IS APP MODE THEN
    if (Engine_Api::_()->seaocore()->isSitemobileApp()) {
      Zend_Registry::set('setFixedCreationForm', true);
      Zend_Registry::set('setFixedCreationFormBack', 'Back');
      Zend_Registry::set('setFixedCreationHeaderTitle', Zend_Registry::get('Zend_Translate')->_('Tell a friend'));
      Zend_Registry::set('setFixedCreationHeaderSubmit', Zend_Registry::get('Zend_Translate')->_('Send'));
      $this->view->form->setAttrib('id', 'tellAFriendFrom');
      Zend_Registry::set('setFixedCreationFormId', '#tellAFriendFrom');
      $this->view->form->removeElement('sitebusiness_send');
      $this->view->form->removeElement('sitebusiness_cancel');
      $form->setTitle('');
    }
    
    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

      $values = $form->getValues();

      //EDPLODES EMAIL IDS
      $reciver_ids = explode(',', $values['sitebusiness_reciver_emails']);

      if (!empty($values['sitebusiness_send_me'])) {
        $reciver_ids[] = $values['sitebusiness_sender_email'];
      }
      $sender_email = $values['sitebusiness_sender_email'];

      //CHECK VALID EMAIL ID FORMITE
      $validator = new Zend_Validate_EmailAddress();
      $validator->getHostnameValidator()->setValidateTld(false);

      if (!$validator->isValid($sender_email)) {
        $form->addError(Zend_Registry::get('Zend_Translate')->_('Invalid sender email address value'));
        return;
      }
      foreach ($reciver_ids as $reciver_id) {
        $reciver_id = trim($reciver_id, ' ');
        if (!$validator->isValid($reciver_id)) {
          $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter correct email address of the receiver(s).'));
          return;
        }
      }
      $sender = $values['sitebusiness_sender_name'];
      $message = $values['sitebusiness_message'];
      $heading = ucfirst($sitebusiness->getTitle());
      foreach ($reciver_ids as $reciver_id) {
        Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciver_id, 'SITEBUSINESS_TELLAFRIEND_EMAIL', array(
            'host' => $_SERVER['HTTP_HOST'],
            'sender_name' => $sender,
            'business_title' => $heading,
            'message' => '<div>' . $message . '</div>',
            'object_link' => 'http://' . $_SERVER['HTTP_HOST'] . Engine_Api::_()->sitebusiness()->getHref($sitebusiness->business_id, $sitebusiness->owner_id, $sitebusiness->getSlug()),
            'sender_email' => $sender_email,
            'queue' => false
        ));
      }
      if ($sitemobile && Engine_Api::_()->sitemobile()->checkMode('mobile-mode'))
				$this->_forwardCustom('success', 'utility', 'core', array(          
          'parentRedirect' => $sitebusiness->getHref(),          
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message to your friend has been sent successfully.'))
      ));
		  else
      $this->_forwardCustom('success', 'utility', 'core', array(
          'smoothboxClose' => true,
          'parentRefresh' => false,
          'format' => 'smoothbox',
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message to your friend has been sent successfully.'))
      ));
    }
  }

  //ACTION FOR PRINTING THE BUSINESS
  public function printAction() {
    $this->_helper->layout->setLayout('default-simple');
    //GET BUSINESS ID AND BUSINESS OBJECT
    $this->view->business_id = $business_id = $this->_getParam('business_id', $this->_getParam('id', null));
    $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    if (empty($sitebusiness))
      return $this->_forwardCustom('notfound', 'error', 'core');
    //AUTHORIZATION CHECK FOR PRINTING
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'print');
    if (empty($isManageAdmin)) {
      return $this->_forwardCustom('requireauth', 'error', 'core');
    }

    if ($sitebusiness->category_id != 0)
      $this->view->category = Engine_Api::_()->getDbTable('categories', 'sitebusiness')->getCategory($sitebusiness->category_id);

    if ($sitebusiness->subcategory_id != 0)
      $this->view->subcategory = Engine_Api::_()->getDbTable('categories', 'sitebusiness')->getCategory($sitebusiness->subcategory_id);

    if ($sitebusiness->subsubcategory_id != 0)
      $this->view->subsubcategory = Engine_Api::_()->getDbTable('categories', 'sitebusiness')->getCategory($sitebusiness->subsubcategory_id);
    
    $this->view->addHelperPath(APPLICATION_PATH . '/application/modules/Sitebusiness/View/Helper', 'Sitebusiness_View_Helper');
     $this->view->fieldStructure = Engine_Api::_()->fields()->getFieldsStructurePartial($sitebusiness);
  }

  //ACTION FOR WRITE BOX AT VIEW PROFILE BUSINESS
  public function displayAction() {

    //GET THE TEXT STRING
    $text = $this->_getParam('text_string');

    //GET BUSINESS ID
    $business_id = $this->_getParam('business_id');

    $writesTable = Engine_Api::_()->getDbtable('writes', 'sitebusiness')->setWriteContent($business_id, $text);
    exit();
  }

  public function contactDetailAction() {



    //GET BUSINESS ID
    $business_id = $this->_getParam("business_id");

    //GET SITEBUSINESS ITEM    
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    //GET PHONE
    $phone = $this->_getParam('phone');

    //GET EMAIL
    $email = $this->_getParam('email');

    //GET WEBSITE
    $website = $this->_getParam('website');
    
    $phone = $this->view->string()->stripTags($phone);
    $email = $this->view->string()->stripTags($email);
    $website = $this->view->string()->stripTags($website);
        
    //SAVE DETAILS
    $sitebusiness->phone = $phone;
    $sitebusiness->email = $email;
    $sitebusiness->website = $website;
    $sitebusiness->save();
  }

  public function getCoverPhotoAction() {

    //GET BUSINESS ID
    $business_id = $this->_getParam("business_id");
    $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    //START MANAGE-ADMIN CHECK
    $this->view->can_edit = $can_edit = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    $onlyMemberWithPhoto = $this->_getParam("onlyMemberWithPhoto", 1);
    if (empty($sitebusiness->business_cover)) {
      $this->view->show_member = $show_member = $this->_getParam("show_member", 0);
      if ($show_member) {
        $this->view->members = $members = Engine_Api::_()->getDbtable('membership', 'sitebusiness')->getJoinMembers($sitebusiness->business_id, null,null,$onlyMemberWithPhoto);
        $this->view->membersCount = $members->getTotalItemCount();
        $this->view->membersCountView = $this->_getParam("memberCount", 8);
      }
      return;
    }
    $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
    $album = $tableAlbum->getSpecialAlbum($sitebusiness, 'cover');
    //$otherinfo = Engine_Api::_()->getDbtable('otherinfo', 'sitebusiness')->getOtherinfo($business_id);
    $this->view->photo = $photo = Engine_Api::_()->getItem('sitebusiness_photo', $sitebusiness->business_cover);

    $this->view->coverTop = 0;
    $this->view->coverLeft = 0;
    if ($album->cover_params && isset($album->cover_params['top'])) {
      $this->view->coverTop = $album->cover_params['top'];
    }
  }
  
  //ACTION FOR Email Me FOR THIS BUSINESS
  public function emailMeAction() {

    //DEFAULT LAYOUT
    $this->_helper->layout->setLayout('default-simple');

    //GET VIEWER DETAIL
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewr_id = $viewer->getIdentity();

    //GET BUSINESS ID AND BUSINESS OBJECT
    $this->view->business_id  = $business_id = $this->_getParam('business_id', $this->_getParam('id', null));
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    if (empty($sitebusiness))
      return $this->_forwardCustom('notfound', 'error', 'core');
      
    //AUTHORIZATION CHECK FOR TELL A FRIEND
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'tfriend');
    if (empty($isManageAdmin)) {
      return $this->_forwardCustom('requireauth', 'error', 'core');
    }

    //FORM GENERATION
    $this->view->form = $form = new Sitebusiness_Form_EmailMe();

    if (!empty($viewr_id)) {
      $value['sender_email'] = $viewer->email;
      $value['sender_name'] = $viewer->displayname;
      $form->populate($value);
    }

    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

      $values = $form->getValues();

      //EDPLODES EMAIL IDS
      $reciver_ids = $sitebusiness->email; //explode(',', $values['sitebusiness_reciver_emails']);
      $values['sitebusiness_sender_email'] = $sitebusiness->email;
      if (!empty($values['sitebusiness_send_me'])) {
        $reciver_ids = $values['sitebusiness_sender_email'];
      }
      $sender_email = $values['sitebusiness_sender_email'];

      //CHECK VALID EMAIL ID FORMITE
      $validator = new Zend_Validate_EmailAddress();
      $validator->getHostnameValidator()->setValidateTld(false);
      if (!$validator->isValid($sender_email)) {
        $form->addError(Zend_Registry::get('Zend_Translate')->_('Invalid sender email address value'));
        return;
      }
//       foreach ($reciver_ids as $reciver_id) {
//         $reciver_id = trim($reciver_id, ' ');
//         if (!$validator->isValid($reciver_id)) {
//           $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter correct email address of the receiver(s).'));
//           return;
//         }
//       }
      $sender = $values['sitebusiness_sender_name'];
      $message = $values['sitebusiness_message'];
      $heading = ucfirst($sitebusiness->getTitle());
      Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciver_ids, 'SITEBUSINESS_EMAILME_EMAIL', array(
          'host' => $_SERVER['HTTP_HOST'],
          'sender_name' => $sender,
          'business_title' => $heading,
          'message' => '<div>' . $message . '</div>',
          'object_link' => 'http://' . $_SERVER['HTTP_HOST'] . Engine_Api::_()->sitebusiness()->getHref($sitebusiness->business_id, $sitebusiness->owner_id, $sitebusiness->getSlug()),
          'sender_email' => $sender_email,
          'queue' => true
      ));

      $this->_forwardCustom('success', 'utility', 'core', array(
          'smoothboxClose' => true,
          'parentRefresh' => false,
          'format' => 'smoothbox',
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message to business owner has been sent successfully.'))
      ));
    }
  }

  public function uploadCoverPhotoAction() {

    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //LAYOUT
    $this->_helper->layout->setLayout('default-simple');
    if (!$this->_helper->requireUser()->checkRequire()) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
      return;
    }

    //BUSINESS ID
    $business_id = $this->_getParam('business_id');

    $special = $this->_getParam('special', 'cover');
    $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //CHECK FORM VALIDATION
    $file='';
    $notNeedToCreate=false;
    $photo_id = $this->_getParam('photo_id');
    if ($photo_id) {
      $photo = Engine_Api::_()->getItem('sitebusiness_photo', $photo_id);
      $album = Engine_Api::_()->getItem('sitebusiness_album', $photo->album_id);
      if ($album && $album->type == 'cover') {
        $notNeedToCreate = true;
      }
      if ($photo->file_id && !$notNeedToCreate)
        $file = Engine_Api::_()->getItemTable('storage_file')->getFile($photo->file_id);
    }


		//PROCESS
		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		try {
			//CREATE PHOTO
			$tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitebusiness');
			if (!$notNeedToCreate) {
				$photo = $tablePhoto->createRow();
				$photo->setFromArray(array(
						'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(),
						'business_id' => $business_id
				));
				$photo->save();
				if ($file) {
					$photo->setPhoto($file);
				} else {
					$photo->setPhoto($_FILES['Filedata'],true);
				}


				$tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
				$album = $tableAlbum->getSpecialAlbum($sitebusiness, $special);

				$tablePhotoName = $tablePhoto->info('name');
				$photoSelect = $tablePhoto->select()->from($tablePhotoName, 'order')->where('album_id = ?', $album->album_id)->order('order DESC')->limit(1);
				$photo_rowinfo = $tablePhoto->fetchRow($photoSelect);
				$photo->collection_id = $album->album_id;
				$photo->album_id = $album->album_id;
				$order = 0;
				if (!empty($photo_rowinfo)) {
					$order = $photo_rowinfo->order + 1;
				}
				$photo->order = $order;
				$photo->save();
			}

			$album->cover_params = $this->_getParam('position', array('top' => '0', 'left' => 0));
			$album->save();
			if (!$album->photo_id) {
				$album->photo_id = $photo->file_id;
				$album->save();
			}
			$sitebusiness->business_cover = $photo->photo_id;
			$sitebusiness->save();
			//ADD ACTIVITY
			$viewer = Engine_Api::_()->user()->getViewer();
			$activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
			$activityFeedType = null;
			if (Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness) && Engine_Api::_()->sitebusiness()->isFeedTypeBusinessEnable())
				$activityFeedType = 'sitebusiness_admin_cover_update';
			elseif ($sitebusiness->all_post || Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness))
				$activityFeedType = 'sitebusiness_cover_update';


			if ($activityFeedType) {
				$action = $activityApi->addActivity($viewer, $sitebusiness, $activityFeedType);
			}
			if ($action) {
				Engine_Api::_()->getApi('subCore', 'sitebusiness')->deleteFeedStream($action);
				if ($photo)
					Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $photo);
			}

			$this->view->status = true;
			$db->commit();
      return $this->_redirectCustom($sitebusiness->getHref());
		} catch (Exception $e) {
			$db->rollBack();
			$this->view->status = false;
			$this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
			return;
		}
  }

  public function removeCoverPhotoAction() {

    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    $business_id = $this->_getParam('business_id');
    if ($this->getRequest()->isPost()) {
      $special = $this->_getParam('special', 'cover');
      $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
      $sitebusiness->business_cover = 0;
      $sitebusiness->save();
      $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
      $album = $tableAlbum->getSpecialAlbum($sitebusiness, $special);
      $album->cover_params = array('top' => '0', 'left' => 0);
      $album->save();
      $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
      ));
    }
  }

  public function getAlbumsPhotosAction() {
    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;
    $sitebusinessalbumEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessalbum');
    if (!$sitebusinessalbumEnabled) {
      return $this->_forward('requireauth', 'error', 'core');
    }
    //GET BUSINESS ID
    $business_id = $this->_getParam("business_id");
    $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    ////START MANAGE-ADMIN CHECK
    $this->view->can_edit = $can_edit = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($can_edit))
      return;
    //FETCH ALBUMS
    $this->view->recentAdded = $recentAdded = $this->_getParam("recent", false);
    $this->view->album_id = $album_id = $this->_getParam("album_id");
    if ($album_id) {
      $this->view->album = $album = Engine_Api::_()->getItem('sitebusiness_album', $album_id);
      $this->view->paginator = $paginator = $album->getCollectiblesPaginator();
      $paginator->setItemCountPerPage(10000);
    } elseif ($recentAdded) {
      $paginator = Engine_Api::_()->getDbtable('photos', 'sitebusiness')->getPhotos(array('business_id' => $business_id, 'orderby' => 'photo_id DESC', 'start' => 0, 'end' => 100));
    } else {
      $paramsAlbum['business_id'] = $business_id;
      $paginator = Engine_Api::_()->getDbtable('albums', 'sitebusiness')->getAlbums($paramsAlbum);
    }
    $this->view->paginator = $paginator;
  }

}