<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Event
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: Controller.php 9747 2012-07-26 02:08:08Z john $
 * @author     John
 */

/**
 * @category   Application_Extensions
 * @package    Event
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 */
class Sitebusiness_Widget_ProfileDiscussionsController extends Engine_Content_Widget_Abstract {

  protected $_childCount;

  //ACTION FOR FETCHING THE DISCUSSIONS FOR THE BUSINESSES
  public function indexAction() {

    //DON'T RENDER IF THERE IS NO SUBJECT
    if (!Engine_Api::_()->core()->hasSubject()) {
      return $this->setNoRender();
    }

    $this->view->subject = $subject = Engine_Api::_()->core()->getSubject();
    if ($subject->getType() == 'sitebusiness_business') {
      return $this->setNoRender();
    } else {
      if ($subject->getType() == 'sitebusinessevent_event') {
        $sitebusiness = $subject->getParentBusiness();
      } elseif ($subject->getType() == 'sitebusinessmusic_playlist') {
        $sitebusiness = $subject->getParentType();
      } else {
        $sitebusiness = $subject->getParent();
      }
    }

    if (!$sitebusiness || $sitebusiness->getType() !== 'sitebusiness_business') {
      return $this->setNoRender();
    }

    //GET SITEBUSINESS SUBJECT
    $this->view->sitebusiness = $sitebusiness;

    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'view');
    if (empty($isManageAdmin)) {
      return $this->setNoRender();
    }

    //GET BUSINESS ID
    $this->view->business_id = $sitebusiness->business_id;

    //START PACKAGE LEVEL CHECK
    if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
      if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessdiscussion")) {
        return $this->setNoRender();
      }
    } else {
      $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sdicreate');
      if (empty($isBusinessOwnerAllow)) {
        return $this->setNoRender();
      }
    }
    //END PACKAGE LEVEL CHECK

    $this->view->canPost = $topicComment = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'sdicreate');

    if (empty($topicComment)) {
      return $this->setNoRender();
    }

    //GET CURRENT BUSINESS NUMBER     
    $business = $this->_getParam('business', 1);

    //GET PAGINATORS
    $this->view->paginators = $paginators = Engine_Api::_()->getDbtable('topics', 'sitebusiness')->getBusinessTopics($sitebusiness->business_id, array('resource_type' => $subject->getType(), 'resource_id' => $subject->getIdentity()));
    $paginators->setItemCountPerPage(100)->setCurrentPageNumber($business);

    //ADD COUNT TO TITLE IF CONFIGURED
    if ($this->_getParam('titleCount', false) && $paginators->getTotalItemCount() > 0) {
      $this->_childCount = $paginators->getTotalItemCount();
    }
  }

  public function getChildCount() {
    return $this->_childCount;
  }

}