<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusinessalbum
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessalbum_Plugin_Menus {

  public function canViewAlbums() {

    $isActive = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessalbum.isActivate', 0);
    if(empty($isActive)) {
      return false;
    }
    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessalbum.album.show.menu', 1)) {
      return false;
    }

    $table = Engine_Api::_()->getDbtable('albums', 'sitebusiness');
    $rName = $table->info('name');
    $table_businesses = Engine_Api::_()->getDbtable('business', 'sitebusiness');
    $rName_businesses = $table_businesses->info('name');
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_businesses, array('photo_id', 'title as sitebusiness_title'))
                    ->join($rName, $rName . '.business_id = ' . $rName_businesses . '.business_id')
                    ->where($rName .'.search = ?', 1);

    $select = $select
                    ->where($rName_businesses . '.closed = ?', '0')
                    ->where($rName_businesses . '.approved = ?', '1')
                    ->where($rName_businesses . '.search = ?', '1')
                    ->where($rName_businesses . '.declined = ?', '0')
                    ->where($rName_businesses . '.draft = ?', '1');
    if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
      $select->where($rName_businesses . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }

   //SITEMOBILE BUSINESS ALBUM MENUS
  public function onMenuInitialize_SitebusinessalbumViewAlbums($row) {

    if(Engine_Api::_()->seaocore()->isSitemobileApp()){
     return false; 
    }
    // $viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();

    //GET ALBUM ID
    $album_id = $subject->getIdentity();

    //GET ALBUM ITEM
    $album = Engine_Api::_()->getItem('sitebusiness_album', $album_id);

    if (empty($album))
      return false;

    $business_id = $album->business_id;
    //SET ALBUMS PARAMS
    $paramsAlbum = array();
    $paramsAlbum['business_id'] = $business_id;
    //GET ALBUM COUNT
    $album_count = Engine_Api::_()->getDbtable('albums', 'sitebusiness')->getAlbumsCount($paramsAlbum);

    //CHECKS
    if ($album_count <= 1) {
      return false;
    }

    return array(
        'label' => 'View Albums',
        'class' => 'ui-btn-action',
        'route' => 'sitebusiness_albumphoto_general',
        'params' => array(
            'action' => 'view-album',
            'album_id' => $subject->getIdentity(),
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessalbumAdd($row) {

    //$viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();
    $upload_photo = 0;
    $engineApiSitebusiness = Engine_Api::_()->sitebusiness();
    //GET ALBUM ID
    $album_id = $subject->getIdentity();

    //GET ALBUM ITEM
    $album = Engine_Api::_()->getItem('sitebusiness_album', $album_id);

    if (empty($album))
      return false;

    $business_id = $album->business_id;
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    $isManageAdmin = $engineApiSitebusiness->isManageAdmin($sitebusiness, 'spcreate');
    if (empty($isManageAdmin)) {
      $canCreatePhoto = 0;
    } else {
      $canCreatePhoto = 1;
    }

    if ($canCreatePhoto == 1 && ($engineApiSitebusiness->isBusinessOwner($sitebusiness) || $album->default_value == 1)) {
      $upload_photo = 1;
    }

    if (empty($upload_photo)) {
      return false;
    }

    return array(
        'label' => 'Add More Photos',
        'class' => 'ui-btn-action',
        'route' => 'sitebusiness_photoalbumupload',
        'params' => array(
            'action' => 'upload',
            'album_id' => $subject->getIdentity(),
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessalbumEdit() {

    //$viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();

    //GET ALBUM ID
    $album_id = $subject->getIdentity();

    //GET ALBUM ITEM
    $album = Engine_Api::_()->getItem('sitebusiness_album', $album_id);
    if (empty($album))
      return false;
    $business_id = $album->business_id;

    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    $engineApiSitebusiness = Engine_Api::_()->sitebusiness();

    $isManageAdmin = $engineApiSitebusiness->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    if (empty($can_edit)) {
      return false;
    }
    return array(
        'label' => 'Edit Album',        
        'route' => 'sitebusiness_albumphoto_general',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'action' => 'edit',
            'album_id' => $subject->getIdentity(),
            'business_id' => $business_id
        )
    );
  }

  public function onMenuInitialize_SitebusinessalbumDelete() {

    // $viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $album_id = $subject->getIdentity();

    //GET ALBUM ITEM
    $album = Engine_Api::_()->getItem('sitebusiness_album', $album_id);
    if (empty($album))
      return false;
    $business_id = $album->business_id;
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    $engineApiSitebusiness = Engine_Api::_()->sitebusiness();

    $isManageAdmin = $engineApiSitebusiness->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    if (empty($can_edit)) {
      return false;
    }

    //SET DEFAULT ALBUM VALUE
    $default_value = $album->default_value;
    if ($default_value == 1) {
      return false;
    }

    return array(
        'label' => 'Delete Album',
        'route' => 'sitebusiness_albumphoto_general',
        'class' => 'ui-btn-danger smoothbox',
        'params' => array(
            'action' => 'delete',
            'album_id' => $subject->getIdentity(),
            'business_id' => $business_id
        )
    );
  }

  //PHOTO VIEW BUSINESS OPTIONS

  public function onMenuInitialize_SitebusinessalbumPhotoEdit($row) {

    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $album_id = $subject->album_id;

    //GET BUSINESS ID
    $business_id = $subject->business_id;

    //GET SITEBUSINESS ITEM
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    //PHOTO OWNER, BUSINESS OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id == $subject->user_id || $can_edit == 1) {
      $canEdit = 1;
    } else {
      $canEdit = 0;
    }
    //CHECK FOR EDIT
    if (empty($canEdit)) {
      return false;
    }

    return array(
        'label' => 'Edit',
        'route' => 'sitebusiness_imagephoto_specific',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'action' => 'photo-edit',
            'photo_id' => $subject->getIdentity(),
            'album_id' => $album_id,
            'business_id' => $business_id,
            //'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessalbumPhotoDelete($row) {

    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $album_id = $subject->album_id;

    //GET BUSINESS ID
    $business_id = $subject->business_id;

    //GET SITEBUSINESS ITEM
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    //PHOTO OWNER, BUSINESS OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id == $subject->user_id || $can_edit == 1) {
      $canDelete = 1;
    } else {
      $canDelete = 0;
    }
    //CHECK FOR EDIT
    if (empty($canDelete)) {
      return false;
    }
    return array(
        'label' => 'Delete',
        'route' => 'sitebusiness_imagephoto_specific',
        'class' => 'ui-btn-danger smoothbox',
        'params' => array(
            'action' => 'remove',
            'photo_id' => $subject->getIdentity(),
            'album_id' => $album_id,
            'business_id' => $business_id,
        )
    );
  }

  public function onMenuInitialize_SitebusinessalbumPhotoShare($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    if (!SEA_PHOTOLIGHTBOX_SHARE) {
      return false;
    }
    return array(
        'label' => 'Share',
        'class' => 'ui-btn-action smoothbox',
        'route' => 'default',
        'params' => array(
            'module' => 'activity',
            'action' => 'share',
            'type' => $subject->getType(),
            'id' => $subject->getIdentity(),
        )
    );
  }

  public function onMenuInitialize_SitebusinessalbumPhotoReport($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    if (!SEA_PHOTOLIGHTBOX_REPORT) {
      return false;
    }
    return array(
        'label' => 'Report',
        'class' => 'ui-btn-action smoothbox',
        'route' => 'default',
        'params' => array(
            'module' => 'core',
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
        )
    );
  }

// $this->canEdit && SEA_PHOTOLIGHTBOX_MAKEPROFILEPHOTO
  public function onMenuInitialize_SitebusinessalbumPhotoProfile($row) {
    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $album_id = $subject->album_id;

    //GET BUSINESS ID
    $business_id = $subject->business_id;

    //GET SITEBUSINESS ITEM
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    //PHOTO OWNER, BUSINESS OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id == $subject->user_id || $can_edit == 1) {
      $canEdit = 1;
    } else {
      $canEdit = 0;
    }
    //CHECK FOR EDIT
    if (empty($canEdit) || !SEA_PHOTOLIGHTBOX_MAKEPROFILEPHOTO) {
      return false;
    }
    return array(
        'label' => 'Make Business Profile Photo',
        'route' => 'sitebusiness_imagephoto_specific',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module' => 'sitebusiness',
            'controller' => 'photo',
            'action' => 'make-business-profile-photo',
            'photo' => $subject->getGuid(),
            'business_id' => $business_id,
        )
    );
  }
}
?>