<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusinessintegration
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2012-31-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessintegration_Form_Admin_Global extends Engine_Form {

  // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
  public $_SHOWELEMENTSBEFOREACTIVATE = array(
      'submit_lsetting', 'environment_mode'
  );

  public function init() {

    $this->setTitle('Global Settings')
            ->setDescription('These settings affect all members in your community.');

    $apiSettings = Engine_Api::_()->getApi('settings', 'core');

    $this->addElement('Text', 'sitebusinessintegration_lsettings', array(
        'label' => 'Enter License key',
        'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessintegration.lsettings'),
    ));

    $global_settings_file = APPLICATION_PATH . '/application/settings/general.php';
    if (file_exists($global_settings_file)) {
      $generalConfig = include $global_settings_file;
    } else {
      $generalConfig = array();
    }
    if ((!empty($generalConfig['environment_mode']) ) && ($generalConfig['environment_mode'] != 'development')) {
      $this->addElement('Checkbox', 'environment_mode', array(
          'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few businesses of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
          'description' => 'System Mode',
//          'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    $this->addElement('Button', 'submit_lsetting', array(
        'label' => 'Activate Your Plugin Now',
        'type' => 'submit',
        'ignore' => true
    ));

    $sitestoreproductEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreproduct');
    $sitepageEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepage');
    $sitereviewEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereview');
    $sitereviewlistingtypeEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereviewlistingtype');
    $listEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('list');

    if (!empty($sitepageEnabled) && (!empty($sitereviewEnabled) || !empty($listEnabled))) {
      $title = "Addable Content";
      $options1 = "Their own Content";
      $options2 = "Business Admins’ Content";
      $options3 = "All Content";
      $Description = "Choose the contents that would be available to Business Admins for adding to their Businesses.";
    } elseif (!empty($sitereviewEnabled) || !empty($listEnabled)) {
      $title = "Addable Content";
      $options1 = "Their own Content";
      $options2 = "Business Admins’ Content";
      $options3 = "All Content";
      $Description = "Choose the contents that would be available to Business Admins for adding to their Businesses.";
    } elseif ($sitepageEnabled) {
      $title = "Addable Content";
      $options1 = "Their own Content";
      $options2 = "Business Admins’ Content";
      $options3 = "All Content";
      $Description = "Choose the contents that would be available to Business Admins for adding to their Businesses.";
    }

    $this->addElement('Radio', 'sitebusinessint_listing_view', array(
        'label' => "Apply Directory Item / Business View Privacy",
        'description' => 'Do you want to apply directory item / business’s view privacy on the addable content? [Note: This setting will not work, if you choose "All Content" from the “Addable Content” setting.]',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => $apiSettings->getSetting('sitebusinessint.listing.view', 0),
    ));

    if (!empty($options1) && !empty($options2) && !empty($options3)) {
      $this->addElement('Radio', 'sitebusiness_addable_integration', array(
          'label' => "$title",
          'description' => "$Description",
          'multiOptions' => array(
              1 => "$options1",
              2 => "$options2",
              0 => "$options3"
          ),
          'value' => $apiSettings->getSetting('sitebusiness.addable.integration', 1),
      ));
    }

    if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('document')) {
      $this->addElement('Radio', 'sitebusiness_document_integration', array(
          'label' => 'Adding Documents',
          'description' => 'Do you want to enable adding of Documents from "Documents / Scribd iPaper Plugin" to Directory Items / Businesses?',
          'multiOptions' => array(
              1 => 'Yes',
              0 => 'No'
          ),
          'value' => $apiSettings->getSetting('sitebusiness.document.integration', 0),
      ));
    }

    if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroup')) {
      $this->addElement('Radio', 'sitebusiness_group_integration', array(
          'label' => 'Adding Groups',
          'description' => 'Do you want to enable adding of Groups from "Groups / Communities Plugin" to Directory Items / Businesses?',
          'multiOptions' => array(
              1 => 'Yes',
              0 => 'No'
          ),
          'value' => $apiSettings->getSetting('sitebusiness.group.integration', 0),
      ));
    }

    if (!empty($listEnabled)) {
      $this->addElement('Radio', 'list_integration', array(
          'label' => 'Adding Listings',
          'description' => "Do you want to enable adding of Listings from “Listings / Catalog Showcase Plugin” to Directory Items / Businesses?",
          'multiOptions' => array(
              1 => 'Yes',
              0 => 'No'
          ),
          'value' => $apiSettings->getSetting('list.integration', 0),
      ));
    }

    if (!empty($sitepageEnabled)) {
      $this->addElement('Radio', 'sitebusiness_page_integration', array(
          'label' => 'Adding Pages',
          'description' => 'Do you want to enable adding of Pages from "Directory / Pages Plugin" to Directory Items / Businesses?',
          'multiOptions' => array(
              1 => 'Yes',
              0 => 'No'
          ),
          'value' => $apiSettings->getSetting('sitebusiness.page.integration', 0),
      ));
    }

    if (!empty($sitestoreproductEnabled)) {
      $this->addElement('Radio', 'sitebusiness_storeproduct_integration', array(
          'label' => 'Adding Products',
          'description' => 'Do you want to enable adding of Store Products from "Stores / Marketplace - Ecommerce Plugin" to Directory Items / Businesses?',
          'multiOptions' => array(
              1 => 'Yes',
              0 => 'No'
          ),
          'value' => $apiSettings->getSetting('sitebusiness.storeproduct.integration', 0),
      ));
    }

    if (!empty($sitereviewEnabled) && !empty($sitereviewlistingtypeEnabled)) {
      $pluginName = 'Multiple Listing Types Plugin';
    } else {
      $pluginName = 'Multiple Listing Types Plugin Core (Reviews & Ratings Plugin)';
    }

    if (!empty($sitereviewEnabled)) {

      $listingTypeTable = Engine_Api::_()->getDbTable('listingtypes', 'sitereview');
      $listingTypeTableName = $listingTypeTable->info('name');

      $select = $listingTypeTable->select()->from($listingTypeTableName, array('title_singular', 'listingtype_id'));
      $listingTypeDatas = $listingTypeTable->fetchAll($select)->toArray();

      // VALUE SAME FOR GROUP, PAGE AND BUSINESS ERROR
      $mixSettingsResults = Engine_Api::_()->getDbtable( 'mixsettings' , 'sitebusinessintegration')->getIntegrationItems(null, $isDashboard = true);
      $mixSettingsArray = array();
      foreach ($mixSettingsResults as $result) {
        $mixSettingsArray[] = $result['resource_type'] . ($result['listingtype_id'] ? : '');
      }
      // VALUE SAME FOR GROUP, PAGE AND BUSINESS ERROR

      foreach ($listingTypeDatas as $key) {
        $this->addElement('Radio', "sitereview_listing_" . $key['listingtype_id'], array(
            'label' => "Adding " . $key['title_singular'] . " Listings",
            'description' => 'Do you want to enable adding of Product Listings from "' . $pluginName . '" to Directory Items / Businesses?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No',
            ),
            // 'value' => $apiSettings->getSetting("sitereview.listing." . $key['listingtype_id'], 0),
            'value' => in_array('sitereview_listing' . $key['listingtype_id'], $mixSettingsArray), 
        ));
        // CUSTOM WORK FOR SEPARATNG ADDING AND LINKING OF LISTING
        $this->addElement('Radio', "sitereview_listing_link" . $key['listingtype_id'], array(
          'label' => "Linking " . $key['title_singular'] . " Listings",
          'description' => 'Do you want to enable linking of already created '.$key['title_singular'].' Listings from "' . $pluginName . '" to Directory Items / Pages?',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No',
            ),
          // 'value' => $apiSettings->getSetting("sitereview.listing.link" . $key['listingtype_id'], 0),
            'value' => in_array('sitereview_listinglink' . $key['listingtype_id'], $mixSettingsArray), 
          ));
        // CUSTOM WORK FOR SEPARATNG ADDING AND LINKING OF LISTING
      }
    }

    $this->addElement('Button', 'submit', array(
        'label' => 'Save Changes',
        'type' => 'submit',
        'ignore' => true
    ));
  }

}