<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusinessmember
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Roles.php 2013-03-18 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessmember_Model_DbTable_Roles extends Engine_Db_Table {

  protected $_rowClass = 'Sitebusinessmember_Model_Role';

  /**
   * Return category
   *
   * @param int $business_id
   */
  public function getRolesAssoc($business_id = null) {

    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    $manageCategorySettings = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessmember.category.settings', 1);

    $select = $this->select()
            ->from($this, array('role_id', 'role_name'));

    if ($manageCategorySettings == 1) {
      $select->where('is_admincreated =?', 1)
            ->where('business_category_id =?', $sitebusiness->category_id);
    } elseif ($manageCategorySettings == 2) {
      $select->where('business_id =?', $business_id)
            ->where('is_admincreated =?', 0)
            ->where('business_category_id =?', $sitebusiness->category_id);
    } elseif ($manageCategorySettings == 3) {
      $is_admincreated = array("0" => 0, "1" => 1);
      $business_id = array("0" => 0, "1" => $business_id);
      $select->where($this->info('name') . '.business_id IN (?)', (array) $business_id)
						->where($this->info('name') . '.is_admincreated IN (?)', (array) $is_admincreated)
						->where('business_category_id =?', $sitebusiness->category_id);
    }

    $select_category = $select->order('role_name ASC')->query();

    $data = array();
    foreach ($select_category->fetchAll() as $category) {
      $data[$category['role_id']] = $category['role_name'];
    }

    return $data;
  }

  /**
   * Return category name
   *
   * @param int $role_id
   */
  public function getRoleName($role_id) {

    $tableMemberCategory = $this->info('name');
    $select = $this->select()
            ->from($tableMemberCategory, array('role_name'))
            ->where('role_id = ?', $role_id);
    return $select->query()->fetchColumn();
  }

  /**
   * Return category data.
   *
   */
  public function getSiteAdminRoles($params=array(), $adminParams = null) {

    $select = $this->select();

    if (isset($params['business_category_id']) && !empty($params['business_category_id'])) {
      $select->from($this->info('name'), 'role_id');
      $select->where('business_category_id =?', $params['business_category_id']);
    } else {
      $select->from($this, array('role_id', 'role_name', 'business_category_id'));
    }
    if (isset($params['role_ids']) && $params['role_ids'])
      $select->where('role_id IN(?)', (array) $params['role_ids']);

    $select->where('is_admincreated =?', 1);
    $select_category = $select->order('business_category_id DESC')->query();

    if (isset($params['business_category_id']) && !empty($params['business_category_id'])) {
      $data = $select_category->fetchAll(Zend_Db::FETCH_COLUMN);
    } else {
      $data = array();
      foreach ($select_category->fetchAll() as $category) {
				if ($adminParams = 'adminParams') {
						//$data[$category['role_id']] = $category['role_name'];
						$tempArray["role_id"] = $category['role_id'];
						$tempArray["role_name"] = $category['role_name'];
						$tempArray["business_category_id"] = $category['business_category_id'];
						$data[] = $tempArray;
				} 
				else {
					$data[$category['role_id']] = $category['role_name'];
				}
      } 
    }
    return $data;
  }

  /**
   * Return businessadmins categories.
   *
   * @param int $business_id
   */
  public function getBusinessadminsRoles($business_id) {

    $data = $select = $this->select()
            ->from($this->info('name'), 'role_id')
            ->where('business_id =?', $business_id)
            ->query()
            ->fetchAll(Zend_Db::FETCH_COLUMN);
//     foreach( $select_category->fetchAll() as $category ) {
//       $data[] = $category['role_id'];
//     }

    return $data;
  }

  /**
   * Roles parameters
   *
   * @param Array $categoryIdsArray
   * @return Review parameters
   */
  public function rolesParams($categoryIdsArray = array(), $is_admincreated=1, $roleIdsArray = array(), $param = null, $business_id = null) {

    if (empty($categoryIdsArray)) {
      return null;
    }

    //MAKE QUERY
    $select = $this->select()
            ->from($this->info('name'), array('role_id', 'role_name'));

    if ($roleIdsArray) {
      $select->where("role_id IN (?)", (array) $roleIdsArray);
    }
    if ($categoryIdsArray) {
      $select
              ->where("business_category_id IN (?)", (array) $categoryIdsArray);
    }
    
    if(isset($business_id) && !empty($business_id)) {
        $business_id = array("0" => 0, "1" => $business_id);
        $select->where("business_id IN (?)", (array) $business_id);
    }
    if ($is_admincreated)
      $select->where("is_admincreated =?", 1);
    $select->order("role_id");

    $results = $this->fetchAll($select);

    if (!empty($param)) {
      $data = array();
      foreach ($results as $result) {
        $data[$result['role_id']] = $result['role_name'];
      }
      if (in_array('0', $roleIdsArray)) {
        $data['-1'] = 'Un-categorized';
      }
      return $data;
    } else {
      //RETURN RESULTS
      return $results;
    }
  }

}