<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusinessmember
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2013-03-18 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitebusinessmember_Plugin_Menus {

  public function canViewMembers() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessmember.member.show.menu', 1)) {
      return false;
    }
    $userstable = Engine_Api::_()->getDbtable('users', 'user');
    $userstableName = $userstable->info('name');
    
    $memberTable = Engine_Api::_()->getDbtable('membership', 'sitebusiness');
    $membershipTableName = $memberTable->info('name');
    $businessTable = Engine_Api::_()->getDbtable('business', 'sitebusiness');
    $businessTableName = $businessTable->info('name');
    $select = $memberTable->select()
                    ->setIntegrityCheck(false)
                    ->from($businessTableName, array('COUNT(*) as count'))
                    ->join($membershipTableName, $membershipTableName . '.resource_id = ' . $businessTableName . '.business_id', array(''))
                    ->join($userstableName, $userstableName . '.user_id = ' . $membershipTableName . '.user_id', array(''))
                    ->where($membershipTableName .'.active = ?', 1)
                    ->where($businessTableName . '.closed = ?', '0')
                    ->where($businessTableName . '.approved = ?', '1')
                    ->where($businessTableName . '.search = ?', '1')
                    ->where($businessTableName . '.declined = ?', '0')
                    ->where($businessTableName . '.draft = ?', '1');
    if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
      $select->where($businessTableName . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    } 
    $row = $select->query()->fetchColumn();
    //$count = count($row);
    if (empty($row)) {
      return false;
    }
    return true;
  }
  
  public function onMenuInitialize_SitebusinessGutterJoin($row) {

    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    if (empty($sitebusiness->member_approval)) {
			return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }
    
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if ($viewer_id == $sitebusiness->owner_id) {
			return false;
    }
    if (empty($viewer_id)) { 
			return false;
    }
    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     } 
    // PACKAGE BASE PRIYACY END

    $hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id);

    if (!empty($hasMembers)) {
      return false;
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }
  
  public function onMenuInitialize_SitebusinessGutterLeave($row) {

    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if (empty($viewer_id)) { 
			return false;
    }
    if ($viewer_id == $sitebusiness->owner_id) {
			return false;
    }
    
    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     }
    // PACKAGE BASE PRIYACY END
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }
    
    $isBusinessAdmins = Engine_Api::_()->getDbtable('manageadmins', 'sitebusiness')->isBusinessAdmins($viewer_id, $sitebusiness->getIdentity());
    if (!empty($isBusinessAdmins)) {
			return false;
    }

		$hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = "Leave");
		
    if (empty($hasMembers)) {
      return false;
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }
  
  public function onMenuInitialize_SitebusinessGutterRequest($row) {

    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if (empty($viewer_id)) { 
			return false;
    }
    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    if (!empty($sitebusiness->member_approval)) {
			return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }
    
    if ($viewer_id == $sitebusiness->owner_id) {
			return false;
    }
    
    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     }
    // PACKAGE BASE PRIYACY END

		$hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id);
    if (!empty($hasMembers)) {
      return false;
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }
  
  public function onMenuInitialize_SitebusinessGutterCancel($row) {

    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if (empty($viewer_id)) { 
			return false;
    }
    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    if (!empty($sitebusiness->member_approval)) {
			return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }

    if ($viewer_id == $sitebusiness->owner_id) {
			return false;
    }

    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     }
    // PACKAGE BASE PRIYACY END

		$hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Cancel');
    if (empty($hasMembers)) {
      return false;
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }
  
  public function onMenuInitialize_SitebusinessGutterInvite($row) {

    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    
		//CHECK THAT WE HAVE TO SHOW MANAGE ADMIN LINK OR NOTE
    $businessAdmin = Engine_Api::_()->getDbTable('manageadmins', 'sitebusiness')->isBusinessAdmins($viewer_id, $sitebusiness->getIdentity());
    if (!empty($businessAdmin)) {
			return false;
    }
    
    $hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Invite');
    if (empty($hasMembers)) {
      return false;
    }

    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     }
    // PACKAGE BASE PRIYACY END

    //START MANAGE-ADMIN CHECK
    if (!empty($sitebusiness->member_invite)) {
      return false;
// 			$isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
// 			if (empty($isManageAdmin)) {
// 				return false;
// 			}
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }
  
  public function onMenuInitialize_SitebusinessGutterInviteBusinessadmin($row) {

    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    
		//CHECK THAT WE HAVE TO SHOW MANAGE ADMIN LINK OR NOTE
    $businessAdmin = Engine_Api::_()->getDbTable('manageadmins', 'sitebusiness')->isBusinessAdmins($viewer_id, $sitebusiness->getIdentity());
    if (empty($businessAdmin)) {
			return false;
    }
    
    $hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Invite');
    if (empty($hasMembers)) {
      return false;
    }
    
    $automaticallyJoin = Engine_Api::_()->getApi('settings', 'core')->getSetting( 'businessmember.automatically.addmember', 1);
    if (empty($automaticallyJoin) && empty($sitebusiness->member_approval)) {
			return false;
    }
    
    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     }
    // PACKAGE BASE PRIYACY END
    
    //START MANAGE-ADMIN CHECK
    if (!empty($sitebusiness->member_invite)) {
			$isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
			if (empty($isManageAdmin)) {
				return false;
			}
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }

  public function onMenuInitialize_SitebusinessGutterRespondinvite($row) {

    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    if ($viewer_id == $sitebusiness->owner_id) {
			return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }

    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusiness)) {
			return false;
		}
//     if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
//       if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitebusinessmember")) {
//         return false;
//       }
//     } else {
//       $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'smecreate');
//       if (empty($isBusinessOwnerAllow)) {
//         return false;
//       }
//     }
    // PACKAGE BASE PRIYACY END
		
		$hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Accept');
    if (empty($hasMembers)) {
      return false;
    }

    $hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Reject');
    if (empty($hasMembers)  || empty($hasMembers->resource_approved)) {
      return false;
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    return $params;
  }
   	
	public function onMenuInitialize_SitebusinessGutterRespondmemberinvite($row) {

    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
      return false;
    }

    $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
    if ($viewer_id == $sitebusiness->owner_id) {
			return false;
    }
    
    $sitebusinessmemberMenuActive = Zend_Registry::isRegistered('sitebusinessmemberMenuActive') ? Zend_Registry::get('sitebusinessmemberMenuActive') : null;
    if( empty($sitebusinessmemberMenuActive) ) {
      return false;
    }
    
    $automaticallyJoin = Engine_Api::_()->getApi('settings', 'core')->getSetting( 'businessmember.automatically.addmember', 1);
    if (!empty($automaticallyJoin) && !empty($sitebusiness->member_approval)) {
			return false;
    }
    
    // PACKAGE BASE PRIYACY START
    $allowBusiness = Engine_Api::_()->sitebusiness()->allowInThisBusiness($sitebusiness, "sitebusinessmember", 'smecreate');
    if (empty($allowBusinesses)) {
			return false;
		}
    // PACKAGE BASE PRIYACY END
		
		$hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Accept');
    if (empty($hasMembers)) {
      return false;
    }

    $hasMembers = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->hasMembers($viewer_id, $sitebusiness->business_id, $params = 'Reject');
    if (empty($hasMembers)  || empty($hasMembers->resource_approved)) {
      return false;
    }

    // Modify params
    $params = $row->params;
    $params['params']['business_id'] = $sitebusiness->getIdentity();
    $params['params']['param'] = 'Invite';
    return $params;
  }
  
  	public function onMenuInitialize_SitebusinessGutterManageJoinedMembers($row) {

		//GETTING THE VIEWER
		$viewer = Engine_Api::_()->user()->getViewer();
		
		$joineBusinesses = Engine_Api::_()->getDbtable('membership', 'sitebusiness')->getJoinBusinesses($viewer->getIdentity(), 'businessJoin');
    if ($joineBusinesses->getTotalItemCount() == 0) {
      return false;
    }
    
		$coreContentTable = Engine_Api::_()->getDbtable('content', 'core');
		$coreContentTableName = $coreContentTable->info('name');

		$select = new Zend_Db_Select($coreContentTable->getAdapter());
		$select->from($coreContentTableName, 'content_id')->where("name = ?", 'sitebusiness.profile-joined-sitebusiness');
		$data = $select->query()->fetchColumn();
		if(empty($data)) {
			return false;
		}

		if ($viewer->getIdentity()) {
			//Return EDIT LINK
			return array(
				'label' => $row->label,
				'route' => 'user_profile',
				'params' => array(
					'id' => $viewer->getIdentity(),
					'tab' => $data
				)
			);
		}
	}
	
	public function sitebusinessGutterNotificationSettings($row) {

		//RETURN FALSE IF SUBJECT IS NOT SET
		if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
				return false;
		}

		//GET VIEWER
		$viewer = Engine_Api::_()->user()->getViewer();

		//GET EVENT SUBJECT
		$sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

		$row = Engine_Api::_()->getDbTable('membership', 'sitebusiness')->getRow($sitebusiness, $viewer);

		if (!$row)
				return false;
    if(!$row->active || !$row->user_approved)
			  return false;

		return array(
				'class' => 'buttonlink icon_sitebusiness_notification smoothbox',
				'route' => "sitebusinessmember_approve",
				'action' => 'notification-settings',
				'params' => array(
						'member_id' => $row->member_id,
						'action' => 'notification-settings'
				),
		);
	}
}