<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessoffer_Plugin_Menus {

  public function canViewOffers() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessoffer.offer.show.menu', 1)) {
      return false;
    }

    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    
    
    $table = Engine_Api::_()->getDbtable('offers', 'sitebusinessoffer');
    $rName = $table->info('name');
    $table_businesses = Engine_Api::_()->getDbtable('business', 'sitebusiness');
    $rName_businesses = $table_businesses->info('name');
    $today = date("Y-m-d H:i:s");
    if (!empty($viewer_id)) {
      // Convert times
      $oldTz = date_default_timezone_get();
      date_default_timezone_set($viewer->timezone);
      $today = date("Y-m-d H:i:s");
      date_default_timezone_set($oldTz);
    }
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_businesses, array('photo_id', 'title as sitebusiness_title'))
                    ->join($rName, $rName . '.business_id = ' . $rName_businesses . '.business_id')
                    ->where("($rName.end_settings = 1 AND $rName.end_time >= '$today' OR $rName.end_settings = 0) ");

    $select = $select
                    ->where($rName_businesses . '.closed = ?', '0')
                    ->where($rName_businesses . '.approved = ?', '1')
                    ->where($rName_businesses . '.search = ?', '1')
                    ->where($rName_businesses . '.declined = ?', '0')
                    ->where($rName_businesses . '.draft = ?', '1');
    if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
      $select->where($rName_businesses . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }

  //SITEMOBILE BUSINESS ALBUM MENUS
  public function onMenuInitialize_SitebusinessofferAdd($row) {

    $can_create_offer = $this->commonChecks();

    //CHECKS FOR ADD OFFER
    if (empty($can_create_offer)) {
      return false;
    }

    $sitebusinessoffer = $this->getSitebusinessOfferObject();

    if (empty($sitebusinessoffer)) {
      return false;
    }

    $business_id = $sitebusinessoffer->business_id;
    return array(
        'label' => 'Add an Offer',
        'route' => 'sitebusinessoffer_general',
        'class'=>'ui-btn-action',
        'params' => array(
            'action' => 'create',
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessofferEdit($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    $can_create_offer = $this->commonChecks();

    //CHECKS FOR EDIT OFFER
    if (empty($can_create_offer)) {
      return false;
    }

    $sitebusinessoffer = $this->getSitebusinessOfferObject();

    if (empty($sitebusinessoffer)) {
      return false;
    }

    $business_id = $sitebusinessoffer->business_id;

    return array(
        'label' => 'Edit Offer',
        'route' => 'sitebusinessoffer_general',
        'class'=>'ui-btn-action',
        'params' => array(
            'action' => 'edit',
            'offer_id' => $subject->getIdentity(),
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessofferDelete($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    $can_create_offer = $this->commonChecks();

    //CHECKS FOR DELETE OFFER
    if (empty($can_create_offer)) {
      return false;
    }

    $sitebusinessoffer = $this->getSitebusinessOfferObject();

    if (empty($sitebusinessoffer)) {
      return false;
    }

    $business_id = $sitebusinessoffer->business_id;
    return array(
        'label' => 'Delete Offer',
        'route' => 'sitebusinessoffer_general',
        'class'=>'ui-btn-danger',
        'params' => array(
            'action' => 'delete',
            'offer_id' => $subject->getIdentity(),
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

//  public function onMenuInitialize_SitebusinessofferPrint($row) {
//
//    $subject = Engine_Api::_()->core()->getSubject();
//
//    $sitebusinessoffer = $this->getSitebusinessOfferObject();
//
//    if (empty($sitebusinessoffer)) {
//      return false;
//    }
//
//    $business_id = $sitebusinessoffer->business_id;
//    return array(
//        'label' => 'Print Offer',
//        'route' => 'sitebusinessoffer_general',
//        'target' => '_blank',
//        'params' => array(
//            'action' => 'print',
//            'offer_id' => $subject->getIdentity(),
//            'business_id' => $business_id
//        )
//    );
//  }

  public function onMenuInitialize_SitebusinessofferShare($row) {

    $subject = Engine_Api::_()->core()->getSubject();
    return array(
        'label' => 'Share',
        'route' => 'default',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module' => 'activity',
            'controller' => 'index',
            'action' => 'share',
            'id' => $subject->getIdentity(),
            'type' => 'sitebusinessoffer_offer',
        ),

    );
  }

  public function onMenuInitialize_SitebusinessofferReport($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    return array(
        'label' => 'Report',
        'route' => 'default',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module' => 'core',
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
        ),

    );
  }

  public function commonChecks() {

    //$viewer = Engine_Api::_()->user()->getViewer();

    $sitebusinessoffer = $this->getSitebusinessOfferObject();
    if (empty($sitebusinessoffer)) {
      return false;
    }
    $business_id = $sitebusinessoffer->business_id;
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    //START MANAGE-ADMIN CHECK
    $can_offer = 1;
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'offer');
    if (empty($isManageAdmin)) {
      $can_offer = 0;
    }

    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    $can_create_offer = '';
    //OFFER CREATION AUTHENTICATION CHECK
    if ($can_edit == 1 && $can_offer == 1) {
      $can_create_offer = 1;
    }

    return $can_create_offer;
  }

  public function getSitebusinessOfferObject() {
    $subject = Engine_Api::_()->core()->getSubject();
    $offer_id = $subject->getIdentity();
    $sitebusinessoffer = Engine_Api::_()->getItem('sitebusinessoffer_offer', $offer_id);

    if (empty($sitebusinessoffer)) {
      return false;
    }

    return $sitebusinessoffer;
  }

}
?>
