<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusinessreview
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Ratings.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessreview_Model_DbTable_Ratings extends Engine_Db_Table {

  protected $_rowClass = 'Sitebusinessreview_Model_Rating';

	/**
   * Return review ratings data
   *
   * @param Int review_id
   * @return Zend_Db_Table_Select
   */
	public function ratingsData($review_id) {
    $select = $this->select()
									->from($this->info('name'), array('reviewcat_id', 'rating'))
									->where("review_id = ?", $review_id);
    return $this->fetchAll($select)->toArray();
	}

  /**
   * Returns a rating datas according to business_id
   *
   * @param Int business_id
   * @return Zend_Db_Table_Select
   */
  public function ratingbyCategory($business_id) {

		//RETURN IF BUSINESS ID IS EMPTY
    if (empty($business_id)) {
      return;
    }

    $tableRatingName = $this->info('name');
    $tableCategory = Engine_Api::_()->getDbtable('reviewcats', 'sitebusinessreview');
    $tableCategoryName = $tableCategory->info('name');
    $select = $this
                    ->select()
                    ->setIntegrityCheck(false)
                    ->from($tableRatingName, array('AVG(rating) AS avg_rating'))
                    ->joinLeft($tableCategoryName, "$tableRatingName.reviewcat_id = $tableCategoryName.reviewcat_id", array('reviewcat_name'))
                    ->where($tableRatingName . ".rating != ?", 0)
                    ->where("business_id = ?", $business_id)
                    ->group($tableRatingName.'.reviewcat_id');
    return $this->fetchAll($select)->toArray();

  }

  /**
   * Returns a rating datas according to review_id
   *
   * @param Int review_id
   * @return Zend_Db_Table_Select
   */
  public function profileRatingbyCategory($review_id) {

		//RETURN IF REVIEW ID IS EMPTY
    if (empty($review_id)) {
      return;
    }

		//GET RATING TABLE NAME
    $tableRatingName = $this->info('name');

		//GET REVIEW PARAMETER TABLE INFO
    $tableCategory = Engine_Api::_()->getDbtable('reviewcats', 'sitebusinessreview');
    $tableCategoryName = $tableCategory->info('name');

		//MAKE QUERY
    $select = $this
                    ->select()
                    ->setIntegrityCheck(false)
                    ->from($tableRatingName, array('rating'))
                    ->joinLeft($tableCategoryName, "$tableRatingName.reviewcat_id = $tableCategoryName.reviewcat_id", array('reviewcat_name'))
                    ->where("review_id = ?", $review_id);

		//RETURN RESULTS
    return $this->fetchAll($select)->toArray();
  }

  /**
   * If business category is updated than update review and rating entries
   *
   * @param Int business_id, pre_cat_id, curr_cat_id
   */
  public function editBusinessCategory($business_id, $pre_cat_id, $curr_cat_id) {

		//DELETE ENTRIES BELONGS TO THIS BUSINESS ID
		$this->delete(array('reviewcat_id != ?' => 0, 'business_id = ?' => $business_id));

		//JUST UPDATE CATEGORY ID
		$this->update(array('category_id' => $curr_cat_id), array('category_id = ?' => $pre_cat_id, 'business_id = ?' => $business_id, 'reviewcat_id = ?' => 0));
  }

  /**
   * Update overall business rating
   *
   * @param Int business_id
   */
  public function businessRatingUpdate($business_id) {

		//RETURN IF BUSINESS ID IS EMPTY
    if (empty($business_id)) {
      return;
    }

    //UPDATE BUSINESS RATING AVERAGE IN BUSINESS TABLE
    $avg_rating = $this
                    ->select()
                    ->from($this->info('name'), array('AVG(rating) AS avg_rating'))
                    ->where("reviewcat_id = ?", 0)
                    ->where("business_id = ?", $business_id)
                    ->group('business_id')
										->query()
                    ->fetchColumn();

    //if (!empty($avg_rating)) {
      $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
      $sitebusiness->rating = round($avg_rating, 4);
      $sitebusiness->save();
    //}
  }

  /**
   * Return rating corrosponding to business_id and review_id
   *
   * @param Int business_id, review_id
   */
	public function getRating($business_id, $review_id) {

		//FETCH DATA
    $rating = $this->select()
                    ->from($this->info('name'), 'rating')
                    ->where('business_id = ?', $business_id)
                    ->where('review_id = ?', $review_id)
                    ->where('reviewcat_id = ?', 0)
										->query()
                    ->fetchColumn();

		//RETURN DATA
    return $rating;
	}
}
?>