<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessvideo_Plugin_Menus {

  public function canViewVideos() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessvideo.video.show.menu', 1)) {
      return false;
    }

    $table = Engine_Api::_()->getDbtable('videos', 'sitebusinessvideo');
    $rName = $table->info('name');
    $table_businesses = Engine_Api::_()->getDbtable('business', 'sitebusiness');
    $rName_businesses = $table_businesses->info('name');
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_businesses, array('photo_id', 'title as sitebusiness_title'))
                    ->join($rName, $rName . '.business_id = ' . $rName_businesses . '.business_id')
                    ->where($rName . '.status = ?', '1')
                    ->where($rName .'.search = ?', 1);

    $select = $select
                    ->where($rName_businesses . '.closed = ?', '0')
                    ->where($rName_businesses . '.approved = ?', '1')
                    ->where($rName_businesses . '.search = ?', '1')
                    ->where($rName_businesses . '.declined = ?', '0')
                    ->where($rName_businesses . '.draft = ?', '1');
    if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
      $select->where($rName_businesses . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }

  //SITEMOBILE BUSINESS VIDEO MENUS
  public function onMenuInitialize_SitebusinessvideoAdd($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitebusinessvideo = Engine_Api::_()->getItem('sitebusinessvideo_video', $video_id);
    $business_id = $sitebusinessvideo->business_id;
    if (empty($sitebusinessvideo)) {
      return false;
    }
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'svcreate');
    if (empty($isManageAdmin)) {
      $can_create = 0;
    } else {
      $can_create = 1;
    }

    if (empty($can_create)) {
      return false;
    }
    return array(
        'label' => 'Add Video',
        'route' => 'sitebusinessvideo_create',
        'class' => 'ui-btn-action',
        'params' => array(
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessvideoEdit($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitebusinessvideo = Engine_Api::_()->getItem('sitebusinessvideo_video', $video_id);
    $business_id = $sitebusinessvideo->business_id;
    if (empty($sitebusinessvideo)) {
     return false;
    }

    $check = $this->commonChecks();
    if (empty($check)) {
      return false;
    }
    return array(
        'label' => 'Edit Video',
        'route' => 'sitebusinessvideo_edit',
        'class' => 'ui-btn-action',
        'params' => array(
            'video_id' => $video_id,
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessvideoDelete($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitebusinessvideo = Engine_Api::_()->getItem('sitebusinessvideo_video', $video_id);
    $business_id = $sitebusinessvideo->business_id;
    if (empty($sitebusinessvideo)) {
      return false;
    }

    $check = $this->commonChecks();
    if (empty($check)) {
      return false;
    }
    return array(
        'label' => 'Delete Video',
        'route' => 'sitebusinessvideo_delete',
        'class' => 'ui-btn-danger',
        'params' => array(
            'video_id' => $video_id,
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function commonChecks() {
    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitebusinessvideo = Engine_Api::_()->getItem('sitebusinessvideo_video', $video_id);
    $business_id = $sitebusinessvideo->business_id;
    if (empty($sitebusinessvideo)) {
      return false;
    }
    $getPackagevideoView = Engine_Api::_()->sitebusiness()->getPackageAuthInfo('sitebusinessvideo');
    $video = empty($getPackagevideoView) ? null : $sitebusinessvideo;

    $owner_id = $video->owner_id;
    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    if ($owner_id != $viewer_id && empty($can_edit)) {
      return false;
    } else {
      return true;
    }
  }
  
  public function onMenuInitialize_SitebusinessvideoReport(){
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if(!$viewer_id){
     return false;    
    }
    $subject = Engine_Api::_()->core()->getSubject();
    if ($subject->getType() !== 'sitebusinessvideo_video') {
      throw new Video_Model_Exception('Whoops, not a video!');
    }

    return array(
        'label' => 'Report',
        'route' => 'default',
        'params' => array(
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
            'module' => 'core',
            'format' => 'smoothbox'
        )
    );
  }
  
  public function onMenuInitialize_SitebusinessvideoShare(){
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if(!$viewer_id){
     return false;
    }
    $subject = Engine_Api::_()->core()->getSubject();
    if ($subject->getType() !== 'sitebusinessvideo_video') {
      throw new Video_Model_Exception('Whoops, not a video!');
    }

    return array(
        'label' => 'Share',
        //'icon' => 'application/modules/Video/externals/images/delete.png',
        'route' => 'default',
        'params' => array(
            'controller' => 'index',
            'action' => 'share',
            'id' => $subject->getIdentity(),
            'type' => 'sitebusinessvideo_video',
            'module' => 'activity',
            'format' => 'smoothbox'
        )
    );
  }
}
?>