<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_Form_Create extends Engine_Form
{
	public function init(){

		$this->setTitle('Create New Contest')->setDescription("Compose your new contest below, then click 'Create Contest' to publish the contest.")->setAttrib('name', 'contests_create')->setAttrib('class', 'global_form global_form_popup');
		$user = Engine_Api::_()->user()->getViewer();

  	$categoryFiles = 'application/modules/Sitecontest/views/scripts/_category.tpl';
		$sub_categoryFiles = 'application/modules/Sitecontest/views/scripts/_sub_category.tpl';
		$setting = Engine_Api::_()->getApi('settings', 'core');

    $this->addElement('Text', 'title', array(
      'label' => 'Contest Title',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        new Engine_Filter_Censor(),
        'StripTags',
        new Engine_Filter_StringLength(array('max' => '63'))
      ),
      'autofocus' => 'autofocus',
    ));
	   
		// Element: contest_url
    $contest_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('contest_id', null);

    $link = $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('contest_url' => Zend_Registry::get('Zend_Translate')->_('CONTEST-NAME')), 'sitecontest_entry_view');
    
    $description = sprintf(Zend_Registry::get('Zend_Translate')->_("This will be the end of your contest URL. It should be indicative of the title and can contain alphabets, numbers, underscores and  dashes only. Its length should be in the range of 3-255 characters. The complete URL of your contest will be: %s"), "<span id='contest_url_address'>http://$link</span>");

    $this->addElement('Text', 'contest_url', array(
      'label' => 'URL',
      'description' => $description,
      'autocomplete' => 'off',
      'required' => true,
      'allowEmpty' => false,
      'validators' => array(
          array('NotEmpty', true),
          // array('Alnum', true),
          array('StringLength', true, array(3, 255)),
          array('Regex', true, array('/^[a-zA-Z0-9-_]+$/')),
          array('Db_NoRecordExists', true, array(Engine_Db_Table::getTablePrefix() . 'sitecontest_contests', 'contest_url'), array('field' => 'contest_id', 'value != ?' => 1))
      ),
      'filters' => array(
      'StripTags',
      new Engine_Filter_Censor(),
    	),
    ));
    $this->contest_url->getDecorator('Description')->setOptions(array('placement' => 'APPEND', 'escape' => false));
    $this->contest_url->getValidator('NotEmpty')->setMessage('Please enter a valid page url.', 'isEmpty');
    $this->contest_url->getValidator('Db_NoRecordExists')->setMessage('Someone has already picked this page url, please use another one.', 'recordFound');
    $this->contest_url->getValidator('Regex')->setMessage('Profile addresses must start with a letter.', 'regexNotMatch');
    $this->addElement('dummy', 'contest_url_msg', array('value' => 0));	

		$this->addElement('Text', 'tags', array(
	      'label'=>'Tags (Keywords)',
	      'autocomplete' => 'off',
	      'description' => 'Separate tags with commas.',
	      'filters' => array(
	        'StripTags',
	        new Engine_Filter_Censor(),
	      ),
	    ));
    $this->tags->getDecorator('Description')->setOption('placement', 'append');
		
		$available = array(
		'text'  => 'Text',
		'photo' => 'Photo',
		'music' => 'Music',
		'video' => 'Video',
		);
		$mediaOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitecontest_cont', $user, 'media_type');
		$mediaOptions = array_intersect_key($available, array_flip($mediaOptions));
		$array = array(''=>'');
		$mediaOptions = array_merge($array,$mediaOptions);

    if( !empty($mediaOptions) && count($mediaOptions) > 0 ) {
	        $this->addElement('Select', 'media_type', array(
	      		'label' => 'Media Type',
	      		'required' => true,
	            'description' => 'Choose the Media Type for contest here.',
	            'multiOptions' => $mediaOptions,
	            'value' => key($mediaOptions),
	        ));
        $this->media_type->getDecorator('Description')->setOption('placement', 'append');
    }
    $category = Engine_Api::_()->getItemTable('sitecontest_category')->fetchAll()->toArray();

		$categories["-1"] = null;
		foreach ($category as $key => $value) { 
			if($value['cat_dependency'] == 0 && $value['subcat_dependency'] == 0)
			$categories[$value['category_id']] = $value['category_name'];
		}
		$this->addElement('Select', 'category_id', array(
			'label' => 'Category',
			'multiOptions' => $categories,
			'required' => true,
			'id' => 'category-wrapper1',
			'onchange' => "sitecontest_addOptions(this.value); var profile_type = getProfileType($(this).value);
			if(profile_type == 0) profile_type = '';
			$('0_0_1').value = profile_type;
			changeFields($('0_0_1'));",
		)); 

		$this->addElement('Select', 'subcategory_id', array(
			'label' => 'Sub-Category',
			'RegisterInArrayValidator' => false,
			'allowEmpty' => true,
			'required' => false,
			'decorators' => array(array('ViewScript', array(
			'viewScript' => $categoryFiles,
			'class' => 'form element'))),
		));

		$this->addElement('Select', 'subsubcategory_id', array(
			'label' => '3rd level Category',
			'RegisterInArrayValidator' => false,
			'allowEmpty' => true,
			'required' => false,
			'decorators' => array(array('ViewScript', array(
			'viewScript' => $sub_categoryFiles,
			'class' => 'form element'))),
		));
                
		if (!$this->_item) {
			$customFields = new Sitecontest_Form_Custom_Standard(array(
			'item' => 'sitecontest_cont',
			'decorators' => array(
			'FormElements'
			)));
		} else {
			$customFields = new Sitecontest_Form_Custom_Standard(array(
			'item' => $this->getItem(),
			'decorators' => array(
			'FormElements'
			)));
		}

		$customFields->removeElement('submit');

		$customFields->getElement("0_0_1")
			->clearValidators()
			->setRequired(false)
			->setAllowEmpty(true);

		$this->addSubForms(array(
		'fields' => $customFields
		));

		$this->addElement('File', 'photo', array(
	      'label' => 'Main Photo',
	      'required' => true,
    ));
    $this->photo->addValidator('Extension', false, 'jpg,png,gif,jpeg');


	  $this->addElement('TinyMce', 'description', array(
    	'label'=>'Description',
      'allowEmpty' => false,
      'filters' => array(
        new Engine_Filter_Censor(),
      ),
    ));

    // Start time
    $contest_start = new Engine_Form_Element_CalendarDateTime('start_datetime');
    $contest_start->setLabel("Start Date for Contest");
    $contest_start->setAllowEmpty(false);
    $contest_start->setRequired(true);
    $contest_start->setOptions(array('dateFormat' => 'dmy'));
    $this->addElement($contest_start);
    $starttime = time();
      $oldTz = date_default_timezone_get();
      date_default_timezone_set($user->timezone);
      $contest_start->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
      date_default_timezone_set($oldTz);

    // End time
    $contest_end = new Engine_Form_Element_CalendarDateTime('end_datetime');
    $contest_end->setLabel("End Date for Contest");
    $contest_end->setAllowEmpty(false);
    $contest_end->setRequired(true);
    $contest_end->setOptions(array('dateFormat' => 'dmy'));
     
    $this->addElement($contest_end);
    $starttime = time();
    $oldTz = date_default_timezone_get();
    date_default_timezone_set($user->timezone);
    $contest_end->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
    date_default_timezone_set($oldTz);

    // Start time
    $entry_start = new Engine_Form_Element_CalendarDateTime('entry_start_datetime');
    $entry_start->setLabel("Start Date for Entry Submission");
    $entry_start->setAllowEmpty(false);
    $entry_start->setRequired(true);
    $entry_start->setOptions(array('dateFormat' => 'dmy'));
    $this->addElement($entry_start);
    $starttime = time();
    $oldTz = date_default_timezone_get();
    date_default_timezone_set($user->timezone);
    $entry_start->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
    date_default_timezone_set($oldTz);

    // End time
    $entry_end = new Engine_Form_Element_CalendarDateTime('entry_end_datetime');
    $entry_end->setLabel("End Date for Entry Submission");
    $entry_end->setAllowEmpty(false);
    $entry_end->setRequired(true);
    $entry_end->setOptions(array('dateFormat' => 'dmy'));
      
    $this->addElement($entry_end);
    $starttime = time();
    $oldTz = date_default_timezone_get();
    date_default_timezone_set($user->timezone);
    $entry_end->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
    date_default_timezone_set($oldTz);

    // Start time
    $vote_start = new Engine_Form_Element_CalendarDateTime('vote_start_datetime');
    $vote_start->setLabel("Start Date for Voting");
    $vote_start->setAllowEmpty(false);
    $vote_start->setRequired(true);
    $vote_start->setOptions(array('dateFormat' => 'dmy'));
      
    $this->addElement($vote_start);
    $starttime = time();
    $oldTz = date_default_timezone_get();
    date_default_timezone_set($user->timezone);
    $vote_start->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
    date_default_timezone_set($oldTz);

    // End time
    $vote_end = new Engine_Form_Element_CalendarDateTime('vote_end_datetime');
    $vote_end->setLabel("End Date for Voting");
    $vote_end->setAllowEmpty(false);
    $vote_end->setRequired(true);
    $vote_end->setOptions(array('dateFormat' => 'dmy'));
      
    $this->addElement($vote_end);
    $starttime = time();
    $oldTz = date_default_timezone_get();
    date_default_timezone_set($user->timezone);
    $vote_end->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
    date_default_timezone_set($oldTz);

	    
		$this->addElement('Radio', 'vote_show', array(
      'label' => 'When Votes will be displayed',
      'description' => 'It shows the voting of the contest.',
      'multiOptions' => array(
        1 => 'After the contest has been ended',
        0 => 'Always Show'
      ),
      'value' => 1,
  	));

    // Result Announce Date
    $result_show = new Engine_Form_Element_CalendarDateTime('result_datetime');
    $result_show->setLabel("Choose Result Announcement Date");
    $result_show->setAllowEmpty(false);
    $result_show->setRequired(true); 
    $result_show->setOptions(array('dateFormat' => 'dmy'));
    
    $this->addElement($result_show);
    $starttime = time();
    $oldTz = date_default_timezone_get();
    date_default_timezone_set($user->timezone);
    $result_show->setValue(date("Y-m-d H:i:s", ($starttime + 3600)));
    date_default_timezone_set($oldTz);
      
    $chkaward = $setting->getSetting('sitecontest.contest.prize');
    if (!empty($chkaward)) {
		$this->addElement('TinyMce', 'first_award_prize', array(
  		'label'=>'1st Award',
  		'description' => 'Enter First Award of the Contest.',
        'required' => true,
	    'allowEmpty' => false,
	    'filters' => array(
	        new Engine_Filter_Censor(),
      ),
	    ));			
		}
 
		$checkrule = $setting->getSetting('sitecontest.contest.show.rule');
  	$mandatory_rule = $setting->getSetting('sitecontest.contest.show.rules.imp');
  	if($mandatory_rule == 1){
    	$set = true;
    } else {
    	$set = false;
    }
    if (!empty($checkrule)) {
		  $this->addElement('TinyMce', 'rules', array(
	    	'label'=>'Rules',
	    	'description' => 'Enter Rules of the Contest.',
	      	'required' => $set,
	      	'allowEmpty' => false,
	      'filters' => array(
	        new Engine_Filter_Censor(),
        ),
	    ));
    }

   	$availableLabels = array(
      'everyone'            => 'Everyone',
      'registered'          => 'All Registered Members',
      'owner_network'       => 'Friends and Networks',
      'owner_member_member' => 'Friends of Friends',
      'owner_member'        => 'Friends Only',
      'owner'               => 'Just Me'
    );

    // Element: auth_view
    $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitecontest_cont', $user, 'auth_view');
    $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));

    if( !empty($viewOptions) && count($viewOptions) >= 1 ) {
      // Make a hidden field
      if( count($viewOptions) == 1 ) {
        $this->addElement('hidden', 'auth_view', array( 'order' => 101, 'value' => key($viewOptions)));
      // Make select box
      } else {
        $this->addElement('Select', 'auth_view', array(
          'label' => 'Privacy',
          'description' => 'Who may see this contest?',
          'multiOptions' => $viewOptions,
          'value' => key($viewOptions),
        ));
        $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
      }
    }

    // Element: auth_comment
    $commentOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitecontest_cont', $user, 'auth_comment');
    $commentOptions = array_intersect_key($availableLabels, array_flip($commentOptions));

    if( !empty($commentOptions) && count($commentOptions) >= 1 ) {
      // Make a hidden field
      if( count($commentOptions) == 1 ) {
        $this->addElement('hidden', 'auth_comment', array('order' => 102, 'value' => key($commentOptions)));
      // Make select box
      } else {
	        $this->addElement('Select', 'auth_comment', array(
            'label' => 'Comment Privacy',
            'description' => 'Who may post comments on this contest?',
            'multiOptions' => $commentOptions,
            'value' => key($commentOptions),
	        ));
        $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
      }
    }

    $chkdraft = $setting->getSetting('sitecontest.contest.status');
    	if (!empty($chkdraft)) {
		    $this->addElement('Select', 'draft', array(
		      'label' => 'Status',
		      'multiOptions' => array("0"=>"Published","1"=>"Saved As Draft"),
		      'description' => 'If this contest is published, it cannot be switched back to draft mode.',
          'onchange' => 'checkDraft();',
		    ));
			}
		// Search
		$chksearch = $setting->getSetting('sitecontest.contest.search');
  	if (!empty($chksearch)) {
			// Search
 		 	$this->addElement('Checkbox', 'search', array(
	      'label' => 'People can search for this Contest.',
	      'value' => 1
	    ));
    }
    // Buttons
    $this->addElement('Button', 'submit', array(
      'label' => 'Create Contest',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array(
        'ViewHelper',
      ),
    ));

    $this->addElement('Cancel', 'cancel', array(
      'label' => 'cancel',
      'link' => true,
      'prependText' => ' or ',
      'decorators' => array(
        'ViewHelper',
      ),
    ));

    $this->addDisplayGroup(array('submit', 'cancel'), 'buttons', array(
      'decorators' => array(
        'FormElements',
        'DivDivDivWrapper',
      ),
    ));
	}
}
?>