<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_Model_DbTable_Categories extends Engine_Db_Table
{
  
  protected $_rowClass = "Sitecontest_Model_Category";

  public function getCategories($fetchColumns = array(), $category_ids = null, $count_only = 0, $sponsored = 0, $cat_depandancy = 0, $limit = 0, $orderBy = 'cat_order') {
    //MAKE QUERY
    $select = $this->select();

    //GET CATEGORY TABLE NAME
    $categoryTableName = $this->info('name');

    if ($orderBy == 'category_name') {
      $select->order('category_name');
    } else {
      $select->order('cat_order');
    }

    if (!empty($cat_depandancy)) {
      $select->where('cat_dependency = ?', 0);
    }

    if (!empty($sponsored)) {
      $select->where('sponsored = ?', 1);
    }

    if (!empty($category_ids)) {
      foreach ($category_ids as $ids) {
        $categoryIdsArray[] = "category_id = $ids";
      }
      $select->where("(" . join(") or (", $categoryIdsArray) . ")");
    }

    if (!empty($count_only)) {
      return $select->from($this->info('name'), 'category_id')->query()->fetchColumn();
    } else {
      if (!empty($fetchColumns)) {
        $select->setIntegrityCheck(false)->from($categoryTableName, $fetchColumns);
      } else {
        $select->setIntegrityCheck(false)->from($categoryTableName);
      }
    }

    if (!empty($limit)) {
      $select->limit($limit);
    }
    //RETURN DATA
    return $this->fetchAll($select);
  }

  // *
  public function getSubCategories($category_id, $fetchColumns = array()) {
    //RETURN IF CATEGORY ID IS EMPTY
    if (empty($category_id)) {
      return;
    }
    //MAKE QUERY
    $select = $this->select();
    if (!empty($fetchColumns)) {
      $select->from($this->info('name'), $fetchColumns);
    }
    $select->where('cat_dependency = ?', $category_id)
            ->order('cat_order');

    //RETURN RESULTS
    return $this->fetchAll($select);
  }

  public function getCategoriesList($cat_depandancy= -1) {
    $select = $this->select()->order('cat_order');
    if ($cat_depandancy != -1) {
      $select->where('cat_dependency = ?', $cat_depandancy);
    }
    //RETURN DATA
    return $this->fetchAll($select);
  }

  public function getCategory($category_id) {
    if (empty($category_id)) {
      return;
    }
    $select = $this->select()->from($this->info('name'), array('category_name', 'category_id','file_id'))->where('category_id =?', $category_id)->order('cat_order');
    return $this->fetchRow($select);
  }

  public function getProfileType($categoryIds = array(), $categoryId = 0, $profileTypeName = 'profile_type') {

    if (!empty($categoryIds)) {
    $profile_type = 0;
    foreach ($categoryIds as $value) {
    $profile_type = $this->select()
    ->from($this->info('name'), array("$profileTypeName"))
    ->where("category_id = ?", $value)
    ->query()
    ->fetchColumn();

    if (!empty($profile_type)) {
    return $profile_type;
    }
    }

    return $profile_type;
    } elseif (!empty($categoryId)) {

    //FETCH DATA
    $profile_type = $this->select()
    ->from($this->info('name'), array("$profileTypeName"))
    ->where("category_id = ?", $categoryId)
    ->query()
    ->fetchColumn();

    return $profile_type;
    }

    return 0;
  }

  public function getMapping($profileTypeName = 'profile_type') {
    //MAKE QUERY
    $select = $this->select()->from($this->info('name'), array('category_id', "$profileTypeName"));
    //FETCH DATA
    $mapping = $this->fetchAll($select);
    //RETURN DATA
    if (!empty($mapping)) {
      return $mapping->toArray();
    }
    return null;
  }

  public function getOnlyViewableCategoryId() {

    $viewer = Engine_Api::_()->user()->getViewer();
    set_time_limit(0);
    $table = Engine_Api::_()->getItemTable('sitecontest_contest');
    $category_select = $table->select()
            ->group('category_id')
            ->order('category_id ASC');

    $i = 0;
    $contest_ids = array();
    foreach ($category_select->getTable()->fetchAll($category_select) as $category) {
            $category_ids[$i++] = $category->category_id;
    }
    if (empty($category_ids))
        $category_ids = array(0);

      $select = $this->select()->where("category_id IN(?)",$category_ids);
      $category = $this->fetchAll($select);
    return $category;
  }
}
?>