<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_Model_DbTable_Entries extends Core_Model_Item_DbTable_Abstract
{
  protected $_name = 'sitecontest_entries';
  protected $_rowClass = "Sitecontest_Model_Entry";
  
  public function getDayItems($title, $limit = 10, $category_id = null) {
    //MAKE QUERY
    $select = $this->select()
            ->from($this->info('name'), array('entry_id','contest_id', 'user_id', 'title', 'photo_id'));
    if (!empty($category_id)) {
      $select->where('category_id = ?', $category_id);
    }
    $select->where($this->info('name') . ".title LIKE ? " , '%' . $title . '%')
            ->order('title ASC')
            ->limit($limit);
     //FETCH RESULTS
    return $this->fetchAll($select);
  }

  public function getItemOfDay() {
    $sitecontestTableName = $this->info('name');
    $itemofthedaytable = Engine_Api::_()->getDbtable('entryitemofthedays', 'sitecontest');
    $itemofthedayName = $itemofthedaytable->info('name');
    $select = $this->select();
    $select = $select->setIntegrityCheck(false)
            ->from($sitecontestTableName, array('entry_id', 'contest_id','title', 'photo_id', 'user_id'))
            ->join($itemofthedayName, $sitecontestTableName . ".entry_id = " . $itemofthedayName . '.resource_id', array('start_date'))
            ->where($itemofthedayName . '.resource_type=?', 'sitecontest_enty')
            ->where($itemofthedayName . '.start_date <=?', date('Y-m-d'))
            ->where($itemofthedayName . '.end_date >=?', date('Y-m-d'))
            ->order('RAND()');
    return $this->fetchRow($select);
  }

  public function getEntriesSelect($params = array()) {

    $viewer = Engine_Api::_()->user()->getViewer();
    $table = Engine_Api::_()->getDbtable('Entries', 'sitecontest');
    $rName = $table->info('name');
   
    $param = array();
    $select = $table->select()->setIntegrityCheck(false);
    
    if (!empty($params['user_id'])) {
      $select->where($rName.'.user_id = ?', $params['user_id']);
      
    }
    if (!empty($params['vote_count'])) {
          $select = $select->where($rName . '.winner <> ?', '0')->order($rName . '.winner ASC');
      } 
   
    if( !empty($params['contest_id']) ) {
        $select->where($rName . '.contest_id = ?', $params['contest_id']);
    }
    // Could we use the search indexer for this?
    if( !empty($params['search']) ) {
      $select->where($rName.".title LIKE ? OR ".$rName.".body LIKE ?", '%'.$params['search'].'%');
    }
    if( !empty($params['start_date']) ) {
      $select->where($rName.".creation_date > ?", date('Y-m-d', $params['start_date']));
    }
    if( !empty($params['end_date']) ) {
      $select->where($rName.".creation_date < ?", date('Y-m-d', $params['end_date']));
    }
  
    if( !empty($owner) ) {
      return $select;
    }
    if(empty($params['vote_count'])) { 
      if(!empty($params['winner'])) { 
        $select->where($rName . '.winner != ?', 0);
        $select->order($rName . '.winner ASC'); 
        $select->limit(5);
      }else {
        $select->order($rName . '.creation_date DESC'); 
      } 
    }
    return $this->getAuthorisedSelect($select);
  }

  public function getEntriesPaginator($params = array()) {

    $paginator = Zend_Paginator::factory($this->getEntriesSelect($params));
    if( !empty($params['page']) ) {
      $paginator->setCurrentPageNumber($params['page']);
    }
    if( !empty($params['limit']) ) {
      $paginator->setItemCountPerPage($params['limit']);
    }

    if( empty($params['limit']) ) {
      $page = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecontest.page', 10);
      $paginator->setItemCountPerPage($page);
    }
    return $paginator;
  }
}
?>