<?php
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitecontest
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
?>
<?php
/**
 * 
 */
class Sitecontest_AdminJuryController extends Core_Controller_Action_Admin
{
	
	public function indexAction() {

		//GET NAVIGATION
		$this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
				->getNavigation('sitecontest_admin_main', array(), 'sitecontest_admin_main_jury');

		//FORM GENERATION
		$this->view->formFilter = $formFilter = new Sitecontest_Form_Admin_Filter();
		$page = $this->_getParam('page', 1); 

		$values = array(); 
		if ($formFilter->isValid($this->_getAllParams())) {
		  $values = $formFilter->getValues();
		}
		foreach ($values as $key => $value) {
		  if (null == $value) {
			unset($values[$key]);
		  }
		}
		$this->view->assign($values);
		//FETCH DATA
		$this->view->paginator = $paginator = Engine_Api::_()->getDbtable('juries', 'sitecontest')->getJuryList($values, 'user_id','');
		$this->view->paginator->setItemCountPerPage(50);
		$this->view->paginator = $paginator->setCurrentPageNumber($page);
	}

	public function addJuryAction() {

		//SET LAYOUT
		$this->_helper->layout->setLayout('admin-simple');
		$viewer = Engine_Api::_()->user()->getViewer();
		//FORM GENERATION
		$form = $this->view->form = new Sitecontest_Form_Admin_Jury();

		//CHECK POST
		if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

			//GET FORM VALUES
			$values = $form->getValues();

			//BEGIN TRANSACTION
			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			try {
			
			$table = Engine_Api::_()->getDbtable('juries', 'sitecontest');
			$select = $table->select()->where('user_id = ?', $values["user_id"]);
			$row = $table->fetchRow($select);

			if (empty($row)) {
			  $row = $table->createRow();
			  $row->user_id = $values["user_id"];
			}
			
			//Notification for Jury Member
			$owner = Engine_Api::_()->user()->getViewer();
			$user = Engine_Api::_()->getItem('user',$values["user_id"]);

			Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $user, 'sitecontest_jury_create');

			//Mail to Jury member
			Engine_Api::_()->sitecontest()->juryEmailNotification($user, 'approved');


			$row->save();

			$db->commit();
		  } catch (Exception $e) {
			$db->rollBack();
			throw $e;
		  }
		  $this->_forward('success', 'utility', 'core', array(
				  'smoothboxClose' => 10,
				  'parentRefresh' => 10,
				  'messages' => array(Zend_Registry::get('Zend_Translate')->_('The Jury Member Sucessfully Added.'))
		  ));
		}
	}

	//ACTION FOR PAGE SUGGESTION DROP-DOWN
	public function getitemAction() {

		$search_text = $this->_getParam('text', null);
		$limit = $this->_getParam('limit', 40);
			
		$data = array();

		$moduleContents = Engine_Api::_()->sitecontest()->getJuryItems($search_text, $limit=10);
		foreach ($moduleContents as $moduleContent) {

			$content_photo = $this->view->itemPhoto($moduleContent, 'thumb.icon');

		$data[] = array(
				'id' => $moduleContent->user_id,
				'label' => $moduleContent->displayname,
				'photo' => $content_photo
			);
		}
		return $this->_helper->json($data);
	}


	//ACTION FOR PAGE DELETE ENTRY
	public function deleteItemAction() {
		
		$user_id = Engine_Api::_()->getItem('sitecontest_jury',$this->_getParam('id'))->user_id;

		if ($this->getRequest()->isPost()) {
		  $db = Engine_Db_Table::getDefaultAdapter();
		  $db->beginTransaction();
		  try {
			$juryTable = Engine_Api::_()->getDbtable('juries', 'sitecontest')->delete(array('jury_id =?' => $this->_getParam('id')));
			
	  
			//Notification for Jury Member
			$owner = Engine_Api::_()->user()->getViewer();
			$user = Engine_Api::_()->getItem('user',$user_id);

			Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $user, 'sitecontest_jury_delete');
			//Mail
			Engine_Api::_()->sitecontest()->juryEmailNotification($user, 'disapproved');


			$db->commit();
		  } catch (Exception $e) {
			$db->rollBack();
			throw $e;
		  }
		  $this->_forward('success', 'utility', 'core', array(
				  'smoothboxClose' => 10,
				  'parentRefresh' => 10,
				  'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
		  ));
		}
		  $this->renderScript('admin-jury/delete.tpl');
	}


	  //ACTION FOR MULTI DELETE PAGE ENTRIES
	public function multiDeleteAction() {

		if ($this->getRequest()->isPost()) {
			$owner = Engine_Api::_()->user()->getViewer();
		  	$values = $this->getRequest()->getPost();
		  	foreach ($values as $key => $value) { 
				$user_id = Engine_Api::_()->getItem('sitecontest_jury',$value)->user_id;
				if ($key == 'delete_' . $value) {
			  		$sitecontestjury = Engine_Api::_()->getItem('sitecontest_jury', (int) $value);
			  		if (!empty($sitecontestjury)) {
						$sitecontestjury->delete();
			  		}
					//Notification for Jury Member 
					$user = Engine_Api::_()->getItem('user',$user_id);
					Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $user, 'sitecontest_jury_delete');
					//Mail
					Engine_Api::_()->sitecontest()->juryEmailNotification($user, 'disapproved');
				}
		  	}
		}
		return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
	}
}

?>