<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_DashboardController extends Core_Controller_Action_Standard
{
	

	public function editAction() {
        // $this->view->TabActive = "edit";
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
		$this->view->contest_id = $this->_getParam('contest_id');
		$viewer = Engine_Api::_()->user()->getViewer();
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		if (!$contest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }

		$this->view->form = $form = new Sitecontest_Form_Edit(array('item' => $contest));
		$form->removeElement('photo');
	    $form->getElement('media_type')->setRequired(false);

	    if(empty($contest->draft))
	    {
	    	$form->getElement('media_type')->setAttrib('disable',true);
	    	$form->getElement('media_type')->setRequired(false);
	    	$form->removeElement('draft');

	    }
	    
	  	if (empty(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecontest.contest.url'))) {
	    	$form->removeElement('contest_url');	    	
	    }
	    $form->removeElement('first_award_prize');
	
		$dateInfo = Engine_Api::_()->sitecontest()->dbToUserDateTime($contest);

	    $contest['start_datetime'] = $dateInfo['start_datetime'];
	    $contest['end_datetime'] = $dateInfo['end_datetime'];
	    $contest['entry_start_datetime'] = $dateInfo['entry_start_datetime'];
	    $contest['entry_end_datetime'] = $dateInfo['entry_end_datetime'];
	    $contest['vote_start_datetime'] = $dateInfo['vote_start_datetime'];
	    $contest['vote_end_datetime'] = $dateInfo['vote_end_datetime'];
	    $contest['result_datetime'] = $dateInfo['result_datetime'];
		$form->populate($contest->toArray());
		//Populate tags
		$tagStr = '';
		foreach( $contest->tags()->getTagMaps() as $tagMap ) {
		$tag = $tagMap->getTag();
		if( !isset($tag->text) ) continue;
		if( '' !== $tagStr ) $tagStr .= ', ';
		$tagStr .= $tag->text;
		}
		$form->populate(array(
		'tags' => $tagStr,
		));
	
	   	$auth = Engine_Api::_()->authorization()->context;
	    $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

	    foreach( $roles as $role ) {
	      if ($form->auth_view){
	        if( $auth->isAllowed($contest, $role, 'view') ) {
	         $form->auth_view->setValue($role);
	        }
	      }

	      if ($form->auth_comment){
	        if( $auth->isAllowed($contest, $role, 'comment') ) {
	          $form->auth_comment->setValue($role);
	        }
	      }
	    }	
		if($form->getValue('contest_url') == $contest->contest_url)
		{	
			$form->getElement('contest_url')->removeValidator('Db_NoRecordExists');
		}
		
		 // Check post/form
	    if( !$this->getRequest()->isPost() ) {
	      return;
	    }
	    if( !$form->isValid($this->getRequest()->getPost()) ) {
	      return;
	    }
	    // Process
	    $db = Engine_Db_Table::getDefaultAdapter();
	    $db->beginTransaction();

	    try {
	    $form->populate(array(
		'media_type' => $contest->media_type,
		));
	    $values = $form->getValues();

	    if($contest->status == 'expired')
	    {
	    	        $script = <<<EOF
          en4.core.runonce.add(function(){
                     Smoothbox.open('<div class = "sitecontest_welcome_message_wrapper"><div class="sitecontest_welcome_popup_close_icon" onclick = "parent.Smoothbox.close()"></div> <div class ="sitecontest_welcome_message" ><b>Winners are declared so you cannot make any changes.<b></div></div>');
          });
EOF;
        $view->headScript()->appendScript($script);
        return;
	    }

		$contest_start = strtotime($values['start_datetime']);
		$contest_end = strtotime($values['end_datetime']);
	    $entry_start = strtotime($values['entry_start_datetime']);
	    $entry_end = strtotime($values['entry_end_datetime']);
    	$current_date = strtotime($contest->start_datetime);
    	$entry = strtotime($contest->entry_start_datetime);
	    if (empty($contest->entry_count)) {
		    // check dates
		    if( $current_date != $contest_start&&$current_date > $contest_start ) {
		      $form->start_datetime->setErrors(array('Contest Start Date should be greater or equal to create date which you have selected at contest create time or edit time.'));
		      $form->populate(array(
					'start_datetime' => $contest->start_datetime,
				));
		      return;
		    }
	    }else{	
		    // check dates
		    if( $current_date != $contest_start ) {
		      $form->start_datetime->setErrors(array('You cannot change contest start date because you have an entry'));
		      $form->populate(array(
					'start_datetime' => $contest->start_datetime,
				));
		      return;
		    }
		    if( $entry != $entry_start ) {
		      $form->start_datetime->setErrors(array('You cannot change entry submission start date because you have an entry'));
		      $form->populate(array(
					'entry_start_datetime' => $contest->entry_start_datetime,
				));
		      return;
		    }
	    }
	    if( $contest_start >= $contest_end ) {
	      $form->start_datetime->setErrors(array('Contest Start Date should be before End Date.'));
	      $form->populate(array(
					'start_datetime' => $contest->start_datetime,
					'end_datetime' => $contest->end_datetime,
				));
	      return;
	    }

	    // check dates
	    if( $entry_start >= $entry_end ) {
		    $form->entry_start_datetime->setErrors(array('Entry Start Date should be before End Date.'));
	    	$form->populate(array(
					'entry_start_datetime' => $contest->entry_start_datetime,
					'entry_end_datetime' => $contest->entry_end_datetime,
				));
	      return;
	    }
	    if( $entry_start < $contest_start ) {
	      $form->entry_start_datetime->setErrors(array('Contest Start Date should be before Entry start Date.'));
	      $form->populate(array(
					'entry_start_datetime' => $contest->entry_start_datetime,
					'start_datetime' => $contest->start_datetime,
				));
	      return;
	    }
	    if( $contest_end < $entry_end ) {
	      $form->entry_start_datetime->setErrors(array('Entry End Date should be before contest End Date.'));
	      $form->populate(array(
					'entry_end_datetime' => $contest->entry_end_datetime,
					'end_datetime' => $contest->end_datetime,
				));
	      return;
	    }
	   
	    $vote_start = strtotime($values['vote_start_datetime']);
	    $vote_end = strtotime($values['vote_end_datetime']);
	    // check dates
	        if( $vote_start >= $vote_end ) {
	      $form->vote_start_datetime->setErrors(array('Vote Start Date should be before End Date.'));
	      $form->populate(array(
					'vote_start_datetime' => $contest->vote_start_datetime,
					'vote_end_datetime' => $contest->vote_end_datetime,
				));
	      return;
	    }
	    if( $vote_start < $entry_start ) {
	      $form->vote_start_datetime->setErrors(array('Entry Start Date should be before Vote start Date.'));
	      $form->populate(array(
					'vote_start_datetime' => $contest->vote_start_datetime,
					'entry_start_datetime' => $contest->entry_start_datetime,
				));
	      return;
	    }
	    if( $contest_end < $vote_end ) {
	      $form->vote_end_datetime->setErrors(array('Vote End Date should be before Contest End Date.'));
	      $form->populate(array(
					'vote_end_datetime' => $contest->vote_end_datetime,
					'end_datetime' => $contest->end_datetime,
				));
	      return;
	    }

	    $vote_show = strtotime($values['vote_show_datetime']);
	    $result_show = strtotime($values['result_datetime']);

	    // check dates
	    if( $vote_show > 0 && $vote_show < $contest_end ) {
	      $form->start_datetime->setErrors(array('Vote show date should be After the Contest End Date.'));
	      return;
	    }

	    if( $result_show < $contest_end ) {
	      $form->start_datetime->setErrors(array('Result Announce date should be after contest End Date.'));
	      $form->populate(array(
					'result_datetime' => $contest->result_datetime,
					'end_datetime' => $contest->end_datetime,
				));
	      return;
	    }
	    $dateInfo = Engine_Api::_()->sitecontest()->userToDbDateTime($values);
	    $values['start_datetime'] = $dateInfo['start_datetime'];
	    $values['entry_start_datetime'] = $dateInfo['entry_start_datetime'];
	    $values['end_datetime'] = $dateInfo['end_datetime'];
	    $values['entry_end_datetime'] = $dateInfo['entry_end_datetime'];
	    $values['vote_start_datetime'] = $dateInfo['vote_start_datetime'];
	    $values['vote_end_datetime'] = $dateInfo['vote_end_datetime'];
	    $values['result_datetime'] = $dateInfo['result_datetime'];

	    if( empty($values['auth_view']) ) {
	       $values['auth_view'] = 'everyone';
	    }
	    if( empty($values['auth_comment']) ) {
	      $values['auth_comment'] = 'everyone';
	    }

	    $values['view_privacy'] = $values['auth_view'];
	    $values['comment_privacy'] = $values['auth_comment'];
	    unset($values['media_type']);
	    $contest->modified_date = date('Y-m-d H:i:s');
	    $contest->save();

	    // Auth
	    $viewMax = array_search($values['auth_view'], $roles);
	    $commentMax = array_search($values['auth_comment'], $roles);

	    foreach( $roles as $i => $role ) {
	      $auth->setAllowed($contest, $role, 'view', ($i <= $viewMax));
	      $auth->setAllowed($contest, $role, 'comment', ($i <= $commentMax));
	    }

        //handle tags
		$tags = preg_split('/[,]+/', $values['tags']);
		$contest->tags()->setTagMaps($viewer, $tags);

		//SAVE CUSTOM VALUES AND PROFILE TYPE VALUE
        $customfieldform = $form->getSubForm('fields');
        $customfieldform->setItem($contest);
        $customfieldform->saveValues();
        
      	$owner = $contest->getOwner('user');
	
	    // insert new activity if contest is just getting published
	    if($contest->draft == 1 && $values['draft'] == 0 && $contest->approved) {
	    	$contest->approved_date = date('Y-m-d H:i:s');
	   		//Send notification of contest create to jury member
	        $juries = Engine_Api::_()->getDbtable('juries', 'sitecontest')->fetchAll();
	        foreach ($juries as $jury) {
			        $user = Engine_Api::_()->getItem('user',$jury->user_id);
			        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $contest, 'sitecontest_create_contest');
	        }
	        //Activity feed of contest create
	        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $contest, 'sitecontest_new');
	        if( $action ) {
	          Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $contest);
	        }
      	}
	    $contest->setFromArray($values);
	    $contest->save();
	    $db->commit();
	    $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
	    }
	    catch( Exception $e ) {
	      $db->rollBack();
	      throw $e;
	    }
	}
	public function changePhotoAction() {
		$this->view->contest_id = $contest_id = $this->_getParam('contest_id');
		$this->view->sitecontest = $sitecontest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$sitecontest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
		$this->view->main_photo = $main_photo = $sitecontest->photo_id;

		$this->view->form = $form = new Sitecontest_Form_Editphoto();

		// Check post/form
	    if( !$this->getRequest()->isPost() ) {
	      return;
	    }
	    if( !$form->isValid($this->getRequest()->getPost()) ) {
	      return;
	    }
	    //UPLOAD PHOTO
        if ($form->Filedata->getValue() !== null) {
            //GET DB
            $db = Engine_Api::_()->getDbTable('contests', 'sitecontest')->getAdapter();
            $db->beginTransaction();
            //PROCESS
            try {
                //SET PHOTO
                $sitecontest->setPhoto($form->Filedata);
                $db->commit();
            } catch (Engine_Image_Adapter_Exception $e) {
                $db->rollBack();
                $form->addError(Zend_Registry::get('Zend_Translate')->_('The uploaded file is not supported or is corrupt.'));
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
        } else if ($form->getValue('coordinates') !== '') {
            $storage = Engine_Api::_()->storage();
            $iProfile = $storage->get($sitecontest->photo_id, 'thumb.profile');
            $iSquare = $storage->get($sitecontest->photo_id, 'thumb.icon');
            $pName = $iProfile->getStorageService()->temporary($iProfile);
            $iName = dirname($pName) . '/nis_' . basename($pName);
            list($x, $y, $w, $h) = explode(':', $form->getValue('coordinates'));
            $image = Engine_Image::factory();
            $image->open($pName)
                    ->resample($x + .1, $y + .1, $w - .1, $h - .1, 48, 48)
                    ->write($iName)
                    ->destroy();
            $iSquare->store($iName);
            @unlink($iName);
        }
        if (!empty($sitecontest->photo_id)) {
            $photoTable = Engine_Api::_()->getItemTable('sitecontest_photo');
            $order = $photoTable->select()
                    ->from($photoTable->info('name'), array('order'))
                    ->where('contest_id = ?', $sitecontest->contest_id)
                    ->group('photo_id')
                    ->order('order ASC')
                    ->limit(1)
                    ->query()
                    ->fetchColumn();
            $photoTable->update(array('order' => $order - 1), array('file_id = ?' => $sitecontest->photo_id));
        }

        return $this->_helper->redirector->gotoRoute(array('action' => 'change-photo', 'contest_id' => $contest_id), "dashboard_default", true);
	}
	//ACTION FOR REMOVE THE PHOTO
    public function removePhotoAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;
        //GET EVENT ID
        $contest_id = $this->_getParam('contest_id');
        //GET EVENT ITEM
        $sitecontest = Engine_Api::_()->getItem('sitecontest_contest', $contest_id);
        $viewer = Engine_Api::_()->user()->getViewer();
        //CAN EDIT OR NOT
        if (!$this->_helper->requireAuth()->setAuthParams($sitecontest, $viewer, "edit")->isValid()) {
            return;
        }
        //GET FILE ID
        $file_id = Engine_Api::_()->getDbtable('photos', 'sitecontest')->getPhotoId($contest_id, $sitecontest->photo_id);
        //DELETE PHOTO
        if (!empty($file_id)) {
            $photo = Engine_Api::_()->getItem('sitecontest_photo', $file_id);
            $photo->delete();
        }
        //SET PHOTO ID TO ZERO
        $sitecontest->photo_id = 0;
        $sitecontest->save();

        return $this->_helper->redirector->gotoRoute(array('action' => 'change-photo', 'contest_id' => $contest_id), "dashboard_default", true);
    }

	public function ruleAction() {
		$this->view->contest_id = $this->_getParam('contest_id');
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$contest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
		$form_type = "rules";
		$this->view->form = $form = new Sitecontest_Form_Dashboard_Rule(array('form_type' => $form_type));
		$form->populate($contest->toArray());

		 // Check post/form
	    if( !$this->getRequest()->isPost() ) {
	      return;
	    }
	    if( !$form->isValid($this->getRequest()->getPost()) ) {
	      return;
	    }

	    $values = $form->getValues();
		$contest->setFromArray($values);
		$contest->save();
		$form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
	}

	public function contactinfoAction() {
		$this->view->contest_id = $contest_id = $this->_getParam('contest_id');
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$contest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
		$this->view->form = $form = new Sitecontest_Form_Dashboard_Contactinfo();

		$tableOtherinfo = Engine_Api::_()->getDbTable('otherinfo', 'sitecontest');
		 //POPULATE FORM
        $row = $tableOtherinfo->getOtherinfo($contest_id);
        $value['name'] = $row->name;
        $value['email'] = $row->email;
        $value['phone'] = $row->phone;
        $value['fb_url'] = $row->fb_url;
        $value['linkedin_url'] = $row->linkedin_url;
        $value['twitter_url'] = $row->twitter_url;
        $value['website_url'] = $row->website_url;

        $form->populate($value);

        //CHECK FORM VALIDATION
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            //GET FORM VALUES
            $values = $form->getValues();
            if (isset($values['email'])) {
                $email_id = $values['email'];

                //CHECK EMAIL VALIDATION
                $validator = new Zend_Validate_EmailAddress();
                $validator->getHostnameValidator()->setValidateTld(false);
                if (!empty($email_id)) {
                    if (!$validator->isValid($email_id)) {
                        $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter a valid email address.'));
                        return;
                    } else {
                        $tableOtherinfo->update(array('email' => $email_id), array('contest_id = ?' => $contest_id));
                    }
                } else {
                    $tableOtherinfo->update(array('email' => $email_id), array('contest_id = ?' => $contest_id));
                }
            }

            //CHECK PHONE OPTION IS THERE OR NOT
            if (isset($values['phone'])) {
                $tableOtherinfo->update(array('phone' => $values['phone']), array('contest_id = ?' => $contest_id));
            }

            //CHECK WEBSITE OPTION IS THERE OR NOT
            if (isset($values['name'])) {
                $tableOtherinfo->update(array('name' => $values['name']), array('contest_id = ?' => $contest_id));
            }

            //CHECK WEBSITE OPTION IS THERE OR NOT
            if (isset($values['fb_url'])) {
                $tableOtherinfo->update(array('fb_url' => $values['fb_url']), array('contest_id = ?' => $contest_id));
            }
            //CHECK WEBSITE OPTION IS THERE OR NOT
            if (isset($values['linkedin_url'])) {
                $tableOtherinfo->update(array('linkedin_url' => $values['linkedin_url']), array('contest_id = ?' => $contest_id));
            }
            //CHECK WEBSITE OPTION IS THERE OR NOT
            if (isset($values['twitter_url'])) {
                $tableOtherinfo->update(array('twitter_url' => $values['twitter_url']), array('contest_id = ?' => $contest_id));
            }
            //CHECK WEBSITE OPTION IS THERE OR NOT
            if (isset($values['website_url'])) {
                $tableOtherinfo->update(array('website_url' => $values['website_url']), array('contest_id = ?' => $contest_id));
            }
            

            //SHOW SUCCESS MESSAGE
            $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
        }
	}
	public function overviewAction() {

		$this->view->contest_id = $contest_id = $this->_getParam('contest_id');
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$contest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //SELECTED TAB
		$form_type = "overview";
		$this->view->form = $form = new Sitecontest_Form_Dashboard_Rule(array('form_type' => $form_type));
		
	    $tableOtherinfo = Engine_Api::_()->getDbTable('otherinfo', 'sitecontest');
        //SAVE THE VALUE
        if ($this->getRequest()->isPost()) {
            $tableOtherinfo->update(array('overview' => $_POST['overview']), array('contest_id = ?' => $contest_id));
            $this->view->form = $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
        }

        //POPULATE FORM
        $values['overview'] = $tableOtherinfo->getColumnValue($contest_id, 'overview');
        $form->populate($values);
	}
	public function awardAction() {
		$view = Zend_Registry::get('Zend_View');
		$this->view->contest_id = $contest_id= $this->_getParam('contest_id');
		$this->view->sitecontest = $contestObj = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$contestObj->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
		$user = $contestObj->getOwner();
		$contest = Engine_Api::_()->getItemTable('sitecontest_award');
		$select = $contest->select()->where('contest_id = ?', $contest_id);
		$this->view->paginator  = $paginator = $contest->fetchAll($select);
		$award_id = $paginator[0]->award_id;
		$viewer = Engine_Api::_()->user()->getViewer();
    	$value = Engine_Api::_()->authorization()->getPermission($user->level_id, 'sitecontest_cont', "prize");
		$awards = Engine_Api::_()->getItem('sitecontest_award',$award_id);
		$this->view->form = $form = new Sitecontest_Form_Dashboard_Award(array('value' => $value));
		$form->getElement('first_award_prize')->setRequired(true);
		$form->getElement('first_award_message')->setRequired(true);
		$form->getElement('first_award_message')->setValue('Congatulation');
		$form->populate($awards->toArray());
		// Check post/form
	    if( !$this->getRequest()->isPost() ) {
	      return;
	    }
	    if( !$form->isValid($this->getRequest()->getPost()) ) {
	      return;
	    }
	    // Process
	    $values = $form->getValues();
	    $values['contest_id'] = $contest_id;
	     if($contestObj->status == 'expired')
	    {
	    	        $script = <<<EOF
          en4.core.runonce.add(function(){
                     Smoothbox.open('<div class = "sitecontest_welcome_message_wrapper"><div class="sitecontest_welcome_popup_close_icon" onclick = "parent.Smoothbox.close()"></div> <div class ="sitecontest_welcome_message" ><b>Winners are declared so you cannot make any changes.<b></div></div>');
          });
EOF;
        $view->headScript()->appendScript($script);
        return;
	    }
	    $db = Engine_Api::_()->getDbtable('awards', 'sitecontest')->getAdapter();
	    $db->beginTransaction();

	    try
	    {
	    	// Create contest	
			$awards->setFromArray($values);
			$awards->save();
	    	// Commit
	    	$db->commit();
	    	$form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
	    } catch( Exception $e ) {
	      return $this->exceptionWrapper($e, $form, $db);
	    }
	}
	public function composeAction() {
		$this->view->contest_id = $contest_id= $this->_getParam('contest_id');
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		// Get paginator
	    $table = Engine_Api::_()->getItemTable('sitecontest_entry');

	    $select = $table->select()->where('contest_id = ?', $contest_id);
	    $select->order('contest_id DESC');
	    $data = array();
	    $this->view->paginator = $paginator = $table->fetchAll($select);

	    foreach ($paginator as $values): 
	      $recipient[] = $data[] = $values->user_id; 
	    endforeach; 
	      
		$this->view->form = $form = new Sitecontest_Form_Compose();

        $data = Zend_Json::encode($data);
 
        //ASSIGN THE COMPOSING STUFF.
        $composePartials = array();
        foreach (Zend_Registry::get('Engine_Manifest') as $data) {
            if (empty($data['composer']))
                continue;
            foreach ($data['composer'] as $type => $config) {
                $composePartials[] = $config['script'];
            }
        }
        $this->view->composePartials = $composePartials;

		// Check method/data
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $values = $form->getValues();
        //PROCESS.
        $db = Engine_Api::_()->getDbtable('messages', 'messages')->getAdapter();
        $db->beginTransaction();

        try {
            $attachment = null;
            $attachmentData = $this->getRequest()->getParam('attachment');
            if (!empty($attachmentData) && !empty($attachmentData['type'])) {
                $type = $attachmentData['type'];
                $config = null;
                foreach (Zend_Registry::get('Engine_Manifest') as $data) {
                    if (!empty($data['composer'][$type])) {
                        $config = $data['composer'][$type];
                    }
                }
                if ($config) {
                    $plugin = Engine_Api::_()->loadClass($config['plugin']);
                    $method = 'onAttach' . ucfirst($type);
                    $attachment = $plugin->$method($attachmentData);
                    $parent = $attachment->getParent();
                    if ($parent->getType() === 'user') {
                        $attachment->search = 0;
                        $attachment->save();
                    } else {
                        $parent->search = 0;
                        $parent->save();
                    }
                }
            }

            $viewer = Engine_Api::_()->user()->getViewer();

            $values['toValues'] = implode(",", $recipient);

            $recipients = preg_split('/[,. ]+/', $values['toValues']);
			if (in_array($viewer->getIdentity(), $recipients)) {
				$recipients = array_diff($recipients, array($viewer->getIdentity()));
				$recipients[] =  $contest->user_id;
            }
			// clean the recipients for repeating ids
            $recipients = array_unique($recipients);
         
            // this can happen if recipient is selected and then a friend list is selected
            $recipientsUsers = Engine_Api::_()->getItemMulti('user', $recipients);

            $conversation = Engine_Api::_()->getItemTable('messages_conversation')->send($viewer, $recipients, $values['title'], $values['body'], $attachment);
            foreach ($recipientsUsers as $user) {
                if ($user->getIdentity() == $viewer->getIdentity()) {
                    continue;
                }
                Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $conversation, 'message_new');
            }

            //Increment messages counter
            Engine_Api::_()->getDbtable('statistics', 'core')->increment('messages.creations');
            $db->commit();

            $this->_forward('success', 'utility', 'core', array(
                        'smoothboxClose' => true,
                        // 'parentRefresh' => true,
                        'class' => 'global_form_popup',
                        'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message has been sent successfully.'))));
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
	}
	public function metadetailAction() {
		$this->view->contest_id = $contest_id = $this->_getParam('contest_id');
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$contest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
		//ONLY LOGGED IN USER CAN ADD OVERVIEW
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SET FORM
        $this->view->form = $form = new Sitecontest_Form_Dashboard_Metainfo();

        $tableOtherinfo = Engine_Api::_()->getDbTable('otherinfo', 'sitecontest');

        //POPULATE FORM
        $value['keywords'] = $tableOtherinfo->getColumnValue($contest_id, 'keywords');
        $form->populate($value);

        //CHECK FORM VALIDATION
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            //GET FORM VALUES
            $values = $form->getValues();
            $tableOtherinfo->update(array('keywords' => $values['keywords']), array('contest_id = ?' => $contest_id));

            //SHOW SUCCESS MESSAGE
            $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes have been saved successfully.'));
        }
	}
	public function entriesAction() {	
	    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
		$this->view->contest_id = $contest_id = $this->_getParam('contest_id');
		$this->view->sitecontest = $contest = Engine_Api::_()->getItem('sitecontest_contest', $this->_getParam('contest_id'));
		$viewer = Engine_Api::_()->user()->getViewer();
		if (!$contest->authorization()->isAllowed($viewer, 'edit')) {
            return $this->_forward('requireauth', 'error', 'core');
        }
		$this->view->viewer_id = $viewer->getIdentity();

		$this->view->columnWidth = 280;
        $this->view->columnHeight =  320;
     	$this->view->turncation = 90;
		$this->view->info = $info[] = array('date','vote','views','comment','post');

		$values['contest_id'] = $contest_id;
        $this->view->entry = 1;
        $this->view->grid_view = 1;

    	$date = $view->locale()->toDateTime(date('Y-m-d H:i:s'),array('size' => 'medium'));
	    $current_date = strtotime($date);
	    if( $current_date >= $contest->result_datetime ) {
	      $this->view->winner_button = 1;
	    }

		// GET SITEPAGES
	    $this->view->paginator = $paginator = Engine_Api::_()->getItemTable('sitecontest_entry')->getEntriesPaginator($values);
	    
	    if( $this->_getParam('page') ) {
			$paginator->setCurrentPageNumber($this->_getParam('page'));
		}
		$this->view->paginator = $paginator = $paginator->setItemCountPerPage(5);
	}

	public function messageAction() {
		$viewer = Engine_Api::_()->user()->getViewer();
		$entryItem = Engine_Api::_()->getItem('sitecontest_entry',$this->_getParam('entry_id'));
		$recipients = $entryItem->user_id;
		$this->view->form = $form = new Sitecontest_Form_Compose();
		// Check method/data
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $values = $form->getValues();
        //PROCESS.
        $db = Engine_Api::_()->getDbtable('messages', 'messages')->getAdapter();
        $db->beginTransaction();

        try {
            $conversation = Engine_Api::_()->getItemTable('messages_conversation')->send($viewer, $recipients, $values['title'], $values['body'], $attachment);
			//Increment messages counter
            Engine_Api::_()->getDbtable('statistics', 'core')->increment('messages.creations');
            $db->commit();
            $this->_forward('success', 'utility', 'core', array(
                        'smoothboxClose' => true,
                        // 'parentRefresh' => true,
                        'class' => 'global_form_popup',
                        'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message has been sent successfully.'))));
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
	}
	public function resetPositionCoverPhotoAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;
    	$viewer = Engine_Api::_()->user()->getViewer();

        //GET GROUP ID
        $contest_id = $this->_getParam("contest_id");
        $this->view->sitecontest = $sitecontest = Engine_Api::_()->getItem('sitecontest_contest', $contest_id);
        ////START MANAGE-ADMIN CHECK
        $this->view->can_edit = $can_edit = $sitecontest->authorization()->isAllowed($viewer, "edit");
        if (empty($can_edit))
            return;
        $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitecontest');
        $album = $tableAlbum->getSpecialAlbum($sitecontest, 'cover');
        $album->cover_params = $this->_getParam('position', array('top' => '0', 'left' => 0));
        $album->save();
    }
     public function uploadCoverPhotoAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;
    	$viewer = Engine_Api::_()->user()->getViewer();

        //LAYOUT
        $this->_helper->layout->setLayout('default-simple');
        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }
        //GROUP ID
        $contest_id = $this->_getParam('contest_id');

        $special = $this->_getParam('special', 'cover');
        $sitecontest = Engine_Api::_()->getItem('sitecontest_contest', $contest_id);

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = $sitecontest->authorization()->isAllowed($viewer, "edit");
        if (empty($isManageAdmin)) {
            return $this->_forward('requireauth', 'error', 'core');
        }
        //GET FORM
        $this->view->form = $form = new Sitecontest_Form_Photo_Cover();

        //CHECK FORM VALIDATION
        $file = '';
        $notNeedToCreate = false;
        $photo_id = $this->_getParam('photo_id');
        if ($photo_id) {
            $photo = Engine_Api::_()->getItem('sitecontest_photo', $photo_id);
            $album = Engine_Api::_()->getItem('sitecontest_album', $photo->album_id);
            if ($album && $album->type == 'cover') {
                $notNeedToCreate = true;
            }
            if ($photo->file_id && !$notNeedToCreate)
                $file = Engine_Api::_()->getItemTable('storage_file')->getFile($photo->file_id);
        }

        if (empty($photo_id) || empty($photo)) {
            if (!$this->getRequest()->isPost()) {
                return;
            }

            //CHECK FORM VALIDATION
            if (!$form->isValid($this->getRequest()->getPost())) {
                return;
            }
        }
        //UPLOAD PHOTO
        if ($form->Filedata->getValue() !== null || $photo || ($notNeedToCreate && $file)) {
            //PROCESS
            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            try {
                //CREATE PHOTO
                $tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitecontest');
                if (!$notNeedToCreate) {
                    $photo = $tablePhoto->createRow();
                    $photo->setFromArray(array(
                        'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(),
                        'contest_id' => $contest_id
                    ));
                    $photo->save();
                    if ($file) {
                        $photo->setPhoto($file);
                    } else {
                        $photo->setPhoto($form->Filedata, true);
                    }
                    $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitecontest');
                    $album = $tableAlbum->getSpecialAlbum($sitecontest, $special);

                    $tablePhotoName = $tablePhoto->info('name');
                    $photoSelect = $tablePhoto->select()->from($tablePhotoName, 'order')->where('album_id = ?', $album->album_id)->order('order DESC')->limit(1);
                    $photo_rowinfo = $tablePhoto->fetchRow($photoSelect);
                    $photo->collection_id = $album->album_id;
                    $photo->album_id = $album->album_id;
                    $order = 0;
                    if (!empty($photo_rowinfo)) {
                        $order = $photo_rowinfo->order + 1;
                    }
                    $photo->order = $order;
                    $photo->save();
                }

                $album->cover_params = $this->_getParam('position', array('top' => '0', 'left' => 0));
                $album->save();
                if (!$album->photo_id) {
                    $album->photo_id = $photo->file_id;
                    $album->save();
                }
                $sitecontest->contest_cover = $photo->photo_id;
                $sitecontest->save();
                //ADD ACTIVITY
                $viewer = Engine_Api::_()->user()->getViewer();
                $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
                $activityFeedType = null;
             
                $activityFeedType = 'sitecontest_cover_update';

                if ($activityFeedType) {
                    $action = $activityApi->addActivity($viewer, $sitecontest, $activityFeedType);
                }
                if ($action) {
                    Engine_Api::_()->getApi('subCore', 'sitecontest')->deleteFeedStream($action);
                    if ($photo)
                        Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $photo);
                }

                $this->view->status = true;
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                $this->view->status = false;
                $this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
                return;
            }
        }
    }
    public function removeCoverPhotoAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        $contest_id = $this->_getParam('contest_id');
        if ($this->getRequest()->isPost()) {
            $special = $this->_getParam('special', 'cover');
            $sitecontest = Engine_Api::_()->getItem('sitecontest_contest', $contest_id);
            $sitecontest->contest_cover = 0;
            $sitecontest->save();
            $tableAlbum = Engine_Api::_()->getDbtable('albums', 'sitecontest');
            $album = $tableAlbum->getSpecialAlbum($sitecontest, $special);
            $album->cover_params = array('top' => '0', 'left' => 0);
            $album->save();

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
            ));
        }
    }

    public function winnerAction() {

    	 //GROUP ID
        $contest_id = $this->_getParam('contest_id');

        $contest = Engine_Api::_()->getItem('sitecontest_contest', $contest_id);

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
		$date = $view->locale()->toDateTime(date('Y-m-d H:i:s'),array('size' => 'medium'));
		$result_date = $view->locale()->toDateTime($contest->result_datetime,array('size' => 'medium'));
	    $result_datetime = strtotime($result_date);
	    $current_date = strtotime($date);

	    if( $current_date <= $result_datetime && $contest->status == 'active') {
	      $this->_forward('success', 'utility', 'core', array(
	            'smoothboxClose' => 3000,
	            'class' => 'global_form_popup',
	            // 'parentRefresh' => true,
	            'messages' => array(Zend_Registry::get('Zend_Translate')->_(' You can not declare winners before the contest ends.  '))));
	    } elseif($contest->status == 'expired') {
	    	$this->_forward('success', 'utility', 'core', array(
	            'smoothboxClose' => 3000,
	            'class' => 'global_form_popup',
	            // 'parentRefresh' => true,
	            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Winners are already declared.'))));
	    } else {

			$value = Engine_Api::_()->authorization()->getPermission($contest->getOwner()->level_id, 'sitecontest_cont', "prize");
			$entryTable = Engine_Api::_()->getDbtable('entries', 'sitecontest');
			$entryTableName = $entryTable->info('name');
			$select = $entryTable->select()->from($entryTableName, '*')
			->where('contest_id=?', $contest->contest_id)
			->order('vote_count DESC')
			->limit($value);
			$entries = $entryTable->fetchAll($select);

			$allselect = $entryTable->select()->from($entryTableName, '*')
			->where('contest_id=?', $contest->contest_id)
			->order('vote_count DESC');
			$allentries = $entryTable->fetchAll($allselect);

			$owner = $contest->getOwner('user');
			$i =1;
			$tie = 0;
			$votes = array();

			$contest->status = 'expired';
			//Cheak any tie condition
			foreach ($entries as $entry) {
				if(in_array($entry->vote_count, $votes)) {
					$tie = 1; 

					// MAIL of Tie to SuperAdmin
					$users = Engine_Api::_()->user()->getSuperAdmins();
					foreach ($users as $user) {
						$contest->sendTieMail($user,$contest);
					}
					$this->_forward('success', 'utility', 'core', array(
		            'smoothboxClose' => 3000,
		            'class' => 'global_form_popup',
		            'parentRefresh' => true,
		            'messages' => array(Zend_Registry::get('Zend_Translate')->_('There is a tie between participants, the winners will be declared by admin. '))));
				}
				$votes[] = $entry->vote_count;
			}
			if(empty($tie)) {
				foreach ($entries as $entry) {
					if (empty($entry->winner)) {
						$entry->winner = $i;
						//Genrate Activity feed of Contest Winner
						$viewer = Engine_Api::_()->getItem('user', $entry->user_id);
						$action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $contest, 'sitecontest_winner',null,array('rank' => $i));
						if( $action ) {
							Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $entry);
						}

						//START DEFAULT EMAIL TO SUPERADMIN WHEN ANYONE CREATE PAGES.
						$awardTable = Engine_Api::_()->getDbtable('awards', 'sitecontest');
						$awardTableName = $awardTable->info('name');
						$select = $awardTable->select()->from($awardTableName, '*')
						->where('contest_id=?', $contest->contest_id);
						$awards = $awardTable->fetchRow($select);
						if ($i == 1) {
								$entry->award = $awards->first_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->first_award_message,$i);
								//MAil to contest Owner
								Engine_Api::_()->sitecontest()->resultdeclareEmail($contest);
						}elseif ($i == 2) {
								$entry->award = $awards->second_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->second_award_message,$i);
						}elseif ($i == 3) {
								$entry->award = $awards->third_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->third_award_message,$i);
						}elseif ($i == 4) {
								$entry->award = $awards->forth_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->forth_award_message,$i);
						}else{
								$entry->award = $awards->fifth_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->fifth_award_message,$i);
						}
						$i++;
						$entry->save();
					}
				}
				$followids = array();
				foreach ($allentries as $entry) {
					$followids[] = $entry->user_id;
					//Winner Declare Notification to ALl Entry Submitor
					$users = Engine_Api::_()->getItem('user',$entry->user_id);
					Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($users, $owner, $contest, 'sitecontest_Winner_declare');
				}

				//Winner Declare Notification to follower
				$followers = $contest->getFollowers($contest);
				foreach ($followers as $follower) {
					if(!in_array($follower->poster_id,$followids)) {
						$user = Engine_Api::_()->getItem('user',$follower->poster_id);
						Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $contest, 'sitecontest_Winner_declare');
					}
				}

				$this->_forward('success', 'utility', 'core', array(
	                    'smoothboxClose' => 3000,
	                    'class' => 'global_form_popup',
	                    'parentRefresh' => true,
	                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Winners are declared successfully.'))));
			}
			$contest->save();  
	    }
    }
}

?>