<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_PhotoController extends Seaocore_Controller_Action_Standard {

    //COMMON ACTION WHICH CALL BEFORE EVERY ACTION OF THIS CONTROLLER
    public function init() {
        //AUTHORIZATION CHECK
        if (!$this->_helper->requireAuth()->setAuthParams('sitecontest_cont', null, "view")->isValid())
            return;
        //SET SUBJECT
        if (!Engine_Api::_()->core()->hasSubject()) {

            if (0 != ($photo_id = (int) $this->_getParam('photo_id')) &&
                    null != ($photo = Engine_Api::_()->getItem('sitecontest_photo', $photo_id))) {
                Engine_Api::_()->core()->setSubject($photo);
            } else if (0 != ($entry_id = (int) $this->_getParam('entry_id')) &&
                    null != ($sitecontest = Engine_Api::_()->getItem('sitecontest_entry', $entry_id))) {
                Engine_Api::_()->core()->setSubject($sitecontest);
            }
        }

    }
    //ACTION FOR UPLOAD PHOTO
    public function uploadPhotoAction() {

        //GET SITEEVENT
        $sitecontest = Engine_Api::_()->getItem('sitecontest_contest', (int) $this->_getParam('contest_id'));

        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }
      
    //AUTHORIZATION CHECK
    $allowed_upload_photo = 1;

    if (empty($allowed_upload_photo)) {
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Maximum photo upload limit has been exceeded.');
      return;
    }

        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $values = $this->getRequest()->getPost();
        $response = Seaocore_Service_FancyUpload::upload();

        if (!empty($response['error'])) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
            return;
        }

        if (empty($response['path']) || empty(file_exists($response['path']))) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('No file');
            return;
        }

        $tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitecontest');
        $db = $tablePhoto->getAdapter();
        $db->beginTransaction();

        try {
            $viewer = Engine_Api::_()->user()->getViewer();
            $album = $sitecontest->getSingletonAlbum();
            $rows = $tablePhoto->fetchRow($tablePhoto->select()->from($tablePhoto->info('name'), 'order')->order('order DESC')->limit(1));
            $order = 0;
            if (!empty($rows)) {
                $order = $rows->order + 1;
            }
            $params = array(
                'collection_id' => $album->getIdentity(),
                'album_id' => $album->getIdentity(),
                'contest_id' => $sitecontest->getIdentity(),
                'user_id' => $viewer->getIdentity(),
                'order' => $order
            );
            $photo_id = Engine_Api::_()->sitecontest()->createPhoto($params, $response['path'])->photo_id;

            if (!$sitecontest->photo_id) {
                $sitecontest->photo_id = $photo_id;
                $sitecontest->save();
            }

            $this->view->status = true;
            // $this->view->name = $_FILES['Filedata']['name'];
            $this->view->photo_id = $photo_id;
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_($e->getMessage());
            return;
        }
        @unlink($response['path']);
    }

    //ACTION FOR EDITING OF PHOTOS TITLE AND DISCRIPTION
    public function editAction() {

        //GET PHOTO SUBJECT
        $photo = Engine_Api::_()->core()->getSubject();

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer->getIdentity();

        //AUTHORIZATION CHECK
        $canEdit = $photo->canEdit();
        if (!$canEdit) {
            return;
        }

        //MAKE FORM
        $this->view->form = $form = new Siteevent_Form_Photo_Edit();

        //CHECK METHOD
        if (!$this->getRequest()->isPost()) {
            $form->populate($photo->toArray());
            return;
        }

        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        //PROCESS
        $db = Engine_Api::_()->getDbtable('photos', 'sitecontest')->getAdapter();
        $db->beginTransaction();

        try {
            $photo->setFromArray($form->getValues())->save();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        return $this->_forwardCustom('success', 'utility', 'core', array(
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Changes saved')),
                    'layout' => 'default-simple',
                    'parentRefresh' => true,
                    'closeSmoothbox' => true,
        ));
    }

    //ACTION FOR PHOTO DELETE
    public function removeAction() {

        //GET PHOTO ID AND ITEM
        $photo_id = (int) $this->_getParam('photo_id');
        $photo = Engine_Api::_()->getItem('sitecontest_photo', $photo_id);

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer->getIdentity();

        //AUTHORIZATION CHECK
        $canEdit = $photo->canEdit();
        if (!$canEdit) {
            return;
        }

        //GET EVENT
        $sitecontest = $photo->getParent('sitecontest_cont');

        $isajax = (int) $this->_getParam('isajax');
        if ($isajax) {
            $db = Engine_Api::_()->getDbTable('photos', 'sitecontest')->getAdapter();
            $db->beginTransaction();

            try {
                $photo->delete();
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
        }

        //MAKE FORM
        $this->view->form = $form = new Siteevent_Form_Photo_Delete();

        //CHECK METHOD
        if (!$this->getRequest()->isPost()) {
            $form->populate($photo->toArray());
            return;
        }

        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $db = Engine_Api::_()->getDbTable('photos', 'sitecontest')->getAdapter();
        $db->beginTransaction();

        try {
            $photo->delete();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        return $this->_forwardCustom('success', 'utility', 'core', array(
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Photo deleted')),
                    'layout' => 'default-simple',
                    'parentRedirect' => $sitecontest->getHref(),
                    'closeSmoothbox' => true,
        ));
    }

    //ACTION FOR VIEWING THE PHOTO
    public function viewAction() {

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

        //GET PHOTOS
        $this->view->image = $photo = Engine_Api::_()->core()->getSubject();

        //GET SITEEVENT DETAILS
        // $this->view->sitecontest = $photo->getCollection();

        //GET SETTINGS
        // $this->view->canEdit = $photo->canEdit();

        if (!$viewer || !$viewer_id || $photo->user_id != $viewer->getIdentity()) {
            $photo->view_count = new Zend_Db_Expr('view_count + 1');
            $photo->save();
        }

        $this->view->enablePinit = Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.photo.pinit', 0);
    }

}
