<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecrowdfunding
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Transactions.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecrowdfunding_Model_DbTable_Transactions extends Engine_Db_Table {

    protected $_rowClass = 'Sitecrowdfunding_Model_Transaction';

    public function getBenefitStatus(User_Model_User $user = null) {
        return true;
    }

    public function getBackerTransactionsPaginator($params = array()) {
        $paginator = Zend_Paginator::factory($this->getBackerTransactionsSelect($params));

        if (!empty($params['page'])) {
            $paginator->setCurrentPageNumber($params['page']);
        }
        $paginator->setItemCountPerPage(10);
        return $paginator;
    }

    public function getBackerTransactionsSelect($params = array()) {
        $tableUserName = Engine_Api::_()->getItemTable('user')->info('name');
        $transactionsName = $this->info('name');

        $backerTableName = Engine_Api::_()->getDbtable('backers', 'sitecrowdfunding')->info('name');
        $gatewayTableName = Engine_Api::_()->getDbtable('gateways', 'payment')->info('name');

        $transactionSelect = $this->select()
                ->from($transactionsName, array('transaction_id', 'timestamp', 'state', 'amount', 'source_id'))
                ->setIntegrityCheck(false)
                ->join($backerTableName, "$backerTableName.backer_id = $transactionsName.source_id", array('backer_id', 'user_id', 'commission_value', 'payout_status', 'refund_status', 'gateway_type'))
                ->joinLeft($tableUserName, "$tableUserName.user_id = $backerTableName.user_id", 'username')
                ->joinLeft($gatewayTableName, "$transactionsName.gateway_id = $gatewayTableName.gateway_id", 'title as gateway_title');

        //FETCH ONLY SITECROWDFUNDING_PROJECT TYPE ROWS
        $transactionSelect->where($transactionsName . '.source_type = ?', 'sitecrowdfunding_backer');

        if (isset($params['project_id']) && !empty($params['project_id'])) {
            $transactionSelect->where($backerTableName . '.project_id = ?', $params['project_id']);
        }

        if (!empty($params['backer_name'])) {
            $transactionSelect->where($tableUserName . '.username  LIKE ?', '%' . trim($params['backer_name']) . '%');
        }

        if (isset($params['from']) && !empty($params['from'])) {
            $transactionSelect->where("CAST($transactionsName.timestamp AS DATE) >=?", trim($params['from']));
        }

        if (isset($params['to']) && !empty($params['to'])) {
            $transactionSelect->where("CAST($transactionsName.timestamp AS DATE) <=?", trim($params['to']));
        }

        if (isset($params['transaction_min_amount']) && is_numeric($params['transaction_min_amount'])) {
            $transactionSelect->where("$transactionsName.amount >= " . trim($params['transaction_min_amount']));
        }
        if (isset($params['transaction_max_amount']) && is_numeric($params['transaction_max_amount'])) {
            $transactionSelect->where("$transactionsName.amount <= " . trim($params['transaction_max_amount']));
        }
        if (isset($params['commission_min_amount']) && is_numeric($params['commission_min_amount'])) {
            $transactionSelect->where("$backerTableName.commission_value >= " . trim($params['commission_min_amount']));
        }

        if (isset($params['commission_max_amount']) && is_numeric($params['commission_max_amount'])) {
            $transactionSelect->where("$backerTableName.commission_value <= " . trim($params['commission_max_amount']));
        }

        if (!empty($params['payment_status']))
            $transactionSelect->where($backerTableName . '.payment_status = ?', $params['payment_status']);

        $transactionSelect->group("$backerTableName.backer_id");
        $transactionSelect->order("$backerTableName.backer_id DESC"); 
        return $transactionSelect;
    } 


    /**
     * Return transactions state
     *
     * @param $sender_type
     * @param #project_id
     * @return string
     */
    public function getTransactionState($sender_type = false, $project_id = null) {
        $paymentRequestTableName = Engine_Api::_()->getDbtable('paymentrequests', 'sitecrowdfunding')->info('name');
        $transactionTableName = $this->info('name');

        $select = $this->select()
                ->setIntegrityCheck(false)
                ->from($transactionTableName, array('state'))
                ->distinct(true)
                ->join($paymentRequestTableName, "($paymentRequestTableName.request_id = $transactionTableName.source_id)", '')
                ->where("$transactionTableName.source_type = ?", 'sitecrowdfunding_paymentrequest');

        empty($sender_type) ? $select->where("sender_type = 0") : $select->where("sender_type = 1");

        if (!empty($project_id))
            $select->where("$paymentRequestTableName.project_id =?", $project_id);

        return $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
    }
}
