<?php

class Siteerror_Form_Admin_ComingSoon extends Engine_Form
{

  public function init()
  {
    $this
    ->setTitle('Coming Soon Page')
    ->setDescription('Here, you can configure the the custom layout for the Coming Soon page on your website.  You can show Coming Soon Page on your website to all the visitors, if your website has to be launched in near future.');

    $coreSettingApi = Engine_Api::_()->getApi('settings', 'core');

    $settingPrefix = 'siteerror.comingsoon.';


    $this->addElement('Radio', 'enable', array(
      'label' => 'Enable Custom Template',
      'description' => "Do you want to enable the custom template for 'Coming Soon' page on your website? If you choose 'Yes', then a custom designed template for Coming Soon will show to your users.
      [Note: Below mentioned settings may not not apply if you select 'No' for Enable Custom Template]
      ",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'enable', 0),
    ));

    $templates = array(
      'template1' => $this->templateOptionLabel('template1.png'),
      'template2' => $this->templateOptionLabel('template2.png'),
      'template3' => $this->templateOptionLabel('template3.png'),
      'template4' => $this->templateOptionLabel('template4.png')
    );
    $this->addElement('Radio', 'template', array(
      'label' => 'Design Template',
      'description' => "Select one template from below preconfigured design templates for Coming Soon page on your website. You can change the image used for the active template, but if you want to show default image, then simply remove your image from below.",
      'multiOptions' => $templates,
      'escape' => false,
      'value' => $coreSettingApi->getSetting($settingPrefix . 'template', 'template1'),
    ));

    $launchDate = new Engine_Form_Element_CalendarDateTime('launchdate');
    $launchDate->setLabel("Website Launch Date");
    $launchDate->setDescription("Choose a launch date for your website. After the website launch date, Coming Soon Page will automatically hide and your website will be visible to all.");
    $this->addElement($launchDate);

    $siteLaunchDate = $coreSettingApi->getSetting($settingPrefix . 'launchdate');
    if( !empty($siteLaunchDate) ) {
      $launchDate->setValue(date('Y-m-d', strtotime($siteLaunchDate)). ' 00:00:00');
    } else {
      $launchDate->setValue(date('Y-m-d'). ' 00:00:00');
    }

    $this->addElement('Text', 'heading', array(
      'label' => 'Heading',
      'description' => 'Enter the heading that you want to display on your custom Coming Soon page.',
      'allowEmpty' => false,
      'required' => true,
      'value' => $coreSettingApi->getSetting($settingPrefix . 'heading', "Coming Soon!"),
    ));

    $this->addElement('Text', 'subheading', array(
      'label' => 'Sub Heading',
      'description' => 'Enter the sub heading that you want to display on your custom Coming Soon page.',
      'value' => $coreSettingApi->getSetting($settingPrefix . 'subheading', "We’re currently working on creating our new website."),
    ));

    $this->addElement('Text', 'body', array(
      'label' => 'Description / Tagline',
      'description' => 'Enter the textual description / tagline that you want to display on your custom Coming Soon page.',
      'value' => $coreSettingApi->getSetting($settingPrefix . 'body', " We Have Been Spending Long Hours In Order To Launch Our New Website. You Can Always Contact Us If You Have Some Query."),
    ));

    $this->addElement('Radio', 'contact_enable', array(
      'label' => 'Show Contact Button',
      'description' => "Do you want to show contact button on the Coming Soon Page on your website?",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'contact_enable', 1),
    ));

    $this->addElement('Select', 'overlay', array(
      'label' => 'Overlay',
      'description' => "Do you want to set overlay effect for your custom Coming Soon page?",
      'multiOptions' => array(
        'siteerrorOverlayOff' => 'Off',
        'siteerrorOverlayDark' => 'Dark Overlay',
        'siteerrorOverlayLight' => 'Light Overlay',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'overlay', 'siteerrorOverlayOff'),
    ));

    $this->addElement('File', 'background_photo', array(
      'label' => 'Background Image',
      'description' => 'Choose a background image to be displayed on your custom Coming Soon page.
      [Note: If you do not upload an image, then default background image will display.]'
    ));
    $this->background_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');

    $fileId = $coreSettingApi->getSetting($settingPrefix . 'background.photo', 0);
    $photoUrl = Engine_Api::_()->siteerror()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_photo', array(
        'label' => 'Remove Background Image.'
      ));
    }

    $this->addElement('File', 'front_photo', array(
      'label' => 'Front Image',
      'description' => 'Choose a front image to be displayed on your custom Coming Soon page.
      [Note: Front image will be shown only in the templates which support it. If you do not upload an image, then default front image will display.]'
    ));
    $this->front_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');
    $fileId = $coreSettingApi->getSetting($settingPrefix . 'front.photo', 0);
    $photoUrl = Engine_Api::_()->siteerror()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_front_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_front_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_front_photo', array(
        'label' => 'Remove Front Image.'
      ));
    }

    $this->addElement('Radio', 'socialsites_enable', array(
      'label' => 'Enable Social Media links ',
      'description' => 'Do you want to enable the Social Media Links in Coming Soon page on your website?',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'socialsites.enable', 1),
    ));

    $this->addElement('Button', 'execute', array(
      'label' => 'Save Settings',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array('ViewHelper'),
    ));
  }

  private function templateOptionLabel($template)
  {
    return '<div><img src="./application/modules/Siteerror/externals/images/templates/coming-soon/' . $template . '" alt="" /></div>';
  }

}