<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteestore
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2012-10-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Siteestore_Api_Core extends Core_Api_Abstract {

  /**
   * Getting the Host name.
   *
   * @return string
   */
  public function getHost() {
    return str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));
  }

  /**
   * Getting the Magento host name, which configured by siteadmin.
   *
   * @return string
   */
  public function getHostUrl() {
    $hostType = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteestore.hostType', 'http');
    $host = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteestore.api.host', '');
    $host = $hostType . '://' . $host;
    $host = rtrim($host, "/");
    return $host;
  }

  /**
   * Getting the status of the user is enabled or disabled.
   *
   * @return true / false
   */
  public function getUserStatus() {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    if (!empty($viewer_id) && ($viewer->level_id != 1)) {
      $status = Engine_Api::_()->getDbTable('users', 'siteestore')->getUser(array('se_user_id' => $viewer_id));
      if( !empty($status) && empty($status[0]['enable']) ) {
        return false;
      }
    }
    return true;
  }

  /**
   * Getting the Magento website information.
   *
   * @param $key: Name of the array key.
   * @return string
   */
  public function getWebsite($key = null) {
    $websiteInfo = @unserialize(Engine_Api::_()->getApi('settings', 'core')->getSetting('mage.website.info'));
    $data = empty($key) ? $websiteInfo : $websiteInfo[$key];
    return $data;
  }

  /**
   * Getting the Magento store information.
   *
   * @param $key: Name of the array key.
   * @return string
   */
  public function getStore($key = null) {
    $storeInfo = @unserialize(Engine_Api::_()->getApi('settings', 'core')->getSetting('mage.store.info'));
    $data = empty($key) ? $storeInfo : $storeInfo[$key];
    return $data;
  }

  
  /**
   * Getting the SocialEngine base url.
   *
   * @return array
   */
  public function getSEBaseUrl() {
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $data = array('host' => $this->getHost(), 'path' => trim($view->baseUrl(), '/'));
    
    $requestUri = Zend_Controller_Front::getInstance()->getRequest()->getRequestUri();
    if( strstr($requestUri, "index.php") ) {
      $data['path'] = !empty($data['path']) ? '/' . $data['path'] . '/index.php' : '/index.php';
    }else {
      $data['path'] = !empty($data['path']) ? '/' . $data['path'] : '';
    }

    return $data;
  }

  /**
   * Getting the Magento base url.
   *
   * @return array
   */
  public function magentoBaseUrl() {
    $host = $this->getHostUrl();
    $host = str_replace("/index.php", "", $host);
    $parseHost = parse_url($host);
    if( !empty($parseHost['path']) ) {
      $parseHost['path'] = trim($parseHost['path'], '/');
      $parseHost['path'] = !empty($parseHost['path']) ? '/' . $parseHost['path'] : '';
    }
    
    if( !array_key_exists('path', $parseHost) ) {
      $parseHost['path'] = '';
    }
    
    return $parseHost;
  }

  /**
   * Getting the SocialEngine site protocol.
   *
   * @return string
   */
  public function getSEProtocol() {
    $hostType = "http://";
    if ((!empty($_SERVER["HTTPS"])) && (@$_SERVER["HTTPS"] == "on")) {
      $hostType = "https://";
    }

    return $hostType;
  }

  /**
   * Getting the Magento site protocol.
   *
   * @return string
   */
  public function getMageProtocol() {
    $hostType = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteestore.hostType', 'http');
    $hostType .=!empty($hostType) ? '://' : '';
    return $hostType;
  }

  /**
   * Getting the prefields url, which configured by siteadmin.
   *
   * @return string
   */
  public function getGlobalUrls() {
    $url = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteestore.manifestUrl', "shop");
    return $url;
  }

  /**
   * Getting all the widgets name array, which placed on passed page.
   * @param $pageId: Page id, which all widgets name will be returned.
   * @return array
   */
  public function getPageBlock($pageId) {
    $bockArray = array();
    $contentTable = Engine_Api::_()->getDbtable('content', 'core');
    $contentTableName = $contentTable->info('name');
    $contentSelect = $contentTable->select()
            ->from($contentTableName, array('params'))
            ->where('page_id = ?', $pageId)
            ->where('name LIKE "Siteestore.blocks"');
    $contentArray = $contentSelect->query()->fetchAll();

    if (!empty($contentArray)) {
      foreach ($contentArray as $parems) {
        $parems = !empty($parems['params']) ? Zend_Json::decode($parems['params']) : array();
        $blockName = $parems['block_name'];
        if ($parems['block_name'] == '-1') {
          $blockName = $parems['shop_block_name'];
        }
        $bockArray[$blockName] = $blockName;
      }
    }

    if (!array_key_exists('catalog.leftnav', $bockArray)) {
      $bockArray['catalog.leftnav'] = 'catalog.leftnav';
    }
    return $bockArray;
  }

  /**
   * Create Magento user in "siteestore_users" tables.
   * 
   * @param $data: Array of the user informtion, which will create in "siteestore_users" table.
   */
  public function crateUser($data) {
    if (!empty($data['user_id'])) {
      $viewer = Engine_Api::_()->getItem('user', $data['user_id']);
    } else {
      $viewer = Engine_Api::_()->user()->getViewer();
    }

    $websiteId = Engine_Api::_()->siteestore()->getWebsite('id');

    $firstName = $data['firstname'];
    $lastName = $data['lastname'];

    $existUesr = Engine_Api::_()->getDbtable("users", "siteestore")->existUser(array('se_user_id' => $viewer->getIdentity()));

    if (empty($existUesr)) {
      Engine_Api::_()->getDbtable("users", "siteestore")->setUser(array("mage_user_id" => $data['id'], "se_user_id" => $viewer->getIdentity(), "name" => $firstName . ' ' . $lastName, "website" => $websiteId, "enable" => true));
    } else {
      //Engine_Api::_()->getDbtable("users", "siteestore")->update(array("mage_user_id" => $data['id'], "se_user_id" => $viewer->getIdentity(), "name" => $firstName . ' ' . $lastName, "website" => $websiteId, "enable" => true), array('se_user_id =?' => $viewer->getIdentity()));
    }

    return;
  }

  /**
   * Create Magento user in SocialEngine.
   *
   * @param $data: array of the user information, which user need to be create in SocialEngine.
   */
  public function doSignup($data) {
    $info['email'] = $data['email'];
    $info['password'] = $data['password'];
    $info['passconf'] = $data['password'];
    $info['displayname'] = $data['firstname'] . ' ' . $data['lastname'];
    $info['username'] = preg_replace('/[^A-Za-z0-9]/', '', $data['email']);
    $info['profile_type'] = 1; // Admin Given
    $info['timezone'] = 'US/Pacific'; // Admin Given
    $info['language'] = 'en'; // Admin Given
    $info['terms'] = 1;
    $info['local'] = 'en';

    $settings = Engine_Api::_()->getApi('settings', 'core');
    $emailadmin = ($settings->getSetting('user.signup.adminemail', 0) == 1);
    $random = ($settings->getSetting('user.signup.random', 0) == 1);

    $users_table = Engine_Api::_()->getDbtable('users', 'user');
    if ($emailadmin) {
      // the signup notification is emailed to the first SuperAdmin by default
      $users_select = $users_table->select()
              ->where('level_id = ?', 1)
              ->where('enabled >= ?', 1);
      $super_admin = $users_table->fetchRow($users_select);
    }

    $user = Engine_Api::_()->getDbtable('users', 'user')->createRow();
    $user->setFromArray($info);
    $user->save();
    Engine_Api::_()->user()->setViewer($user);

    // Increment signup counter
    Engine_Api::_()->getDbtable('statistics', 'core')->increment('user.creations');

    if ($user->verified && $user->enabled) {
      // Create activity for them
      Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($user, $user, 'signup');
      // Set user as logged in if not have to verify email
      Engine_Api::_()->user()->getAuth()->getStorage()->write($user->getIdentity());
    }

    $mailType = null;
    $mailParams = array(
        'host' => $_SERVER['HTTP_HOST'],
        'email' => $user->email,
        'date' => time(),
        'recipient_title' => $user->getTitle(),
        'recipient_link' => $user->getHref(),
        'recipient_photo' => $user->getPhotoUrl('thumb.icon'),
        'object_link' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(), 'user_login', true),
    );

    // Add password to email if necessary
    if ($random) {
      $mailParams['password'] = $data['password'];
    }

    // Mail stuff
    switch ($settings->getSetting('user.signup.verifyemail', 0)) {
      case 0:
        // only override admin setting if random passwords are being created
        if ($random) {
          $mailType = 'core_welcome_password';
        }
        if ($emailadmin) {
          $mailAdminType = 'notify_admin_user_signup';

          $mailAdminParams = array(
              'host' => $_SERVER['HTTP_HOST'],
              'email' => $user->email,
              'date' => date("F j, Y, g:i a"),
              'recipient_title' => $super_admin->displayname,
              'object_title' => $user->displayname,
              'object_link' => $user->getHref(),
          );
        }
        break;

      case 1:
        // send welcome email
        $mailType = ($random ? 'core_welcome_password' : 'core_welcome');
        if ($emailadmin) {
          $mailAdminType = 'notify_admin_user_signup';

          $mailAdminParams = array(
              'host' => $_SERVER['HTTP_HOST'],
              'email' => $user->email,
              'date' => date("F j, Y, g:i a"),
              'recipient_title' => $super_admin->displayname,
              'object_title' => $user->getTitle(),
              'object_link' => $user->getHref(),
          );
        }
        break;

      case 2:
        // verify email before enabling account
        $verify_table = Engine_Api::_()->getDbtable('verify', 'user');
        $verify_row = $verify_table->createRow();
        $verify_row->user_id = $user->getIdentity();
        $verify_row->code = md5($user->email
                . $user->creation_date
                . $settings->getSetting('core.secret', 'staticSalt')
                . (string) rand(1000000, 9999999));
        $verify_row->date = $user->creation_date;
        $verify_row->save();

        $mailType = ($random ? 'core_verification_password' : 'core_verification');

        $mailParams['object_link'] = Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
            'action' => 'verify',
            'email' => $user->email,
            'verify' => $verify_row->code
                ), 'user_signup', true);

        if ($emailadmin) {
          $mailAdminType = 'notify_admin_user_signup';

          $mailAdminParams = array(
              'host' => $_SERVER['HTTP_HOST'],
              'email' => $user->email,
              'date' => date("F j, Y, g:i a"),
              'recipient_title' => $super_admin->displayname,
              'object_title' => $user->getTitle(),
              'object_link' => $user->getHref(),
          );
        }
        break;

      default:
        // do nothing
        break;
    }

    if ($mailType) {
      // Moved to User_Plugin_Signup_Fields
      Engine_Api::_()->getApi('mail', 'core')->sendSystem(
              $user, $mailType, $mailParams
      );
    }

    if ($mailAdminType) {
      // Moved to User_Plugin_Signup_Fields
      Engine_Api::_()->getApi('mail', 'core')->sendSystem(
              $user, $mailType, $mailParams
      );
    }
  }

  /**
   * Plugin which return the error, if Siteadmin not using correct version for the plugin.
   *
   */
  public function isModulesSupport() {
    $modArray = array(
        'suggestion' => '4.2.7',
        'facebookse' => '4.2.7p1',
        'sitelike' => '4.2.7',
        'sitefaq' => '4.2.7'
    );
    $finalModules = array();
    foreach ($modArray as $key => $value) {
      $isModEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($key);
      if (!empty($isModEnabled)) {
        $getModVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule($key);
        $isModSupport = $this->checkVersion($getModVersion->version, $value);
        if (empty($isModSupport)) {
          $finalModules[] = $getModVersion->title;
        }
      }
    }
    return $finalModules;
  }
    private function checkVersion($databaseVersion, $checkDependancyVersion) {
        $f = $databaseVersion;
        $s = $checkDependancyVersion;
        if (strcasecmp($f, $s) == 0)
            return -1;

        $fArr = explode(".", $f);
        $sArr = explode('.', $s);
        if (count($fArr) <= count($sArr))
            $count = count($fArr);
        else
            $count = count($sArr);

        for ($i = 0; $i < $count; $i++) {
            $fValue = $fArr[$i];
            $sValue = $sArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                if ($fValue > $sValue)
                    return 1;
                elseif ($fValue < $sValue)
                    return 0;
                else {
                    if (($i + 1) == $count) {
                        return -1;
                    } else
                        continue;
                }
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);

                if ($fsArr[0] > $sValue)
                    return 1;
                elseif ($fsArr[0] < $sValue)
                    return 0;
                else {
                    return 1;
                }
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);

                if ($fValue > $ssArr[0])
                    return 1;
                elseif ($fValue < $ssArr[0])
                    return 0;
                else {
                    return 0;
                }
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                if ($fsArr[0] > $ssArr[0])
                    return 1;
                elseif ($fsArr[0] < $ssArr[0])
                    return 0;
                else {
                    if ($fsArr[1] > $ssArr[1])
                        return 1;
                    elseif ($fsArr[1] < $ssArr[1])
                        return 0;
                    else {
                        return -1;
                    }
                }
            }
        }
    }
  /**
   * Check widgets will render or not on the page.
   *
   */
  public function isWidgetsRender() {
    return true;
    $requestUri = Zend_Controller_Front::getInstance()->getRequest()->getRequestUri();
    if (strstr($requestUri, 'checkout') || strstr($requestUri, '?')) {
      return false;
    }

    return true;
  }

  /**
   * This function return the complete path of image, from the photo id.
   *
   * @param $id: The photo id.
   * @param $type: The type of photo required.
   * @return Image path.
   */
  public function getPhoto($id, $type = 'thumb.profile') {
    if (empty($id)) {
      return null;
    }
    $file = Engine_Api::_()->getItemTable('storage_file')->getFile($id, $type);
    if (!$file) {
      return null;
    }

    // Get url of the image
    $src = $file->map();
    return $src;
  }

  /**
   *
   * @param $title: String which are require for truncate
   * @return string
   */
  public function truncateStr($title, $truncateLimit = 15) {
    $tmpBody = strip_tags($title);
    return ( Engine_String::strlen($tmpBody) > $truncateLimit ? Engine_String::substr($tmpBody, 0, $truncateLimit) . '..' : $tmpBody );
  }

  /**
   * CONVERT THE DECODE STRING INTO ENCODE
   * 
   * @param $string: string which need to be encode.
   * @return string
   */
  public function getEncode($string=null) {
    $encodeString = '';

    if (!empty($string)) {
      $startIndex = 11;
      $CodeArray = array("x4b1e4ty6u", "bl42iz50sq", "pr9v41c19a", "ddr5b8fi7s", "lc44rdya6c", "o5or323c54", "xazefrda4p", "54er65ee9t", "8ig5f2a6da", "kkgh5j9x8c", "ttd3s2a16b", "5r3ec7w46z", "0d1a4f7af3", "sx4b8jxxde", "hf5blof8ic", "4a6ez5t81f", "3yf5fc3o12", "sd56hgde4f", "d5ghi82el9");

      $time = time();
      $timeLn = Engine_String::strlen($time);
      $last2DigtTime = substr($time, $timeLn - 2, 2);
      $sI1 = (int) ($last2DigtTime / 10);
      $sI2 = $last2DigtTime % 10;
      $Index = $sI1 + $sI2;

      $codeString = $CodeArray[$Index];
      $startIndex+=$Index % 10;
      $lenght = Engine_String::strlen($string);
      for ($i = 0; $i < $lenght; $i++) {
        $code = md5(uniqid(rand(), true));
        $encodeString.= substr($code, 0, $startIndex);
        $encodeString.=$string{$i};
        $startIndex++;
      }
      $code = md5(uniqid(rand(), true));
      $appendEnd = substr($code, 5, $startIndex);
      $prepandStart = substr($code, 20, 10);
      $encodeString = $prepandStart . $codeString . $encodeString . $appendEnd;
    }

    return $encodeString;
  }

  /**
   * CONVERT THE ENCODE STRING INTO DECODE
   * 
   * @param $string: string which need to be decode.
   * @return string
   */
  public function getDecode($string) {
    $decodeString = '';

    if (!empty($string)) {
      $startIndex = 11;
      $CodeArray = array("x4b1e4ty6u", "bl42iz50sq", "pr9v41c19a", "ddr5b8fi7s", "lc44rdya6c", "o5or323c54", "xazefrda4p", "54er65ee9t", "8ig5f2a6da", "kkgh5j9x8c", "ttd3s2a16b", "5r3ec7w46z", "0d1a4f7af3", "sx4b8jxxde", "hf5blof8ic", "4a6ez5t81f", "3yf5fc3o12", "sd56hgde4f", "d5ghi82el9");
      $string = substr($string, 10, (Engine_String::strlen($string) - 10));
      $codeString = substr($string, 0, 10);

      $Index = array_search($codeString, $CodeArray);
      $string = substr($string, 10, Engine_String::strlen($string) - 10);
      $startIndex+=$Index % 10;

      $string = substr($string, 0, (Engine_String::strlen($string) - $startIndex));

      $lenght = Engine_String::strlen($string);
      $j = 1;
      for ($i = $startIndex; $i < $lenght;
      ) {
        $j++;
        $decodeString.= $string{$i};
        $i = $i + $startIndex + $j;
      }
    }
    return $decodeString;
  }

  /**
   * GET LIKES COUNT FOR THE RESPECTIVE PASSED ID.
   * 
   * @param $id: Product id
   * @return int
   */
  public function getLike($id) {
    $like_count = 0;
    $table = Engine_Api::_()->getDbtable('likes', 'core');
    $name = $table->info('name');
    $select = $table->select()
            ->setIntegrityCheck(false)
            ->from($name, array('COUNT(like_id) AS like_count'))
            ->where('resource_type =?', 'siteestore_product')
            ->where('resource_id  =?', $id)
            ->limit(1);
    $fetch = $select->query()->fetch();

    $like_count = !empty($fetch) ? $fetch['like_count'] : $like_count;
    return $like_count;
  }

}

?>
