<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteestore
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Orders.php 2012-10-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Siteestore_Model_DbTable_Orders extends Engine_Db_Table {

  protected $_name = 'siteestore_orders';
  protected $_rowClass = 'Siteestore_Model_Order';

  /**
   * SET THE ORDER INTO THE TABLE.
   *
   * @param $data: Array of the information, which need to be insert into the table.
   * @return
   */
  public function setOrder($data) {
    $row = $this->createRow();
    $row->order_id = $data['order'];
    $row->product_id = $data['products'];
    $row->owner_id = $data['owner_id'];
    $row->quantity = $data['quantity'];
    $row->save();
    return true;
  }

  /**
   * GET THE ORDER FROM THE TABLE.
   *
   * @param $data: Array of the information, which need to be filter from the table.
   * @return: array
   */
  public function getOrder($data) {
    $table = $this->info('name');
    $select = $this->select();

    if (!empty($data)) {
      foreach ($data as $key => $value) {
        $select->where('`' . $key . '`=?', $value);
      }
    }
    $fetchArray = $select->query()->fetchAll();
    return $fetchArray;
  }

  /**
   * GETTING THE PRODUCTS ACCORDING TO THE QUANTITY.
   *
   * @param $data: Array of the information, which need to be filter from the table.
   * @return: array
   */
  public function getProductQtys($data) {
    $name = $this->info('name');

    $productTable = Engine_Api::_()->getDbTable('products', 'siteestore');
    $productName = $productTable->info('name');

    $select = $this->select()
            ->setIntegrityCheck(false)
            ->from($name, array('owner_id', 'product_id', 'SUM(' . $name . '.quantity) AS quantity_count'))
            ->join($productName, "`{$productName}`.`product_id`= `{$name}`.product_id", null)
            ->where($productName . '.status =?', 1);

    if (!empty($data)) {
      foreach ($data as $key => $value) {
        $select->where($name . '.`' . $key . '`=?', $value);
      }
    }

    $select
            ->where($name . '.quantity != ?', 0)
            ->group($name . '.product_id');
    $fetchArray = $select->query()->fetchAll();

    return $fetchArray;
  }

  /**
   * GET THE TOP BUYER.
   *
   * @return: object
   */
  public function topBuyer($limit) {
    $userTable = Engine_Api::_()->getItemTable('user');
    $userName = $userTable->info('name');

    $productTable = Engine_Api::_()->getDbTable('products', 'siteestore');
    $productName = $productTable->info('name');

    $name = $this->info('name');

    $select = $this->select()
            ->setIntegrityCheck(false)
            ->from($name, array('owner_id', 'SUM(' . $name . '.quantity) AS quantity_count'))
            ->join($userName, "`{$userName}`.`user_id`= `{$name}`.owner_id")
            ->join($productName, "`{$productName}`.`product_id`= `{$name}`.product_id", null)
            ->where($productName . '.status =?', 1)
            ->group($name . '.owner_id')
            ->order('quantity_count DESC');
            
    if( !empty($limit) ) {
      $select->limit($limit);
    }
    
    $fetch = $userTable->fetchAll($select);
    if (!empty($fetch)) {
      return $fetch;
    }
    return;
  }

}
