<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteestore
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Users.php 2012-10-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Siteestore_Model_DbTable_Users extends Engine_Db_Table {

  protected $_name = 'siteestore_users';
  protected $_rowClass = 'Siteestore_Model_User';

  /**
   * INSERT THE USER INFORMATION INTO THIS TABLE.
   *
   * @param $data: Array of the information, which required for filter data.
   * @return array
   */
  public function setUser($data) {
    $row = $this->createRow();
    $row->se_user_id = $data["se_user_id"];
    $row->mage_user_id = $data["mage_user_id"];
    $row->name = $data["name"];
    $row->website = $data["website"];
    $row->enable = $data["enable"];
    $row->save();
    return;
  }

  /**
   * RETURN THE USER OBJECT FOR THE "MANAGE USER" PAGE.
   *
   * @param $data: Array of the information, which required for filter data.
   * @return array
   */
  public function getUser($data = array()) {
    $table = $this->info('name');
    $select = $this->select();

    if (!empty($data)) {
      foreach ($data as $key => $value) {
        $select->where($key . '=?', $value);
      }
    }

    $fetchArray = $select->query()->fetchAll();
    return $fetchArray;
  }

  /**
   * RETURN THE USER OBJECT FOR THE "MANAGE USER" PAGE.
   *
   * @param $params: Array of the user information for filtering data.
   * @return object
   */
  public function getUsersPaginator($params = array()) {
    $websiteId = Engine_Api::_()->getApi('settings', 'core')->getSetting('mage.website', 0);
    $tableName = $this->info('name');

    $userTable = Engine_Api::_()->getItemtable('user');
    $userTableName = $userTable->info('name');


    $select = $this->select()
            ->setIntegrityCheck(false)
            ->from($tableName, array('mage_user_id', 'name', 'website', 'enable'))
            ->join($userTableName, "`$userTableName`.`user_id`=`$tableName`.`se_user_id`", array('user_id', 'email', 'displayname', 'username', 'level_id'));

    $select->order((!empty($params['order']) ? $params['order'] : 'user_id' ) . ' ' . (!empty($params['order_direction']) ? $params['order_direction'] : 'DESC' ));

    if (!empty($params['displayname'])) {
      $select->where($userTableName . '.displayname LIKE ?', '%' . $params['displayname'] . '%');
    }
    if (!empty($params['username'])) {
      $select->where($userTableName . '.username LIKE ?', '%' . $params['username'] . '%');
    }
    if (!empty($params['email'])) {
      $select->where($userTableName . '.email LIKE ?', '%' . $params['email'] . '%');
    }

    $queryArray = $select->query()->fetchAll();

    $paginator = Zend_Paginator::factory($select);
    if (!empty($params['page'])) {
      $paginator->setCurrentPageNumber($params['page']);
    }
    if (!empty($params['limit'])) {
      $paginator->setItemCountPerPage($params['limit']);
    }

    if (empty($params['limit'])) {
      $page = 10;
      $paginator->setItemCountPerPage($page);
    }

    return $paginator;
  }

  /**
   * RETURN THE USER EXIST OR NOT.
   *
   * @param $data: Array of the information, which required for filter data.
   * @return array
   */
  public function existUser($data) {
    $table = $this->info('name');
    $select = $this->select();

    foreach ($data as $key => $value) {
      $select->where("$key = ?", $value);
    }
    $select->limit(1);

    $fetchArray = $select->query()->fetchAll();
    $fetchArray = !empty($fetchArray) ? $fetchArray[0] : array();
    return $fetchArray;
  }

  /**
   * CALLING WHEN USER WILL DELETE HIS ACCOUNT FROM THE SocilEngine EXISTING SITE. USER WILL DELETE FROM THE MAGENTOINT_USER TABLE ALSO.
   *
   * @param $seUserId: User id.
   * @return
   */
  public function deleteUser($seUserId) {
    $db = Zend_Db_Table_Abstract::getDefaultAdapter();
    $db->query("DELETE FROM `engine4_siteestore_users` WHERE `engine4_siteestore_users`.`se_user_id` = " . $seUserId['se_user_id'] . " LIMIT 1");
  }

}