<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteevent
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Encode.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteevent_Plugin_Job_Invite extends Core_Plugin_Job_Abstract
{
  public $_chunk = 10;

  protected function _execute()
  {
    // Get job and params
    $job = $this->getJob();
    $isComplete = false;
    $progress = $this->getParam('progress', 0);

    if( !$progress ) {
      $this->setParam('progress', 0);
    }

    // No viewer id?
    if (!($viewer_id = $this->getParam('viewer_id'))) {
      $this->_setState('failed', 'No viewer identity provided.');
      $this->_setWasIdle();
      return;
    }

    // No event id?
    if (!($event_id = $this->getParam('event_id'))) {
      $this->_setState('failed', 'No event identity provided.');
      $this->_setWasIdle();
      return;
    }

    // No user ids?
    if (empty($usersIds = $this->getParam('usersIds')) || empty(json_decode($usersIds))) {
      $this->_setState('failed', 'No users identity provided.');
      $this->_setWasIdle();
      return;
    }

    $usersIds = json_decode($usersIds);
    $occurrence_id = $this->getParam('occurrence_id');

    // Get event object
    $event = Engine_Api::_()->getItem('siteevent_event', $event_id);
    if (!$event || !($event instanceof Siteevent_Model_Event)) {
      $this->_setState('failed', 'Event is missing.');
      $this->_setWasIdle();
      return;
    }

    // Get viewer object
    $viewer = Engine_Api::_()->getItem('user', $viewer_id);
    if (!$viewer || !($viewer instanceof User_Model_User)) {
      $this->_setState('failed', 'Event is missing.');
      $this->_setWasIdle();
      return;
    }

    // Process
    try {
      $processIds = array_slice($usersIds, 0, $this->_chunk);
      $this->_process($event, $viewer, $processIds, $occurrence_id);
      
      $updateIds = array_values(array_diff($usersIds, $processIds));
      $this->setParam('usersIds', json_encode($updateIds));
      
      if (!empty($updateIds)) {
        $progress = $this->getTaskProgress($progress, $usersIds);
        $this->setParam('progress', $progress);
        $isComplete = false;
      } else {
        $this->setParam('progress', 1);
        $isComplete = true;
      }
    } catch (Exception $e) {
      $this->_setState('failed', 'Process ' . ($progress*100) . '% completed. Exception: ' . $e->getMessage());
    }

    $this->_setIsComplete($isComplete);
    return;
  }

  private function _process($event, $viewer, $processIds, $occurrence_id) {

      $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
      $friendsToJoin = array();

      foreach ($processIds as $user_id) {
          $user = Engine_Api::_()->getItem('user', $user_id);

          if (null === $user || !isset($user->email)) {
              continue;
          }
          if ($event->membership()->isMember($user, null)) {
              continue;
          }
          
          $friendsToJoin[] = $user->email . '#' . $user->displayname;
          $event->membership()->addMember($user)
                  ->setResourceApproved($user);

          if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteeventinvite'))
              $notifyApi->addNotification($user, $viewer, $event, 'siteevent_invite', array('occurrence_id' => $occurrence_id));
      }

      //SEND MAIL NOTIFICATION AS WELL
      if (!empty($friendsToJoin) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteeventinvite') && Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode'))
          Engine_Api::_()->getApi('Invite', 'Seaocore')->sendPageInvites($friendsToJoin, $event->event_id, 'siteevent', '', 'siteevent_event', array() , $viewer->getIdentity());
  }

  public function getTaskProgress($progress, $usersIds) {
    $processLeft = count(array_chunk($usersIds, $this->_chunk));
    $progress += ( (1 - $progress) / $processLeft );
    return number_format($progress,2);
  }

}
