<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventdocument_Form_Admin_Settings_Global extends Engine_Form {

    public function init() {
        $this
                ->setTitle('Document Settings')
                ->setDescription('These settings affect all members in your community.');

        $coreApi = Engine_Api::_()->getApi('settings', 'core');

        //GET SCRIBD KEYS IF OTHER DOCUMENT PLUGIN IS ALREADY INSTALLED AND HAVING THESE KEYS. 
        $scribd_api_key = $coreApi->getSetting('siteeventdocument.api.key');
        $scribd_secret_key = $coreApi->getSetting('siteeventdocument.secret.key');
        if (empty($scribd_api_key) && empty($scribd_secret_key)) {
            Engine_Api::_()->seaocore()->getScribdApiKeys('siteeventdocument');
        }

        $this->addElement('Text', 'siteeventdocument_api_key', array(
            'label' => 'Scribd API Key',
            'required' => true,
            'description' => 'The Scribd API Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
            'value' => $coreApi->getSetting('siteeventdocument.api.key', ''),
        ));

        $this->addElement('Text', 'siteeventdocument_secret_key', array(
            'label' => 'Scribd Secret Key',
            'required' => true,
            'description' => 'The Scribd Secret Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
            'value' => $coreApi->getSetting('siteeventdocument.secret.key', ''),
        ));

        $this->addElement('Radio', 'siteeventdocument_default_visibility', array(
            'label' => 'Visibility for Event Documents',
            'description' => 'Event Documents visible only on this website will be private and available only on your website, whereas the ones which will be public on Scribd.com will be available to everyone on Scribd.(Note : This setting will only apply to new event documents created and not to the existing event documents on the site.)',
            'multiOptions' => array(
                'public' => 'Public on Scribd.com',
                'private' => 'Only on this website'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.default.visibility', 'private'),
        ));

        $this->addElement('Radio', 'siteeventdocument_visibility_option', array(
            'description' => 'Show visibility option to users. Allow users to choose whether their event documents will be public or private,i.e., available only on your website, or also on Scribd.com.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.visibility.option', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_featured', array(
            'label' => 'Making Event Documents Featured',
            'description' => 'Allow event owners to make documents in their events as featured.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.featured', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_show_editor', array(
            'label' => 'WYSIWYG Editor',
            'description' => 'Allow WYSIWYG editor for description of event documents.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.show.editor', 1),
        ));

        $filesize = (int) ini_get('upload_max_filesize') * 1024;
        $show_description = Zend_Registry::get('Zend_Translate')->_('Enter the maximum event document file size in KB. Valid values are from 1 to %s KB.');
        $show_description = sprintf($show_description, $filesize);
        $this->addElement('Text', 'siteeventdocument_filesize', array(
            'label' => 'Maximum file size',
            'description' => $show_description,
            'value' => $coreApi->getSetting('siteeventdocument.filesize', 2048),
        ));

        $this->addElement('Radio', 'siteeventdocument_scribd_viewer', array(
            'label' => 'Default Document Viewer Type',
            'description' => 'Select the default viewer type for documents on your site. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
            'multiOptions' => array(
                1 => 'Flash Reader',
                0 => 'HTML5 Reader'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.scribd.viewer', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_fullscreen_button', array(
            'label' => 'Fullscreen option in Flash Reader',
            'description' => "Do you want the 'Fullscreen' option to be available in the Flash Reader?",
            'multiOptions' => array(
                0 => 'Yes',
                1 => 'No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.fullscreen.button', 0),
        ));

        $this->addElement('Radio', 'siteeventdocument_flash_mode', array(
            'label' => 'Default View Mode in Flash Reader',
            'description' => 'Choose the default view mode of Flash Reader for viewing documents. Users will be able to change the mode in the viewer.',
            'multiOptions' => array(
                'list' => 'List',
                'book' => 'Book',
                'slide' => 'Slide',
                'tile' => 'Tile'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.flash.mode', 'list'),
        ));

        $this->addElement('Radio', 'siteeventdocument_disable_button', array(
            'label' => 'Disabled links in Reader',
            'description' => 'Do you want the disabled links in the Document Viewer like Download, etc to be hidden?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.disable.button', 0),
        ));

        $this->addElement('Radio', 'siteeventdocument_rating', array(
            'label' => 'Event Document Rating',
            'description' => 'Allow logged-in users to give rating to event documents.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.rating', 1),
        ));

        $this->addElement('Checkbox', 'siteeventdocument_licensing_option', array(
            'label' => 'Selecting this will allow users to choose the license to be associated with their event documents.',
            'description' => 'Show license option to users',
            'value' => $coreApi->getSetting('siteeventdocument.licensing.option', 1),
        ));

        $this->addElement('Select', 'siteeventdocument_licensing_scribd', array(
            'label' => 'License associated with event documents',
            'description' => 'Choose the license to be associated with the event documents on your site. The license will be shown on your site, as well as on Scribd.com.',
            'multiOptions' => array(
                'ns' => 'Unspecified - no licensing information associated',
                'by' => 'By attribution (by)',
                'by-nc' => 'By attribution, non-commercial (by-nc)',
                'by-nc-nd' => 'By attribution, non-commercial, non-derivative (by-nc-nd)',
                'by-nc-sa' => 'By attribution, non-commercial, share alike (by-nc-sa)',
                'by-nd' => 'By attribution, non-derivative (by-nd)',
                'by-sa' => 'By attribution, share alike (by-sa)',
                'pd' => 'Public domain',
                'c' => 'Copyright - all rights reserved',
            ),
            'value' => $coreApi->getSetting('siteeventdocument.licensing.scribd', 'ns'),
        ));
        $this->siteeventdocument_licensing_scribd->getDecorator('Description')->setOption('placement', 'append');

        $this->addElement('Checkbox', 'siteeventdocument_include_full_text', array(
            'label' => "If this option is checked, the full text for an event document will be visible if downloading is enabled for that event document and if the iPaper viewer is not visible because of javascript being disabled on user's browser. Also, full text on the page allows search engines to index content, and increases SEO.",
            'description' => 'Include full text on pages',
            'value' => $coreApi->getSetting('siteeventdocument.include.full.text', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_visitor_fulltext', array(
            'label' => '',
            'description' => ' Do you want full texts for event documents to be included on event document pages for non-logged-in users also? (Choosing "Yes" over here will enable full text on your event document pages to be indexed by search engines.)',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.visitor.fulltext', 1),
        ));

        $this->addElement('Checkbox', 'siteeventdocument_save_local_server', array(
            'label' => "Save event documents on your site's server",
            'description' => 'Save event documents on server',
            'value' => $coreApi->getSetting('siteeventdocument.save.local.server', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_download_allow', array(
            'label' => 'Event Document downloading',
            'description' => 'Enable downloading of event documents.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.download.allow', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_download_show', array(
            'description' => 'Show option to users during event document creation to allow downloading of their event documents.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.download.show', 1),
        ));

        $this->addElement('Select', 'siteeventdocument_download_format', array(
            'label' => 'Download Format',
            'description' => 'Select the format in which the downloadable event documents will be downloaded in.',
            'multiOptions' => array(
                'pdf' => 'PDF',
                'original' => 'Original Event Document Format',
                'txt' => 'Plain Text'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.download.format', 'pdf'),
        ));

        $this->addElement('Radio', 'siteeventdocument_secure_allow', array(
            'label' => 'Secure iPaper Settings',
            'description' => 'Secure event document iPaper cannot be embedded on other sites. Note that this is a permanent setting for an event document during its first upload. Thus any change in this setting will only work for new event document uploads.(Note : This setting will only apply to new event documents created and not to the existing event documents on the site. )',
            'multiOptions' => array(
                1 => 'Make iPaper event documents secure. Do not allow embedding on other sites. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
                0 => 'Do not make iPaper event documents secure. Allow embedding on other sites.'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.secure.allow', 0),
        ));

        $this->addElement('Radio', 'siteeventdocument_secure_show', array(
            'description' => 'Show security option to users. Allow users to choose if their event documents should be secure or not.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.secure.show', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_email_allow', array(
            'label' => 'Email attachment Settings',
            'description' => 'Enable emailing as attachments for event documents on your site.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.email.allow', 1),
        ));

        $this->addElement('Radio', 'siteeventdocument_email_show', array(
            'description' => 'Allow members to choose during event document creation if their event documents could be emailed as attachments or not.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => $coreApi->getSetting('siteeventdocument.email.show', 1),
        ));

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $field = 'siteeventdocument_code_share';
        $this->addElement('Dummy', "$field", array(
            'label' => 'Social Share Widget Code',
            'description' => "<a class='smoothbox' href='". $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'social-share', 'field' => "$field"), 'admin_default', true) ."'>Click here</a> to add your social share code.",
            'ignore' => true,
        ));
        $this->$field->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}