<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Siteeventdocuments.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventdocument_Model_DbTable_Documents extends Engine_Db_Table {

    protected $_name = 'siteeventdocument_documents';
    protected $_rowClass = 'Siteeventdocument_Model_Document';

    /**
     * Get siteeventdocument detail
     * @param array $params : contain desirable siteeventdocument info
     * @return  object of siteeventdocument
     */
    public function getSiteeventdocumentsPaginator($params = array(), $customParams = null) {
        $paginator = Zend_Paginator::factory($this->getSiteeventdocumentsSelect($params, $customParams));
        if (!empty($params['page'])) {
            $paginator->setCurrentPageNumber($params['page']);
        }
        if (!empty($params['limit'])) {
            $paginator->setItemCountPerPage($params['limit']);
        }
        return $paginator;
    }

    /**
     * Get siteeventdocuments 
     * @param array $params : contain desirable siteeventdocument info
     * @return  array of siteeventdocuments
     */
    public function getSiteeventdocumentsSelect($params = array(), $customParams = null) {

        $tableDocument = Engine_Api::_()->getDbtable('documents', 'siteeventdocument');
        $tableDocumentName = $tableDocument->info('name');

        $select = $tableDocument->select();

        if (!empty($params['orderby'])) {
            $select = $select->order($tableDocumentName . '.' . $params['orderby'] . ' DESC');
        }

        if (!empty($params['orderby']) && $params['orderby'] != 'document_id') {
            $select = $select->order($tableDocumentName . '.document_id DESC');
        }

        $searchTable = Engine_Api::_()->fields()->getTable('siteeventdocument_document', 'search')->info('name');
        $select = $select
                ->setIntegrityCheck(false)
                ->from($tableDocumentName, array('document_id', 'owner_id', 'event_id', 'title', 'description', 'doc_id', 'thumbnail', 'creation_date', 'rating', 'comment_count', 'like_count', 'view_count', 'featured', 'search', 'draft', 'featured', 'approved', 'status'))
                ->group("$tableDocumentName.document_id");

        if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
            $select->where($tableDocumentName . '.owner_id = ?', $params['user_id']);
        }

        if (!empty($params['user']) && $params['user'] instanceof User_Model_User) {
            $select->where($tableDocumentName . '.owner_id = ?', $params['user_id']->getIdentity());
        }

        if (!empty($params['users'])) {
            $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
            $select->where($tableDocumentName . '.owner_id in (?)', new Zend_Db_Expr($str));
        }

        if (isset($params['owner_id'])) {
            $select->where($tableDocumentName . '.owner_id = ?', $params['owner_id']);
        }

        if (isset($params['draft'])) {
            $select->where($tableDocumentName . '.draft = ?', $params['draft']);
        }

        if (isset($params['approved'])) {
            $select->where($tableDocumentName . '.approved = ?', $params['approved']);
        }

        if (isset($params['event_id'])) {
            $select->where($tableDocumentName . '.event_id = ?', $params['event_id']);
        }

        if (isset($params['featured'])) {
            $select->where($tableDocumentName . '.featured = ?', $params['featured']);
        }

        if (isset($params['status'])) {
            $select->where($tableDocumentName . '.status = ?', $params['status']);
        }

        if (!empty($params['search'])) {
            $select->where($tableDocumentName . ".fulltext LIKE ? OR " . $tableDocumentName . ".title LIKE ? OR " . $tableDocumentName . ".description LIKE ?", '%' . $params['search'] . '%');
        }

        if (!empty($params['visible'])) {
            $select->where($tableDocumentName . ".search = ?", $params['visible']);
        }

        if (!empty($params['show_document']) && empty($params['search']) && empty($params['featured'])) {
            $select->where($tableDocumentName . ".draft = ?", 0)
                    ->where($tableDocumentName . ".approved = ?", 1)
                    ->where($tableDocumentName . ".status = ?", 1)
                    ->where($tableDocumentName . ".search = ?", 1)
                    ->orwhere($tableDocumentName . ".owner_id = ?", $params['document_owner_id']);
        }

        if (!empty($params['show_document']) && (!empty($params['search']) || !empty($params['featured']))) {
            $select->where("($tableDocumentName.draft = 0 AND $tableDocumentName.approved = 1 AND $tableDocumentName.status = 1 AND $tableDocumentName.search = 1)  OR ($tableDocumentName.owner_id = " . $params['document_owner_id'] . ")");
        }

        if (isset($params['event_id'])) {
            $select->where($tableDocumentName . '.event_id = ?', $params['event_id']);
        }

        return $select;
    }

    /**
     * Documents from same siteevent
     * @param int $document_id : siteeventdocument id
     * @param int $event_id : siteevent id
     * @return same event documents
     */
    public function sameSiteeventDocuments($event_id, $document_id) {

        $selectUserDocs = $this->select()
                ->from($this->info('name'), array('title', 'rating', 'owner_id', 'thumbnail', 'description',
                    'view_count', 'creation_date', 'modified_date', 'comment_count', 'like_count', 'document_id'))
                ->where('event_id = ?', $event_id)
                ->where('document_id != ?', $document_id)
                ->where('approved = ?', 1)
                ->where('draft = ?', 0)
                ->where('status = ?', 1)
                ->where('search = ?', 1)
                ->order('creation_date DESC')
                ->limit(4);
        return $this->fetchAll($selectUserDocs);
    }

    /**
     * Documents of same siteevent for scribd conversion
     * @param int $event_id : siteevent id
     * @return documents of status zero
     */
    public function updateDocs($event_id) {

        $selectDocs = $this->select()
                ->from($this->info('name'), array('document_id', 'owner_id', 'doc_id', 'fulltext', 'thumbnail', 'status', 'activity_feed'))
                ->where('status = ?', 0)
                ->where('event_id = ?', $event_id)
                ->order('document_id DESC')
                ->limit(5);
        return $this->fetchAll($selectDocs);
    }

    /**
     * Return document data
     *
     * @param array params
     * @return Zend_Db_Table_Select
     */
    public function widgetDocumentsData($params = array()) {

        $select = $this->select()
                ->from($this->info('name'), array('document_id', 'event_id', 'owner_id', 'title', 'creation_date', 'thumbnail', 'rating', 'comment_count', 'like_count', 'view_count', 'featured'))
                ->where('draft = ?', 0)
                ->where('approved = ?', 1)
                ->where('status = ?', 1)
                ->where('search = ?', 1);

        if (isset($params['featured']) && !empty($params['featured'])) {
            $select = $select->where('featured = ?', 1);
        }

        if (isset($params['event_id']) && !empty($params['event_id'])) {
            $select = $select->where('event_id = ?', $params['event_id']);
        }

        if (isset($params['document_id']) && !empty($params['document_id'])) {
            $select = $select->where('document_id != ?', $params['document_id']);
        }

        if (isset($params['orderby']) && !empty($params['orderby'])) {
            $select = $select->order($params['orderby'] . " DESC ");
        }

        if (!isset($params['orderby']) || (isset($params['orderby']) && $params['orderby'] != 'document_id')) {
            $select = $select->order('document_id DESC');
        }

        if (isset($params['itemCount']) && !empty($params['itemCount'])) {
            $select = $select->limit($params['itemCount']);
        }

        return $this->fetchAll($select);
    }

    /**
     * Return documents of same siteevent
     *
     * @param int $event_id
     * @param int $owner_id
     * @return Zend_Db_Table_Select
     */
    public function getSiteeventDocuments($event_id, $owner_id) {

        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), 'document_id');

        if (!empty($event_id)) {
            $select = $select->where('event_id = ?', $event_id);
        }

        if (!empty($owner_id)) {
            $select = $select->where('owner_id = ?', $owner_id);
        }

        //RETURN RESULTS
        return $this->fetchAll($select);
    }

}