<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
include_once APPLICATION_PATH . '/application/modules/Siteeventdocument/Api/Scribdsiteevent.php';

class Siteeventdocument_IndexController extends Seaocore_Controller_Action_Standard {

    //COMMAN FUNCTION WHICH CALLS AUTOMATICALLY BEFORE ALL ACTIONS
    public function init() {
        global $siteeventdocumentIsScribdEnabled;
        //SET SCRIBD API AND SCECRET KEY
        $this->scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->siteeventdocument_api_key;
        $this->scribd_secret = Engine_Api::_()->getApi('settings', 'core')->siteeventdocument_secret_key;
        if (empty($siteeventdocumentIsScribdEnabled))
            return;

        $this->scribdsiteevent = new Scribdsiteevent($this->scribd_api_key, $this->scribd_secret);
    }

    //ACTION FOR CREATE THE NEW DOCUMENT
    public function createAction() {
        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET VIEWER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET LEVEL ID
        $level_id = Engine_Api::_()->user()->getViewer()->level_id;

        //GET SITEEVENT ID AND OBJECT
        $this->event_id = $event_id = $this->_getParam('event_id');
        $this->view->siteevent = $siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id);

        //WHO CAN VIEW THIS DOCUMENT
        if (!$siteevent->authorization()->isAllowed($viewer, 'view')) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //CHECK WHO CAN CREATE DOCUMENTS
        $can_create = Engine_Api::_()->authorization()->isAllowed($siteevent, $viewer, 'document');
        if (empty($can_create)) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //MAKE LINK OF "Back to Event Documents"
        $tempValueFlag = null;
        $this->view->tab_selected_id = Engine_Api::_()->siteeventdocument()->getTabId();

        //SHOW DOCUMENT CREATE FORM
        $this->view->form = $form = new Siteeventdocument_Form_Create();

        //CHECK THAT CREATOR ALREADY HAVE DOCUMENTS AT SCRIBD SITE
        try {
            $result = $this->scribdsiteevent->getList();
        } catch (Exception $e) {
            $code = $e->getCode();
            if ($code == 401) {
                $message = $e->getMessage();

                $error = $message . $this->view->translate(': API key is not correct');
                $error = Zend_Registry::get('Zend_Translate')->_($error);

                $form->getDecorator('errors')->setOption('escape', false);
                $form->addError($error);
                return;
            }
        }

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $translate = Zend_Registry::get('Zend_Translate');
            $siteeventdocumentCreatePrivacy = Zend_Registry::isRegistered('siteeventdocumentCreatePrivacy') ? Zend_Registry::get('siteeventdocumentCreatePrivacy') : null;

            //CONNET WITH DOCUMENT TABLE
            $siteeventdocumentTable = Engine_Api::_()->getItemTable('siteeventdocument_document');
            $db = $siteeventdocumentTable->getAdapter();
            $db->beginTransaction();

            //GET POSTED VALUES FROM CREATE FORM
            $values = !empty($siteeventdocumentCreatePrivacy) ? $form->getValues() : $tempValueFlag;

            //SET SCRIBD MY_USER_ID
            $this->scribdsiteevent->my_user_id = $viewer_id;

            //DOCUMENT CREATION CODE
            try {
                $values = array_merge($form->getValues(), array(
                    'owner_type' => $viewer->getType(),
                    'owner_id' => $viewer->getIdentity(),
                ));
                $this->view->is_error = $this->view->excep_error = 0;

                //MAKE SURE THAT FILE SIZE SHOULD NOT EXCEED FROM ALLOWED LIMIT DEPEND ON USER LEVEL
                $filesize = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.filesize', 2048);
                $filesize = $filesize * 1024;
                if ($filesize < 0) {
                    $filesize = (int) ini_get('upload_max_filesize') * 1024 * 1024;
                }
                if ($_FILES['filename']['size'] > $filesize) {
                    $error = $this->view->translate('File size can not be exceed from ') . ($filesize / 1024) . $this->view->translate(' KB');
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }
                //MAKE SURE THAT FILE EXTENSION SHOULD NOT DIFFER FROM ALLOWED TYPE
                $ext = str_replace(".", "", strrchr($_FILES['filename']['name'], "."));
                if (!in_array($ext, array('pdf', 'txt', 'ps', 'rtf', 'epub', 'odt', 'odp', 'ods', 'odg', 'odf', 'sxw', 'sxc', 'sxi', 'sxd', 'doc', 'ppt', 'pps', 'xls', 'docx', 'pptx', 'ppsx', 'xlsx', 'tif', 'tiff'))) {
                    $error = $this->view->translate("Invalid file extension. Allowed extensions are :'pdf', 'txt', 'ps', 'rtf', 'epub', 'odt', 'odp', 'ods', 'odg', 'odf', 'sxw', 'sxc', 'sxi', 'sxd', 'doc', 'ppt', 'pps', 'xls', 'docx', 'pptx', 'ppsx', 'xlsx', 'tif', 'tiff'");
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }

                //CHECKS FOR SCRIBD LICENSE AND LICENSE OPTION
                $licensing_option = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.licensing.option', 1);
                $licensing_scribd = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.licensing.scribd', 'ns');

                if ($licensing_option == 0) {
                    $license_siteeventdocument = $licensing_scribd;
                    $values['license'] = $licensing_scribd;
                } else {
                    $license_siteeventdocument = $values['license'];
                }

                if ($license_siteeventdocument == 'ns') {
                    $scribd_license = null;
                } else {
                    $scribd_license = $license_siteeventdocument;
                }

                //CREATE THE MAIN DOCUMENT
                $siteeventdocumentRow = $siteeventdocumentTable->createRow();
                $siteeventdocumentRow->setFromArray($values);
                $siteeventdocumentRow->owner_id = $viewer_id;
                $siteeventdocumentRow->event_id = $event_id;
                $siteeventdocumentRow->save();

                //SECURE IPAPER CHECK
                $secure_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.secure.allow', 0);
                $secure_show = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.secure.show', 1);
                if (empty($secure_allow)) {
                    $siteeventdocumentRow->secure_allow = 0;
                } elseif (empty($secure_show)) {
                    $siteeventdocumentRow->secure_allow = 1;
                } else {
                    $siteeventdocumentRow->secure_allow = $values['secure_allow'];
                }

                //DOWNLOAD ALLOW CHECK
                $download_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.download.allow', 1);
                $download_show = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.download.show', 1);
                if (empty($download_allow)) {
                    $siteeventdocumentRow->download_allow = 0;
                } elseif (empty($download_show)) {
                    $siteeventdocumentRow->download_allow = 1;
                } else {
                    $siteeventdocumentRow->download_allow = $values['download_allow'];
                }

                //CHECKS FOR DEFAULT VISIBILITY
                $siteeventdocument_default_visibility = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.default.visibility', 'private');
                $siteeventdocument_visibility_option = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.visibility.option', 1);
                if ($siteeventdocument_default_visibility == 'private') {
                    $access = 'private';
                } elseif ($siteeventdocument_visibility_option == 1) {
                    $access = $values['default_visibility'];
                } else {
                    $access = 'public';
                }
                $siteeventdocumentRow->private = $access;

                //IF FILENAME IS NOT EMPTY THAN BEGIN THE SCRIBD WORK
                if (!empty($values['filename'])) {
                    $local_info = $siteeventdocumentRow->setFile($form->filename);
                    $secure_allow = $siteeventdocumentRow->secure_allow;
                    $download = "view-only";
                    $rev_id = NULL;
                    $data = $this->scribdUpload($local_info, $rev_id, $access, $secure_allow, $download, $siteeventdocumentRow->filename_id);
                }
                $doc_title = $values['title'];
                $description = $values['description'];
                try {
                    $changesetting = $this->scribdsiteevent->changeSettings($data['doc_id'], $doc_title, $description, $access, $scribd_license, $siteeventdocumentRow->download_allow);

                    $setting = $this->scribdsiteevent->getSettings($data['doc_id']);
                } catch (Exception $e) {
                    $message = $e->getMessage();
                    $this->view->excep_error = 1;
                    $this->view->excep_message = $message;
                }

                //EMAIL ALLOW CHECK
                $email_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.email.allow', 1);
                $email_show = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.email.show', 1);
                if (empty($email_allow)) {
                    $siteeventdocumentRow->email_allow = 0;
                } elseif (empty($email_show)) {
                    $siteeventdocumentRow->email_allow = 1;
                } else {
                    $siteeventdocumentRow->email_allow = $values['email_allow'];
                }

                $siteeventdocumentRow->approved = 1;
                $siteeventdocumentRow->featured = 0;
                $siteeventdocumentRow->doc_id = $data['doc_id'];
                $siteeventdocumentRow->access_key = $data['access_key'];
                $siteeventdocumentRow->secret_password = $data['secret_password'];
                $siteeventdocumentRow->filemime = $_FILES['filename']['type'];
                $siteeventdocumentRow->filesize = $_FILES['filename']['size'];
                $siteeventdocumentRow->save();

                //COMMENT PRIVACY
                $auth = Engine_Api::_()->authorization()->context;
                $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'everyone');
                $auth_comment = "everyone";
                $commentMax = array_search($auth_comment, $roles);
                foreach ($roles as $i => $role) {
                    $auth->setAllowed($siteeventdocumentRow, $role, 'comment', ($i <= $commentMax));
                }

                //SAVE CUSTOM FIELDS VALUES
                $customfieldform = $form->getSubForm('fields');
                $customfieldform->setItem($siteeventdocumentRow);
                $customfieldform->saveValues();

                //COMMIT
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }

            //REDIRECT
            $tabId = $this->view->tab_selected_id;
            return $this->_redirectCustom($siteevent->getHref() . "/tab/$tabId", array('prependBase' => false));
            //return $this->_helper->redirector->gotoRoute(array('event_id' => $siteevent->event_id, 'slug' => $siteevent->getSlug(), 'tab' => $this->view->tab_selected_id), 'siteevent_entry_view', true);
        }
    }

    //ACTION FOR RETURN THE SCRIBD THUMBNAIL IMAGE
    public function sslAction() {

        $url = urldecode($_GET['url']);
        header("Cache-Control: no-cache");
        header("Content-type:image/jpeg");
        $image2 = imagecreatefromjpeg($url);
        $width = imagesx($image2);
        $height = imagesy($image2);
        $imgh = 84;
        $imgw = $width / $height * $imgh;
        $thumb = imagecreatetruecolor($imgw, $imgh);
        imagecopyresampled($thumb, $image2, 0, 0, 0, 0, $imgw, $imgh, $width, $height);
        imagejpeg($thumb);
        die;
    }

    //ACTION FOR EDIT THE DOCUMENT
    public function editAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET LOGGED IN USER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET DOCUMENT INFO
        $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $this->_getParam('document_id'));

        //GET SITEEVENT OBJECT
        $this->view->siteevent = $siteevent = Engine_Api::_()->getItem('siteevent_event', $siteeventdocument->event_id);

        //WHO CAN EDIT DOCUMENT
        $canEdit = $siteeventdocument->canEdit();
        if (!$canEdit) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //GENERATE EDIT FORM
        $this->view->form = $form = new Siteeventdocument_Form_Edit(array('item' => $siteeventdocument));

        //SEND TAB AND SITEEVENT ID TO TPL FILE
        $siteeventdocumentEditPrivacy = Zend_Registry::isRegistered('siteeventdocumentEditPrivacy') ? Zend_Registry::get('siteeventdocumentEditPrivacy') : null;
        $this->view->tab_selected_id = Engine_Api::_()->siteeventdocument()->getTabId();
        $this->view->event_id = $event_id = $siteeventdocument->event_id;

        //IF DOCUMENT IN PUBLISHED STAT THAN REMOVE ELEMENT
        if ($siteeventdocument->draft == "0") {
            $form->removeElement('draft');
        }

        //SET SCRIBD MY_USER_ID
        $this->scribdsiteevent->my_user_id = $siteeventdocument->owner_id;

        //SAVE DOCUMENT DETAIL
        $saved = $this->_getParam('saved');
        if (!$this->getRequest()->isPost() || $saved) {
            if ($saved) {
                $url = $this->_helper->url->url(array('document_id' => $siteeventdocument->getIdentity(), 'slug' => $siteeventdocument->getSlug()), 'siteeventdocument_detail_view');
                $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes were saved. Click <a href=\'%1$s\'>here</a> to view your document.', $url));
            }

            //SHOW PREFIELD
            $form->populate($siteeventdocument->toArray());

            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        if (empty($siteeventdocumentEditPrivacy))
            return;

        $values = $form->getValues();

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $siteeventdocument->setFromArray($values);
            $siteeventdocument->modified_date = new Zend_Db_Expr('NOW()');
            $doc_title = $values['title'];
            $description = $values['description'];
            $license_siteeventdocument = $values['license'];
            $siteeventdocument->download_allow = $values['download_allow'];

            if ($license_siteeventdocument == 'ns') {
                $scribd_license = null;
            } else {
                $scribd_license = $license_siteeventdocument;
            }

            //CHECKS FOR DEFAULT VISIBILITY
            $siteeventdocument_default_visibility = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.default.visibility', 'private');
            $siteeventdocument_visibility_option = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.visibility.option', 1);
            if ($siteeventdocument_default_visibility == 'private') {
                $access = 'private';
            } elseif ($siteeventdocument_visibility_option == 1) {
                $access = $values['default_visibility'];
            } else {
                $access = 'public';
            }
            $siteeventdocument->private = $access;

            //MAKE SURE THAT FILE SIZE SHOULD NOT EXCEED FROM ALLOWED LIMIT DEPEND ON USER LEVEL
            if (!empty($_FILES['filename']['name'])) {
                $filesize = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.filesize', 2048);
                $filesize = $filesize * 1024;
                if ($filesize < 0) {
                    $filesize = (int) ini_get('upload_max_filesize') * 1024 * 1024;
                }
                if ($_FILES['filename']['size'] > $filesize) {
                    $error = $this->view->translate('Filesize can not be exceed from ') . $filesize . $this->view->translate(' KB.');
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }

                //MAKE SURE THAT FILE EXTENSION SHOULD NOT DIFFER FROM ALLOWED TYPE
                $ext = str_replace(".", "", strrchr($_FILES['filename']['name'], "."));
                if (!in_array($ext, array('pdf', 'txt', 'ps', 'rtf', 'epub', 'odt', 'odp', 'ods', 'odg', 'odf', 'sxw', 'sxc', 'sxi', 'sxd', 'doc', 'ppt', 'pps', 'xls', 'docx', 'pptx', 'ppsx', 'xlsx', 'tif', 'tiff'))) {
                    $error = $this->view->translate('Invalid file extension!');
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }

                //IF FILENAME IS NOT EMPTY THAN BEGIN THE SCRIBD WORK
                if (!empty($values['filename'])) {

                    $filename_id_prev = $siteeventdocument->filename_id;
                    $local_info = $siteeventdocument->setFile($form->filename);
                    $secure_allow = $siteeventdocument->secure_allow;
                    $download = "view-only";
                    $rev_id = $siteeventdocument->doc_id;
                    $data = $this->scribdUpload($local_info, $rev_id, $access, $secure_allow, $download, $siteeventdocument->filename_id);

                    //FIRST DELETE FILE ENTRY FROM engine4_storage_files
                    Engine_Api::_()->getDbtable('files', 'storage')->delete(array(
                        'file_id = ?' => $filename_id_prev,
                    ));
                }
                try {
                    $stat = $this->scribdsiteevent->getConversionStatus($data['doc_id']);
                } catch (Exception $e) {
                    $message = $e->getMessage();
                    $this->view->excep_error = 1;
                    $this->view->excep_message = $message;
                }
                try {
                    $changesetting = $this->scribdsiteevent->changeSettings($data['doc_id'], $doc_title, $description, $access, $scribd_license, $siteeventdocument->download_allow);
                    $setting = $this->scribdsiteevent->getSettings($data['doc_id']);
                } catch (Exception $e) {
                    $message = $e->getMessage();
                    $this->view->excep_error = 1;
                    $this->view->excep_message = $message;
                }

                $siteeventdocument->status = 0;
                $siteeventdocument->doc_id = $data['doc_id'];
                $siteeventdocument->access_key = $data['access_key'];
                $siteeventdocument->secret_password = $data['secret_password'];
                $siteeventdocument->filemime = $_FILES['filename']['type'];
                $siteeventdocument->filesize = $_FILES['filename']['size'];
                $siteeventdocument->thumbnail = NULL;
                //FILE UPLOADING WORK END HERE
            }
            $siteeventdocument->save();

            $customfieldform = $form->getSubForm('fields');
            $customfieldform->setItem($siteeventdocument);
            $customfieldform->saveValues();

            $draft_value = 0;
            if (isset($values['draft'])) {
                $draft_value = $values['draft'];
            }

            //INSERT NEW ACTIVITY IF DOCUMENT IS JUST GETTING PUBLISHED
            $action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($siteeventdocument);
            if (count($action->toArray()) <= 0 && $draft_value == 0 && $siteeventdocument->approved == 1 && $siteeventdocument->status == 1 && $siteeventdocument->activity_feed == 0) {
                $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $siteevent, Engine_Api::_()->siteevent()->getActivtyFeedType($siteevent, 'siteeventdocument_new'));

                //MAKE SURE ACTION EXISTS BEFOR ATTACHING THE DOCUMENT TO THE ACTIVITY
                if ($action != null) {
                    Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $siteeventdocument);
                    $siteeventdocument->activity_feed = 1;
                    $siteeventdocument->save();

                    //START NOTIFICATION AND EMAIL WORK
                    Engine_Api::_()->siteevent()->sendNotificationEmail($siteevent, $action, 'siteeventdocument_new', 'SITEEVENTDOCUMENT_CREATENOTIFICATION_EMAIL', null, null, 'created', $siteeventdocument);
                    $isChildIdLeader = Engine_Api::_()->getDbtable('listItems', 'siteevent')->checkLeader($siteevent);
                    if (!empty($isChildIdLeader)) {
                        Engine_Api::_()->siteevent()->sendNotificationToFollowers($siteevent, 'siteeventdocument_new');
                    }
                    //END NOTIFICATION AND EMAIL WORK
                }
            }

            $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
            foreach ($actionTable->getActionsByObject($siteeventdocument) as $action) {
                $actionTable->resetActivityBindings($action);
            }
            $db->commit();

            $tabId = $this->view->tab_selected_id;
            return $this->_redirectCustom($siteevent->getHref() . "/tab/$tabId", array('prependBase' => false));
            //return $this->_helper->redirector->gotoRoute(array('event_id' => $siteevent->event_id, 'slug' => $siteevent->getSlug(), 'tab' => $this->view->tab_selected_id), 'siteevent_entry_view', true);
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    //ACTION FOR VIEW THE DOCUMENT
    public function viewAction() {
        //GET LOGGED IN USER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

        //GET USER LEVEL
        if (!empty($viewer_id)) {
            $level_id = Engine_Api::_()->user()->getViewer()->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //GET DOCUMNET MODEL
        $siteeventdocumentViewInfo = Zend_Registry::isRegistered('siteeventdocumentViewInfo') ? Zend_Registry::get('siteeventdocumentViewInfo') : null;
        $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $this->_getParam('document_id'));

        if (empty($siteeventdocument) || empty($siteeventdocumentViewInfo)) {
            return $this->_forward('notfound', 'error', 'core');
        } else {
            Engine_Api::_()->core()->setSubject($siteeventdocument);
        }

        //GET SITEEVENT OBJECT
        $siteevent = Engine_Api::_()->getItem('siteevent_event', $siteeventdocument->event_id);

        //WHO CAN VIEW THIS DOCUMENT
        if (!$siteevent->authorization()->isAllowed($viewer, 'view')) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //SUPERADMIN, DOCUMENT OWNER AND SITEEVENT OWNER CAN VIEW DOCUMENT
        if ($level_id != 1 && $viewer_id != $siteeventdocument->owner_id && $viewer_id != $siteevent->owner_id) {
            if ($siteeventdocument->draft == 1 || $siteeventdocument->status != 1 || $siteeventdocument->approved != 1 || $siteeventdocument->search != 1) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        }

        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR EMAIL THE DOCUMENT
    public function emailAction() {

        //GET VIEWER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //TO BE VERIFY THAT DOCUMNETS HAD ENABLED FOR THIS USER
        $document_id = $this->_getParam('document_id');
        if (empty($document_id)) {
            return $this->_redirect("siteeventdocuments/manage");
        } else {
            $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);
        }

        //GET SITEEVENT ID AND OBJECT
        $event_id = $siteeventdocument->event_id;
        $siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id);

        //CHECK VIEWER CAN VIEW THIS DOCUMENT OR NOT
        if (!$siteevent->authorization()->isAllowed($viewer, 'view')) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        //DOCUMENT OWNER ID SHOULD NOT BE NULL
        if ($siteeventdocument->owner_id == 0) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $siteeventdocumentEmailType = Zend_Registry::isRegistered('siteeventdocumentEmailType') ? Zend_Registry::get('siteeventdocumentEmailType') : null;
        if (empty($siteeventdocumentEmailType))
            return $this->_forward('requireauth', 'error', 'core');

        //DO NOT SHOW DOCUMENT IF IT IS NOT PUBLISHED TO OTHER USER
        if ($viewer_id != $siteeventdocument->owner_id && $siteeventdocument->draft == 1) {
            $page = "error";
            $this->view->error_header = 639;
            $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
            $this->error_submit = 641;
        }

        //DO NOT SHOW DOCUMENT IF IT IS NOT ACTIVE
        if ($viewer_id != $siteeventdocument->owner_id && $siteeventdocument->approved != 1) {
            $page = "error";
            $this->view->error_header = 639;
            $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
            $this->error_submit = 641;
        }

        //CHECK THAT EMAIL IS ALLOW OR NOT
        $email_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.email.allow', 1);
        if (($siteeventdocument->email_allow != 1) || ($siteeventdocument->status != 1) || ($email_allow != 1 )) {
            $page = "error";
            $this->view->error_header = 639;
            $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
            $this->error_submit = 641;
        }

        $time_out = 50000;
        $is_error = 0;
        $error_array = array();
        $excep_error = 0;
        $excep_message = '';

        //FILENAME FROM STORAGE TABLE
        $file_name = $siteeventdocument->getDocumentFileName();

        if (!empty($file_name)) {
            $this->view->attach = $file_name;
        } else {
            $this->view->attach = $siteeventdocument->storage_path;
        }

        $this->view->smoothbox_error = 0;
        if (isset($_POST['submit']) && $_POST['submit'] == 'Send') {
            $to = $_POST['to'];
            $subject = $_POST['subject'];
            $user_message = $_POST['message'];

            if (empty($to) || !filter_var($to, FILTER_VALIDATE_EMAIL)) {
                $is_error = 1;
                $this->view->smoothbox_error = 1;
                $error = $this->view->translate('Please enter a valid email.');
                $error_array[] = $error;
            }

            if (empty($subject)) {
                $is_error = 1;
                $this->view->smoothbox_error = 1;
                $error = $this->view->translate('Please enter the subject.');
                $error_array[] = $error;
            }
            if ($is_error != 1) {

                $from = $viewer->displayname . '<' . $viewer->email . '>';

                $fileatt_type = $siteeventdocument->filemime;
                $fileatt_name = $file_name;
                $headers = "From: $from";

                //SET SCRIBD USER ID
                $this->scribdsiteevent->my_user_id = $siteeventdocument->owner_id;

                try {
                    $link = $this->scribdsiteevent->getDownloadUrl($siteeventdocument->doc_id, 'original');
                } catch (Exception $e) {
                    $message = $e->getMessage();
                    $this->view->excep_error = 1;
                    $this->view->excep_message = $message;
                }

                $link = trim($link['download_link']);
                $data = file_get_contents($link);

                if (empty($data)) {
                    $ch = curl_init();
                    $timeout = 0;
                    curl_setopt($ch, CURLOPT_URL, $link);
                    curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
                    ob_start();
                    curl_exec($ch);
                    curl_close($ch);
                    $data = ob_get_contents();
                    ob_end_clean();
                }

                $semi_rand = md5(time());
                $mime_boundary = "==Multipart_Boundary_x{$semi_rand}x";

                $headers .= "\nMIME-Version: 1.0\n" .
                        "Content-Type: multipart/mixed;\n" .
                        " boundary=\"{$mime_boundary}\"";

                $email_message = "This is a multi-part message in MIME format.\n\n" .
                        "--{$mime_boundary}\n" .
                        "Content-Type:text/html; charset=\"iso-8859-1\"\n" .
                        "Content-Transfer-Encoding: 7bit\n\n" . $user_message . "\n\n";

                $data = chunk_split(base64_encode($data));

                $email_message .= "--{$mime_boundary}\n" .
                        "Content-Type: {$fileatt_type};\n" .
                        " name=\"{$fileatt_name}\"\n" .
                        "Content-Transfer-Encoding: base64\n\n" .
                        $data . "\n\n" .
                        "--{$mime_boundary}--\n";

                $mail_sent = mail($to, $subject, $email_message, $headers);
                if ($mail_sent) {
                    $this->view->msg = $this->view->translate('Email has been sent successfully.');
                    $time_out = 7000;
                    $this->view->no_form = 1;
                } else {
                    $is_error = 1;
                    $error_array[] = $this->view->translate('There was an error in sending your email. Please try again later.');
                    $time_out = 50000;
                    $this->view->no_form = 1;
                }
            }
            $this->view->to = $to;
            $this->view->subject = $subject;
            $this->view->user_message = $user_message;
        }
        $this->view->is_error = $is_error;
        $this->view->time_out = $time_out;
        $this->view->error_array = array_unique($error_array);
        $this->view->excep_error = $excep_error;
        $this->view->excep_message = $excep_message;
    }

    //ACTION FOR RATING DOCUMENTS
    public function ratingAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET VIEWER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        $rating = $this->_getParam('rating');
        $document_id = $this->_getParam('document_id');

        $tableRating = Engine_Api::_()->getDbtable('ratings', 'siteeventdocument');
        $db = $tableRating->getAdapter();
        $db->beginTransaction();

        try {
            $tableRating->doSiteeventdocumentRating($document_id, $viewer_id, $rating);

            $total = $tableRating->countRating($document_id);

            $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);

            //UPDATE CURRENT AVERAGE RATING IN DOCUMENT TABLE
            $avg_rating = $tableRating->avgRating($document_id);

            $siteeventdocument->rating = $avg_rating;
            $siteeventdocument->save();

            //COMMIT
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        $data = array();
        $data[] = array(
            'total' => $total,
            'rating' => $avg_rating,
        );
        return $this->_helper->json($data);
        $data = Zend_Json::encode($data);
        $this->getResponse()->setBody($data);
    }

    //ACTION FOR DOCUMENT PUBLISH
    public function publishAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {//NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        $document_id = $this->view->document_id = $this->_getParam('document_id');
        if (!$this->getRequest()->isPost())
            return;

        $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);

        //WHO CAN EDIT DOCUMENT
        $canEdit = $siteeventdocument->canEdit();
        if (!$canEdit) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        if ($canEdit) {
            $this->view->permission = true;
            $this->view->success = false;
            $db = Engine_Api::_()->getDbtable('documents', 'siteeventdocument')->getAdapter();
            $db->beginTransaction();
            try {
                $siteeventdocument->modified_date = new Zend_Db_Expr('NOW()');
                $siteeventdocument->draft = 0;
                $siteeventdocument->save();
                $db->commit();
                $this->view->success = true;
            } catch (Exception $e) {
                $db->rollback();
                throw $e;
            }

            //GET SITEEVENT OBJECT
            $siteevent = Engine_Api::_()->getItem('siteevent_event', $siteeventdocument->event_id);

            //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
            if ($siteeventdocument->draft == 0 && $siteeventdocument->approved == 1 && $siteeventdocument->status == 1 && $siteeventdocument->activity_feed == 0) {
                $api = Engine_Api::_()->getDbtable('actions', 'activity');
                $creator = Engine_Api::_()->getItem('user', $siteeventdocument->owner_id);
                $action = $api->addActivity($creator, $siteevent, Engine_Api::_()->siteevent()->getActivtyFeedType($siteevent, 'siteeventdocument_new', $creator));

                //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
                if ($action != null) {
                    $api->attachActivity($action, $siteeventdocument);
                    $siteeventdocument->activity_feed = 1;
                    $siteeventdocument->save();

                    //START NOTIFICATION AND EMAIL WORK
                    Engine_Api::_()->siteevent()->sendNotificationEmail($siteeventdocument, $action, 'siteeventdocument_new', 'SITEEVENTDOCUMENT_CREATENOTIFICATION_EMAIL', null, null, 'created');
                    $isChildIdLeader = Engine_Api::_()->getDbtable('listItems', 'siteevent')->checkLeader($siteevent);
                    if (!empty($isChildIdLeader)) {
                        Engine_Api::_()->siteevent()->sendNotificationToFollowers($siteevent, 'siteeventdocument_new');
                    }
                    //END NOTIFICATION AND EMAIL WORK
                }
            }
        } else {
            $this->view->permission = false;
        }

        $tabId = Engine_Api::_()->siteeventdocument()->getTabId();
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 2,
            'parentRedirect' => $siteevent->getHref() . "/tab/$tabId",
            'parentRedirectTime' => '2',
            'format' => 'smoothbox',
            'messages' => array('Changes has been done successfully.')
        ));
    }

    //ACTION FOR MAKE THE SITEEVENTDOCUMENT FEATURED/UNFEATURED
    public function featuredAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        $document_id = $this->view->document_id = $this->_getParam('document_id');
        $siteeventdocumentFeaturedInfo = Zend_Registry::isRegistered('siteeventdocumentFeaturedInfo') ? Zend_Registry::get('siteeventdocumentFeaturedInfo') : null;
        $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);
        $this->view->featured = $siteeventdocument->featured;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {//NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        if (!$this->getRequest()->isPost())
            return;

        if (empty($siteeventdocumentFeaturedInfo))
            return;

        //GET VIEWER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //CHECK THAT FEATURED ACTION IS ALLOWED BY ADMIN OR NOT
        $this->view->canMakeFeatured = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.featured', 1);

        //GET SITEEVENT ITEM
        $siteevent = Engine_Api::_()->getItem('siteevent_event', $siteeventdocument->event_id);

        //CHECK CAN MAKE FEATURED OR NOT(ONLY SITEEVENT DOUCMENT CAN MAKE FEATURED/UN-FEATURED)
        if (($viewer_id == $siteevent->owner_id || $viewer->level_id == 1) && $this->view->canMakeFeatured == 1) {
            $this->view->permission = true;
            $this->view->success = false;
            $db = Engine_Api::_()->getDbtable('documents', 'siteeventdocument')->getAdapter();
            $db->beginTransaction();
            try {
                if ($siteeventdocument->featured == 0) {
                    $siteeventdocument->featured = 1;
                } else {
                    $siteeventdocument->featured = 0;
                }

                $siteeventdocument->save();
                $db->commit();
                $this->view->success = true;
            } catch (Exception $e) {
                $db->rollback();
                throw $e;
            }
        } else {
            $this->view->permission = false;
        }

        $tabId = Engine_Api::_()->siteeventdocument()->getTabId();
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 2,
            'parentRedirect' => $siteevent->getHref() . "/tab/$tabId",
            'parentRedirectTime' => '2',
            'format' => 'smoothbox',
            'messages' => array('')
        ));
    }

    //ACTION FOR DELETE DOCUMENT
    public function deleteAction() {
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {//NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        //GET VIEWER ID
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET DOCUMETN OBJECT
        $this->view->siteeventdocument = $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $this->_getParam('document_id'));

        //WHO CAN EDIT DOCUMENT
        $canEdit = $siteeventdocument->canEdit();
        if (!$canEdit) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $this->view->siteevent = $siteevent = Engine_Api::_()->getItem('siteevent_event', $siteeventdocument->event_id);

        //GET DOCUMENT TAB ID
        $this->view->tab_selected_id = Engine_Api::_()->siteeventdocument()->getTabId();

        //DELETE DOCUMENT FROM DATATBASE AND SCRIBD AFTER CONFIRMATION
        if ($this->getRequest()->isPost() && $this->getRequest()->getPost('confirm') == true) {

            //DELETE DOCUMENT BELONGINGS
            $siteeventdocument->delete();

            $tabId = $this->view->tab_selected_id;
            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 2,
                'parentRedirect' => $siteevent->getHref() . "/tab/$tabId",
                'parentRedirectTime' => '2',
                'format' => 'smoothbox',
                'messages' => array('Document has been deleted successfully.')
            ));
        }
    }

    /**
     * Upload a siteeventdocument from a file
     * @param string $local_info : relative path to file
     * @param int $rev_id : id of file to modify
     * @param string $access : public or private. Default is Public.
     * @return array containing doc_id, access_key, and secret_password if nessesary.
     */
    public function scribdUpload($local_info, $rev_id, $access, $secure_allow, $download, $filename_id) {
        try {

            //GET BASE PATH
            $base = Zend_Controller_Front::getInstance()->getBaseUrl();

            //STORAGE MODEL VERSION
            global $siteeventdocumentScribdPath;
            $sitedocumentFilesScribdInfo = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocumentfiles.scribd.info', null);
            $siteeventdocumentGetShowViewType = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.getshow.viewtype', null);
            $documentUploadedByHost = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));
            $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
            $storageversion = $storagemodule->version;
            if (!empty($_SERVER["HTTPS"]) && 'on' == strtolower($_SERVER["HTTPS"])) {
                if ($storageversion < '4.1.1') {
                    $doc_base_url = "https://" . $_SERVER['HTTP_HOST'] . $base . "/";
                } else {
                    $doc_base_url = "https://" . $_SERVER['HTTP_HOST'];
                }
            } else {
                if ($storageversion < '4.1.1') {
                    $doc_base_url = "http://" . $_SERVER['HTTP_HOST'] . $base . "/";
                } else {
                    $doc_base_url = "http://" . $_SERVER['HTTP_HOST'];
                }
            }

            $doc_base_url = str_replace("index.php/", '', $doc_base_url);
            $scribd_upload_url = $doc_base_url . $local_info['file_path'];
            $tempDocumentUploadedBy = @md5($documentUploadedByHost);

            $db = Engine_Db_Table::getDefaultAdapter();
            $type_array = $db->query("SHOW COLUMNS FROM engine4_storage_servicetypes LIKE 'enabled'")->fetch();

            if ($storageversion >= '4.1.6' && !empty($type_array)) {
                $storageServiceTypeTable = Engine_Api::_()->getDbtable('serviceTypes', 'storage');
                $storageServiceTypeTableName = $storageServiceTypeTable->info('name');

                $storageServiceTable = Engine_Api::_()->getDbtable('services', 'storage');
                $storageServiceTableName = $storageServiceTable->info('name');

                $select = $storageServiceTypeTable->select()
                        ->setIntegrityCheck(false)
                        ->from($storageServiceTypeTableName, array(''))
                        ->join($storageServiceTableName, "$storageServiceTypeTableName.servicetype_id = $storageServiceTableName.servicetype_id", array('enabled', 'default'))
                        ->where("$storageServiceTypeTableName.plugin = ?", "Storage_Service_Local")
                        ->where("$storageServiceTypeTableName.enabled = ?", 1)
                        ->limit(1);
                $storageCheck = $storageServiceTypeTable->fetchRow($select);
                if (!empty($storageCheck)) {
                    if ($storageCheck->enabled == 1 && $storageCheck->default == 1) {
                        $scribd_upload_url = $doc_base_url . $local_info['file_path'];
                    } else {
                        $scribd_upload_url = $local_info['file_path'];
                    }
                }
            }

            if ((!empty($siteeventdocumentGetShowViewType) || empty($sitedocumentFilesScribdInfo) || ($sitedocumentFilesScribdInfo == $tempDocumentUploadedBy)) && !empty($siteeventdocumentScribdPath)) {
                //GET STORAGE FILE OBJECT
                $storage_file = Engine_Api::_()->getItem('storage_file', $filename_id);
                $scribd_upload_url = $storage_file->temporary();

                $data = $this->scribdsiteevent->upload("$scribd_upload_url", NULL, $access, $rev_id, $download, $secure_allow);
                $data['local_path'] = $scribd_upload_url;
            }
        } catch (Exception $e) {
            $message = $e->getMessage();
            $this->view->excep_error = 1;
            $this->view->excep_message = $message;
        }
        return $data;
    }

}
