<?php

class Siteeventrepeat_IndexController extends Siteapi_Controller_Action_Standard {

    public function init() {

        //AUTHORIZATION CHECK
        if (!$this->_helper->requireAuth()->setAuthParams('siteevent_event', null, "view")->isValid())
            $this->respondWithError('unauthorized');

        //SET EVENT SUBJECT
        if ($this->getRequestParam('event_id') && (0 !== ($event_id = (int) $this->getRequestParam('event_id')) &&
                null !== ($siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id))))
            if (!Engine_Api::_()->core()->hasSubject('siteevent_event')) {

                Engine_Api::_()->core()->setSubject($siteevent);
            }
    }

    /**
     * RETURN THE LIST AND DETAILS OF ALL OCCURRENCES OF EVENT  WITH DATE FILTERING PARAMETERS.
     * 
     * @return array
     */
    //itemCount
    //page
    //firstStartDate
    //lastStartDate

    public function indexAction() {

        //DONT RENDER IF NOT AUTHORIZED
        if (!Engine_Api::_()->core()->hasSubject('siteevent_event')) {
            $this->respondWithError('no_record');
        }

        if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteeventrepeat'))
            $this->respondWithError('no_record');

        $siteevent = Engine_Api::_()->core()->getSubject();

        $subject = $siteevent;

        //IF THE EVENT IS NOT A REPEATING EVENT.
        if (empty($siteevent->repeat_params))
            $this->respondWithError('no_record');

        //IF THE EVENT IS REPEATING EVENT BUT DO NOT HAVE MORE THEN ONE OCCURRENCES THEN ALSO DO NOT RENDER THIS WIDGET.
        $totalEventOccurrences = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getOccurrenceCount($siteevent->event_id);

        $allParams = $this->_getAllParams();

        //GET EVENT FIRST OCCURRENCE START DATE AND EVENT LAST OCCURRENCE START DATE.
        $firstStartDate = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getOccurenceStartDate($siteevent->event_id);

        $lastStartDate = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getOccurenceStartDate($siteevent->event_id, 'DESC');
        if (strtotime($lastStartDate) > time()) {
            $nextOccurrID = Engine_Api::_()->getDbTable('events', 'siteevent')->getNextOccurID($siteevent->event_id);
            $firstStartDate = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getOccurenceStartDate($siteevent->event_id, 'ASC', $nextOccurrID);
        }

        $page = $this->_getParam('page', 1);
        $rsvp_form = $this->_getParam('rsvp_form', 1);
        $limit = $this->_getParam('itemCount', 20);
        $getMenu = $this->_getParam('menu', 1);
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $canEdit = $siteevent->authorization()->isAllowed($viewer, "edit");
        $guest_pictures = $this->_getParam('guest_pictures', true);
        $guest_count_link = $this->_getParam('guest_count_link', true);

        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        $params = array();
        //IF ADMIN HAS ALLWOED THE SETTING FOR WRITE A REVIEW.
        //CHECK IF VIEWER IS A MEMBER OF ANY PAST EVENT.
        $isPastEventMember = $siteevent->membership()->isMemberOfPastOccurrence($viewer, true);
        $enable_WriteReview = 0;

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.allowreview', 1) && $isPastEventMember) {

            $enable_WriteReview = 1;

            $create_review = ($siteevent->owner_id == $viewer_id) ? Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.allowownerreview', 0) : 1;

            $creationAllowOwner = 1;
            if (empty($create_review) && $siteevent->rating_users <= 0) {
                $creationAllowOwner = 0;
            }
            $seeAllReviews = $this->_getParam('seeAllReviews', 0);
            $ratingTable = Engine_Api::_()->getDbTable('ratings', 'siteevent');

            //GET REVIEW TABLE
            $reviewTable = Engine_Api::_()->getDbTable('reviews', 'siteevent');

            if ($viewer_id) {
                $params = array();
                $params['resource_id'] = $siteevent->event_id;
                $params['resource_type'] = $siteevent->getType();
                $params['viewer_id'] = $viewer_id;
                $params['type'] = 'user';
                $hasPosted = $reviewTable->canPostReview($params);
            } else {
                $hasPosted = 0;
            }

            $autorizationApi = Engine_Api::_()->authorization();
            if (Engine_Api::_()->siteevent()->allowReviewCreate($siteevent) && $autorizationApi->getPermission($level_id, 'siteevent_event', "review_create") && empty($hasPosted)) {
                $createAllow = 1;
            } elseif ($autorizationApi->getPermission($level_id, 'siteevent_event', "review_update") && !empty($hasPosted)) {
                $createAllow = 2;
            } else {
                $createAllow = 0;
            }

            $selectRatingTable = $ratingTable->select()
                    ->from($ratingTable->info('name'), 'rating_id')
                    ->where('resource_id = ?', $siteevent->event_id)
                    ->where('resource_type = ?', $siteevent->getType())
                    ->where('user_id = ?', $viewer_id);
            $rating_exist = $selectRatingTable->query()->fetchColumn();

            $show_rating = 0;
            if (!empty($rating_exist) && !Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.allowreview', 1))
                $show_rating = 1;

            $creationAllow = 1;
            if (empty($createAllow) && empty($show_rating))
                $creationAllow = 0;

            if (empty($creationAllow) || empty($creationAllowOwner)) {
                $createAllow = 0;
            }

            if (empty($seeAllReviews) && (empty($creationAllow) || empty($creationAllowOwner))) {
                $enable_WriteReview = 0;
            }

            if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.reviews', 2) || Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.reviews', 2) == 1) {
                $enable_WriteReview = 0;
            }
        }

        if ($viewer && $viewer_id)
            $guestCount = $this->_getParam('guestCountActive', 13);
        else
            $guestCount = $this->_getParam('guestCountDeactive', 18);

        if (!empty($viewer_id)) {
            $event_members = $siteevent->membership()->getMemberCount(true);

            $message_downloadlink = false;
            if ($event_members)
                $message_downloadlink = true;
        }
        $params['page'] = $page;
        $params['limit'] = $limit;
        $params['event_id'] = $siteevent->getIdentity();
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        if ($viewer->getIdentity()) {
            $timezone = $viewer->timezone;
        }

        $params['firststarttime'] = $firstStartDate;
        $params['laststarttime'] = $lastStartDate;

        if ($this->_getParam('firstStartDate', false)) {
            $oldTz = date_default_timezone_get();
            date_default_timezone_set($timezone);
            $startdate = strtotime($this->_getParam('firstStartDate', false));
            $lastDate = strtotime($this->_getParam('lastStartDate', false));

            //TODO GET LOCAL
            //$startdate = strtotime(Engine_Api::_()->siteevent()->convertDateFormat($this->_getParam('firstStartDate', false)));
            //$lastDate = strtotime(Engine_Api::_()->siteevent()->convertDateFormat($this->_getParam('lastStartDate', false)));
            date_default_timezone_set($oldTz);
            $params['firststarttime'] = date("Y-m-d H:i:s", $startdate);
            if ($this->_getParam('lastStartDate', false)) {
                $params['laststarttime'] = date("Y-m-d H:i:s", $lastDate + (24 * 3600) - 1);
            } else
                $params['laststarttime'] = $lastStartDate;
        }

        $params['order'] = 'ASC';
        if (!isset($params['firststarttime'])) {

            $oldTz = date_default_timezone_get();
            date_default_timezone_set($timezone);
            $params['firststarttime'] = date('Y-m-d H:i:s', time());
            //   $firstStartDate = $this->locale()->toDateTime(time());
            $params['laststarttime'] = isset($params['laststarttime']) ? $params['laststarttime'] : $lastStartDate;
            date_default_timezone_set($oldTz);
        }

        $paginator = Engine_Api::_()->getDbTable('occurrences', 'siteevent')->getEventOccurrencesPaginator($params);
        $paginator->setItemCountPerPage($limit);
        $paginator->setCurrentPageNumber($page);
        $totalItemCount = $paginator->getTotalItemCount();
        $params['totalItemCount'] = $totalItemCount;
        $showContent = true;


        foreach ($paginator as $eventOccurrence) {
            //to provide info on joining an occurence
            if (isset($_REQUEST['getJoinInfo']) && !empty($_REQUEST['getJoinInfo'])) {
                if (isset($_REQUEST['occurrence_id']) && ($eventOccurrence->occurrence_id != $_REQUEST['occurrence_id']))
                    continue;
            }

            $event = $eventOccurrence->toArray();

            $occurrence_info = Engine_Api::_()->siteeventrepeat()->getOccurrenceInfo($eventOccurrence->occurrence_id, $guestCount);

            if ($guest_count_link) {

                $event['totalMembers'] = $subject->membership()->getMemberCount(true, array('occurrence_id' => $eventOccurrence->occurrence_id));
            }

            $endDate = Engine_Api::_()->getDbTable('occurrences', 'siteevent')->getOccurenceEndDate($subject->getIdentity(), 'DESC', $eventOccurrence->occurrence_id);
            $url = Engine_Api::_()->siteeventrepeat()->getOccurrenceHref($eventOccurrence->occurrence_id);
            if (!empty($occurrence_info)) {
                $tempresponse = array();

                foreach ($occurrence_info as $member) {

                    $guest = Engine_Api::_()->getItem('user', $member['user_id']);

                    if (!isset($guest->user_id))
                        continue;

                    $memberguest["guest_title"] = $guest->getTitle();
                    $memberguest['guest_id'] = $member['user_id'];


                    if ($guest_pictures) {
                        // ADD GUEST IMAGES
                        $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($guest);
                        $memberguest = array_merge($memberguest, $getContentImages);
                    }
                    $tempresponse[] = $memberguest;
                }

                $event['guest'] = $tempresponse;
            }
            $memberInfo = null;
            $menu = array();
            if ($viewer->getIdentity()) {
                $params['occurrence_id'] = $eventOccurrence->occurrence_id;
                $memberInfo = $subject->membership()->getMemberInfoCustom($viewer, $params);
                //AUTHORIZATION CHECK
                $auth = Engine_Api::_()->authorization()->context;
                $list = $subject->getLeaderList();
                $leaderRow = $list->get($viewer);
                if (!empty($memberInfo))
                    $event['rsvp'] = $memberInfo->rsvp;

                if (strtotime($endDate) > time() && $auth->isAllowed($subject, $viewer, "invite") && $leaderRow == null && ($memberInfo && $memberInfo->rsvp != 3 || $viewer->getIdentity() == $subject->owner_id)) {
                    //CHECK IF SITEEVENTINVITE MODULE IS ENABLED
                    $siteeventinvite = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteeventinvite');

                    if (!empty($siteeventinvite)) {
                        //TODO SITEEVENT INVITE WORK
                    } else {

                        $menu[] = array(
                            'label' => $this->translate('Invite Guests'),
                            'name' => 'invite',
                            'url' => 'advancedevents/member/invite/' . $subject->getIdentity(),
                            'urlParams' => array(
                                'occurrence_id' => $eventOccurrence->occurrence_id
                            )
                        );
                    }
                }

                if (strtotime($endDate) <= time() && $enable_WriteReview && $memberInfo && $memberInfo->active) {

                    if ($createAllow == 1) {
                        $menu[] = array(
                            'label' => $this->translate('Write Review'),
                            'name' => 'createReview',
                            'url' => 'advancedevents/review/create/' . $subject->getIdentity(),
                            'urlParams' => array(
                                'occurrence_id' => $eventOccurrence->occurrence_id
                            )
                        );
                    } elseif ($createAllow == 2) {
                        $menu[] = array(
                            'label' => $this->translate('Update Review'),
                            'name' => 'updateReview',
                            'url' => 'advancedevents/review/update/' . $subject->getIdentity(),
                            'urlParams' => array(
                                'occurrence_id' => $eventOccurrence->occurrence_id
                            )
                        );
                    }
                }
                if (null == $memberInfo) {

                    if ($subject->membership()->isResourceApprovalRequired()) {
                        $menu[] = array(
                            'label' => $this->translate('Request Invite'),
                            'name' => 'request_invite',
                            'url' => 'advancedevents/member/request/' . $subject->getIdentity(),
                            'urlParams' => array(
                                'occurrence_id' => $eventOccurrence->occurrence_id
                            )
                        );
                    } else {
                        if (strtotime($endDate) >= time()) {
                            $menu[] = array(
                                'label' => $this->translate('Join Event'),
                                'name' => 'join',
                                'url' => 'advancedevents/member/join/' . $subject->getIdentity(),
                                'urlParams' => array(
                                    'occurrence_id' => $eventOccurrence->occurrence_id
                                )
                            );
                        }
                    }
                } elseif ($memberInfo->active) {

                    if ($memberInfo->resource_approved && $memberInfo->user_approved) {
                        $menu[] = array(
                            'label' => $this->translate('Leave Event'),
                            'name' => 'leave',
                            'url' => 'advancedevents/member/leave/' . $subject->getIdentity(),
                            'urlParams' => array(
                                'occurrence_id' => $eventOccurrence->occurrence_id
                            )
                        );
                    }
                } else if (!$memberInfo->resource_approved && $memberInfo->user_approved) {
                    $menu[] = array(
                        'label' => $this->translate('Cancel Invite Request'),
                        'name' => 'cancel_invite',
                        'url' => 'advancedevents/member/cancel/' . $subject->getIdentity(),
                        'urlParams' => array(
                            'occurrence_id' => $eventOccurrence->occurrence_id
                        )
                    );
                } else if (!$memberInfo->user_approved && $memberInfo->resource_approved) {
                    $menu[] = array(
                        'label' => $this->translate('Accept Invite Request'),
                        'name' => 'accept_invite',
                        'url' => 'advancedevents/member/accept/' . $subject->getIdentity(),
                        'urlParams' => array(
                            'occurrence_id' => $eventOccurrence->occurrence_id
                        )
                    );
                }

                if (!empty($memberInfo) && !$memberInfo->user_approved && $memberInfo->resource_approved) {
                    $menu[] = array(
                        'label' => $this->translate('Reject Invite Request'),
                        'name' => 'reject_invite',
                        'url' => 'advancedevents/member/reject/' . $subject->getIdentity(),
                        'urlParams' => array(
                            'occurrence_id' => $eventOccurrence->occurrence_id
                        )
                    );
                }
            }

            if (isset($getMenu) && !empty($getMenu))
                $event['menu'] = $menu;

            if (isset($viewer) && !empty($viewer) && $event['rsvp'] && $rsvp_form) {
                $event['rsvp_form'] = $this->_getProfileRSVP();
            }

            $event['event_id'] = $siteevent->getIdentity();

            $occurenceparams['response'][] = $event;
        }

        //@todo paid extension
        if (!Engine_Api::_()->siteevent()->isTicketBasedEvent() && ($level_id == 1 || $siteevent->isOwner($viewer) || $canEdit)) {
            if (($level_id == 1 || $siteevent->isOwner($viewer) || $canEdit)) {
                $occurenceparams['messageGuest'] = array(
                    'label' => $this->translate('Message Guest'),
                    'name' => 'messageGuest',
                    'url' => 'advancedevents/member/compose/' . $siteevent->getIdentity(),
                );
            }
        }

        if (!isset($occurenceparams) && empty($occurenceparams))
            $occurenceparams['response'] = array();
        
        $this->respondWithSuccess($occurenceparams);
    }

    /**
     * RETURN THE DETAILS OF OCCURRENCES OF EVENT .
     * 
     * @return array
     */
    public function infoAction() {

// VALIDATE REQUEST METHOD
        $this->validateRequestMethod();

        //AUTHORIZATION CHECK
        if (!$this->_helper->requireAuth()->setAuthParams('siteevent_event', null, "view")->isValid())
            $this->respondWithError('unauthorized');

        //RETURN IF NO SUBJECT
        if (!Engine_Api::_()->core()->hasSubject('siteevent_event')) {
            $this->respondWithError('no_record');
        }

        $event_id = (int) $this->getRequestParam('event_id');

        $siteevent = Engine_Api::_()->core()->getSubject();

//GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $isAllowedView = $siteevent->authorization()->isAllowed($viewer, 'view');
        $siteeventrepeatDate = Zend_Registry::isRegistered('siteeventrepeatDate') ? Zend_Registry::get('siteeventrepeatDate') : null;
        $info = "";


// RETURN IF LOGGED-IN USER NOT AUTHORIZED TO VIEW EVENT.
        if (empty($isAllowedView))
            $this->respondWithError('unauthorized');

        if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteeventrepeat'))
            $this->respondWithError('unauthorized');

        $show_eventtype = $this->_getParam('showeventtype', 1);
        $show_eventtime = $this->_getParam('showeventtime', 1);
        $show_eventcondition = $this->_getParam('showeventcondition', 1);

        if (empty($siteevent->repeat_params))
            $this->respondWithError('no_record');
        try {
            $totalEventOccurrences = $totalEventOccurrences = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getOccurrenceCount($siteevent->event_id);
//            if ($totalEventOccurrences <= 1)
//                $this->respondWithError('no_record');
//GET THE EVENT FIRST OCCURRENCE STARTTIME AND ENDTIME.
//SAVE THE OCCURRENCE ID IN THE ZEND REGISTRY.

            if (empty($occurrence_id) || !is_numeric($occurrence_id)) {
//GET THE NEXT UPCOMING OCCURRENCE ID
                $occurrence_id = Engine_Api::_()->getDbTable('events', 'siteevent')->getNextOccurID($siteevent->event_id);
            }

            $eventInfo = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getEventDate($siteevent->event_id, $occurrence_id);
            $repeat_params = json_decode($siteevent->repeat_params, true);
            $response = $repeat_params;
            $response['end_date'] = $repeat_params['endtime']['date'];
            $datetimeFormat = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.datetime.format', 'medium');
            if (!empty($repeat_params['eventrepeat_type']) && $repeat_params['eventrepeat_type'] != 'custom') {
                if ($show_eventtime) {
                    $response['starttime'] = $eventInfo['starttime'];
                    $response['endtime'] = $eventInfo['endtime'];
                    if ($datetimeFormat == 'full' || $datetimeFormat == 'long') {
                        if ($viewer)
                            $response['timezone'] = $local;
                        else
                            $response['timezone'] = date_default_timezone_get();
                    }
                }
            }

            if ($repeat_params['eventrepeat_type'] == 'daily') {
                $info = $this->translate('Daily Event');
                if (($repeat_params['repeat_interval'] / (24 * 60 * 60)) > 1) {
                    $info = $info . ' - ';
                    $info = $info . (($repeat_params['repeat_interval'] / (24 * 60 * 60)) > 1) ? 'Every ' . $repeat_params['repeat_interval'] / (24 * 60 * 60) . ' days' : '';
                }
            } elseif ($repeat_params['eventrepeat_type'] == 'weekly') {
                $info = $this->translate('Weekly Event');
                $info = $info . ' - ';
                if ($repeat_params['repeat_week'] > 1)
                    $info = $info . 'Every %s weeks' . $repeat_params['repeat_week'] . ' - ';

                $weekdays = array(1 => 'monday', 2 => 'tuesday', 3 => 'wednesday', 4 => 'thursday', 5 => 'friday', 6 => 'saturday', 7 => 'sunday');
                $info = $info . $this->translate('Every') . ' ';
                $totalWeekDays = count($repeat_params['repeat_weekday']);
                foreach ($repeat_params['repeat_weekday'] as $key => $weekday) {
                    $key++;
                    if ($key == 1)
                        $info = $info . $this->translate(ucfirst($weekdays[$weekday]));
                    elseif ($key > 1 && $key < $totalWeekDays)
                        $info = $info . $this->translate(ucfirst($weekdays[$weekday]));
                    elseif ($key > 1 && $key == $totalWeekDays)
                        $info = $info . $this->translate(ucfirst($weekdays[$weekday]));
                }
            } elseif ($repeat_params['eventrepeat_type'] == 'monthly') {
                $info = $info . $this->translate('Monthly Event');
                $info = $info . ' - ';
                if ($repeat_params['repeat_month'] > 1)
                    $info = $info . $this->translate('Every ' . $repeat_params['repeat_month'] . '  months, ');
                $noOfWeeks = array('first' => 1, 'second' => 2, 'third' => 3, 'fourth' => 4, 'fifth' => 5, 'last' => 6);
                $dayOfWeeks = array('monday' => 1, 'tuesday' => 2, 'wednesday' => 3, 'thursday' => 4, 'friday' => 5, 'saturday' => 6, 'sunday' => 7);
                if (isset($repeat_params['repeat_week'])) {
                    $info = $info . $this->translate(ucfirst(array_search($repeat_params['repeat_week'], $noOfWeeks))) . ' ' . $this->translate(ucfirst(array_search($repeat_params['repeat_weekday'], $dayOfWeeks))) . ' ' . $this->translate('of every month');
                } else {
                    $info = $info . $this->translate('Day %s of every month', $repeat_params['repeat_day']);
                }
            }

            $response['infoString'] = $info;

            $this->respondWithSuccess($response);
        } catch (Exception $ex) {
            
        }
    }

    /**
     * Getting the event profile page rsvp form array.
     * 
     * @return array
     */
    private function _getProfileRSVP() {
        $rsvpForm = array();
        $rsvpForm[] = array(
            'type' => 'Select',
            'name' => 'rsvp',
            'multiOptions' => array(
                2 => $this->translate('Attending'),
                1 => $this->translate('Maybe Attending'),
                0 => $this->translate('Not Attending'),
            //3 => 'Awaiting Reply',
            )
        );

        $rsvpForm[] = array(
            'type' => 'Submit',
            'name' => 'submit',
            'label' => $this->translate('Submit')
        );

        return $rsvpForm;
    }

}
