<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventticket
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Order.php 2015-05-11 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventticket_Model_Order extends Core_Model_Item_Abstract {

    // Properties
    protected $_parent_is_owner = true;
    protected $_package;
    protected $_statusChanged;
    protected $_product;
    protected $_searchTriggers = false;

    public function getGatewayParams() {
        $params = array();

        $siteTitle = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.general.site.title', '');

        $orderTitle = '#' . $this->order_id;

        // General
        $params['name'] = $siteTitle . ' Order Nos ' . $orderTitle;
        $params['price'] = @round($this->grand_total, 2);
//    $params['tax'] = @round(10, 2);
        $params['description'] = 'Orders ' . $orderTitle . ' on ' . $siteTitle;
        $params['vendor_product_id'] = $this->getGatewayIdentity();
        $params['tangible'] = false;
        // Non-recurring
        $params['recurring'] = false;

        return $params;
    }

    public function onPaymentSuccess() {
        $this->_statusChanged = false;

        if (in_array($this->payment_status, array('initial', 'trial', 'pending', 'active', 'overdue', 'expired'))) {
            // Change status
            if ($this->payment_status != 'active') {
                $this->payment_status = 'active';
                $this->_statusChanged = true;
            }
        }
        $this->save();
        return $this;
    }

    public function onPaymentPending() {
        $this->_statusChanged = false;
        if (in_array($this->payment_status, array('initial', 'trial', 'pending', 'active', 'overdue', 'expired'))) {
            // Change status
            if ($this->payment_status != 'pending') {
                $this->payment_status = 'pending';
                $this->_statusChanged = true;
            }
        }
        $this->save();
        return $this;
    }

    public function onPaymentFailure() {
        $this->_statusChanged = false;
        if (in_array($this->payment_status, array('initial', 'trial', 'pending', 'active', 'overdue', 'expired'))) {
            // Change status
            if ($this->payment_status != 'overdue') {
                $this->payment_status = 'overdue';
                $this->_statusChanged = true;
            }

            $session = new Zend_Session_Namespace('Payment_Siteeventticket');
            $session->unsetAll();
        }
        $this->save();
        return $this;
    }

    public function onRefund() {
        $this->_statusChanged = false;
        if (in_array($this->payment_status, array('initial', 'trial', 'pending', 'active', 'refunded'))) {
            // Change status
            if ($this->payment_status != 'refunded') {
                $this->payment_status = 'refunded';
                $this->_statusChanged = true;
            }
        }
        $this->save();
        return $this;
    }

    public function getGatewayIdentity() {
        return $this->getProduct()->sku;
    }

    public function getProduct() {
        if (null === $this->_product) {
            $productsTable = Engine_Api::_()->getDbtable('products', 'payment');
            $this->_product = $productsTable->fetchRow($productsTable->select()
                            ->where('extension_type = ?', 'siteeventticket_order')
                            ->where('extension_id = ?', $this->getIdentity())
                            ->limit(1));
            // Create a new product?
            if (!$this->_product) {
                $this->_product = $productsTable->createRow();
                $this->_product->setFromArray($this->getProductParams());
                $this->_product->save();
            }
        }

        return $this->_product;
    }

    public function getProductParams() {

        return array(
            'title' => 'order',
            'description' => 'siteeventticket',
            'price' => @round($this->grand_total, 2),
            'extension_type' => 'siteeventticket_order',
            'extension_id' => $this->order_id,
        );
    }
    
    public function showPrintLink() {

    if (in_array($this->gateway_id, array("3", "4", "5", "15"))) {
      return true;
    } else {
      if ($this->order_status == 3) :
        $payment_status = 'marked as non-payment';
      elseif ($this->payment_status == 'active') :
        $payment_status = 'Yes';
      else:
        $payment_status = 'No';
      endif;
      if ($payment_status == 'Yes' && $this->order_status != 3) {
        return true;
      }
    }
    return false;
  }

  public function setPhoto($photo){
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
      $fileName = $file;
    } else if( $photo instanceof Storage_Model_File ) {
      $file = $photo->temporary();
      $fileName = $photo->name;
    } else if( $photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id) ) {
      $tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
      $file = $tmpRow->temporary();
      $fileName = $tmpRow->name;
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
      $fileName = $photo['name'];
    } else if( is_string($photo) && file_exists($photo)) {
      $file = $photo;
      $fileName = $photo;
      // $unlink = false;
    } else {
      throw new User_Model_Exception('invalid argument passed to setPhoto');
    }


    $name = basename($file);
    $extension = ltrim(strrchr($fileName, '.'), '.');
    $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
    if( !$fileName ) {
      $fileName = $file;
    }
    $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => $this->getType(),
      'parent_id' => $this->getIdentity(),
      'user_id' => $this->user_id,
      'name' => $fileName,
    );
    // Resize image (main)
    $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(1200, 700)
      ->write($mainPath)
      ->destroy();
        
    // Store
    try {
      $iMain = $filesTable->createFile($mainPath, $params);      
    } catch( Exception $e ) {
            @unlink($file);
      // Remove temp files
      @unlink($mainPath);
     
      // Throw
      if( $e->getCode() == Storage_Model_DbTable_Files::SPACE_LIMIT_REACHED_CODE ) {
        throw new Sesalbum_Model_Exception($e->getMessage(), $e->getCode());
      } else {
        throw $e;
      }
    }
        if(!isset($unlink))
            @unlink($file);
    // Remove temp files
      @unlink($mainPath);
     
    // Update row
    $this->file_id = $iMain->file_id;
    $this->save();
    // Delete the old file?
    if( !empty($tmpRow) ) {
      $tmpRow->delete();
    }
    return $this;
    } 
  public function getPhotoUrl($type = null) {
    if ($this->file_id) {
      $file = Engine_Api::_()->getItemTable('storage_file')->getFile($this->file_id, $type);
            if($file)
        return $file->map();
            else{
                $file = Engine_Api::_()->getItemTable('storage_file')->getFile($this->file_id,'thumb.profile');
                if($file)
                    return $file->map();
            }
    }
  }

}
