<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventticket
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventticket_CouponController extends Siteapi_Controller_Action_Standard {

    public function init() {
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.ticket.enabled', 1)) {
            $this->respondWithError('unauthorized');
        }

        $viewer = Engine_Api::_()->user()->getViewer();

        if (!Engine_Api::_()->authorization()->isAllowed('siteevent_event', $viewer, "view")) {
            $this->respondWithError('unauthorized');
        }

        //SET EVENT SUBJECT
        if ($this->getRequestParam('event_id') && (0 !== ($event_id = (int) $this->getRequestParam('event_id')) &&
                null !== ($siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id))))
            Engine_Api::_()->core()->setSubject($siteevent);
    }

    /**
     * Returns the list & details of all coupons with search parameters.
     * 
     * @return array
     */
    public function indexAction() {
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.couponprivate', 0)) {
            $this->respondWithError('unauthorized');
        }

        //DON'T RENDER IF SUBJECT IS NOT SET
         $params = array();
        //DON'T RENDER IF SUBJECT IS NOT SET
        if (Engine_Api::_()->core()->hasSubject('siteevent_event')) {
            $siteevent = Engine_Api::_()->core()->getSubject('siteevent_event');
            $params['event_id'] = $siteevent->event_id;
            $can_create_coupons = $siteevent->authorization()->isAllowed($viewer, 'edit');
            $params['show_all_coupons'] = $can_create_coupons;
            $params['var'] = 1;
        }


        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $response['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
        try {
            $paginator = Engine_Api::_()->getDbtable('coupons', 'siteeventticket')->getSiteEventTicketCouponsPaginator($params);
            $paginator->setItemCountPerPage($this->_getParam('itemCount', 20));
            $paginator->setCurrentPageNumber($this->_getParam('page', 1));
            $response['totalItemCount'] = $paginator->getTotalItemCount();

            foreach ($paginator as $coupon) {
                $couponArray = $coupon->toArray();

                //Set event title
                $event = Engine_Api::_()->getItem('siteevent_event', $coupon->event_id);
                $couponArray['event_title'] = $event->getTitle();

                //Set coupon images
                $getCouponImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($coupon, false);
                $couponArray = array_merge($couponArray, $getCouponImages);

                $tempResponse[] = $couponArray;
            }
            if (!empty($tempResponse))
                $response['response'] = $tempResponse;
            $this->respondWithSuccess($response, true);
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
    }

}
