<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventticket
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: OrderController.php 2015-05-11 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventticket_OrderController extends Siteapi_Controller_Action_Standard {
	public function init() {

		//TICKET SETTING DISABLED FROM ADMIN SIDE
		$ticket = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.ticket.enabled', 1);
		if (empty($ticket)) {
			$this->respondWithError('unauthorized');
		}

		//LOGGED IN USER VALIDATON
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		//SET SUBJECT
		$event_id = $this->_getParam('event_id', null);

		if ($event_id) {
			$siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id);
			if ($siteevent && !Engine_Api::_()->core()->hasSubject('siteevent_event')) {
				Engine_Api::_()->core()->setSubject($siteevent);
			}
		}
		//END - SET SUBJECT
	}

	public function viewAction() {

		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		$order_id = $this->_getParam('order_id', null);
		$orderObj = Engine_Api::_()->getItem('siteeventticket_order', $order_id);

		if (empty($order_id) || empty($orderObj)) {
			$this->respondWithError('unauthorized');
		}

		$occurrenceObj = Engine_Api::_()->getItem('siteevent_occurrence', $orderObj->occurrence_id);

		//  WHEN OCCURRENCE HAS BEEN DELETED
		if ($occurrenceObj) {
			$siteevent = Engine_Api::_()->getItem('siteevent_event', $occurrenceObj->event_id);
			$eventTitle = $siteevent->getTitle();
		}

		$event_id = $orderObj->event_id;
		$event_owner_id = $siteevent->owner_id;

		if ($viewer->level_id == 1 || $viewer_id == $event_owner_id) {
			$displayAllDetails = true;
		}

		if ($viewer_id != $orderObj->user_id && $viewer->level_id != 1 && $viewer_id != $event_owner_id) {
			$this->respondWithError('unauthorized');
		}

		//TAX ID NO.
		if ($orderObj->tax_amount) {
			$tax_id_no = Engine_Api::_()->getDbtable('otherinfo', 'siteevent')->getColumnValue($orderObj->event_id, 'tax_id_no');
		}

		//CHEQUE DETAILS
		if ($orderObj->gateway_id == 3) {
			$cheque_info = Engine_Api::_()->getDbtable('ordercheques', 'siteeventticket')->getChequeDetail($orderObj->cheque_id);
		}

		$orderInfo = $orderObj->toArray();
		$orderInfo['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');

		$orderInfo['creation_date'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($orderInfo['creation_date']);
		$orderInfo['occurrence_starttime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($orderInfo['occurrence_starttime']);
		$orderInfo['occurrence_endtime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($orderInfo['occurrence_endtime']);

		if (isset($orderInfo['ip_address'])) {
			unset($orderInfo['ip_address']);
		}

		//DETAILS ORDER_ID
		$user = Engine_Api::_()->getItem('user', $orderObj->user_id);
		$orderTickets = Engine_Api::_()->getDbtable('orderTickets', 'siteeventticket')->getOrderTicketsDetail(array('order_id' => $order_id));

		$coupon_details = array();
		$fixedDiscount = 1;
		if (!empty($orderObj->coupon_detail)) {
			$coupon_details = unserialize($orderObj->coupon_detail);
			if (is_array($coupon_details)) {
				foreach ($coupon_details as $coupon_detail) {
					$coupon_details = $coupon_detail;
					$fixedDiscount = !empty($coupon_detail['coupon_type']) ? 1 : 0;
					if ($fixedDiscount) {
						$orderInfo['grand_total'] -= $coupon_detail['coupon_amount'];
					}
					break;
				}
			}
		}

		$isOrderHavingDiscount = Engine_Api::_()->getDbtable('orderTickets', 'siteeventticket')->isOrderHavingDiscount(array('order_id' => $order_id));
		$site_title = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.general.site.title', '');
		$admin_cheque_detail = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.send.cheque.to', null);

		if ($orderObj->gateway_id == 3 && !empty($admin_cheque_detail) && empty($orderObj->direct_payment)) {

			$orderInfo['details'] = $this->translate("%s's Bank Account Details", $site_title);
		} elseif (!empty($orderObj->direct_payment) && $orderObj->gateway_id == 3) {
			$eventChequeDetail = Engine_Api::_()->getDbtable('eventGateways', 'siteeventticket')->getEventChequeDetail(array('event_id = ?' => $orderObj->event_id, "title = 'ByCheque'", "enabled = 1"));
			if (!empty($eventChequeDetail)) {
				$chequeDetailUrl = $this->url(array('module' => 'siteeventticket', 'controller' => 'order', 'action' => 'event-cheque-detail', 'event_id' => $orderObj->event_id, 'title' => $eventTitle), 'default', true);
				$orderInfo['details'] = $this->translate("%s event's Bank Account Details", $eventTitle);
			}
		}

		if (!empty($orderObj->direct_payment)) {
			if ($orderObj->order_status == 3) {
				$orderInfo['payment_method'] = $this->translate('marked as non-payment');
			}
		}

		if (!empty($this->orderObj->direct_payment)) {
			if (!empty($orderObj->non_payment_seller_reason)) {
				if ($orderObj->non_payment_seller_reason == 1) {
					$orderInfo['non_payment_seller_reason'][$this->translate("Non-Payment Reason")] = $this->translate("Chargeback");
				} elseif ($orderObj->non_payment_seller_reason == 2) {
					$orderInfo['non_payment_seller_reason'][$this->translate("Non-Payment Reason")] = $this->translate("Payment not received");
				} elseif ($orderObj->non_payment_seller_reason == 3) {
					$orderInfo['non_payment_seller_reason'][$this->translate("Non-Payment Reason")] = $this->translate("Cancelled payment");
				}

			}

			if (!empty($orderObj->non_payment_seller_message)) {
				$orderInfo['non_payment_seller_reason'][$this->translate("Seller Message")] = $orderObj->non_payment_seller_message;
			}
			if (!empty($orderObj->non_payment_admin_reason)) {
				if ($this->orderObj->non_payment_admin_reason == 1) {
					$orderInfo['non_payment_admin_reason'][$this->translate("Non-Payment Action")] = $this->translate("Approved");
				} elseif ($orderObj->non_payment_admin_reason == 2) {
					$orderInfo['non_payment_admin_reason'][$this->translate("Non-Payment Action")] = $this->translate("Declined");
				}

			}
			if (!empty($this->orderObj->non_payment_admin_message)) {
				$orderInfo['non_payment_admin_reason'][$this->translate("Site Administrator Message")] = $orderObj->non_payment_admin_message;
			}
		}
		if ($orderObj->gateway_id == 3) {
			$orderInfo['cheque_details'][$this->translate('Cheque No')] = $cheque_info['cheque_no'];
			$orderInfo['cheque_details'][$this->translate('Account Holder Name')] = $cheque_info['customer_signature'];
			$orderInfo['cheque_details'][$this->translate('Account Number')] = $cheque_info['account_number'];
			$orderInfo['cheque_details'][$this->translate('Bank Rounting Number')] = $cheque_info['bank_routing_number'];
		}
		$orderCouponAmount = 0;
		if (!empty($coupon_details)) {
			$orderCouponAmount = $coupon_details['coupon_amount'];
		}

		if (!empty($orderCouponAmount) && $fixedDiscount) {
			$orderInfo['discount'] = $orderCouponAmount;
		}

		$orderInfo['user_title'] = $user->getTitle();
		if (isset($user->email)) {
			$orderInfo['user_email'] = $user->email;
		}

		$orderInfo['event_title'] = $eventTitle;
		$orderInfo['payment_method'] = $this->translate(Engine_Api::_()->siteeventticket()->getGatwayName($orderObj->gateway_id));
		if (!empty($orderObj->direct_payment) && $orderObj->order_status == 3) {
			$orderInfo['order_status_text'] = '-';
		} else {
			$orderInfo['order_status_text'] = $this->_getTicketOrderStatus($orderObj->order_status);
		}

		$orderInfo['commission_type'] = empty($orderObj->commission_type) ? $this->translate('Fixed') : $this->translate('Percentage');
		if (!empty($orderObj->commission_type)) {
			$orderInfo['commission_rate'] = number_format($orderObj->commission_rate, 2) . ' %';
		}

		if ($orderObj->commission_value) {
			$orderInfo['commission_value'] = $orderObj->commission_value;
		}

		if ($tax_id_no) {
			$orderInfo['tax_id_no'] = $tax_id_no;
		}

		$orderInfo['tabs']['ticket'] = $this->translate("Ticket");
		$orderInfo['tabs']['price'] = $this->translate('Price');
		if ($isOrderHavingDiscount && !$fixedDiscount) {
			$orderInfo['tabs']['discount'] = $this->translate('Discounted Price');
		}

		$orderInfo['tabs']['quantity'] = $this->translate("Quantity");
		$orderInfo['tabs']['subtotal'] = $this->translate('Subtotal');
		foreach ($orderTickets as $item) {
			$ticket['title'] = $this->translate($item->title);
			if (!empty($order_ticket_info) && !empty($order_ticket_info['calendarDate']) && !empty($order_ticket_info['calendarDate']['starttime']) && !empty($order_ticket_info['calendarDate']['endtime'])) {
				$ticket['starttime'] = $order_ticket_info['calendarDate']['starttime'];
				$ticket['endtime'] = $order_ticket_info['calendarDate']['endtime'];
			}
			$ticket['price'] = $item->price;
			if ($isOrderHavingDiscount && !$fixedDiscount) {
				$ticket['discountedPrice'] = $item->discounted_price;
			}
			$ticket['quantity'] = $item->quantity;
			$ticket['subTotal'] = $item->discounted_price * $item->quantity;
			$ticketArray[] = $ticket;
		}
		$orderInfo['tickets'] = $ticketArray;
		$this->respondWithSuccess($orderInfo, true);
	}

	public function buyerDetailsAction() {
		// GET VIEWER
		$viewer = Engine_Api::_()->user()->getViewer();
		$event_id = $this->_getParam('event_id');
		$cartInfo = $this->_getParam('order_info');
		$stripslashesContent = stripslashes($cartInfo);
		$cartInfo = !empty($stripslashesContent) ? Zend_Json::decode($stripslashesContent) : array();
		$siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id);
		Engine_Api::_()->getApi('Core', 'siteapi')->setView();

		$isCopiedDetails = 0;
		try {
			$values = $_REQUEST;
			$isCopiedDetails = $_REQUEST['isCopiedDetails'];
			$detailsTobeCopied['firstName'] = $_REQUEST['fname'];
			$detailsTobeCopied['lastName'] = $_REQUEST['lname'];
			$detailsTobeCopied['email'] = $_REQUEST['email'];
			$tax_rate = false;
			if (Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.tax.enabled', 0) && Engine_Api::_()->getDbtable('otherinfo', 'siteevent')->getColumnValue($event_id, 'is_tax_allow') && Engine_Api::_()->getDbtable('otherinfo', 'siteevent')->getColumnValue($event_id, 'tax_rate') > 0) {
				$tax_rate = true;
			}

			$form = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getBuyerForm($cartInfo, $isCopiedDetails, $detailsTobeCopied);
			if ($this->getRequest()->isGet() || ($isCopiedDetails && !$this->getRequest()->isPost())) {
				$this->respondWithSuccess($form, true);
			} else if ($this->getRequest()->isPost()) {
				$jsonBuild = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getBuyerFormJsonHelper($cartInfo, $isCopiedDetails, $detailsTobeCopied, $values);
				if (!empty($jsonBuild)) {
					$this->respondWithSuccess($jsonBuild);
				}
			}
		} catch (Exception $ex) {
			$this->respondWithValidationError('internal_server_error', $ex->getMessage());
		}
	}

	//ACTION TO DISPLAY CHECKOUT PAGE (BUY TICKETS)
	public function checkoutAction() {
		$event_id = $this->_getParam('event_id');
		$formValues = $order_info = $this->_getParam('order_info');
		$buyer_info = $this->_getParam('buyer_info');
		$siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id);

		if (isset($formValues) && !empty($formValues)) {
			$values = Zend_Json_Decoder::decode($formValues);
		}

		// Check if direct payment enable
		$isPaymentToSiteEnable = (int)Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.payment.to.siteadmin', 0);
		$gatewayType = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.payment.method', 'normal');
		if ($gatewayType != 'normal') {
			$isPaymentToSiteEnable = false;
		}

		// Set occurence_id
		if (!empty($values)) {
			if (!empty($values['date_filter_occurrence'])) {
				$occurrence_id = $values['date_filter_occurrence'];
			} else {
				$occurrence_id = Engine_Api::_()->getDbTable('occurrences', 'siteevent')->getOccurrence();
			}
		}

		$checkout_process = array();

		// Get Payment Gateways enabled work start
		if (empty($isPaymentToSiteEnable)) {
			$eventEnabledgateway = Engine_Api::_()->getDbtable('otherinfo', 'siteevent')->getColumnValue($event_id, 'event_gateway');

			if (!empty($eventEnabledgateway)) {
				if ($gatewayType == 'split') {
					$siteAdminEnablePaymentGateway = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.allowed.payment.split.gateway', array());
				} else {
					$siteAdminEnablePaymentGateway = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.allowed.payment.gateway', array('paypal', 'cheque', 'cod'));
				}
				$eventEnabledgateway = Zend_Json_Decoder::decode($eventEnabledgateway);

				foreach ($eventEnabledgateway as $gatewayName => $gatewayTableId) {
					if (in_array($gatewayName, $siteAdminEnablePaymentGateway)) {
						$finalEventEnableGateway[] = $gatewayName;
					}
				}
				$payment_gateway = $finalEventEnableGateway;
				if (count($finalEventEnableGateway) == 1 && in_array('cod', $finalEventEnableGateway)) {
					$isOnlyCodGatewayEnable = true;
				}

			}

			// IF NO PAYMENT GATEWAY ENABLE
			if (empty($eventEnabledgateway) || empty($finalEventEnableGateway)) {
				$no_payment_gateway_enable = true;
			}

			if (isset($eventEnabledgateway['cheque']) && !empty($eventEnabledgateway['cheque'])) {
				$chequeParams['event_id'] = $event_id;
				$chequeParams['eventgateway_id'] = $eventEnabledgateway['cheque'];
				$eventChequeDetail = Engine_Api::_()->getDbtable('eventGateways', 'siteeventticket')->getEventChequeDetail($chequeParams);
			}

			if (isset($eventEnabledgateway['cod']) && !empty($eventEnabledgateway['cod']) && (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0')) {

				$codParams['event_id'] = $event_id;
				$codParams['eventgateway_id'] = $eventEnabledgateway['cod'];
				$codParams['cheque'] = 0;
				$cod_receipt = Engine_Api::_()->getDbtable('eventGateways', 'siteeventticket')->getEventChequeDetail($codParams);
			}
			if (isset($eventEnabledgateway['bank']) && !empty($eventEnabledgateway['bank'])  && (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0')) {

				$bankParams['event_id'] = $event_id;
				$bankParams['eventgateway_id'] = $eventEnabledgateway['bank'];
				$bankParams['cheque'] = 0;
				$eventBankDetails = Engine_Api::_()->getDbtable('eventGateways', 'siteeventticket')->getEventChequeDetail($bankParams);
				$eventBankDetails = json_decode($eventBankDetails);
				$eventBankDetail = $eventBankDetails->account_details;
				$eventBankReceipt = $eventBankDetails->receipt;

			}
		} else {
			$gateway_table = Engine_Api::_()->getDbtable('gateways', 'payment');
			$enable_gateway = $gateway_table->select()
				->from($gateway_table->info('name'), array('gateway_id', 'title', 'plugin', 'config'))
				->where('enabled = 1')
				->where('plugin not in (?)', array('Sitegateway_Plugin_Gateway_MangoPay'))
				->query()
				->fetchAll();

			$admin_payment_gateway = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.admin.gateway', array('cheque'));

			if (!empty($admin_payment_gateway)) {
				foreach ($admin_payment_gateway as $payment_gateway) {
					if ($payment_gateway == 'cheque') {
						$by_cheque_enable = true;
						$admin_cheque_detail = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.send.cheque.to', null);
						$eventChequeReceipt = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.cheque.receipt');
					} else if ($payment_gateway == 'cod') {
						$cod_enable = true;
						$cod_receipt = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.cod.receipt');
					}
				}
			}

			if (empty($enable_gateway) && !empty($admin_payment_gateway) && empty($by_cheque_enable) && !empty($cod_enable)) {
				$isOnlyCodGatewayEnable = true;
			}
			// IF NO PAYMENT GATEWAY ENABLE BY THE SITEADMIN
			if (empty($enable_gateway) && empty($admin_payment_gateway)) {
				$no_payment_gateway_enable = true;
			}

			$payment_gateway = $enable_gateway;
		}
		// Get Payment Gateways enabled work end

		if (isset($values['date_filter_occurrence']) && $values['date_filter_occurrence']) {
			$selected_occurrence_id = $values['date_filter_occurrence'];
		} else {
			$selected_occurrence_id = Engine_Api::_()->getDbTable('occurrences', 'siteevent')->getOccurrence();
		}

		$occurrenceObj = Engine_Api::_()->getItem('siteevent_occurrence', $selected_occurrence_id);

		//CHECK TICKETS AVAILABILITY
		foreach ($values['ticket_column'] as $key => $row) {
			$ticket_id = $key;
			//IF - row[1] QUANTITY IS SELECTED & GREATER THAN ZERO
			if (isset($row[1]) && $row[1] > 0) {
				$ticketObj = Engine_Api::_()->getItem('siteeventticket_ticket', $ticket_id);
				$ticketDetailArray = $occurrenceObj->ticket_id_sold;
				$ticket_sold = $ticketDetailArray['tid_' . $ticket_id];
				$quantity = $row[1];
				$remainingTickets = $ticketObj->quantity - $ticket_sold;
				if ($quantity > $remainingTickets) {
					$ticketUnavailabilityMessage = true;
					//break foreach
				}
			}
		}

		$totalOrderPrice = $values['grandTotal'];

		if (!empty($coupon_amount) && ($totalOrderPrice <= $coupon_amount)) {
			$totalOrderPrice = 0;
		}

		//FREE ORDER WORK
		if (empty($totalOrderPrice) || $totalOrderPrice == '0.00') {
			$totalOrderPriceFree = true;
			$this->totalOrderPriceFree = true;
		}

		if (($totalOrderPrice > '0.00' && !empty($no_payment_gateway_enable))) {
			if (empty($isPaymentToSiteEnable)) {
				$error[] = $this->translate("There is no payment gateway enable by the site administrator. So you can't process for checkout process. Please contact to site administrator.");
				$this->respondWithValidationError('validation_fail', $error);
			} else {
				$error[] = $this->translate("Payment gateway is not enabled by Event Owner. Please contact the respective event owner to complete your purchase. Thanks for your patience!");
				$this->respondWithValidationError('validation_fail', $error);
			}
		}

		if ($ticketUnavailabilityMessage) {
			$error[] = $this->translate("Sorry, The tickets you have selected are not available. Please go back and make your selection again according to the availability.");
			$this->respondWithValidationError('validation_fail', $error);
		}

		$isNotAllowedOnlinePayment = !empty($isNotAllowedOnlinePayment) ? $isNotAllowedOnlinePayment : null;
		$temp_online_gateway = false;
		$checkout_process = @unserialize($checkout_process);

//        if (!empty($this->totalOrderPriceFree)) {
		//            $response['free'] = $this->translate("Free Order");
		//            $this->respondWithSuccess($response, true);
		//        }

		foreach ($payment_gateway as $payment_method) {
			if ((isset($payment_method['plugin']) && $payment_method['plugin'] === 'Payment_Plugin_Gateway_2Checkout') || ($payment_method == '2checkout')) {
				$temp_online_gateway = true;

				if (empty($isNotAllowedOnlinePayment)) {
					$multioptions['1'] = $this->translate("2checkout");
					$twoCheckoutEnable = true;
				}
			}

			if ((isset($payment_method['plugin']) && $payment_method['plugin'] === 'Payment_Plugin_Gateway_PayPal') || ($payment_method == 'paypal')) {
				$temp_online_gateway = true;

				if (empty($isNotAllowedOnlinePayment)) {
					$paypalEnable = true;
					$multioptions['2'] = $this->translate("PayPal");
				}
			}

			if (((isset($payment_method['plugin']) && $payment_method['plugin'] === 'Payment_Plugin_Gateway_Bank') || ($payment_method == 'bank')) && (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0')) {
              	$payment_method['config'] = html_entity_decode($payment_method['config']);
              	$config = json_decode($payment_method['config'], true);
          	}

			if (Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
				if ((isset($payment_method['plugin']) && strstr($payment_method['plugin'], 'Sitegateway_Plugin_Gateway_')) || Engine_Api::_()->sitegateway()->isValidGateway($payment_method)) {
					if (is_array($payment_method)) {
						$pluginName = $payment_method['plugin'];
					} else {
						$pluginName = 'Sitegateway_Plugin_Gateway_' . $payment_method;
					}

					Engine_Api::_()->sitegateway()->getGatewayColumn(array('pluginLike' => 'Sitegateway_Plugin_Gateway_', 'columnName' => 'gateway_id', 'gateway_id' => $gateway_id));

					$temp_online_gateway = true;
					$paymentGateway = Engine_Api::_()->sitegateway()->getGatewayColumn(array('fetchRow' => true, 'plugin' => $pluginName));
					$otherPaymentGateways[] = $paymentGatewayId = $paymentGateway->gateway_id;
					$paymentGatewayTitle = strtolower($paymentGateway->title);
					$paymentGatewayTitleUC = ucfirst($paymentGateway->title);

					if (empty($isNotAllowedOnlinePayment)) {
						$otherGatewayEnabled = true;
						$multioptions[$paymentGatewayId] = $this->translate($paymentGatewayTitle);
					}
				}
			}
			if ($payment_method == 'cheque') {
				$byChequeEnable = true;
			}

			if ($payment_method == 'cod') {
				$codEnable = true;
			}

			if ((_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0')) {
				if ($payment_method == 'bank' || (isset($payment_method['plugin']) && $payment_method['plugin'] === 'Payment_Plugin_Gateway_Bank')) {
					$bankEnable = true;
				}
			}

		}

		$options = array();
		if (!empty($cod_enable) || !empty($codEnable)) {
			$temp_payment_gateway_flag = true;
			$multioptions['4'] = $this->translate('Pay at the Event');

			if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
				$codForm[] = array(
					'type' => 'File',
					'name' => 'file',
					'label' => $this->translate('Upload the receipt of Transaction'),
				);

				$formValue['cod_receipt'] = $cod_receipt;
				$options['4'] = $codForm;
			}
		}

		if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
			if (!empty($bankEnable)) {
				$multioptions['15'] = $this->translate('Bank');

				$bankForm[] = array(
					'type' => 'Textarea',
					'name' => 'bank_details',
					'label' => $this->translate("Send Bank to: ")
				);
				$bankForm[] = array(
					'type' => 'File',
					'name' => 'bank_file',
					'label' => $this->translate('Upload the receipt of Transaction'),
				);

				if (!empty($config['account_details']) || (!empty($event_id) && empty($isPaymentToSiteEnable) && !empty($eventBankDetail) ) ) {
					
					if (!empty($config['account_details'])) {
						$formValue['bank_details'] = nl2br($config['account_details']);
						$formValue['bank_receipt'] = $config['receipt'];
					} elseif (!empty($event_id) && empty($isPaymentToSiteEnable) && !empty($eventBankDetail)) {
						$formValue['bank_details'] = nl2br($eventBankDetail);
						$formValue['bank_receipt'] = $eventBankReceipt;
					}
				}

				$options['15'] = $bankForm;
			}
		}

		if (!empty($by_cheque_enable) || !empty($byChequeEnable)) {
			$multioptions['3'] = $this->translate('By Cheque');

			if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
				$chequeForm[] = array(
					'type' => 'Textarea',
					'name' => 'cheque_details',
					'label' => $this->translate("Send Cheque to: ")
				);
			}

			$chequeForm[] = array(
				'type' => 'Text',
				'name' => 'cheque_no',
				'label' => $this->translate("Cheque No"),
				'hasValidator' => 'true',
			);
			$chequeForm[] = array(
				'type' => 'Text',
				'name' => 'signature',
				'label' => $this->translate("Account Holder Name"),
				'hasValidator' => 'true',
			);
			$chequeForm[] = array(
				'type' => 'Text',
				'name' => 'account_no',
				'label' => $this->translate("Account Number"),
				'hasValidator' => 'true',
			);
			$chequeForm[] = array(
				'type' => 'Text',
				'name' => 'routing_no',
				'label' => $this->translate("Bank Routing Number"),
				'hasValidator' => 'true',
			);

			if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
				$chequeForm[] = array(
					'type' => 'File',
					'name' => 'cheque_file',
					'label' => $this->translate('Upload the receipt of Transaction'),
				);

				if (!empty($admin_cheque_detail) || (!empty($event_id) && empty($isPaymentToSiteEnable) && !empty($eventChequeDetail))) {
					
					if (!empty($admin_cheque_detail)) {
						$formValue['cheque_details'] = nl2br($admin_cheque_detail);
						$formValue['cheque_receipt'] = $eventChequeReceipt;
					} elseif (!empty($event_id) && empty($isPaymentToSiteEnable) && !empty($eventChequeDetail)) {
						$eventChequeDetail = json_decode($eventChequeDetail);
						$formValue['cheque_details'] = nl2br($eventChequeDetail->account_details);
						$formValue['cheque_receipt'] = $eventChequeDetail->receipt;
					}
				}
			}

			$options['3'] = $chequeForm;
		}

		if (count($payment_gateway) == 1 && !empty($temp_online_gateway) && $isNotAllowedOnlinePayment && empty($temp_payment_gateway_flag)) {
			$error[] = $this->translate("'NO PAYMENT METHODS AVAILABLE.");
			$this->respondWithValidationError('validation_fail', $error);
		}

		if (!empty($temp_online_gateway) && !empty($isNotAllowedOnlinePayment)) {
			$error[] = $this->translate('Your purchasable amount exceeds the Threshold Amount, Please %1$sclick here%2$s to enable online transaction option, by managing your ordered amount');
			$this->respondWithValidationError('validation_fail', $error);
		}
		if (!empty($this->totalOrderPriceFree)) {
			$multioptions = array();
			$multioptions['5'] = $this->translate('Free Order');
			$paymentMethodForm[] = array(
				'type' => (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') ? 'radio' : 'Radio',
				'name' => 'method',
				'label' => $this->translate('Payment Method'),
				'multiOptions' => $multioptions,
				'hasValidator' => 'true',
			);
		} else {
			$paymentMethodForm[] = array(
				'type' => (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') ? 'radio' : 'Radio',
				'name' => 'method',
				'label' => $this->translate('Payment Method'),
				'multiOptions' => $multioptions,
				'hasValidator' => 'true',
			);
		}

		$isPlaceOrderActivityEnabled = Engine_Api::_()->getDbTable('actionTypes', 'activity')->getActionType("siteeventticket_order_place");

		if (!empty($isPlaceOrderActivityEnabled) && !empty($isPlaceOrderActivityEnabled->enabled)) {
			$paymentMethodForm[] = array(
				'type' => 'Checkbox',
				'name' => 'isPrivateOrder',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Make my purchase private.'),
				'value' => 1,
			);
		}

		if (isset($paymentMethodForm) && !empty($paymentMethodForm)) {
			if (_CLIENT_TYPE == 'ios' && _IOS_VERSION >= '1.5.8') {
				$paymentMethodForm[] = array(
					'type' => 'Submit',
					'name' => 'continue',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Continue'),
				);
				$response['form'] = $paymentMethodForm;
			} else {
				$response['paymentForm'] = $paymentMethodForm;
			}

		}

		if (isset($multioptions['3']))
			$response['options'] = $options;

		if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
			if (isset($multioptions['15']))
				$response['options'] = $options;

			if (isset($multioptions['4']))
				$response['options'] = $options;

			if (isset($formValue) && !empty($formValue))
				$response['formValues'] = $formValue;
		}

		$this->respondWithSuccess($response, true);
	}

	public function placeOrderAction() {
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
		$event_id = $this->_getParam('event_id', null);
		$payment_info = $_REQUEST;
		$buyer_info = $_REQUEST['buyer_info'];
		$coupon_info = stripslashes($_REQUEST['coupon_info']);
		$payment_information = array();
		$directPayment = 0;

		if ($payment_info['method'] == 3) {
			if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
				if (!isset($payment_info['cheque_receipt']))
					$this->respondWithValidationError('parameter_missing', 'cheque_receipt');
				$cheque_receipt = $payment_info['cheque_receipt'];
				if ($cheque_receipt && empty($_FILES['photo']))
					$this->respondWithError('unauthorized', 'Please upload the transaction receipt.');
			}
			if (empty($payment_info['cheque_no']))
				$this->respondWithError('unauthorized', 'Enter Cheque No');
			if (empty($payment_info['signature']))
				$this->respondWithError('unauthorized', 'Enter Account Holder Name');
			if (empty($payment_info['account_no']))
				$this->respondWithError('unauthorized', 'Enter Account Number');
			if (empty($payment_info['routing_no']))
				$this->respondWithError('unauthorized', 'Enter Bank Routing Number');
		} elseif ((_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') && $payment_info['method'] == 15) {
			if (!isset($payment_info['bank_receipt']))
				$this->respondWithValidationError('parameter_missing', 'bank_receipt');
			$bank_receipt = $payment_info['bank_receipt'];
			if ($bank_receipt && empty($_FILES['photo']))
				$this->respondWithError('unauthorized', 'Please upload the transaction receipt.');
		} elseif ((_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') && $payment_info['method'] == 4) {
			if (!isset($payment_info['cod_receipt']))
				$this->respondWithValidationError('parameter_missing', 'cod_receipt');
			$cod_receipt = $payment_info['cod_receipt'];
			if ($cod_receipt && empty($_FILES['photo']))
				$this->respondWithError('unauthorized', 'Please upload the transaction receipt.');
		}

		// Check if direct payment
		$isPaymentToSiteEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.payment.to.siteadmin', 0);
		if (empty($isPaymentToSiteEnable)) {
			$directPayment = 1;
		}

		if (($payment_info['method'] != 3)) {
			$payment_information['method'] = $payment_info['method'];
		} else {
			$payment_information['method'] = $payment_info['method'];
			$payment_information['cheque_no'] = $payment_info['cheque_no'];
			$payment_information['signature'] = $payment_info['signature'];
			$payment_information['account_no'] = $payment_info['account_no'];
			$payment_information['routing_no'] = $payment_info['routing_no'];
		}
		$checkout_process['payment_information'] = $payment_information;

		$setOrderTicketInfo = Engine_Api::_()->siteeventticket()->setOrderTicketInfo();
		$order_table = Engine_Api::_()->getDbtable('orders', 'siteeventticket');
		$order_ticket_table = Engine_Api::_()->getDbtable('orderTickets', 'siteeventticket');

		// PROCESS
		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();

		// GET IP ADDRESS
		$ipObj = new Engine_IP();
		$ipExpr = new Zend_Db_Expr($db->quoteInto('UNHEX(?)', bin2hex($ipObj->toBinary())));

		try {
			// PAYMENT VIA BY CHEQUE
			if ($checkout_process['payment_information']['method'] == 3) {
				Engine_Api::_()->getDbtable('ordercheques', 'siteeventticket')->insert(array(
					'cheque_no' => $checkout_process['payment_information']['cheque_no'],
					'customer_signature' => $checkout_process['payment_information']['signature'],
					'account_number' => $checkout_process['payment_information']['account_no'],
					'bank_routing_number' => $checkout_process['payment_information']['routing_no'],
				));

				$cheque_id = Engine_Api::_()->getDbtable('ordercheques', 'siteeventticket')->getAdapter()->lastInsertId();
			}

			//check if value of grandtotal is 0
			if (isset($_REQUEST['order_info'])) {
				$values = Zend_Json_Decoder::decode(stripslashes($_REQUEST['order_info']));
			} else {
				$this->respondWithError('unauthorized');
			}
			if (isset($values['date_filter_occurrence']) && $values['date_filter_occurrence']) {
				$checkoutOccurrenceId = $selected_occurrence_id = $values['date_filter_occurrence'];
			} else {
				$checkoutOccurrenceId = $selected_occurrence_id = Engine_Api::_()->getDbTable('occurrences', 'siteevent')->getOccurrence();
			}

			if (empty($setOrderTicketInfo)) {
				$this->respondWithError('unauthorized');
			}

			$occurrenceObj = Engine_Api::_()->getItem('siteevent_occurrence', $selected_occurrence_id);
			try {
				//SAVE ORDER TICKETS DETAILS IN TICKET TABLE.
				$table = Engine_Api::_()->getDbtable('orders', 'siteeventticket');
				$order = $table->createRow();

				$order->user_id = $viewer_id;
				$order->event_id = $event_id;
				$order->occurrence_id = $selected_occurrence_id; //current occurrence_id selected
				$order->order_status = 1;
				$order->occurrence_starttime = $occurrenceObj->starttime;
				$order->occurrence_endtime = $occurrenceObj->endtime;

				//status
				if ($checkout_process['payment_information']['method'] == 3) {
					$order_status = 0; // APPROVAL PENDING
					$payment_status = 'initial';
				} else if ($checkout_process['payment_information']['method'] == 5) {
					$order_status = 2; // PROCESSING
					$payment_status = 'active';
				} else {
					$order_status = 1; // PAYMENT PENDING
					$payment_status = 'initial';
				}
				//status
				$order->order_status = $order_status;
				$order->payment_status = $payment_status;
				$order->creation_date = date('Y-m-d H:i:s');

				$order->gateway_id = $checkout_process['payment_information']['method'];
				$order->ip_address = $ipExpr;
				$order->direct_payment = $directPayment;
				if ($checkout_process['payment_information']['method'] == 3) {
					$order->cheque_id = $cheque_id;
				}

				$order->save();

				if (_IOS_VERSION >= '3.2.2' || _ANDROID_VERSION >= '4.3.0') {
					if(isset($_FILES['photo']) && !empty($_FILES['photo'])) {
					    $order->setPhoto($_FILES['photo']);
			        }
			    }
			} catch (Exception $e) {

			}
			try {
				$orderTicketTable = Engine_Api::_()->getDbtable('orderTickets', 'siteeventticket');

				$ticket_qty = 0;
				$subtotal = 0;

				foreach ($values['ticket_column'] as $key => $row) {
					$ticket_id = $key;
					//IF - row[1] QUANTITY IS SELECTED & GREATER THAN ZERO
					if (isset($row[1]) && $row[1] > 0) {
						$ticketObj = Engine_Api::_()->getItem('siteeventticket_ticket', $ticket_id);
						$ticketDetailArray = $occurrenceObj->ticket_id_sold;
						$ticket_sold = $ticketDetailArray['tid_' . $ticket_id];
						$quantity = $row[1];
						$discountedPrice = $price = $row[0];
						if (isset($row['coupon_id']) && !empty($row['coupon_id'])) {
							$couponObj = Engine_Api::_()->getItem('siteeventticket_coupon', $row['coupon_id']);
							if (!empty($couponObj)) {
								if (!empty($couponObj->discount_type)) {
									$discountedPrice = $price;
								} else {
									$discountedPrice = $price - (($price * $couponObj->discount_amount) / 100);
								}
							}
						}
						$remainingTickets = $ticketObj->quantity - $ticket_sold;
						if ($quantity > $remainingTickets) {
//                            $checkout_place_order_error = '<div style="color:red">' . Zend_Registry::get('Zend_Translate')->_('Sorry, The tickets you have selected are not available. Please go back and make your selection again according to the availability.') . '</div>';
							$this->respondWithError('unauthorized');
						}

						//SAVE DETAILS IN ORDER TICKETS TABLE
						$orderRow = $orderTicketTable->createRow();
						$orderRow->order_id = $order->order_id;
						$orderRow->ticket_id = $ticket_id;
						$orderRow->title = $ticketObj->title; //current occurrence_id selected
						$orderRow->price = $price;
						$orderRow->quantity = $quantity;
						$orderRow->discounted_price = $discountedPrice;
						$orderRow->save();

						$ticket_qty = $ticket_qty + $quantity;
						$subtotal = $subtotal + ($discountedPrice * $quantity);
					}
				}

				//VALUE OF GRAND TOTAL & ITEM COUNT
				$order->tax_amount = $total_tax = isset($values['tax']) ? @round($values['tax'], 2) : 0;
                                
				if(isset($values['grandTotal']))
                                $grandtotal = $values['grandTotal'] + $total_tax;
                                else{
                                  $grandtotal = $subtotal + $total_tax;
                                }
				$order->ticket_qty = $ticket_qty;
				$order->sub_total = @round($subtotal, 2);
				$order->grand_total = @round($grandtotal, 2);
				if (!empty($coupon_info)) {
					$order->coupon_detail = $coupon_info;
				}

				$order->is_private_order = $_POST['isPrivateOrder'];
				//COMMISSION WORK
				$commission = Engine_Api::_()->siteeventticket()->getOrderCommission($event_id);
				$commission_type = $commission[0];
				$commission_rate = $commission[1];

				// IF COMMISSION VALUE IS FIX.
				if ($commission_type == 0):
					$commission_value = $commission_rate;
				else:
					$commission_value = (@round($subtotal, 2) * $commission_rate) / 100;
				endif;
				$order->commission_type = $commission_type;
				$order->commission_value = $commission_value;
				$order->commission_rate = $commission_rate;

				if (Engine_Api::_()->hasModuleBootstrap('sitegateway') && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegateway.stripeconnect', 0)) {
					$stripeGatewayId = Engine_Api::_()->sitegateway()->getGatewayColumn(array('plugin' => 'Sitegateway_Plugin_Gateway_Stripe', 'columnName' => 'gateway_id'));
					if ($stripeGatewayId == $order->gateway_id) {
						$order->payment_split = 1;
					}
				}

				//END - COMMISSION WORK
				$order->save();
			} catch (Exception $e) {

			}
			// COMMIT
			$db->commit();
		} catch (Exception $e) {
			$db->rollBack();
			$this->respondWithError('internal_server_error', $e->getMessage());
		}
		$order_id = Engine_Api::_()->siteeventticket()->getDecodeToEncode($order->order_id);
		// Add schedule in calendar
		if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('calendar')){
			Engine_Api::_()->getDbtable('schedules', 'calendar')->setEventSchedules($order);
		}
		$gateway_id = $checkout_process['payment_information']['method'];
		$this->setRequestMethod();
		if ($gateway_id == 3 || $gateway_id == 4 || $gateway_id == 5 || $gateway_id == 15) {
			$this->_forward('success', 'order', 'siteeventticket', array(
				'event_id' => $event_id,
				'success_id' => $order_id,
				'buyer_info' => $buyer_info,
			));
		} else {
			$getHost = Engine_Api::_()->getApi('core', 'siteapi')->getHost();
			$baseUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
			$baseUrl = @trim($baseUrl, "/");
			if (!empty($baseUrl)) {
				$baseUrl = $baseUrl . '/';
			}
			$getOauthToken = Engine_Api::_()->getApi('oauth', 'siteapi')->getAccessOauthToken($viewer);
			$slug_plural = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.slugplural', 'event-items');
			$url = $getHost . '/' . $baseUrl . $slug_plural . '/order/payment/' . $event_id . '?order_id=' . $order_id . '&gateway_id=' . $gateway_id . '&occurrence_id=' . $selected_occurrence_id . '&token=' . $getOauthToken['token'] . '&disableHeaderAndFooter=1';
			$response['order_id'] = $order_id;
			$response['method'] = 'online';
			$response['webviewUrl'] = $url;
			$this->respondWithSuccess($response, false);
		}
	}

	public function paymentAction() {
		$gateway_id = $this->_getParam('gateway_id');
		$event_id = $this->_getParam('event_id', null);
		$occurrence_id = $this->_getParam('occurrence_id', null);

		//PAYMENT FLOW CHECK
		$paymentToSiteadmin = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.payment.to.siteadmin', 0);

		if (empty($paymentToSiteadmin)) {
			if (Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
				$validGatewayId = Engine_Api::_()->sitegateway()->getGatewayColumn(array('pluginLike' => 'Sitegateway_Plugin_Gateway_', 'columnName' => 'gateway_id', 'gateway_id' => $gateway_id));
				if (empty($event_id) || ($gateway_id != 2 && !$validGatewayId)) {
					$this->respondWithError('unauthorized');
				}
			} else {
				if (empty($event_id) || ($gateway_id != 2)) {
					$this->respondWithError('unauthorized');
				}
			}
		}

		$order_id = (int) Engine_Api::_()->siteeventticket()->getEncodeToDecode($this->_getParam('order_id'));
		if (empty($gateway_id) || empty($order_id)) {
			$this->respondWithError('unauthorized');
		}

		$params['Payment_Siteeventticket']['user_order_id'] = $order_id;

		if (empty($paymentToSiteadmin)) {
			$params['Payment_Siteeventticket']['checkout_event_id'] = $event_id;
			$params['Payment_Siteeventticket']['checkout_occurrence_id'] = $occurrence_id;
		}

		// IF PAYMENT GATEWAY IS 2CHECKOUT
		if ($gateway_id == 1) {
			$order = Engine_Api::_()->getItem('siteeventticket_order', $order_id);
			$gateway = Engine_Api::_()->getItem('siteeventticket_usergateway', 1);
			// Get gateway plugin
			$gatewayPlugin = $gateway->getGateway();
			$gatewayPlugin->createProduct($order->getGatewayParams());
		}

		$this->setRequestMethod();
		$this->_forward('process', 'payment', 'siteeventticket', array(
			'user_order_id' => $order_id,
			'checkout_event_id' => $params['Payment_Siteeventticket']['checkout_event_id'],
			'checkout_occurrence_id' => $params['Payment_Siteeventticket']['checkout_occurrence_id'],
		));
	}

	public function successAction() {
		$viewer_id = $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
		$values['buyer_detail'] = Zend_Json_Decoder::decode(stripslashes($this->_getParam('buyer_info')));
		Engine_Api::_()->getApi('Core', 'siteapi')->setView();

		if ($this->_getParam('success_id')) {
			$order_id = (int) Engine_Api::_()->siteeventticket()->getEncodeToDecode($this->_getParam('success_id'));
		} else {
			$this->respondWithError('unauthorized');
		}

		$order_obj = Engine_Api::_()->getItem('siteeventticket_order', $order_id);
		$siteevent = Engine_Api::_()->getItem('siteevent_event', $order_obj->event_id);
		if (empty($order_id) || empty($order_obj)) {
			$this->respondWithError('unauthorized');
		}
		$orderTicketTable = Engine_Api::_()->getDbtable('orderTickets', 'siteeventticket');
		$order_table = Engine_Api::_()->getDbtable('orders', 'siteeventticket');

		// IF PAYMENT IS SUCCESSFULLY DONE FOR THE ORDER
		if (($order_obj->payment_status == 'active' || $order_obj->gateway_id == 3 || $order_obj->gateway_id == 4) && empty($error)) {

			//UPDATE SOLD COUNT OF CORRESPONDING TICKETS ID IN EVENT_OCCURRENCES TABLE.
			Engine_Api::_()->siteeventticket()->updateTicketsSoldQuantity(array('occurrence_id' => $order_obj->occurrence_id));

			// CHANGE EACH ORDER STATUS
			if ($order_obj->gateway_id != 3 && $order_obj->gateway_id != 4) {
				$order_table->update(array('order_status' => 2), array('order_id = ?' => $order_id));
			}
		}

		$order_table->update(array('payment_status' => $order_obj->payment_status), array('order_id = ?' => $order_id));

		// PROCESS
		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		$buyerDetails = !empty($values['buyer_detail']) ? $values['buyer_detail'] : array();
		try {
			//SAVE ORDER TICKETS DETAILS IN TICKET TABLE.
			$buyerDetail_table = Engine_Api::_()->getDbtable('buyerdetails', 'siteeventticket');
			foreach ($buyerDetails as $key => $buyers) {
				$ticket_id = $key;
				foreach ($buyers as $buyer) {
					$buyerDetail = $buyerDetail_table->createRow();
					$buyerDetail->ticket_id = $ticket_id;
					$buyerDetail->order_id = $order_id;
					if (isset($values) && isset($values['buyer_detail']) && !empty($values['buyer_detail'])) {
						if (isset($buyer['fname'])) {
							$buyerDetail->first_name = $buyer['fname'];
						}
						if (isset($buyer['lname'])) {
							$buyerDetail->last_name = $buyer['lname'];
						}
						if (isset($buyer['email'])) {
							$buyerDetail->email = $buyer['email'];
						}
					}
					//SAVE A RANDOM ALPHANUMERIC NO. AS BUYER TICKET ID
					$buyerDetail->buyer_ticket_id = Engine_Api::_()->siteeventticket()->buyerTicketIdGenerate();
					$buyerDetail->save();
				}
			}
			// Commit
			$db->commit();
		} catch (Exception $e) {
			$db->rollBack();
		}

		//END - BUYER DETAIL SAVE WORK
		//THRESHOLD AMOUNT EMAIL NOTIFICATION
		if (Engine_Api::_()->siteeventticket()->isAllowThresholdNotifications(array('event_id' => $order_obj->event_id))) {

			$notificationType = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.thresholdnotify');
			$admin_email_id = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.mail.contact', null);
			$newVar = (_ENGINE_SSL ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'];
			$event_title_with_link = '<a href="' . $newVar . $siteevent->getHref() . '">' . $siteevent->getTitle() . '</a>';
			$dashboard_commission_bills = '<a href="' . $newVar . $this->view->url(array('action' => 'your-bill', 'event_id' => $siteevent->event_id), 'siteeventticket_order', true) . '">' . $this->view->translate('Click here') . '</a>';

			$optionsArray = array(
				'event_title' => $siteevent->getTitle(),
				'event_title_with_link' => $event_title_with_link,
				'dashboard_commission_bills' => $dashboard_commission_bills,
			);

			if (in_array('admin', $notificationType) && $admin_email_id) {
				Engine_Api::_()->getApi('mail', 'core')->sendSystem($admin_email_id, 'SITEEVENTTICKET_THRESHOLD_COMMISSION_ADMIN', $optionsArray);
			}

			if (in_array('owner', $notificationType) && !empty($siteevent->getOwner()->email)) {
				Engine_Api::_()->getApi('mail', 'core')->sendSystem($siteevent->getOwner()->email, 'SITEEVENTTICKET_THRESHOLD_COMMISSION_OWNER', $optionsArray);
			}
		}

		$response['order_id'] = $order_id;
		$response['method'] = 'cheque';
		$this->respondWithSuccess($response, true);
	}

	public function _getTicketOrderStatus($order_status) {
		switch ($order_status) {
		case 0:
			$current_status = $this->translate('Approval Pending');
			break;
		case 1:
			$current_status = $this->translate('Payment Pending');
			break;
		case 2:
			$current_status = $this->translate('Completed');
			break;
		default:
			$current_status = $this->translate('No Order Status Found');
		}
		return $current_status;
	}

}
