<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitefbclone
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Pagelayouts.php 2015-06-04 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

# Load the libraries. Do it manually if you don't like this way.
include APPLICATION_PATH . '/application/libraries/Scaffold/libraries/Bootstrap.php';

class Sitefbclone_Form_Admin_Themes_EditColors extends Engine_Form
{

	protected $_theme;
	protected $_updateMethod;

	public function setTheme($theme)
	{
		$this->_theme = $theme;
	}
	public function setUpdateMethod($method)
	{
		$this->_updateMethod = $method;
	}

	public function init()
	{
		$this
		->setTitle('Update Color Scheme')
		->setDescription('Here you can manage color scheme for your website.');
		// Show layout to only logged in users
		$this->addElement('Select', 'sitefbclone_update_method', array(
			'label' => 'Color Updation Method',
			'description' => "Select the method which you want to use to update color scheme.",
			'multiOptions' => array(
				'single' => 'Update the colors for specific elements solely',
				'group' => 'Update the colors wherever they are being used',
			),
			'value' => ($this->_updateMethod) ? $this->_updateMethod : 'single',
			'onchange' => 'spwThemeUpdateMethod(this.value)'
		));
		
		$this->addElement('Dummy', 'sitefbclone_header_constants_label', array(
			'label' => 'Heading Color',
		));
		
		$this->addElement('Dummy', 'sitefbclone_body_constants_label', array(
			'label' => 'Body Colors',
		));
		//ADD HERE THE LEBEL REPLACEMENT FOR THE CONSTANTS
		$constantLebels = array('sitefbclone_body_header_color' => 'Heading Font Color',
			'sitefbclone_body_font_color_light' => 'Body Font Color Light',
			'sitefbclone_body_input_background_color' => 'Input Box Background Color',
			'sitefbclone_body_input_font_color' => 'Input Box Font Color',
			'sitefbclone_body_input_border_color' => 'Input Box Border Color',
			'sitefbclone_body_comments_background_color' => 'Comments Box Background Color',
			'sitefbclone_body_list_background_color' => 'Listview Background Color',
			'sitefbclone_body_list_background_color_alt' => 'Listview Background Color Alt',
			'sitefbclone_body_list_background_color_on_hover' => 'Listview Background Color On Hover',
			'sitefbclone_header_minimenu_items_background_color' => 'Mini Menu Items Background Color',
			'sitefbclone_header_minimenu_items_background_color_on_hover' => 'Mini Menu Items Background Color On Hover',
		);
		$colors = array();
		$headerConstants = array();
		$footerConstants = array();
		$bodyConstants = array();
		foreach( $this->getColorConstants() as $name => $value ) {
			$colors[$value] = $value;
			$constantType = explode('_', $name)[1];
			$labelString = $name;
			if($constantType == 'header') {
				$headerConstants[] = $name;
				$labelString = str_replace('sitefbclone_header_', '', $name);
			} else if($constantType == 'footer') {
				$footerConstants[] = $name;
				$labelString = str_replace('sitefbclone_footer_', '', $name);
			} else if($constantType == 'body') {
				$bodyConstants[] = $name;
				$labelString = str_replace('sitefbclone_body_', '', $name);
			}
			
			$labelString = ucwords(preg_replace('/[^a-z-0-9]/', ' ', $labelString));
			if (array_key_exists($name, $constantLebels)) {
				$labelString = $constantLebels[$name];
			}

			$this->addElement('Text', $name, array(
				'label' => ucwords(preg_replace('/[^a-z-0-9]/', ' ', $name)),
				'decorators' => array(array('ViewScript', array(
					'viewScript' => '_formColor.tpl',
					'class' => 'constant_color_single_element form element',
					'name' => $name,
					'value' => $value,
					'label' => $labelString
				)))
			));
		}
		$this->addDisplayGroup(array_merge(array('sitefbclone_header_constants_label'), $headerConstants), 'sitefbclone_header_constants');
		
		$this->addDisplayGroup(array_merge(array('sitefbclone_body_constants_label'), $bodyConstants), 'sitefbclone_body_constants');
		foreach( $colors as $name => $value ) {
			$name = 'spwgroupcolor-' . md5($name);
			$this->addElement('Text', $name, array(
				'label' => "Color: " . $value,
				'decorators' => array(array('ViewScript', array(
					'viewScript' => '_formColor.tpl',
					'class' => 'constant_color_group_element form element',
					'name' => $name,
					'value' => $value,
					'label' => "Color: " . $value,
				)))
			));
		}
		// Add submit button
		$this->addElement('Button', 'submit', array(
			'label' => 'Save Changes',
			'type' => 'submit',
			'ignore' => true
		));
	}

	public function getColorConstants()
	{
		$path = APPLICATION_PATH . '/application/themes/sitefbclone/' . $this->_theme . '/colorConstants.css';
		$elements = array();
		if( file_exists($path) ) {
			$css = new Scaffold_CSS($path);
			$css->string = '@constants {' . $css->string . '}';
			$found = $css->find_at_group('constants');

			unset($found['values']["sitefbclone_header_mini_menu_items_color_on_hover"]);
			unset($found['values']["sitefbclone_header_minimenu_items_background_color"]);
			unset($found['values']["sitefbclone_header_minimenu_items_background_color_on_hover"]);
			unset($found['values']["sitefbclone_header_theme_main_menu_links_color_on_hover"]);
			$elements = $found['values'];
		}

		return $elements;
	}

}