<?php

/**
 * SocialEngine
 *
 * @category   Application_Theme
 * @package    Sitefbclone
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menu.php 2017-12-15 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitefbclone_Model_Simage extends Core_Model_Item_Abstract {
    protected $_searchTriggers = false;



    public function setPhoto($photo) {

		if ($photo instanceof Zend_Form_Element_File) {
			$file = $photo->getFileName();
			$fileName = $file;
		} else if ($photo instanceof Storage_Model_File) {
			$file = $photo->temporary();
			$fileName = $photo->name;
		} else if ($photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id)) {
			$tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
			$file = $tmpRow->temporary();
			$fileName = $tmpRow->name;
		} else if (is_array($photo) && !empty($photo['tmp_name'])) {
			$file = $photo['tmp_name'];
			$fileName = $photo['name'];
		} else if (is_string($photo) && file_exists($photo)) {
			$file = $photo;
			$fileName = $photo;
		} else {
			throw new User_Model_Exception('invalid argument passed to setPhoto');
		}

		if (!$fileName) {
			$fileName = $file;
		}

		$name = basename($file);
		$extension = ltrim(strrchr($fileName, '.'), '.');
		$base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
		$path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
		$params = array(
			'parent_type' => $this->getType(),
			'parent_id' => $this->getIdentity(),
			'name' => $fileName,
		);
		// Add autorotation for uploded images. It will work only for SocialEngine-4.8.9 Or more then.
		$hasVersion = Engine_Api::_()->seaocore()->usingLessVersion('core', '4.8.9');
		if(!empty($hasVersion)) {
		  $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
		  $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
		  $image = Engine_Image::factory();
		  $image->open($file)
				  ->resize(1024, 720)
				  ->write($mainPath)
				  ->destroy();
		  $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
		  $image = Engine_Image::factory();
		  $image->open($file)
				  ->resize(140, 160)
				  ->write($normalPath)
				  ->destroy();
		  $normalLargePath = $path . DIRECTORY_SEPARATOR . $base . '_inl.' . $extension;
		  $image = Engine_Image::factory();
		  $image->open($file)
				  ->resize(250, 250)
				  ->write($normalLargePath)
				  ->destroy();
		}else {
		  $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
		  $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
		  $image = Engine_Image::factory();
		  $image->open($file)
				  ->autoRotate()
				  ->resize(1024, 720)
				  ->write($mainPath)
				  ->destroy();
		  $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
		  $image = Engine_Image::factory();
		  $image->open($file)
				  ->autoRotate()
				  ->resize(140, 160)
				  ->write($normalPath)
				  ->destroy();
		  $normalLargePath = $path . DIRECTORY_SEPARATOR . $base . '_inl.' . $extension;
		  $image = Engine_Image::factory();
		  $image->open($file)
				  ->autoRotate()
				  ->resize(250, 250)
				  ->write($normalLargePath)
				  ->destroy();
		}

		//RESIZE IMAGE (ICON)
		$iSquarePath = $path . DIRECTORY_SEPARATOR . $base . '_is.' . $extension;
		$image = Engine_Image::factory();
		$image->open($file);

		$size = min($image->height, $image->width);
		$x = ($image->width - $size) / 2;
		$y = ($image->height - $size) / 2;

		$image->resample($x, $y, $size, $size, 48, 48)
				->write($iSquarePath)
				->destroy();
		try {
			$iMain = $filesTable->createFile($mainPath, $params);
			$iIconNormal = $filesTable->createFile($normalPath, $params);
			$iMain->bridge($iIconNormal, 'thumb.normal');
			$iIconNormalLarge = $filesTable->createFile($normalLargePath, $params);
			$iMain->bridge($iIconNormalLarge, 'thumb.large');
			$iSquare = Engine_Api::_()->storage()->create($iSquarePath, $params);
			$iMain->bridge($iSquare, 'thumb.icon');
		} catch (Exception $e) {
			@unlink($mainPath);
			@unlink($normalPath);
			@unlink($normalLargePath);
			@unlink($iSquarePath);
			if ($e->getCode() == Storage_Model_DbTable_Files::SPACE_LIMIT_REACHED_CODE) {
				throw new Album_Model_Exception($e->getMessage(), $e->getCode());
			} else {
				throw $e;
			}
		}
		@unlink($mainPath);
		@unlink($normalPath);
		@unlink($normalLargePath);
		$this->modified_date = date('Y-m-d H:i:s');
		$this->file_id = $iMain->file_id;
		$this->save();
		if (!empty($tmpRow)) {
			$tmpRow->delete();
		}
		return $this;
	}
}
