<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegdpr
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: General.php 2018-05-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegdpr_Form_Admin_Cookies_General extends Engine_Form
{

  public function init()
  {
    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $this->setTitle("Cookies Banner Settings")
      ->setDescription('Below are the general settings for cookies banner. You can edit the banner text, privacy link and labels. Also, position of the banner can be selected here.');
    // Init name
    $this->addElement('Textarea', 'gdpr_cookies_general_bannerText', array(
      'label' => 'Cookies Banner Text',
      'description' => 'Add the text which you want to display on the cookies banner.',
      'maxlength' => '500',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '500')),
      ),
      'value' => $coreSettings->getSetting('gdpr.cookies.general.bannerText', 'This website uses cookies to ensure you get the best experience on our website.'),
    ));


    $this->addElement('Textarea', 'gdpr_cookies_general_privacyLinkText', array(
      'label' => 'Privacy Page Link Text',
      'description' => 'Add the text for privacy page link.',
      'maxlength' => '256',
      'value' => $coreSettings->getSetting('gdpr.cookies.general.privacyLinkText', 'To learn more about our privacy policy'),
    ));

    $this->addElement('Text', 'gdpr_cookies_general_privacyLink', array(
      'label' => 'URL of Privacy Page',
      'description' => 'Add the URL of the privacy page for your site.',
      'maxlength' => '256',
      'value' => $coreSettings->getSetting('gdpr.cookies.general.privacyLink', '/help/privacy'),
    ));

    $this->addElement('Text', 'gdpr_cookies_general_privacyLinkLabel', array(
      'label' => 'Privacy Page Link Label',
      'description' => 'Add the label you want to showcase for the privacy page link below.',
      'maxlength' => '256',
      'value' => $coreSettings->getSetting('gdpr.cookies.general.privacyLinkLabel', 'Click here'),
    ));

    $this->addElement('Text', 'gdpr_cookies_general_agreeLabel', array(
      'label' => 'Agree Button Label',
      'description' => 'Add the label you want to showcase for the agree button.',
      'maxlength' => '64',
      'allowEmpty' => false,
      'required' => true,
      'value' => $coreSettings->getSetting('gdpr.cookies.general.agreeLabel', 'I Agree'),
    ));

    $this->addElement('Text', 'gdpr_cookies_general_preferenceLabel', array(
      'label' => 'Privacy Preferences Button Label',
      'description' => 'Add the label you want to showcase for the privacy preferences button.',
      'maxlength' => '64',
      'allowEmpty' => false,
      'required' => true,
      'value' => $coreSettings->getSetting('gdpr.cookies.general.preferenceLabel', 'Privacy Preferences'),
    ));

    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $baseURL = $view->baseUrl();
    $footerBannerurl = $baseURL . '/application/modules/Sitegdpr/externals/images/Bottom.png';
    $leftBannerurl = $baseURL . '/application/modules/Sitegdpr/externals/images/Left.png';
    $rightBannerurl = $baseURL . '/application/modules/Sitegdpr/externals/images/Right.png';
    $topBannerurl = $baseURL . '/application/modules/Sitegdpr/externals/images/Top.png';

    $this->addElement('Radio', 'gdpr_bannerPostion', array(
      'label' => 'Cookies Banner Position',
      'description' => 'Choose the position of the cookies banner.',
      'multiOptions' => array(
        'sitegdpr_banner_footer' => 'On bottom of the page. <a title="View Screenshot" class="sitegdpr_icon_view" href="' . $footerBannerurl . '" target="_blank"></a>',
        'sitegdpr_banner_middle-left' => 'On left bottom of the page. <a title="View Screenshot" class="sitegdpr_icon_view" href="' . $leftBannerurl . '" target="_blank"></a>',
        'sitegdpr_banner_middle-right' => 'On right bottom of the page. <a title="View Screenshot" class="sitegdpr_icon_view" href="' . $rightBannerurl . '" target="_blank"></a>',
        'sitegdpr_banner_page-top' => 'On top of the page. <a title="View Screenshot" class="sitegdpr_icon_view" href="' . $topBannerurl . '" target="_blank"></a>',
      ),
      'escape' => false,
      'value' => $coreSettings->getSetting('gdpr.bannerPostion', 'sitegdpr_banner_footer'),
    ));

    $this->addElement('Button', 'submit', array(
      'label' => 'Submit',
      'type' => 'submit',
      'ignore' => true,
    ));
  }

}
