<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegdpr
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AuditLog.php 2018-05-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegdpr_Model_DbTable_AuditLogs extends Engine_Db_Table
{

  protected $_name = 'sitegdpr_audit_logs';

  public function getAuditLog($user)
  {
    $auditLogs = $this->select()->where('user_id =?', $user['user_id'])->query()->fetchAll();
    $position = 0;
    foreach( $auditLogs as $auditLog ) {
      $eventType = $auditLog['event_type'];
      $eventDate = $auditLog['event_date'];
      if( isset($auditLog['params']) ) {
        $params = $auditLog['params'];
      } else {
        $params = null;
      }
      $message = $this->checkEventType($eventType, $eventDate, $user['displayname'], $position, $params);
      $auditMessageLog[$position] = $message;
      $position++;
    }
    return $auditMessageLog;
  }

  public function checkEventType($eventType, $eventDate, $userName, $position, $params = null)
  {
    if( $params ) {
      $params = json_decode($params, TRUE);
    }
    $eventTypeArray = explode('_', $eventType);
    $eventItemType = $eventTypeArray[0];
    switch( $eventItemType ) {
      case 'Preference':
        // consentens/cookies
        $subEvents = $this->getSubEvents($eventTypeArray, $params['ids']);
        $message = $eventDate . ' ' . $userName . ' has ' . strtolower($eventTypeArray[2]) . ' ' . strtolower($eventTypeArray[1]) . ': ' . $subEvents;
        break;
      case 'Request':
        $message = $eventDate . ' ' . $userName . ' made ' . strtolower($eventTypeArray[1]) . ' request';
        break;
      case 'All':
        $message = $eventDate . ' ' . $userName . ' accepted all cookies and consents ';
        break;
    }
    return $message;
  }

  public function getSubEvents($eventTypeArray, $ids)
  {
    // eventTypeArray[1] indicate consents or cookies
    $subEventStr = '';
    switch( $eventTypeArray[1] ) {
      case 'Consents':
        $consentIds = explode(',', $ids);
        foreach( $consentIds as $consentId ) {
          $consentItem = Engine_Api::_()->getItem('sitegdpr_consent', $consentId);
          if( $consentItem ) {
            if( empty($subEventStr) ) {
              $subEventStr = $consentItem->title;
            } else {
              $subEventStr = $subEventStr . ',' . $consentItem->title;
            }
          }
        }
        break;
      case 'Cookies':
        $cookieIds = explode(',', $ids);
        foreach( $cookieIds as $cookieId ) {
          $cookieItem = Engine_Api::_()->getItem('sitegdpr_cookiesCategory', $cookieId);
          if( $cookieItem ) {
            if( empty($subEventStr) ) {
              $subEventStr = $cookieItem->title;
            } else {
              $subEventStr = $subEventStr . ',' . $cookieItem->title;
            }
          }
        }
        break;
    }
    return $subEventStr;
  }

  public function setAuditLog($eventType, $subEventType, $idParams = array())
  {
    $viewerId = Engine_Api::_()->user()->getViewer()->getIdentity();
    $db = $this->getAdapter();
    switch( $eventType ) {
      case 'Request':
        $type = $eventType . '_' . $subEventType;
        $db->beginTransaction();
        try {
          $auditLog = $this->createRow();
          $auditLog->user_id = $viewerId;
          $auditLog->event_type = $type;
          $auditLog->event_date = date('Y-m-d H:i:s');
          $auditLog->save();
          $db->commit();
        } catch( Exception $e ) {
          $db->rollBack();
          throw $e;
        }
        break;
      case 'Preference':
        // fetch enable consents from user preference table
        $userPreferenceRow = $this->getEnableConsents($subEventType, $viewerId);
        $subEventInSmall = lcfirst($subEventType);
        $savedIds = '';
        if( !empty($userPreferenceRow['consents']) ) {
          $params = json_decode($userPreferenceRow['consents'], true);
          if( isset($params['cookiesAccepted']) ) {
            $cookiesCategories = Engine_Api::_()->getDbtable('cookiesCategories', 'sitegdpr')->getCategories(array('enabled' => 1));
            $cookiesIds = array();
            foreach( $cookiesCategories as $cookie ) {
              $cookiesIds[] = $cookie->getIdentity();
            }
            $consents = Engine_Api::_()->getDbtable('consents', 'sitegdpr')->getConsents(array('enabled' => 1));
            $consentIds = array();
            foreach( $consents as $consent ) {
              $consentIds[] = $consent->getIdentity();
            }
            if( $subEventType == 'Cookies' ) {
              $savedIds = $cookiesIds;
            } elseif( $subEventType == 'Consents' ) {
              $savedIds = $consentIds;
            }
          } elseif( isset($params[$subEventInSmall]) ) {
            $savedIds = explode(',', $params[$subEventInSmall]);
          }
        }

        $rows = $this->comparingExistingEvent($subEventType, $idParams, $savedIds);
        if( $rows == 1 ) {
          break;
        }
        if( !empty($rows) ) {
          foreach( $rows as $row ) {
            $db->beginTransaction();
            try {
              $auditLog = $this->createRow();
              $auditLog->user_id = $viewerId;
              $auditLog->params = json_encode($row['params']);
              $auditLog->event_type = $row['event_type'];
              $auditLog->event_date = date('Y-m-d H:i:s');
              $auditLog->save();
              $db->commit();
            } catch( Exception $e ) {
              $db->rollBack();
              throw $e;
            }
          }
        } else {
          $params = array();
          $params['ids'] = implode(',', $idParams);
          if( $params['ids'] == '' ) {
            return;
          }
//          $params['activeIds'] = implode(',', $idParams);
          $db->beginTransaction();
          try {
            $auditLog = $this->createRow();
            $auditLog->user_id = $viewerId;
            $auditLog->params = json_encode($params);
            $auditLog->event_type = 'Preference_' . $subEventType . '_Enabled';
            $auditLog->event_date = date('Y-m-d H:i:s');
            $auditLog->save();
            $db->commit();
          } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
          }
        }
        break;
      case 'All':
        $db->beginTransaction();
        try {
          $auditLog = $this->createRow();
          $auditLog->user_id = $viewerId;
          $auditLog->event_type = 'All_' . $subEventType;
          $auditLog->event_date = date('Y-m-d H:i:s');
          $auditLog->save();
          $db->commit();
        } catch( Exception $e ) {
          $db->rollBack();
          throw $e;
        }
        break;
    }
  }

  public function comparingExistingEvent($subEventType, $idParams, $savedIds)
  {
    if( empty($savedIds) ) {
      return false;
    }
    $existingIds = array_values($savedIds);
    $newAddedIds = array_values($idParams);
    $commonIds = array_intersect($newAddedIds, $existingIds);
    $enableIds = array_diff($newAddedIds, $commonIds);
    $disableIds = array_diff($existingIds, $commonIds);
    $data = array();
    $params = array();

    if( empty($disableIds) && empty($enableIds) ) {
      return 1;
    }

    if( isset($disableIds) ) {
      $disableIdsValue = array_values($disableIds);
    }

    if( isset($enableIdsIds) ) {
      $enableIdsValue = array_values($enableIds);
    }

    if( !empty($disableIds) && isset($disableIds) && !empty($disableIdsValue[0]) ) {
      $params['ids'] = implode(',', $disableIds);
      $data[0] = array('event_type' => 'Preference_' . $subEventType . '_' . 'disabled', 'params' => $params);
    }

    if( !empty($enableIds) && isset($enableIds) && !empty($enableIdsValue[0]) ) {
//      $params['activeIds'] = implode(',', $newAddedIds);
      $params['ids'] = implode(',', $enableIds);
      $data[1] = array('event_type' => 'Preference_' . $subEventType . '_' . 'enabled', 'params' => $params);
    }
    return $data;
  }

  public function getEnableConsents($subEventType, $viewerId)
  {
    $preferenceTable = Engine_Api::_()->getDbtable('userPreferences', 'sitegdpr');
    $select = $preferenceTable->select();
    $select
      ->where('user_id =?', $viewerId)
      ->limit(1);
    $result = $select->query()->fetch();
    return $result;
  }

}
