<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegdpr
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminConsentController.php 2018-05-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitegdpr_AdminConsentController extends Core_Controller_Action_Admin
{

  public function indexAction()
  {
    // Make navigation
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_consent');


    $this->view->categories = Engine_Api::_()->getDbtable('consents', 'sitegdpr')->getConsents();
  }

  public function addCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');

    // Generate and assign form
    $form = $this->view->form = new Sitegdpr_Form_Admin_Consent_Category();
    $form->setAction($this->view->url(array()));

    // Check post
    if( !$this->getRequest()->isPost() ) {
      $this->renderScript('admin-consent/form.tpl');
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      $this->renderScript('admin-consent/form.tpl');
      return;
    }

    // Process
    $values = $form->getValues();

    $table = Engine_Api::_()->getDbtable('consents', 'sitegdpr');
    $db = $table->getAdapter();
    $db->beginTransaction();
    // Update row
    try {
      if( !empty($values['show_on_pages']) ) {
        $values['show_on_pages'] = implode(',', $values['show_on_pages']);
      }

      $category = $table->createRow();
      $category->setFromArray($values);
      $category->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('')
    ));
  }

  public function enableCategoryAction()
  {
    $id = $this->_getParam('id');
    $enable = $this->_getParam('enable');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();
    try {
      $categoryTable = Engine_Api::_()->getItem('sitegdpr_consent', $id);
      $categoryTable->enabled = $enable;
      $categoryTable->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    $this->_redirect('admin/sitegdpr/consent');
  }

  public function deleteCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $categoryId = $this->_getParam('id');
    $this->view->category_id = $categoryId;
    $categoriesTable = Engine_Api::_()->getDbtable('consents', 'sitegdpr');
    $category = $categoriesTable->find($categoryId)->current();

    $categoryId = $category->getIdentity();

    if( !$categoryId ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_("Entry doesn't exist or not authorized to delete");
      return;
    }

    $this->view->form = $form = new Sitegdpr_Form_Admin_Consent_Delete();

    if( !$this->getRequest()->isPost() ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
      return;
    }
    // Process
    $db = $categoriesTable->getAdapter();
    $db->beginTransaction();

    try {

      $category->delete();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->view->status = true;
    $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your entry has been deleted.');
    return $this->_forward('success', 'utility', 'core', array(
        'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'sitegdpr', 'controller' => 'consent'), "admin_default", true),
        'messages' => Array($this->view->message)
    ));
  }

  public function editCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $categoryId = $this->_getParam('id');
    $categoryTable = Engine_Api::_()->getDbtable('consents', 'sitegdpr');
    $categoryRow = $categoryTable->find($categoryId)->current();

    if( !$categoryRow ) {
      return $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('')
      ));
    } else {
      $categoryId = $categoryRow->getIdentity();
    }

    $form = $this->view->form = new Sitegdpr_Form_Admin_Consent_Category();
    $form->setAction($this->getFrontController()->getRouter()->assemble(array()));
    $form->populate($categoryRow->toArray());
    $form->show_on_pages->setValue(explode(',', $categoryRow->show_on_pages));
    
    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-consent/form.tpl');
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      // Output
      $this->renderScript('admin-consent/form.tpl');
      return;
    }

    // Process
    $values = $form->getValues();
    $viewer = Engine_Api::_()->user()->getViewer();
    $db = $categoryTable->getAdapter();
    $db->beginTransaction();

    try {
      if( !empty($values['show_on_pages']) ) {
        $values['show_on_pages'] = implode(',', $values['show_on_pages']);
      }

      $categoryRow->setFromArray($values);
      $categoryRow->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('')
    ));
  }


}
