<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegdpr
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminUserConsentsController.php 2018-05-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegdpr_AdminGeneralController extends Core_Controller_Action_Admin
{

  public function samplePolicyAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_samplepolicy');
  }

  public function userConsentsAction()
  {
    // Make navigation
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_userconsents');

    $this->view->userPreferences = Engine_Api::_()->getDbtable('userPreferences', 'sitegdpr')->fetchAll();
  }

  public function userRequestAction()
  {
    // Make navigation
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_userrequest');

    $type = $this->_getParam('type', '1');

    switch( $type ) {
      case '2':
        $formType = 'UNSUBSCRIBE';
        $activeMenu = 'gdpr_admin_settings_unsubscriberequest';
        $pageTitle = 'Unsubscription Requests';
        $pageDesc = 'Below are the requests send by the users in order to unsubscribe our promotional emails / Newsletters.';
        break;
      case '3':
        $formType = 'DELETE';
        $activeMenu = 'gdpr_admin_settings_deleterequest';
        $pageTitle = 'Data Abolish Requests';
        $pageDesc = 'Below is the list of the users who have applied to abolish all their data accessed till now.';
        break;
      case '4':
        $formType = 'ARCHIVE';
        $activeMenu = 'gdpr_admin_settings_archiverequest';
        $pageTitle = 'Applications for Records';
        $pageDesc = 'Below is the list of the applications send by the users to get the complete record of all their personal data accessed till now.';
        break;
      default:
        $formType = 'DPO';
        $activeMenu = 'gdpr_admin_settings_dporequest';
        $pageTitle = 'Contact Requests';
        $pageDesc = 'All the requests generated by the users for contacting Data Protection Officer are listed below:';
    }

    $this->view->pageTitle = $pageTitle;
    $this->view->pageDesc = $pageDesc;

    $this->view->subnavigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_settings_userrequest', array(), $activeMenu);
    $this->view->requests = Engine_Api::_()->getDbtable('requests', 'sitegdpr')->getUsersRequest($formType);
  }

  public function faqAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_faq');

    $this->view->faq_id = $faq_id = $this->_getParam('faq', 'faq_1');
  }

  public function privacyCenterAction()
  {
    // Make navigation
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_privacyCenter');

    $table = Engine_Api::_()->getDbtable('privacyCenterComponents', 'sitegdpr');
    $select = $table->select()
      ->order('order ASC');

    $this->view->privacyCenterComponents = $privacyCenterComponets = $table->fetchAll($select);
  }

  public function editPrivacyComponentAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $componentId = $this->_getParam('id');
    $componentTable = Engine_Api::_()->getDbtable('privacyCenterComponents', 'sitegdpr');
    $componentRow = $componentTable->find($componentId)->current();

    if( !$componentRow ) {
      return $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('')
      ));
    } else {
      $componentRowId = $componentRow->getIdentity();
    }

    $form = $this->view->form = new Sitegdpr_Form_Admin_General_EditPrivacyComponents();
    $form->setAction($this->getFrontController()->getRouter()->assemble(array()));
    $form->populate($componentRow->toArray());

    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-general/form.tpl');
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      // Output
      $this->renderScript('admin-general/form.tpl');
      return;
    }

    // Process
    $values = $form->getValues();
    $viewer = Engine_Api::_()->user()->getViewer();
    $db = $componentTable->getAdapter();
    $db->beginTransaction();

    try {
      $componentRow->name = $values['name'];
      $componentRow->description = $values['description'];
      $componentRow->icon_class = $values['icon_class'];
      $componentRow->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('')
    ));
  }

  public function enablePrivacyComponentAction()
  {
    $id = $this->_getParam('id');
    $enable = $this->_getParam('enable');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();
    try {
      $componentItem = Engine_Api::_()->getItem('sitegdpr_privacyCenterComponent', $id);
      $componentItem->enabled = $enable;
      $componentItem->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    $this->_redirect('admin/sitegdpr/general/privacy-center');
  }

  public function setOrderAction()
  {
    if( !empty($_POST) ) {
      foreach( $_POST as $key => $value ) {
        if( strstr($key, "content_") ) {
          $keyArray = explode("content_", $key);

          if( !empty($keyArray) )
            $componentId = end($keyArray);
          if( !empty($componentId) ) {
            $obj = Engine_Api::_()->getItem('sitegdpr_privacyCenterComponent', $componentId);
            $obj->order = $value;
            $obj->save();
          }
        }
      }
    }
  }

  public function manageCookiesAction()
  {
    // Make navigation
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_managecookies');
    $this->view->cookies = Engine_Api::_()->getDbtable('cookiesLogs', 'sitegdpr')->fetchAll();
  }

  public function userAuditAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('gdpr_admin_main', array(), 'gdpr_admin_settings_useraudit');

    $form = $this->view->form = new Sitegdpr_Form_Admin_Search();

    // Check post
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Process
    $values = $form->getValues();
    if( !empty($values['email']) ) {
      $userTable = Engine_Api::_()->getDbtable('users', 'user');
      $user = $userTable->select()->where('email =?', $values['email'])->query()->fetch();
      if( !empty($user) && isset($user) ) {
        $this->view->user = $user;
        $this->view->auditLogs = $auditLogs = Engine_Api::_()->getDbtable('auditLogs', 'sitegdpr')->getAuditLog($user);
      } else {
        return;
      }
    } else {
      return;
    }
  }

}
