<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegifplayer
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2017-05-15 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegifplayer_Plugin_Core extends Zend_Controller_Plugin_Abstract
{
  public function onRenderNestedcommentFeeds($event)
  {
    $this->loadOnRender($event, 'feed');
  }

  public function onRenderNestedcomment($event)
  {
    $this->loadOnRender($event, 'comment');
  }

  private function loadOnRender($event, $type)
  {
    $view = $event->getPayload();
    $viewer = $view->viewer();
    if( !$viewer || !$viewer->getIdentity() || !Engine_Api::_()->hasModuleBootstrap('nestedcomment') ) {
      return;
    }
    if( !Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitegifplayer', 'allow_gifcomment') ) {
      return;
    }

    $view->headTranslate(array(
      'Attach a Gif',
    ));
    if( $type == 'comment' ) {
      $view->headScript()->appendFile($view->layout()->staticBaseUrl . 'application/modules/Sitegifplayer/externals/scripts/composer_nested_comment_gif.js');
      $view->headScript()->appendFile($view->layout()->staticBaseUrl . 'application/modules/Sitegifplayer/externals/scripts/core.js');
     $view->headScript()->appendFile($view->layout()->staticBaseUrl . 'application/modules/Sitegifplayer/externals/scripts/gifmooscroll/GIFMooVerticalScroll.js');
    } else {
      $view->headScript()->appendFile($view->layout()->staticBaseUrl . 'application/modules/Sitegifplayer/externals/scripts/composer_nested_comment_activity_gif.js');
      $view->headScript()->appendFile($view->layout()->staticBaseUrl . 'application/modules/Sitegifplayer/externals/scripts/core.js');
      $view->headScript()->appendFile($view->layout()->staticBaseUrl . 'application/modules/Sitegifplayer/externals/scripts/gifmooscroll/GIFMooVerticalScroll.js');
    }
  }

  public function onStorageFileCreateAfter($event)
  {
    $file = $event->getPayload();
    if( !( $file instanceof Core_Model_Item_Abstract && $file->storage_path && strtolower($file->mime_minor) === 'gif' ) ) {
      return;
    }
    $this->createFile($file);
  }

  public function onStorageFileUpdateAfter($event)
  {
    $file = $event->getPayload();
    if( !( $file instanceof Core_Model_Item_Abstract && $file->storage_path && strtolower($file->mime_minor) === 'gif' ) ) {
      return;
    }

    if( in_array('parent_file_id', $file->getModifiedFieldsName()) ) {
      $type = 'thumb.gif-' . substr(md5(substr($file->storage_path, -46)), 0, 6);
      $thumbFile = Engine_Api::_()->getItemTable('storage_file')->getFile($file->file_id, $type);
      if( $thumbFile->file_id && $thumbFile->parent_file_id == $file->file_id ) {
        try {
          $thumbFile->parent_file_id = $file->parent_file_id;
          $thumbFile->save();
        } catch( Exception $e ) {
          
        }
        return;
      }
    }
    if( !in_array('storage_path', $file->getModifiedFieldsName()) || strpos('thumb.gif-', $file->type) === 0 ) {
      return;
    }

    $this->createFile($file);
  }

  private function createFile($file)
  {
    $feedPath = '';
    try {
      $tmpRow = $file;
      $tempFile = Zend_Registry::isRegistered('FILE_' . $tmpRow->hash) ? Zend_Registry::get('FILE_' . $tmpRow->hash) : $tmpRow->temporary();
      $fileName = $tmpRow->name;

      if( !$fileName ) {
        $fileName = $tempFile;
      }
      $extension = 'jpeg';
      $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
      $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
      $type = 'thumb.gif-' . substr(md5(substr($file->storage_path, -46)), 0, 6);
      $params = array(
        'parent_type' => $file->parent_type,
        'parent_id' => $file->parent_id,
        'user_id' => $file->user_id,
        'name' => $fileName,
        'type' => $type,
        'parent_file_id' => $file->parent_file_id ? $file->parent_file_id : $file->file_id
      );

      // Save
      $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
      $feedPath = $path . DIRECTORY_SEPARATOR . $base . '_gif.' . $extension;
      $image = Sitegifplayer_Image::factory();
      $image->open($tempFile)
        ->setFormat($extension);
      $image->write($feedPath)
        ->destroy();
      if( $params['parent_type'] == 'system' ) {
        $storage = $filesTable->createSystemFile($feedPath);
        $storage->setFromArray($params);
        $storage->save();
      } else {
        $filesTable->createFile($feedPath, $params);
      }
    } catch( Exception $e ) {
      // Remove temp files
      throw $e;
    }
    if( $feedPath ) {
      @unlink($feedPath);
    }
  }

}
