<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupadmincontact
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Mail.php 2011-11-15 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupadmincontact_Form_Admin_Mail_Mail extends Engine_Form {

  public function init() {

    //GET DECORATORS
    $this->loadDefaultDecorators();

    //GET DESCRIPTION
    $description = sprintf(Zend_Registry::get('Zend_Translate')->_("Using this form, you will be able to send an email out to all of the Admins of Groups on your website. Emails are sent out using a queue system, so they will be sent out over time. An email will be sent to you when all emails have been sent. You can also first send out a test email to your account before sending it to your site's Group Admins. To configure settings for the outgoing emails from this tool, please visit the 'Email Settings' tab.<br />You can use this tool to communicate to users about tips to more effectively use Groups on your website. You can also inform them about new features added to Groups. SocialApps.tech is regularly releasing %s and enhancements and this tool can help you inform your users about them as you make these features available on your website.<br />This can be a great way to motivate users to keep their Groups updated and active on your website."), '<a href="http://www.socialengineaddons.com/catalog/directory-groups-extensions" target="_blank">new extensions</a>');

    $this->getDecorator('Description')->setOption('escape', false);

    //SET TITLE AND DESCRIPTION
    $this
            ->setTitle('Email All Group Admins')
            ->setDescription("$description");

    //CHECK WHETHER THE PACKAGE IS ENABLED OR NOT
    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $packageTable = Engine_Api::_()->getDbtable('packages', 'sitegroup');
      $packageselect = $packageTable->select()->from($packageTable->info("name"), array("package_id", "title"))->order("package_id DESC");
      $packageList = $packageTable->fetchAll($packageselect);
      foreach ($packageList as $package) {
        $package_prepared[0] = "All Packages";
        $package_prepared[$package->package_id] = $package->title;
      }

      $this->addElement('Multiselect', 'packages', array(
          'label' => 'Packages',
          'description' => 'Hold down the CTRL key to select or de-select specific Packages for which Admins of corresponding Groups need to be sent emails.',
          'required' => false,
          'allowEmpty' => true,
          'multiOptions' => $package_prepared,
          'value' => 0
      ));

      $this->packages->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));
    }

    //PREPARE CATEGORIES
    $categories = Engine_Api::_()->getDbTable('categories', 'sitegroup')->getCategories();
    if (count($categories) != 0) {
      $categories_prepared[0] = "All Categories";
      foreach ($categories as $category) {
        $categories_prepared[$category->category_id] = $category->category_name;
      }
    

        $this->addElement('Multiselect', 'categories', array(
            'label' => 'Group Categories',
            'description' => 'Hold down the CTRL key to select or de-select specific Group Categories for which Admins of corresponding Groups need to be sent emails.',
            'required' => false,
            'allowEmpty' => true,
            'multiOptions' => $categories_prepared,
            'value' => 0
        ));
        $this->categories->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));
    }
    $status_prepared = array("All" => "All Groups", "Draft" => "Draft Groups", "Published" => "Published Groups", "Open" => "Open Groups", "Closed" => "Closed Groups", "Featured" => "Featured Groups", "Sponsored" => "Sponsored Groups", "Approved" => "Approved Groups", "DisApproved" => "Dis-approved Groups");

    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $status_prepared = array_merge($status_prepared, array("Running" => "Running Groups", "Expired" => "Expired Groups"));
    }

    $this->addElement('Multiselect', 'status', array(
        'label' => 'Status',
        'RegisterInArrayValidator' => false,
        'description' => 'Hold down the CTRL key to select or de-select specific Group Status for which Admins of corresponding Groups need to be sent emails.',
        'required' => false,
        'allowEmpty' => true,
        'multiOptions' => $status_prepared,
        'value' => "All"
    ));
    $this->status->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));

    $this->addElement('Text', 'subject', array(
        'label' => 'Subject:',
        'required' => true,
        'allowEmpty' => false,
    ));

    //UPLOAD PHOTO URL
    $upload_url = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'sitegroupadmincontact', 'controller' => 'mails', 'action' => "upload-photo"), 'admin_default', true);

    //GET FILTER
    $filter = new Engine_Filter_Html();

    //BODY
    $this->addElement('TinyMce', 'body', array(
        'label' => 'Body',
        'required' => true,
        'allowEmpty' => false,
        'filters' => array(
            new Engine_Filter_Censor(),
            $filter,
        ),

        'editorOptions' => Engine_Api::_()->seaocore()->tinymceEditorOptions($upload_url),
    ));
    $this->body->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));

    //SEND TEST EMAIL
    $this->addElement('Checkbox', 'group_contactemail_demo', array(
        'label' => 'Send me a test email. Do not send emails to Group Admins right now.',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('group.contactemail.demo', 1),
        'description' => 'Test Email',
        'onclick' => 'showGroupOption(this.checked)'
    ));

    //EMAIL ID FOR TESTING
    $this->addElement('Text', 'group_contactemail_admin', array(
        'label' => 'Email ID for Testing',
        'required' => true,
        'allowEmpty' => false,
        'validators' => array(
            array('NotEmpty', true),
            array('EmailAddress', true),
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('group.contactemail.admin', Engine_API::_()->seaocore()->getSuperAdminEmailAddress()),
    ));

    $this->group_contactemail_admin->getValidator('NotEmpty')->setMessage('Please enter a valid email address.', 'isEmpty');
    $this->group_contactemail_admin->getValidator('EmailAddress')->getHostnameValidator()->setValidateTld(false);

    //SUBMIT
    $this->addElement('Button', 'submit', array(
        'label' => 'Send Emails',
        'type' => 'submit',
        'ignore' => true,
    ));
  }

}

?>
