<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupmusic
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http:// www.socialengineaddons.com/license/
 * @version    $Id: Create.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupmusic_Form_Create extends Engine_Form {

  protected $_playlist;

  public function init() {

    $auth = Engine_Api::_()->authorization()->context;
    $user = Engine_Api::_()->user()->getViewer();

    $this
            ->setTitle('Add New Songs')
            ->setDescription('Choose music from your computer to add to the playlist of this Group.')
            ->setAttrib('id', 'form-upload-music')
            ->setAttrib('name', 'playlist_create')
            ->setAttrib('enctype', 'multipart/form-data')
            ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
    ;

    $this->addElement('Text', 'title', array(
        'label' => 'Playlist Name',
        'maxlength' => '63',
        'filters' => array(
          'StripTags',
            new Engine_Filter_Censor(),
            new Engine_Filter_StringLength(array('max' => '63')),
        )
    ));

    $this->addElement('Textarea', 'description', array(
        'label' => 'Playlist Description',
        'maxlength' => '300',
        'filters' => array(
            'StripTags',
            new Engine_Filter_Censor(),
            new Engine_Filter_StringLength(array('max' => '300')),
            new Engine_Filter_EnableLinks(),
        ),
    ));

    $this->addElement('Checkbox', 'search', array(
        'label' => "Show this playlist in search results.",
        'value' => 1,
        'checked' => true,
    ));


    $this->addElement('File', 'art', array(
        'label' => 'Playlist Artwork',
    ));
    $this->art->addValidator('Extension', false, 'jpg,png,gif,jpeg');

    $uploadUrl = Zend_Controller_Front::getInstance()->getRouter()->assemble(array()) . '?ul=1';
    $data = array(
      'responseParamId' => 'song_id',
      'view' => 'list',
      'linkTitle' => 'Add Music',
      'linkClass' => 'buttonlink icon_sitegroupmusic_new',
      'fileIdsElement' => 'fancyuploadfileids',
      'linkDescription' => 'Click \'Add Music\' to select one or more songs from your computer. After you have selected the songs, they will begin to upload right away. When your upload is finished, click the button below the song list to save them to your playlist.',
    );
    $this->addElement('SeaoFancyUpload', 'file', array(
        'url' =>  $uploadUrl,
        'accept' => 'audio/*',
        'data' => $data,
    ));
    $this->addElement('Hidden', 'fancyuploadfileids',array( 'order' => 900,));

    $this->addElement('Button', 'submit', array(
        'label' => 'Save Music to Playlist',
        'type' => 'submit',
    ));
  }

  public function clearUploads() {

    $this->getElement('fancyuploadfileids')->setValue('');
  }

  public function saveValues() {

    $group_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('group_id', null);
    $playlist = null;
    $values = $this->getValues();
    $translate = Zend_Registry::get('Zend_Translate');
    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $viewer = Engine_Api::_()->user()->getViewer();

    if (!empty($values['playlist_id']))
      $playlist = Engine_Api::_()->getItem('sitegroupmusic_playlist', $values['playlist_id']);
    else {
      $playlist = $this->_playlist = Engine_Api::_()->getDbtable('playlists', 'sitegroupmusic')->createRow();

      $playlist->title = trim($values['title']);
      if (empty($playlist->title))
        $playlist->title = $translate->_('_SITEGROUPMUSIC_UNTITLED_PLAYLIST');

      $playlist->group_id = $group_id;
      $playlist->owner_id = Engine_Api::_()->user()->getViewer()->getIdentity();
      $playlist->description = trim($values['description']);
      $playlist->search = $values['search'];
      $playlist->view_count = 1;
      $playlist->save();
      $values['playlist_id'] = $playlist->playlist_id;
      $playlist = $this->_playlist = Engine_Api::_()->getItem('sitegroupmusic_playlist', $values['playlist_id']);

      $file_ids = array();
      foreach (explode(' ', $values['fancyuploadfileids']) as $file_id) {
        $file_id = trim($file_id);
        if (!empty($file_id))
          $file_ids[] = $file_id;
      }

      if (!empty($file_ids))
        foreach ($file_ids as $file_id)
          $playlist->addSong($file_id);

      if ($playlist->search) {
        $activity = Engine_Api::_()->getDbtable('actions', 'activity');
        $activityFeedType = null;
        $linked_music_title = '<b>' . $view->htmlLink($playlist->getHref(), $playlist->getTitle()) . '</b>';
        if (Engine_Api::_()->sitegroup()->isGroupOwner($sitegroup) && Engine_Api::_()->sitegroup()->isFeedTypeGroupEnable()) {
          $activityFeedType = 'sitegroupmusic_admin_new';
        } else {
          $activityFeedType = 'sitegroupmusic_playlist_new';
        }
        if ($activityFeedType) {
          $action = $activity->addActivity(Engine_Api::_()->user()->getViewer(), $sitegroup, $activityFeedType, null, array('count' => count($file_ids), 'linked_music_title' => $linked_music_title));
          Engine_Api::_()->getApi('subCore', 'sitegroup')->deleteFeedStream($action);
        }
        if (null !== $action)
          $activity->attachActivity($action, $playlist);

        foreach ($activity->getActionsByObject($playlist) as $action) {
          $actionTable->resetActivityBindings($action);
        }

				//GROUP Music CREATE NOTIFICATION AND EMAIL WORK
				if(!empty($action)) {
					$sitegroupVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitegroup')->version;
					if ($sitegroupVersion >= '4.3.0') {
						Engine_Api::_()->sitegroup()->sendNotificationEmail($playlist, $action, 'sitegroupmusic_create', 'SITEGROUPMUSIC_CREATENOTIFICATION_EMAIL', 'Groupevent Invite');
						
						$isGroupAdmins = Engine_Api::_()->getDbtable('manageadmins', 'sitegroup')->isGroupAdmins($viewer->getIdentity(), $group_id);
						if (!empty($isGroupAdmins)) {
							//NOTIFICATION FOR ALL FOLLWERS.
							Engine_Api::_()->sitegroup()->sendNotificationToFollowers($playlist, $action, 'sitegroupmusic_create');
						}
					}
				}

        //SENDING ACTIVITY FEED TO FACEBOOK.
        $enable_Facebooksefeed = $enable_fboldversion = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('facebooksefeed');
        if (!empty($enable_Facebooksefeed)) {
          $musiccreate_array = array();
          $musiccreate_array['type'] = 'sitegroupmusic_playlist_new';
          $musiccreate_array['object'] = $playlist;
          $musiccreate_array['description'] = trim($values['description']);
          Engine_Api::_()->facebooksefeed()->sendFacebookFeed($musiccreate_array);
        }
      }
    }

    if (!empty($values['art']))
      $playlist->setPhoto($this->art);

    return $playlist;
  }

}

?>