<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupmusic
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupmusic_Plugin_Menus {

  public function canViewMusics() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupmusic.music.show.menu', 1)) {
      return false;
    }

    $table = Engine_Api::_()->getDbTable('playlists', 'sitegroupmusic');
    $rName = $table->info('name');
    $table_groups = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $rName_groups = $table_groups->info('name');
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_groups, array('photo_id', 'title as sitegroup_title'))
                    ->join($rName, $rName . '.group_id = ' . $rName_groups . '.group_id')
                    ->where($rName . '.search = ?', '1');
    $select = $select
                    ->where($rName_groups . '.closed = ?', '0')
                    ->where($rName_groups . '.approved = ?', '1')
                    ->where($rName_groups . '.search = ?', '1')
                    ->where($rName_groups . '.declined = ?', '0')
                    ->where($rName_groups . '.draft = ?', '1');
    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $select->where($rName_groups . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }
//SITEMOBILE GROUP MUSIC MENUS
   public function onMenuInitialize_SitegroupmusicAdd($row) { 
    $subject = Engine_Api::_()->core()->getSubject();

    $playlist_id = $subject->getIdentity();

    $playlist = Engine_Api::_()->getItem('sitegroupmusic_playlist', $playlist_id);
    $group_id = $playlist->group_id;
    if (empty($playlist)) {
      return false;
    }
    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'smcreate');
    if (empty($isManageAdmin)) {
      $can_create = 0;
    } else {
      $can_create = 1;
    }
    //CHECKS FOR UPLOAD MUSIC
    if (empty($can_create)) {
      return false;
    }
    return array(
        'label' => 'Upload Music',
        'route' => 'sitegroupmusic_create',
        'class' => 'ui-btn-action',
        'params' => array(
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }
  
   public function onMenuInitialize_SitegroupmusicEdit($row) { 
    $playlist = Engine_Api::_()->core()->getSubject('sitegroupmusic_playlist');
    if (empty($playlist)) {
      return false;
    }

    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    $owner_id = $playlist->owner_id;
    $group_id = $playlist->group_id;

    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    //CHECKS FOR EDIT PLAYLIST
    if ($owner_id != $viewer_id && empty($can_edit)) {
      return false;
    }

    return array(
        'label' => 'Edit Playlist',
        'route' => 'sitegroupmusic_playlist_specific',
        'class' => 'ui-btn-action',
        'params' => array(
            'action' => 'edit',
            'group_id' => $group_id,
            'playlist_id' => $playlist->playlist_id,
            'slug' => $playlist->getTitle(),
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupmusicDelete($row) {
    $playlist = Engine_Api::_()->core()->getSubject('sitegroupmusic_playlist');
    if (empty($playlist)) {
      return false;
    }

    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    $owner_id = $playlist->owner_id;
    $group_id = $playlist->group_id;

    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    //CHECKS FOR DELETE PLAYLIST
    if ($owner_id != $viewer_id && empty($can_edit)) {
      return false;
    }
    return array(
        'label' => 'Delete Playlist',
        'route' => 'sitegroupmusic_playlist_specific',
        'class' => 'ui-btn-danger smoothbox',
        'params' => array(
            'action' => 'delete',
            'group_id' => $group_id,
            'playlist_id' => $playlist->playlist_id,
            'slug' => $playlist->getTitle(),
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupmusicShare($row) {
    $playlist = Engine_Api::_()->core()->getSubject('sitegroupmusic_playlist');
    if (empty($playlist)) {
      return false;
    }
    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    //CHECKS FOR SHARE PLAYLIST
    if (empty($viewer_id)) {
      return false;
    }

    return array(
        'label' => 'Share',
        'route'=>'default',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module'=>'activity',
            'controller'=>'index',
	          'action'=>'share',
            'type'=>'sitegroupmusic_playlist',
            'id' => $playlist->getIdentity(),
        )
    );
  }

  public function onMenuInitialize_SitegroupmusicReport($row) {
    $playlist = Engine_Api::_()->core()->getSubject('sitegroupmusic_playlist');
    if (empty($playlist)) {
      return false;
    }
    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    //CHECKS FOR REPORT PLAYLIST
    if (empty($viewer_id)) {
      return false;
    }

    return array(
        'label' => 'Report',
        'route' => 'default',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module' => 'core',
            'controller' => 'report',
            'action' => 'create',
            'subject' => $playlist->getGuid(),
        )
    );
  }
}
?>