<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupoffer
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupoffer_IndexController extends Siteapi_Controller_Action_Standard {

    /**
     * Returns the listing of the offers of particular Group
     * 
     * 
     */
    public function indexAction() {
        $this->validateRequestMethod();

        $group_id = $this->_getParam('group_id');
        $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);

        if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitegroup()->allowPackageContent($sitegroup->package_id, "modules", "sitegroupoffer")) {
                $this->respondWithError('unauthorized');
            }
        } else {
            $isGroupOwnerAllow = Engine_Api::_()->sitegroup()->isGroupOwnerAllow($sitegroup, 'offer');
            if (empty($isGroupOwnerAllow)) {
                $this->respondWithError('unauthorized');
            }
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        try {
            if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
                if (!Engine_Api::_()->sitegroup()->allowPackageContent($sitegroup->package_id, "modules", "sitegroupoffer")) {
                    $this->respondWithError('unauthorized');
                }
            } else {
                $groupOwnerBase = Engine_Api::_()->sitegroup()->isGroupOwnerAllow($sitegroup, 'offer');
                if (empty($groupOwnerBase)) {
                    $this->respondWithError('unauthorized');
                }
            }

            $can_edit = 1;
            $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
            if (empty($isManageAdmin)) {
                $can_edit = 0;
            }

            $can_offer = 1;
            $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'offer');
            if (empty($isManageAdmin)) {
                $can_offer = 0;
            }
            //END MANAGE-ADMIN CHECK

            $can_create_offer = '';
            if ($can_edit == 1 && $can_offer == 1) {
                $can_create_offer = 1;
            }

            //TOTAL OFFER
            $offerCount = Engine_Api::_()->sitegroup()->getTotalCount($sitegroup->group_id, 'sitegroupoffer', 'offers');
            if (empty($offerCount)) {
                $this->respondWithError('no_record');
            }

            $paginator = Engine_Api::_()->getItemTable('sitegroupoffer_offer')->getSitegroupoffersPaginator($sitegroup->group_id);
            $this->_childCount = $paginator->getTotalItemCount();

            $tempResponse['totalItemCount'] = $this->_childCount;

            foreach ($paginator as $offerObj) {
                $offers = $offerObj->toArray();

                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($offerObj);
                $offers = array_merge($offers, $getContentImages);
                $tempResponse['offers'][] = $offers;
            }
            $this->respondWithSuccess($tempResponse, true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    /**
     * Returns the particular offer array
     * 
     * 
     */
    public function viewAction() {
        //GET LOGGED IN USER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        $sitegroupoffer = Engine_Api::_()->getItem('sitegroupoffer_offer', $this->getRequest()->getParam('offer_id'));
        if ($sitegroupoffer) {
            Engine_Api::_()->core()->setSubject($sitegroupoffer);
        }

        if (empty($sitegroupoffer))
            $this->respondWithError('no_record');

        $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $sitegroupoffer->group_id);

        if (empty($sitegroup))
            $this->respondWithError('no_record');

        $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'view');
        if (empty($isManageAdmin)) {
            $this->respondWithError('unauthorized');
        }

        $can_offer = 1;
        $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'offer');
        if (empty($isManageAdmin)) {
            $can_offer = 0;
        }

        $can_create_offer = '';
        if ($can_edit == 1 && $can_offer == 1) {
            $can_create_offer = $can_create_offer = 1;
        }
        try {

            $bodyParams = $sitegroupoffer->toArray();
            $bodyParams['group_title'] = $sitegroup->title;

            $contentURL = Engine_Api::_()->getApi('Core', 'siteapi')->getContentURL($sitegroupoffer);
            if (isset($contentURL) && !empty($contentURL))
                $bodyParams = array_merge($bodyParams, $contentURL);

            // Add offer images
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($sitegroupoffer);
            $bodyParams = array_merge($bodyParams, $getContentImages);
            $bodyParams["owner_title"] = $sitegroupoffer->getOwner()->getTitle();

            // Add Owner Images
            $getOwnerImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($sitegroupoffer, true);
            $bodyParams = array_merge($bodyParams, $getOwnerImages);

            // Getting viewer like or not to content.
            $bodyParams["is_like"] = Engine_Api::_()->getApi('Core', 'siteapi')->isLike($sitegroupoffer);

            $this->respondWithSuccess($bodyParams, true);
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
    }

    /**
     * Returns the particular offer array
     * 
     * 
     */
    public function getofferAction() {
        $param = $this->_getParam('param');
        $request_url = $this->_getParam('request_url');
        $return_url = $this->_getParam('return_url');
        $front = Zend_Controller_Front::getInstance();
        $base_url = $front->getBaseUrl();

        // CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid()) {
            $host = (!empty($_ENV["HTTPS"]) && 'on' == strtolower($_ENV["HTTPS"])) ? "https://" : "http://";
            if ($base_url == '') {
                $URL_Home = $host . $_SERVER['HTTP_HOST'] . '/login';
            } else {
                $URL_Home = $host . $_SERVER['HTTP_HOST'] . '/' . $request_url . '/login';
            }
            if (empty($param)) {
                $this->respondWithError('unauthorized');
            } else {
                $this->respondWithError('unauthorized');
            }
        }

        $offer_id = $this->_getParam('id');
        //GET OFFER OBJECT
        $sitegroupoffer = Engine_Api::_()->getItem('sitegroupoffer_offer', $offer_id);
        $sitegroupObject = Engine_Api::_()->getItem('sitegroup_group', $sitegroupoffer->group_id);

        $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroupObject, 'view');
        if (empty($isManageAdmin)) {
            $private_message = 1;
        } else {
            //GET LOGGED IN USER INFORMATION
            $viewer = Engine_Api::_()->user()->getViewer();

            $claim_value = Engine_Api::_()->getDbTable('claims', 'sitegroupoffer')->getClaimValue($viewer->getIdentity(), $offer_id, $sitegroupoffer->group_id);

            if (!empty($claim_value)) {
                $this->respondWithError('unauthorized');
            } else {

                //GET THE TAB ID OF OFFER ON GROUP PROFILE
                $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroup.layoutcreate', 0);
                $offer_tab_id = Engine_Api::_()->sitegroup()->GetTabIdinfo('sitegroupoffer.profile-sitegroupoffers', $sitegroupoffer->group_id, $layout);

                //GROUP URL
                $group_url = Engine_Api::_()->sitegroup()->getGroupUrl($sitegroupObject->group_id);

                $data['grouphome_offer'] = $this->view->htmlLink('http://' . $_SERVER['HTTP_HOST'] .
                        Zend_Controller_Front::getInstance()->getRouter()->assemble(array(), 'sitegroupoffer_home', true), $this->view->translate('View More Offers'), array('style' => 'color:#3b5998;text-decoration:none;margin-left:10px;', 'target' => '_blank'));
                if ($sitegroupObject->photo_id) {
                    $data['group_photo_path'] = $sitegroupObject->getPhotoUrl('thumb.icon');
                } else {
                    $data['group_photo_path'] = 'application/modules/Sitegroup/externals/images/nophoto_sitegroup_thumb_icon.png';
                }

                $data['share_offer'] = $this->view->htmlLink('http://' . $_SERVER['HTTP_HOST'] .
                        Zend_Controller_Front::getInstance()->getRouter()->assemble(array('user_id' => $sitegroupoffer->owner_id, 'offer_id' => $sitegroupoffer->offer_id, 'tab' => $offer_tab_id, 'slug' => $sitegroupoffer->getOfferSlug($sitegroupoffer->title), 'share_offer' => 1), 'sitegroupoffer_view', true), $this->view->translate('Share Offer'), array('style' => 'text-decoration:none;font-weight:bold;color:#fff;font-size:11px;', 'target' => '_blank'));

                $data['like_group'] = $this->view->htmlLink('http://' . $_SERVER['HTTP_HOST'] .
                        Zend_Controller_Front::getInstance()->getRouter()->assemble(array('group_url' => $group_url), 'sitegroup_entry_view', true), $this->view->translate('Like') . ' ' . $sitegroupObject->getTitle(), array('style' => 'color:#3b5998;text-decoration:none;margin-right:10px;margin-left:10px;', 'target' => '_blank'));

                $group_title = $this->view->htmlLink('http://' . $_SERVER['HTTP_HOST'] .
                        Zend_Controller_Front::getInstance()->getRouter()->assemble(array('group_url' => $group_url), 'sitegroup_entry_view', true), $sitegroupObject->getTitle(), array('target' => '_blank'));

                $data['group_title'] = $this->view->htmlLink('http://' . $_SERVER['HTTP_HOST'] .
                        Zend_Controller_Front::getInstance()->getRouter()->assemble(array('group_url' => $group_url), 'sitegroup_entry_view', true), $sitegroupObject->getTitle(), array('target' => '_blank', 'style' => 'color:#3b5998;text-decoration:none;'));

                if ($sitegroupoffer->photo_id) {
                    $data['offer_photo_path'] = $sitegroupoffer->getPhotoUrl('thumb.icon');
                } else {
                    $data['offer_photo_path'] = 'application/modules/Sitegroupoffer/externals/images/offer_thumb.png';
                }

                $data['site_title'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.general.site.title', 1);

                $data['offer_title'] = $this->view->htmlLink('http://' . $_SERVER['HTTP_HOST'] .
                        Zend_Controller_Front::getInstance()->getRouter()->assemble(array('user_id' => $sitegroupoffer->owner_id, 'offer_id' => $sitegroupoffer->offer_id, 'tab' => $offer_tab_id, 'slug' => $sitegroupoffer->getOfferSlug($sitegroupoffer->title)), 'sitegroupoffer_view', true), $sitegroupoffer->title, array('style' => 'color:#3b5998;text-decoration:none;'));

                $data['coupon_code'] = $sitegroupoffer->coupon_code;
                $data['offer_url'] = $sitegroupoffer->url;
                $data['offer_description'] = $sitegroupoffer->description;
                $data['offer_time'] = gmdate('M d, Y', strtotime($sitegroupoffer->end_time));
                $data['offer_time_setting'] = $sitegroupoffer->end_settings;
                $data['claim_owner_name'] = Engine_Api::_()->user()->getViewer()->username;
                $data['enable_mailtemplate'] = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemailtemplates');

                // INITIALIZE THE STRING TO BE SEND IN THE CLAIM MAIL
                $template_header = "";
                $template_footer = "";
                $string = '';
                $string = $this->view->groupoffermail($data);

                $sitegroupofferClaimTable = Engine_Api::_()->getDbTable('claims', 'sitegroupoffer');
                $db = Engine_Db_Table::getDefaultAdapter();
                $db->beginTransaction();
                try {

                    //CREATE CLAIM FOR OFFER
                    $sitegroupofferRow = $sitegroupofferClaimTable->createRow();
                    $sitegroupofferRow->owner_id = $viewer->getIdentity();
                    $sitegroupofferRow->group_id = $sitegroupoffer->group_id;
                    $sitegroupofferRow->offer_id = $sitegroupoffer->offer_id;
                    $sitegroupofferRow->claim_value = 1;
                    $sitegroupofferRow->save();

                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $sitegroupoffer, 'sitegroupoffer_home');

                    if ($action != null) {
                        Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $sitegroupoffer);
                    }

                    $db->commit();
                } catch (Exception $e) {
                    $this->respondWithError('internal_server_error', $ex->getMessage());
                }

                $subject = $this->translate('Your ') . $data['site_title'] . $this->translate(' offer from ') . $sitegroupObject->title;

                // SEND MAIL CLAIM OFFER
                $email = Engine_Api::_()->user()->getViewer()->email;
                $email_admin = Engine_Api::_()->getApi('settings', 'core')->core_mail_from;
                Engine_Api::_()->getApi('mail', 'core')->sendSystem($email, 'offer_claim', array(
                    'subject' => $subject,
                    'template_header' => $template_header,
                    'message' => $string,
                    'template_footer' => $template_footer,
                    'email' => $email_admin,
                    'queue' => false));

                $today = date("Y-m-d H:i:s");

                if ($sitegroupoffer->claim_count > 0) {
                    $sitegroupoffer->claim_count--;
                }
                $sitegroupoffer->claimed++;
                $sitegroupoffer->save();
                $claim_count = $sitegroupoffer->claim_count;
                $offer_id = $sitegroupoffer->offer_id;

                if (($claim_count == 0) && $sitegroupoffer->end_settings == 1 && $sitegroupoffer->end_time < $today) {
                    $sitegroupofferClaimTable->deleteClaimOffers($offer_id);
                }
            }
        }
        $this->successResponseNoContent('no_content', true);
    }

}

?>