<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegrouppoll
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegrouppoll_Form_Admin_Global extends Engine_Form {
 
  // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
  public $_SHOWELEMENTSBEFOREACTIVATE = array(
      'submit_lsetting', 'environment_mode', 'include_in_package'
  );
    
  public function init() {
    $this
            ->setTitle('Global Settings')
            ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'sitegrouppoll_lsettings', array(
        'label' => 'Enter License key',
        'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.lsettings'),
    ));

    $global_settings_file = APPLICATION_PATH . '/application/settings/general.php';
    if (file_exists($global_settings_file)) {
      $generalConfig = include $global_settings_file;
    } else {
      $generalConfig = array();
    }

    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $this->addElement('Checkbox', 'include_in_package', array(
          'label' => ' Enable polls module for the default package that was created upon installation of the "Groups Plugin". If enabled, Polls App will also be enabled for the Groups created so far under the default package.',
          'description' => 'Enable Polls Module for Default Package',
          'value' => 1,
      ));
    }
    
    if ( ( !empty($generalConfig['environment_mode']) ) && ($generalConfig['environment_mode'] != 'development') ) {
      $this->addElement('Checkbox', 'environment_mode', array(
          'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few groups of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
          'description' => 'System Mode',
         // 'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    $this->addElement('Button', 'submit_lsetting', array(
        'label' => 'Activate Your Plugin Now',
        'type' => 'submit',
        'ignore' => true
    ));
    
    $this->addElement('Text', 'sitegrouppoll_maxoptions', array(
        'label' => 'Maximum Options',
        'description' => 'How many possible poll answers do you want to allow in Group poll creation?',
        'required' => true,
        'empty' => false,
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.maxoptions', 4),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));
    
    $this->addElement('Radio', 'sitegrouppoll_poll_show_menu', array(
        'label' => 'Polls Link',
        'description' => 'Do you want to show the Polls link on Groups Navigation Menu? (You might want to show this if Polls from Groups are an important component on your website. This link will lead to a widgetized group listing all Group Polls, with a search form for Group Polls and multiple widgets.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.poll.show.menu', 1),
    ));

     // Order of group poll group
    $this->addElement('Radio', 'sitegrouppoll_order', array(
        'label' => 'Default Ordering in Group Polls listing',
        'description' => 'Select the default ordering of polls in Group Polls listing. (This widgetized group will list all Group Polls. Sponsored polls are polls created by paid Groups.)',
        'multiOptions' => array(
            1 => 'All polls in descending order of creation.',
            2 => 'All polls in alphabetical order.',
            3 => 'Sponsored polls followed by others in descending order of creation.(If you have enabled packages.)',
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.order', 1),
    ));

    $this->addElement('Radio', 'sitegrouppoll_canchangevote', array(
        'label' => 'Change Vote',
        'description' => 'Do you want to permit your members to change their vote?',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No',
        ),
        'value' => (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.canchangevote', false),
    ));

    $this->addElement('Text', 'sitegrouppoll_title_truncation', array(
        'label' => 'Title Truncation Limit',
        'description' => 'What maximum limit should be applied to the number of characters in the titles of items in the widgets? (Enter a number between 1 and 999. Titles having more characters than this limit will be truncated. Complete titles will be shown on mouseover.)',
        'maxlength' => 3,
        'required' => true,
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.title.truncation', 13),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

		$this->addElement('Text', 'sitegrouppoll_manifestUrl', array(
        'label' => 'Group Polls URL alternate text for "group-polls"',
        'allowEmpty' => false,
        'required' => true,
        'description' => 'Please enter the text below which you want to display in place of "grouppolls" in the URLs of this plugin.',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegrouppoll.manifestUrl', "group-polls"),
    ));

    $this->addElement('Button', 'submit', array(
        'label' => 'Save Changes',
        'type' => 'submit',
        'ignore' => true
    ));
  }

}
?>