<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitehomepagevideo
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2015-05-15 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitehomepagevideo_Api_Core extends Core_Api_Abstract {

    protected $_isComplete = false;

    const THUMB_WIDTH = 80;
    const THUMB_HEIGHT = 51;

    /**
     * This function return the complete path of image, from the photo id.
     *
     * @param $type: The type of photo required.
     * @return Image path.
     */
    public function displayPhoto($id, $type = 'thumb.profile') {
        if (empty($id)) {
            return null;
        }
        $file = Engine_Api::_()->getItemTable('storage_file')->getFile($id, $type);
        if (!$file) {
            return null;
        }

        //Get url of the image
        $src = $file->map();
        return $src;
    }

    /**
     * Plugin which return the error, if Siteadmin not using correct version for the plugin.
     *
     */
    public function isModulesSupport() {
        $isSitehomepagevideoActivate = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitehomepagevideo.isActivate', 0);
        if (empty($isSitehomepagevideoActivate))
            return array();

        $modArray = array(
            'sitemenu' => '4.8.8p2'
        );
        $finalModules = array();
        foreach ($modArray as $key => $value) {
            $isModEnabled = Engine_Api::_()->hasModuleBootstrap($key);
            if (!empty($isModEnabled)) {
                $getModVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule($key);
                $isModSupport = $this->checkVersion($getModVersion->version, $value);
                if (empty($isModSupport)) {
                    $finalModules[] = $getModVersion->title;
                }
            }
        }
        return $finalModules;
    }

    private function checkVersion($databaseVersion, $checkDependancyVersion) {
        $f = $databaseVersion;
        $s = $checkDependancyVersion;
        if (strcasecmp($f, $s) == 0)
            return -1;

        $fArr = explode(".", $f);
        $sArr = explode('.', $s);
        if (count($fArr) <= count($sArr))
            $count = count($fArr);
        else
            $count = count($sArr);

        for ($i = 0; $i < $count; $i++) {
            $fValue = $fArr[$i];
            $sValue = $sArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                if ($fValue > $sValue)
                    return 1;
                elseif ($fValue < $sValue)
                    return 0;
                else {
                    if (($i + 1) == $count) {
                        return -1;
                    } else
                        continue;
                }
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);

                if ($fsArr[0] > $sValue)
                    return 1;
                elseif ($fsArr[0] < $sValue)
                    return 0;
                else {
                    return 1;
                }
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);

                if ($fValue > $ssArr[0])
                    return 1;
                elseif ($fValue < $ssArr[0])
                    return 0;
                else {
                    return 0;
                }
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                if ($fsArr[0] > $ssArr[0])
                    return 1;
                elseif ($fsArr[0] < $ssArr[0])
                    return 0;
                else {
                    if ($fsArr[1] > $ssArr[1])
                        return 1;
                    elseif ($fsArr[1] < $ssArr[1])
                        return 0;
                    else {
                        return -1;
                    }
                }
            }
        }
    }

    /**
     * Get language array
     *
     * @return array $localeMultiOptions
     */
    public function getLanguageArray() {

        //PREPARE LANGUAGE LIST
        $languageList = Zend_Registry::get('Zend_Translate')->getList();

        //PREPARE DEFAULT LANGUAGE
        $defaultLanguage = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.locale.locale', 'en');
        if (!in_array($defaultLanguage, $languageList)) {
            if ($defaultLanguage == 'auto' && isset($languageList['en'])) {
                $defaultLanguage = 'en';
            } else {
                $defaultLanguage = null;
            }
        }
        //INIT DEFAULT LOCAL
        $localeObject = Zend_Registry::get('Locale');
        $languages = Zend_Locale::getTranslationList('language', $localeObject);
        $territories = Zend_Locale::getTranslationList('territory', $localeObject);

        $localeMultiOptions = array();
        foreach ($languageList as $key) {
            $languageName = null;
            if (!empty($languages[$key])) {
                $languageName = $languages[$key];
            } else {
                $tmpLocale = new Zend_Locale($key);
                $region = $tmpLocale->getRegion();
                $language = $tmpLocale->getLanguage();
                if (!empty($languages[$language]) && !empty($territories[$region])) {
                    $languageName = $languages[$language] . ' (' . $territories[$region] . ')';
                }
            }

            if ($languageName) {
                $localeMultiOptions[$key] = $languageName;
            } else {
                $localeMultiOptions[$key] = Zend_Registry::get('Zend_Translate')->_('Unknown');
            }
        }
        $localeMultiOptions = array_merge(array(
            $defaultLanguage => $defaultLanguage
                ), $localeMultiOptions);
        return $localeMultiOptions;
    }

    /**
     * Get Video Object
     * @param $params : array()
     * @param $file
     * @param $values
     * @return Video
     */
    public function createVideo($params, $file, $values) {
        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $isVideoStorageEnabled = true;
        $video = Engine_Api::_()->getDbtable('videos', 'sitehomepagevideo')->createRow();
        $tempSitemenuLtype = $tempHostType = 3532;
        $sitehomepagevideoGlobalType = $coreSettings->getSetting('sitehomepagevideo.global.type', 0);
        $hostType = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));
        $sitehomepagevideoManageType = $coreSettings->getSetting('sitehomepagevideo.manage.type', 1);
        $sitehomepagevideoInfoType = $coreSettings->getSetting('sitehomepagevideo.info.type', 1);
        $sitehomepagevideoLtype = $coreSettings->getSetting('sitehomepagevideo.lsettings', 0);
        $file_ext = pathinfo($file['name']);
        $file_ext = $file_ext['extension'];
        $video->code = $file_ext;
        $video->save();
        $viewer = Engine_Api::_()->user()->getViewer();
        if (empty($sitehomepagevideoGlobalType)) {
            for ($check = 0; $check < strlen($hostType); $check++) {
                $tempHostType += @ord($hostType[$check]);
            }

            for ($check = 0; $check < strlen($sitehomepagevideoLtype); $check++) {
                $tempSitemenuLtype += @ord($sitehomepagevideoLtype[$check]);
            }
        }

        if ((empty($sitehomepagevideoGlobalType)) && (($sitehomepagevideoManageType != $tempHostType) || ($sitehomepagevideoInfoType != $tempSitemenuLtype))) {
            $isVideoStorageEnabled = false;
            $coreSettings->setSetting('sitehomepagevideo.viewtypeinfo.type', 0);
            $coreSettings->setSetting('sitehomepagevideo.viewtypeinfo.settings', 0);
        }

        if (!empty($isVideoStorageEnabled)) {
            //Store video in temporary storage object for ffmpeg to handle
            $storage = Engine_Api::_()->getItemTable('storage_file');

            if (isset($values['file_webm'])) {
                $storageObject = $storage->createFile($values['file_webm'], array(
                    'parent_id' => $video->getIdentity(),
                    'parent_type' => $video->getType(),
                    'user_id' => $viewer->getIdentity(),
                ));
            } else {
                $storageObject = $storage->createFile($file, array(
                    'parent_id' => $video->getIdentity(),
                    'parent_type' => $video->getType(),
                    'user_id' => $viewer->getIdentity(),
                ));
            }

            $video->file_id = $storageObject->file_id;
            $storageObject = $storage->createFile($file, array(
                'parent_id' => $video->getIdentity(),
                'parent_type' => $video->getType(),
                'user_id' => $viewer->getIdentity(),
            ));

            //Remove temporary file
            if (!isset($values['default'])) {
                @unlink($file['tmp_name']);
            }

            if (isset($values['title']))
                $video->title = $values['title'];

            $video->save();
        }

        return $video;
    }

    /**
     * Get Widgetized PageId
     * @param $params
     */
    public function getWidgetizedPageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $page_id = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'page_id')
                ->where('name =?', $params['name'])
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    /**
     * Check Widget Exist
     * @param $params
     */
    public function checkWidgetExist($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $content_id = $tableNameContent->select()
                ->from($tableNameContent->info('name'), 'content_id')
                ->where('page_id =?', $this->getWidgetizedPageId(array('name' => 'core_index_index')))
                ->where('name =?', $params['name'])
                ->query()
                ->fetchColumn();
        return $content_id;
    }

    /**
     * Set Default Layout
     */
    public function setDefaultLayout() {

        Engine_Api::_()->sitehomepagevideo()->getBackupOfHomePage();

        $page_id = Engine_Api::_()->sitehomepagevideo()->getWidgetizedPageId(array('name' => 'core_index_index'));
        $tableNameThemes = Engine_Api::_()->getDbtable('themes', 'core');
        $tableNameThemesName = $tableNameThemes->info('name');
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $tableNameContentName = $tableNameContent->info('name');
        $db = Engine_Db_Table::getDefaultAdapter();
        $theme_id = $tableNameThemes->select()
                ->from($tableNameThemesName, 'theme_id')
                ->where('name =?', 'luminous')
                ->where('active =?', 1)
                ->query()
                ->fetchColumn();

        $theme_captivate_id = $tableNameThemes->select()
                ->from($tableNameThemesName, 'theme_id')
                ->where('name =?', 'captivate')
                ->where('active =?', 1)
                ->query()
                ->fetchColumn();
        if (!empty($page_id)) {
            $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = '$page_id' AND `engine4_core_content`.`name` = 'spectacular.images' LIMIT 1");

            $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = '$page_id' AND `engine4_core_content`.`name` = 'captivate.images' LIMIT 1");
            if ($theme_captivate_id) {
                $db->query("UPDATE `engine4_core_pages` SET  `layout` =  '' WHERE  `engine4_core_pages`.`page_id` = '$page_id' LIMIT 1 ;");
            } else {
                $db->query("UPDATE `engine4_core_pages` SET  `layout` =  'default-simple' WHERE  `engine4_core_pages`.`page_id` = '$page_id' LIMIT 1 ;");
            }

            $content_id = Engine_Api::_()->sitehomepagevideo()->checkWidgetExist(array('name' => 'sitehomepagevideo.videos'));

            if (empty($content_id)) {
                $db->query("UPDATE  `engine4_core_content` SET  `order` =  '2' WHERE  `engine4_core_content`.`name` ='main' AND `engine4_core_content`.`page_id` = '$page_id' LIMIT 1 ;");

                $header_page_id = Engine_Api::_()->sitehomepagevideo()->getWidgetizedPageId(array('name' => 'header'));

                $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
                $main_content_id = $tableNameContent->select()
                        ->from($tableNameContent->info('name'), 'content_id')
                        ->where('name =?', 'main')
                        ->where('page_id =?', $header_page_id)
                        ->query()
                        ->fetchColumn();

                $top_content_id = $tableNameContent->select()
                        ->from($tableNameContentName, 'content_id')
                        ->where('page_id =?', $page_id)
                        ->where('name =?', 'top')
                        ->query()
                        ->fetchColumn();
                if (empty($top_content_id)) {
                    $db->insert('engine4_core_content', array(
                        'type' => 'container',
                        'name' => 'top',
                        'page_id' => $page_id,
                        'parent_content_id' => null,
                        'order' => 1,
                        'params' => ''
                    ));
                    $content_id = $db->lastInsertId('engine4_core_content');
                    $middle_content_id = $tableNameContent->select()
                            ->from($tableNameContentName, 'content_id')
                            ->where('page_id =?', $page_id)
                            ->where('parent_content_id =?', $content_id)
                            ->where('name =?', 'middle')
                            ->query()
                            ->fetchColumn();

                    if (empty($middle_content_id)) {
                        $db->insert('engine4_core_content', array(
                            'type' => 'container',
                            'name' => 'middle',
                            'page_id' => $page_id,
                            'parent_content_id' => $content_id,
                            'order' => 2,
                            'params' => ''
                        ));

                        $content_id = $db->lastInsertId('engine4_core_content');

                        $db->insert('engine4_core_content', array(
                            'type' => 'widget',
                            'name' => 'sitehomepagevideo.videos',
                            'page_id' => $page_id,
                            'parent_content_id' => $content_id,
                            'order' => 3,
                            'params' => '{"columnHeightWidth":"0","videoScreenHeight":"1","showStartViewing":"1","columnHeight":"600","columnWidth":"","selectedSlides":"1","showNextLink":"1","showLogo":"1","logo":"","sitehomepagevideoSignupLoginLink":"1","sitehomepagevideoBrowseMenus":"1","max":"20","sitehomepagevideoFirstImprotantLink":"1","sitehomepagevideoFirstTitle":"Create Your Event","sitehomepagevideoFirstUrl":"#","sitehomepagevideoHtmlTitle":"BRING PEOPLE TOGETHER","sitehomepagevideoHtmlDescription":"Create Events, Sell Tickets Online and Share Events.","sitehomepagevideoHowItWorks":"0","sitehomepagevideoSignupLoginButton":"0","sitehomepagevideoSearchBox":"4","showSignupFields":"","showTagLine":"1","showLeftRightSignupButton":"0","playVideoSound":"0","nomobile":"0","title":"","name":"sitehomepagevideo.videos"}'
                        ));
                    }
                } else {
                    $middle_content_id = $tableNameContent->select()
                            ->from($tableNameContentName, 'content_id')
                            ->where('page_id =?', $page_id)
                            ->where('parent_content_id =?', $top_content_id)
                            ->where('name =?', 'middle')
                            ->query()
                            ->fetchColumn();

                    if (!empty($middle_content_id)) {
                        $db->insert('engine4_core_content', array(
                            'type' => 'widget',
                            'name' => 'sitehomepagevideo.videos',
                            'page_id' => $page_id,
                            'parent_content_id' => $middle_content_id,
                            'order' => 3,
                            'params' => '{"columnHeightWidth":"0","videoScreenHeight":"1","showStartViewing":"1","columnHeight":"600","columnWidth":"","selectedSlides":"1","showNextLink":"1","showLogo":"1","logo":"","sitehomepagevideoSignupLoginLink":"1","sitehomepagevideoBrowseMenus":"1","max":"20","sitehomepagevideoFirstImprotantLink":"1","sitehomepagevideoFirstTitle":"Create Your Event","sitehomepagevideoFirstUrl":"#","sitehomepagevideoHtmlTitle":"BRING PEOPLE TOGETHER","sitehomepagevideoHtmlDescription":"Create Events, Sell Tickets Online and Share Events.","sitehomepagevideoHowItWorks":"0","sitehomepagevideoSignupLoginButton":"0","sitehomepagevideoSearchBox":"4","showSignupFields":"","showTagLine":"1","showLeftRightSignupButton":"0","playVideoSound":"0","nomobile":"0","title":"","name":"sitehomepagevideo.videos"}'
                        ));
                    }
                }
            }

            $header_page_id = Engine_Api::_()->sitehomepagevideo()->getWidgetizedPageId(array('name' => 'header'));
            $main_content_id = $tableNameContent->select()
                    ->from($tableNameContent->info('name'), 'content_id')
                    ->where('name =?', 'main')
                    ->where('page_id =?', $header_page_id)
                    ->query()
                    ->fetchColumn();

            if (!empty($main_content_id)) {
                $content_id = $tableNameContent->select()
                        ->from($tableNameContent->info('name'), 'content_id')
                        ->where('name =?', 'core.html-block')
                        ->where('page_id =?', $header_page_id)
                        ->where('params like (?)', '%jQuery.noConflict()%')->query()
                        ->fetchColumn();

                if (!$content_id) {
                    $db->insert('engine4_core_content', array(
                        'type' => 'widget',
                        'name' => 'core.html-block',
                        'page_id' => $header_page_id,
                        'parent_content_id' => $main_content_id,
                        'order' => 1,
                        'params' => '{"title":"","data":"<script type=\"text\/javascript\"> \r\nif(typeof(window.jQuery) !=  \"undefined\") {\r\njQuery.noConflict();\r\n}\r\n<\/script>","nomobile":"0","name":"core.html-block"}'
                    ));
                }
            }

            if ($theme_id) {
                $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = '$page_id' AND `engine4_core_content`.`name` = 'siteluminous.homepage-images' LIMIT 1");
                $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = '$page_id' AND `engine4_core_content`.`name` = 'siteluminous.landing-search' LIMIT 1");

                $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = '$page_id' AND `engine4_core_content`.`name` = 'siteluminous.menu-footer' LIMIT 1");
                $footer_page_id = Engine_Api::_()->sitehomepagevideo()->getWidgetizedPageId(array('name' => 'footer'));

                if ($footer_page_id) {
                    $main_footer_content_id = $tableNameContent->select()
                            ->from($tableNameContentName, 'content_id')
                            ->where('page_id =?', $footer_page_id)
                            ->where('name =?', 'main')
                            ->query()
                            ->fetchColumn();

                    if ($main_footer_content_id) {
                        $menu_footer_content_id = $tableNameContent->select()
                                ->from($tableNameContentName, 'content_id')
                                ->where('page_id =?', $footer_page_id)
                                ->where('parent_content_id =?', $main_footer_content_id)
                                ->where('name =?', 'siteluminous.menu-footer')
                                ->query()
                                ->fetchColumn();

                        if (!$menu_footer_content_id) {
                            $db->insert('engine4_core_content', array(
                                'type' => 'widget',
                                'name' => 'siteluminous.menu-footer',
                                'page_id' => $footer_page_id,
                                'parent_content_id' => $main_footer_content_id,
                            ));
                        }
                    }
                }
            }
        }
    }

    /**
     * Get Widgetized PageId
     * @param $params
     */
    public function getBackupHomePageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $page_id = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'page_id')
                ->where('url =?', 'home')
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    public function getBackupOfHomePage() {

        $page_id = $this->getWidgetizedPageId(array('name' => 'core_index_index'));
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $tableNameContentName = $tableNameContent->info('name');
        $db = Engine_Db_Table::getDefaultAdapter();

        //CHECK PAGE EXIST OR NOT
        $home_backup_page_id = $this->getBackupHomePageId();

        //CREATE PAGE
        if (empty($home_backup_page_id)) {
            $db->query("INSERT IGNORE INTO `engine4_core_pages` ( `name`, `displayname`, `url`, `title`, `description`, `keywords`, `custom`, `fragment`, `layout`, `levels`, `provides`, `view_count`, `search`) VALUES (NULL, 'Landing Page - Backup of Landing Page on Installation of Home Page Background Videos & Photos Plugin', 'home', 'Backup of Landing Page on Installation of Home Page Background Videos & Photos Plugin', '', '', '0', '0', '', NULL, NULL, '0', '0');");
        }

        //GET EXISTING PAGE ID
        $home_backup_page_id = $this->getBackupHomePageId();

        $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = $home_backup_page_id");

        //GET MAIN CONTAINER WORK
        $select = $tableNameContent->select()
                ->from($tableNameContentName, '*')
                ->where('page_id =?', $page_id)
                ->where('name =?', 'main')
                ->where('type =?', 'container');

        $mainRow = $tableNameContent->fetchRow($select);

        if (!empty($mainRow)) {

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $home_backup_page_id,
                'parent_content_id' => null,
                'order' => $mainRow->order,
                'params' => $mainRow->params ? json_encode($mainRow->params) : ''
            ));
            $content_id = $db->lastInsertId('engine4_core_content');

            $results = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('name in (?)', array('left', 'middle', 'right'))
                    ->where('type =?', 'container')
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->query()
                    ->fetchAll();

            foreach ($results as $values) {
                $db->insert('engine4_core_content', array(
                    'type' => $values['type'],
                    'name' => $values['name'],
                    'page_id' => $home_backup_page_id,
                    'parent_content_id' => $content_id,
                    'order' => $values['order'],
                    'params' => $values['params']
                ));
            }

            //LEFT CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->where('name =?', 'left')
                    ->where('type =?', 'container');

            $leftRow = $tableNameContent->fetchRow($select);

            if (!empty($leftRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $leftRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'left')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END LEFT CONTAINER WIDGET
            //MIDDLE CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->where('name =?', 'middle')
                    ->where('type =?', 'container');

            $middleRow = $tableNameContent->fetchRow($select);

            if (!empty($middleRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $middleRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'middle')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END MIDDLE CONTAINER WIDGET
            //RIGHT CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $mainRow->content_id)
                    ->where('name =?', 'right')
                    ->where('type =?', 'container');

            $rightRow = $tableNameContent->fetchRow($select);

            if (!empty($rightRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $rightRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'right')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END RIGHT CONTAINER WIDGET
        }

        //TOP CONTAINER
        $select = $tableNameContent->select()
                ->from($tableNameContentName, '*')
                ->where('page_id =?', $page_id)
                ->where('name =?', 'top')
                ->where('type =?', 'container');

        $topRow = $tableNameContent->fetchRow($select);

        if (!empty($topRow)) {

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'top',
                'page_id' => $home_backup_page_id,
                'parent_content_id' => null,
                'order' => $topRow->order,
                'params' => $topRow->params ? json_encode($topRow->params) : ''
            ));
            $content_id = $db->lastInsertId('engine4_core_content');

            $results = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('name in (?)', array('left', 'middle', 'right'))
                    ->where('type =?', 'container')
                    ->where('parent_content_id =?', $topRow->content_id)
                    ->query()
                    ->fetchAll();

            foreach ($results as $values) {
                $db->insert('engine4_core_content', array(
                    'type' => 'container',
                    'name' => $values['name'],
                    'page_id' => $home_backup_page_id,
                    'parent_content_id' => $content_id,
                    'order' => $values['order'],
                    'params' => $values['params']
                ));
            }

            //MIDDLE CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $topRow->content_id)
                    ->where('name =?', 'middle')
                    ->where('type =?', 'container');

            $topMiddleRow = $tableNameContent->fetchRow($select);

            if (!empty($topMiddleRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $topMiddleRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'middle')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END MIDDLE CONTAINER WIDGET
        }


        //GET BOTTOM CONTAINER
        $select = $tableNameContent->select()
                ->from($tableNameContentName, '*')
                ->where('page_id =?', $page_id)
                ->where('name =?', 'bottom')
                ->where('type =?', 'container');

        $bottomRow = $tableNameContent->fetchRow($select);

        if (!empty($bottomRow)) {

            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'bottom',
                'page_id' => $home_backup_page_id,
                'parent_content_id' => null,
                'order' => $bottomRow->order,
                'params' => $bottomRow->params ? json_encode($bottomRow->params) : ''
            ));
            $content_id = $db->lastInsertId('engine4_core_content');

            $results = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('name in (?)', array('left', 'middle', 'right'))
                    ->where('type =?', 'container')
                    ->where('parent_content_id =?', $bottomRow->content_id)
                    ->query()
                    ->fetchAll();

            foreach ($results as $values) {
                $db->insert('engine4_core_content', array(
                    'type' => 'container',
                    'name' => $values['name'],
                    'page_id' => $home_backup_page_id,
                    'parent_content_id' => $content_id,
                    'order' => $values['order'],
                    'params' => $values['params']
                ));
            }

            //MIDDLE CONTAINER WIDGETS
            $select = $tableNameContent->select()
                    ->from($tableNameContentName, '*')
                    ->where('page_id =?', $page_id)
                    ->where('parent_content_id =?', $bottomRow->content_id)
                    ->where('name =?', 'middle')
                    ->where('type =?', 'container');

            $bottomMiddleRow = $tableNameContent->fetchRow($select);

            if (!empty($bottomMiddleRow)) {
                $results = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $page_id)
                        ->where('parent_content_id =?', $bottomMiddleRow->content_id)
                        ->where('type =?', 'widget')
                        ->query()
                        ->fetchAll();

                $select = $tableNameContent->select()
                        ->from($tableNameContentName, '*')
                        ->where('page_id =?', $home_backup_page_id)
                        ->where('parent_content_id =?', $content_id)
                        ->where('name =?', 'middle')
                        ->where('type =?', 'container');

                $row = $tableNameContent->fetchRow($select);

                foreach ($results as $values) {
                    $db->insert('engine4_core_content', array(
                        'type' => $values['type'],
                        'name' => $values['name'],
                        'page_id' => $home_backup_page_id,
                        'parent_content_id' => $row->content_id,
                        'order' => $values['order'],
                        'params' => $values['params']
                    ));
                }
            }
            //END MIDDLE CONTAINER WIDGET
        }
    }

    public function encodeVideo($video_id) {
        set_time_limit(0);

        // Get video object
        $video = Engine_Api::_()->getItem('sitehomepagevideo_video', $video_id);
        if (!$video || !($video instanceof Sitehomepagevideo_Model_Video)) {
            return;
        }
        $type = 'webm';
        // Process
        try {
            $this->_process($video, $type);
        } catch (Exception $e) {
            // Attempt to set video state to failed
            try {
                if (1 != $video->status) {
                    $video->status = 3;
                    $video->save();
                }
            } catch (Exception $e) {
                $this->_addMessage($e->getMessage());
            }
        }
    }

    private function getFFMPEGPath() {
        set_time_limit(0);
        // Check we can execute
        if (!function_exists('shell_exec')) {
            throw new Sitehomepagevideo_Model_Exception('Unable to execute shell commands using shell_exec(); the function is disabled.');
        }
        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        if (!function_exists('exec')) {
            throw new Sitehomepagevideo_Model_Exception('Unable to execute shell commands using exec(); the function is disabled.');
        }

        // Make sure FFMPEG path is set
        $ffmpeg_path = $coreSettings->getSetting('sitehomepagevideo.video.ffmpeg.path', $coreSettings->getSetting('video.ffmpeg.path', ''));

        if (!$ffmpeg_path) {
            throw new Sitehomepagevideo_Model_Exception('Ffmpeg not configured');
        }

        // Make sure FFMPEG can be run
        if (!@file_exists($ffmpeg_path) || !@is_executable($ffmpeg_path)) {
            $output = null;
            $return = null;
            exec($ffmpeg_path . ' -version', $output, $return);

            if ($return > 0) {
                throw new Sitehomepagevideo_Model_Exception('Ffmpeg found, but is not executable');
            }
        }

        return $ffmpeg_path;
    }

    private function getTmpDir() {
        set_time_limit(0);
        // Check the video temporary directory
        $tmpDir = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary' .
                DIRECTORY_SEPARATOR . 'sitehomepagevideo_video';
        if (!is_dir($tmpDir) && !mkdir($tmpDir, 0777, true)) {
            throw new Sitehomepagevideo_Model_Exception('Video temporary directory did not exist and could not be created.');
        }

        if (!is_writable($tmpDir)) {
            throw new Sitehomepagevideo_Model_Exception('Video temporary directory is not writable.');
        }

        $format = "AddType video/mp4 .mp4";
        $htaccessfilepath = APPLICATION_PATH . '/public/sitehomepagevideo_video' . '/.htaccess';
        chmod($htaccessfilepath, 0777);
        $fp = fopen($htaccessfilepath, 'w');
        fwrite($fp, $format);
        fclose($fp);

        return $tmpDir;
    }

    private function getVideo($video) {
        set_time_limit(0);

        // Get the video object
        if (is_numeric($video)) {
            $video = Engine_Api::_()->getItem('sitehomepagevideo_video', $video);
        }

        if (!($video instanceof Sitehomepagevideo_Model_Video)) {
            throw new Sitehomepagevideo_Model_Exception('Argument was not a valid video');
        }

        return $video;
    }

    private function getStorageObject($video) {
        set_time_limit(0);

        // Pull video from storage system for encoding
        $storageObject = Engine_Api::_()->getItem('storage_file', $video->file_id);

        if (!$storageObject) {
            throw new Sitehomepagevideo_Model_Exception('Video storage file was missing');
        }

        return $storageObject;
    }

    private function getOriginalPath($storageObject) {
        set_time_limit(0);
        $originalPath = $storageObject->temporary();

        if (!file_exists($originalPath)) {
            throw new Sitehomepagevideo_Model_Exception('Could not pull to temporary file');
        }

        return $originalPath;
    }

    private function getVideoFilters($video, $width, $height) {
        set_time_limit(0);
        $filters = "scale=$width:$height";
        if ($video->rotation > 0) {
            $filters = "pad='max(iw,ih*($width/$height))':ow/($width/$height):(ow-iw)/2:(oh-ih)/2,$filters";
            if ($video->rotation == 180)
                $filters = "hflip,vflip,$filters";
            else {
                $transpose = array(90 => 1, 270 => 2);

                if (empty($transpose[$video->rotation]))
                    throw new Sitehomepagevideo_Model_Exception('Invalid rotation value');

                $filters = "transpose=${transpose[$video->rotation]},$filters";
            }
        }

        return $filters;
    }

    private function conversionSucceeded($video, $videoOutput, $outputPath) {
        set_time_limit(0);
        $success = true;

        // Unsupported format
        if (preg_match('/Unknown format/i', $videoOutput) ||
                preg_match('/Unsupported codec/i', $videoOutput) ||
                preg_match('/patch welcome/i', $videoOutput) ||
                preg_match('/Audio encoding failed/i', $videoOutput) ||
                !is_file($outputPath) ||
                filesize($outputPath) <= 0) {
            $success = false;
            $video->status = 3;
        }

        // This is for audio files
        else if (preg_match('/video:0kB/i', $videoOutput)) {
            $success = false;
            $video->status = 5;
        }

        return $success;
    }

    private function getDuration($videoOutput) {
        set_time_limit(0);
        $duration = 0;

        if (preg_match('/Duration:\s+(.*?)[.]/i', $videoOutput, $matches)) {
            list($hours, $minutes, $seconds) = preg_split('[:]', $matches[1]);
            $duration = ceil($seconds + ($minutes * 60) + ($hours * 3600));
        }

        return $duration;
    }

    private function generateThumbnail($outputPath, $output, $thumb_splice, $thumbPath, $log) {
        $ffmpeg_path = $this->getFFMPEGPath();
        set_time_limit(0);
        // Thumbnail process command
        $thumbCommand = $ffmpeg_path . ' '
                . '-i ' . escapeshellarg($outputPath) . ' '
                . '-f image2' . ' '
                . '-ss ' . $thumb_splice . ' '
                . '-vframes 1' . ' '
                . '-v 2' . ' '
                . '-y ' . escapeshellarg($thumbPath) . ' '
                . '2>&1';

        // Process thumbnail
        $thumbOutput = $output .
                $thumbCommand . PHP_EOL .
                shell_exec($thumbCommand);

        // Log thumb output
        if ($log) {
            $log->log($thumbOutput, Zend_Log::INFO);
        }

        // Check output message for success
        $thumbSuccess = true;
        if (preg_match('/video:0kB/i', $thumbOutput)) {
            $thumbSuccess = false;
        }

        if ($thumbSuccess) {
            try {
                $image = Engine_Image::factory();
                $image->open($thumbPath)
                        ->resize(1600, 500)
                        ->write($thumbPath)
                        ->destroy();
            } catch (Exception $e) {
                $this->_addMessage((string) $e->__toString());
                $thumbSuccess = false;
            }
        }

        return $thumbSuccess;
    }

    protected function _process($video, $type, $compatibilityMode = false) {
        $tmpDir = $this->getTmpDir();
        $video = $this->getVideo($video);
        set_time_limit(0);
        // Update to encoding status
        $video->status = 2;
        $video->type = 3;
        $video->save();

        $storageObject = $this->getStorageObject($video);
        $originalPath = $this->getOriginalPath($storageObject);

        $outputPath = $tmpDir . DIRECTORY_SEPARATOR . $video->getIdentity() . '_vconverted.' . $type;
        $thumbPath = $tmpDir . DIRECTORY_SEPARATOR . $video->getIdentity() . '_vthumb.jpg';

        $width = 1600;
        $height = 1200;

        $videoCommand = $this->buildVideoCmd2($video, $width, $height, $type, $originalPath, $outputPath, $compatibilityMode);

        // Prepare output header
        $output = PHP_EOL;
        $output .= $originalPath . PHP_EOL;
        $output .= $outputPath . PHP_EOL;
        $output .= $thumbPath . PHP_EOL;

        // Prepare logger
        $log = new Zend_Log();
        $log->addWriter(new Zend_Log_Writer_Stream(APPLICATION_PATH . '/temporary/log/video.log'));

        // Execute video encode command
        $videoOutput = $output .
                $videoCommand . PHP_EOL .
                shell_exec($videoCommand);

        // Log
        if ($log) {
            $log->log($videoOutput, Zend_Log::INFO);
        }

        // Check for failure
        $success = $this->conversionSucceeded($video, $videoOutput, $outputPath);

        // Failure
        if (!$success) {
            if (!$compatibilityMode) {
                $this->_process($video, $type);
                return;
            }

            $exceptionMessage = '';

            $db = $video->getTable()->getAdapter();
            $db->beginTransaction();

            try {
                $video->save();
                //$exceptionMessage = $this->notifyOwner($video, $owner);
                $db->commit();
            } catch (Exception $e) {
                $videoOutput .= PHP_EOL . $e->__toString() . PHP_EOL;

                if ($log) {
                    $log->write($e->__toString(), Zend_Log::ERR);
                }

                $db->rollBack();
            }

            // Write to additional log in dev
            if (APPLICATION_ENV == 'development') {
                file_put_contents($tmpDir . '/' . $video->video_id . '.txt', $videoOutput);
            }

            throw new Sitehomepagevideo_Model_Exception($exceptionMessage);
        }

        // Success
        else {
            // Get duration of the video to caculate where to get the thumbnail
            $duration = $this->getDuration($videoOutput);

            // Log duration
            if ($log) {
                $log->log('Duration: ' . $duration, Zend_Log::INFO);
            }

            // Fetch where to take the thumbnail
            $thumb_splice = $duration / 4;

            $thumbSuccess = $this->generateThumbnail($outputPath, $output, $thumb_splice, $thumbPath, $log);
            // $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
            // Save video and thumbnail to storage system
            $params = array(
                'parent_id' => $video->getIdentity(),
                'parent_type' => $video->getType(),
                'user_id' => Engine_Api::_()->seaocore()->getSuperAdmin()->getIdentity()
            );

            $db = $video->getTable()->getAdapter();
            $db->beginTransaction();

            try {
                $storageObject->setFromArray($params);
                $storageObject->store($outputPath);

                if ($thumbSuccess) {
                    $thumbFileRow = Engine_Api::_()->storage()->create($thumbPath, $params);
                }

                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();

                // delete the files from temp dir
                unlink($originalPath);
                unlink($outputPath);

                if ($thumbSuccess) {
                    unlink($thumbPath);
                }

                $video->status = 7;
                $video->save();

                throw $e; // throw
            }

            // Video processing was a success!
            // Save the information
            if ($thumbSuccess) {
                $video->photo_id = $thumbFileRow->file_id;
            }

            $video->duration = $duration;
            $video->status = 1;
            $video->enabled = 1;
            $video->save();

            // delete the files from temp dir
            unlink($originalPath);
            unlink($outputPath);
            unlink($thumbPath);
        }
    }

    private function buildVideoCmd2($video, $width, $height, $type, $originalPath, $outputPath, $compatibilityMode = false) {
        set_time_limit(0);
        $ffmpeg_path = $this->getFFMPEGPath();

        $videoCommand = $ffmpeg_path . ' '
                . '-i ' . escapeshellarg($originalPath) . ' ';

        if ($type == 'webm')
            $videoCommand .= '-acodec libvorbis -aq 5 -ac 2 -qmax 25 -threads 2' . ' '
            ;
        else
            $videoCommand .= '-vcodec flv -f flv ';

        $videoCommand .=
                escapeshellarg($outputPath);

        return $videoCommand;
    }

    /**
     * Create a slide
     *
     * @param array params
     * @param array file
     * @return created image object
     */
    public function createImage($params, $file) {
        if ($file instanceof Storage_Model_File) {
            $params['file_id'] = $file->getIdentity();
        } else {
            //GET IMAGE INFO AND RESIZE
            $name = basename($file['tmp_name']);
            $path = dirname($file['tmp_name']);
            $extension = ltrim(strrchr($file['name'], '.'), '.');

            $mainName = $path . '/m_' . $name . '.' . $extension;
            $thumbName = $path . '/t_' . $name . '.' . $extension;

            //GET SLIDESHOW OBJECT
            $slideshow_id = $params['slideshow_id'];
            $slideshow = Engine_Api::_()->getItem('sitehomepagevideo_slideshow', $slideshow_id);

            //GET SLIDESHOW HEIGHT
            $height = 1600; //$slideshow->height;
            //GET SLIDESHOW WIDTH
            $width = 1600; //$slideshow->width;

            $image = Engine_Image::factory();
            $image->open($file['tmp_name'])
                    ->resize($width, $height)
                    ->write($mainName)
                    ->destroy();

            $image = Engine_Image::factory();
            $image->open($file['tmp_name'])
                    //->resize(self::THUMB_WIDTH, self::THUMB_HEIGHT)
                    ->resize($width, $height)
                    ->write($thumbName)
                    ->destroy();



            $image_params = array(
                'parent_id' => 5,
                'parent_type' => 'sitehomepagevideo',
            );

            $imageFile = Engine_Api::_()->storage()->create($mainName, $image_params);
            $thumbFile = Engine_Api::_()->storage()->create($thumbName, $image_params);

            $imageFile->bridge($thumbFile, 'thumb.normal');

            $file_name = basename($file['name'], '.' . $extension);
            $params['file_id'] = $imageFile->file_id;
            $params['title'] = $file_name;
        }

        $params['photo_id'] = $params['file_id'];
        $params['code'] = 'image';
        $params['status'] = 1;
        $params['enabled'] = 1;
        $params['type'] = 3;

        $row = Engine_Api::_()->getDbtable('videos', 'sitehomepagevideo')->createRow();
        $row->setFromArray($params);
        $row->save();

        return $row;
    }

    /**
     * Get Widgetized Page Layout Value
     * @param $params
     */
    public function getWidgetizedPageLayoutValue($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $select = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'layout');

        if (isset($params['name'])) {
            $select->where('name =?', $params['name']);
        }
        if (isset($params['page_id'])) {
            $select->where('page_id =?', $params['page_id']);
        }
        $layout = $select->query()
                ->fetchColumn();
        return $layout;
    }

    public function getContentPageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNameContent = Engine_Api::_()->getDbtable('content', 'core');
        $page_id = $tableNameContent->select()
                ->from($tableNameContent->info('name'), 'page_id')
                ->where('content_id =?', $params['content_id'])
                ->query()
                ->fetchColumn();
        return $page_id;
    }

    public function getOldVersionImages($array){
        // Get available files
        $imgOptions = array();
        $imgOptions = $array;
        $imageExtensions = array('gif', 'jpg', 'jpeg', 'png');

        $it = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
        foreach ($it as $file) {
            if ($file->isDot() || !$file->isFile())
                continue;
            $basename = basename($file->getFilename());
            if (!($pos = strrpos($basename, '.')))
                continue;
            $ext = strtolower(ltrim(substr($basename, $pos), '.'));
            if (!in_array($ext, $imageExtensions))
                continue;
            $imgOptions['public/admin/' . $basename] = $basename;
        }
        return $imgOptions;
    }

    public function getNewVersionImages($array){
        $params = array();
        $params['extension'] = array('gif', 'jpg', 'jpeg', 'png');
        $filesTable = Engine_Api::_()->getDbTable('files','core');
        $select = $filesTable->getFiles($params);
        $fileData = $filesTable->fetchAll($select);
        $imgOptions = array();
        if(!empty($array))
            $imgOptions = $array;
        else
            $imgOptions = array('0' => $default);
        foreach ($fileData as $key => $value) {
            $imgOptions[$value->storage_path] =  $value->name;
        }
        return $imgOptions;
    }

    public function getImages($array = array('0' => 'No Image')){
        $coreVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core')->version;
        $checkVersion = Engine_Api::_()->seaocore()->checkVersion($coreVersion, '5.0.0');
        // changes in calling of function on the basis of core version
        if($checkVersion) {
          return $this->getNewVersionImages($array);
        } else {
          return $this->getOldVersionImages($array);
        }
    }
}
