<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteiosapp
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Core.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteiosapp_Api_Core extends Core_Api_Abstract {
    // Disabled previous APPs module if exist on plugin install or update.
    public function validatePreviousMobileAPP() {
        $db = Engine_Db_Table::getDefaultAdapter();

        $select = new Zend_Db_Select($db);
        $isPreviousAndroidMobileAPPExist = $select
                ->from('engine4_core_modules', 'enabled')
                ->where('name = ?', 'sitemobileiosapp')
                ->where('enabled = ?', 1)
                ->query()
                ->fetchColumn();

        $select = new Zend_Db_Select($db);
        $isPreviousiOSMobileAPPExist = $select
                ->from('engine4_core_modules', 'enabled')
                ->where('name = ?', 'sitemobileiosapp')
                ->where('enabled = ?', 1)
                ->query()
                ->fetchColumn();

        $select = new Zend_Db_Select($db);
        $isPreviousMobileAPPExist = $select
                ->from('engine4_core_modules', 'enabled')
                ->where('name = ?', 'sitemobileapp')
                ->where('enabled = ?', 1)
                ->query()
                ->fetchColumn();

        if (!empty($isPreviousAndroidMobileAPPExist)) {
            // Delete all exist package files.  
            array_map('unlink', glob(APPLICATION_PATH . "/application/packages/module-sitemobileiosapp*.json"));
            unlink(APPLICATION_PATH . "/application/packages/sitemobileiosapp.csv");

            // Delete all db dependent code.
            $db->query('DELETE FROM `engine4_core_modules` WHERE `engine4_core_modules`.`name` = "sitemobileiosapp" LIMIT 1');
        }

        if (empty($isPreviousiOSMobileAPPExist) && !empty($isPreviousMobileAPPExist)) {
            // Delete all exist package files.  
            array_map('unlink', glob(APPLICATION_PATH . "/application/packages/module-sitemobileapp*.json"));
            unlink(APPLICATION_PATH . "/application/packages/sitemobileapp.csv");

            // Delete all db dependent code.
            $db->query('DELETE FROM `engine4_core_modules` WHERE `engine4_core_modules`.`name` = "sitemobileapp" LIMIT 1');
        }

        return;
    }

    /*
     * Synchronised review listing types to iOS menus.
     * 
     * @return empty
     */
    public function synchroniseDashboardMenus() {
        if (!_IOS_VERSION || (_IOS_VERSION < '1.5.2'))
            return;

        $availableListingTypesArray = array();
        $listingTypes = Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypes(-1, array('visible' => 1));

        // Get all rows of review to insert / delete listing type.
        $table = Engine_Api::_()->getDbtable('menus', 'siteiosapp');
        $select = $table->getSelect();
        $paginator = $table->fetchAll($select);
        foreach ($paginator as $menu) {
            if (isset($menu->params) && !empty($menu->params)) {
                $params = @unserialize($menu->params);
                if (isset($params['listingtype_id']) && !empty($params['listingtype_id']))
                    $availableListingTypesArray[$menu->menu_id] = $params['listingtype_id'];
            }
        }

        // Add listing type in menu table, If not exist.
        $this->_addListingTypeInMenu($listingTypes, $availableListingTypesArray);

        // Remove listing type in menu table, If not exist.
        $this->_removeListingTypeInMenu($availableListingTypesArray);

        return;
    }

    /*
     * Set the listing type in menu table
     * 
     * @param $listingTypes object
     * @param $availableListingTypesArray array
     * @return empty
     */
    private function _addListingTypeInMenu($listingTypes, $availableListingTypesArray) {
        if (!empty($listingTypes)) {
            $table = Engine_Api::_()->getDbtable('menus', 'siteiosapp');
            foreach ($listingTypes as $listingType) {
                $this->_listingTypeArray[] = $listingType->listingtype_id;
                $listingTypeInfo = Engine_Api::_()->getItem('sitereview_listingtype', $listingType->listingtype_id);
                if (!in_array($listingType->listingtype_id, $availableListingTypesArray)) {
                    $row = $table->createRow();
                    $row->name = 'sitereview_listing';
                    $row->dashboard_label = $listingType->title_plural;
                    $row->header_label = $listingType->title_plural;
                    $row->module = 'sitereview';
                    $row->show = 'both';
                    $row->type = 'menu';
                    $row->status = 1;
                    $row->default = 1;
                    $row->params = @serialize(array("listingtype_id" => $listingType->listingtype_id, "header_label_singular" => $listingTypeInfo->title_singular));
                    $row->save();
                }
            }
        }

        return;
    }

    /*
     * Remove the listing type from menu table
     * 
     * @param $availableListingTypesArray array
     * @param $listingTypes object
     * @return empty
     */
    private function _removeListingTypeInMenu($availableListingTypesArray) {
        if (!empty($availableListingTypesArray)) {
            foreach ($availableListingTypesArray as $menu_id => $listingtype_id) {
                if (!in_array($listingtype_id, $this->_listingTypeArray))
                    Engine_Api::_()->getItem('siteiosapp_menus', $menu_id)->delete();
            }
        }

        return;
    }

    public function getSettingsFile() {
        $getHost = $_SERVER['HTTP_HOST'];
        $getHost = str_replace('www.', '', $getHost);
        $getHost = str_replace(".", "-", $getHost);

        // Android App Details
        $iosParentDirectoryPath = 'public/ios-' . $getHost . '-app-builder';
        $iosCoreDirectoryPath = APPLICATION_PATH . '/' . $iosParentDirectoryPath;
        include $iosCoreDirectoryPath . '/settings.php';
        if (!empty($appBuilderParams))
            return $appBuilderParams;
        return array();
    }

    public function getPackageNameFile($formError = 0, $name = '') {
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;

        if (empty($formError) && empty($name)) {
            $text = Zend_Registry::get('Zend_Translate')->_("Package Name cannot be null");
            return Zend_Json::encode(array('success' => 0, 'error_msg' => '   <span style="color:red;"><img src="' . $view->layout()->staticBaseUrl . 'application/modules/Siteiosapp/externals/images/cross.png"/>  ' . $text . '</span>'));
        }

        if (!empty($name)) {
            $explodeArray = explode(".", $name);
            if (COUNT($explodeArray) != 3) {
                $text = Zend_Registry::get('Zend_Translate')->_("Package Name is not available");
                return Zend_Json::encode(array('success' => 0, 'error_msg' => ' <span style="color:red;"><img src="' . $view->layout()->staticBaseUrl . 'application/modules/Siteiosapp/externals/images/cross.png"/> ' . $text . '</span>'));
            }
        }

        if (empty($name)) {
            $name = 'com.' . $_SERVER['SERVER_NAME'] . '.app';
        }

        //Try Creating Unique Package name for app - first attempt.
        $available = $this->getResultsFromApple($name);
        if (!empty($available)) {
            if (!empty($formError)) {
                return $name;
            } else {
                $error_msg5 = Zend_Registry::get('Zend_Translate')->_("Package Name is Available!");
                return Zend_Json::encode(array('success' => 1, 'success_msg' => " <span style='color:green;'><img src='" . $view->layout()->staticBaseUrl . "application/modules/Siteiosapp/externals/images/tick.png'/> $error_msg5</span>"));
            }
        } else {
            if (empty($formError)) {
                $text = Zend_Registry::get('Zend_Translate')->_("Package Name is not valid.");
                return Zend_Json::encode(array('success' => 0, 'error_msg' => ' <span style="color:red;"><img src="' . $view->layout()->staticBaseUrl . 'application/modules/Siteiosapp/externals/images/cross.png"/> ' . $text . '</span>'));
            } else {
                //second attempt
                $name = 'com.' . $_SERVER['SERVER_NAME'] . '.mobiapp';
                $available = $this->getResultsFromApple($name);
                if (isset($available) && !empty($available)) {
                    return $name;
                } else {
                    //third attempt
                    $name = 'com.' . $_SERVER['SERVER_NAME'] . '.mobileapp';
                    $available = $this->getResultsFromApple($name);
                    if (isset($available) && !empty($available)) {
                        return $name;
                    }
                }
            }
        }
        return '';
    }

    public function getResultsFromApple($name) {
        $getAppleResult = file_get_contents("https://itunes.apple.com/lookup?bundleId=" . $name);
        if (isset($getAppleResult) && !empty($getAppleResult)) {
            $getDecodedAppleResponce = Zend_Json::decode($getAppleResult);
            if (isset($getDecodedAppleResponce['results'][0]['trackViewUrl']) && !empty($getDecodedAppleResponce['results'][0]['trackViewUrl'])) {
                return 0;
            }
            return 1;
        }
        return 0;
    }
    
    public function getAgoraKey()
    {
    //Refresh Primessenger Details
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('primemessenger')) 
        {
        
            $apiKey = Engine_Api::_()->getApi('settings', 'core')->getSetting('primemessenger.apikey', '');
           if (isset($apiKey) && !empty($apiKey)) {
               $website = str_replace('www.', '', 'https://api.primemessenger.com/v1/modules?includes=settings');
               $auth = 'Basic ' . base64_encode($apiKey);
               $curl = curl_init($website);
               curl_setopt($curl, CURLOPT_HTTPHEADER, array(
                   "authorization: $auth",
               ));
               curl_setopt($curl, CURLOPT_HEADER, false);
               curl_setopt($curl, CURLOPT_HTTPGET, true);
               ob_start();
               curl_exec($curl);
               curl_close($curl);
               $response = ob_get_contents();
               ob_end_clean();
               $getCurlArray = json_decode($response, 1);

               if (empty($response) || strstr($response, 'error::'))
                   return 0;

               //Primessenger api keys.....................
               $apiKeyArray = array(
                   "apiKey",
                   "appId"
               );
               $primmessengerApiKeyArray=array();
               foreach ($getCurlArray as $module) 
               {
                   if ($module['enabled'] == 'true')           
                   {
                       foreach($module['settings'] as $settingVal)
                       {
                           if(in_array($settingVal['key'], $apiKeyArray))
                           {
                              $primmessengerApiKeyArray[$module['identifier']] = $settingVal['value']; 
                              break;
                           }
                       }


                   }

               }
               if (!empty($primmessengerApiKeyArray) && isset($primmessengerApiKeyArray['video-voice-call'])){
                   return $primmessengerApiKeyArray['video-voice-call'];
                   
               }
               else
                   return '';
           }
           return '';
       }
    }


}

?>