<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteiosapp
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Settings.php 2015-10-01 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteiosapp_Form_Admin_AppBuilder_Settings extends Engine_Form {

    protected $_doWeHaveLatestVersion;
    protected $_enabledTabName;
    protected $_appBuilderParams;

    public function getDoWeHaveLatestVersion() {
        return $this->_doWeHaveLatestVersion;
    }

    public function setDoWeHaveLatestVersion($default_profile_id) {
        $this->_doWeHaveLatestVersion = $default_profile_id;
        return $this;
    }

    public function getEnabledTabName() {
        return $this->_enabledTabName;
    }

    public function setEnabledTabName($enabledTabName) {
        $this->_enabledTabName = $enabledTabName;
        return $this;
    }

    public function init() {
        $package = Zend_Controller_Front::getInstance()->getRequest()->getParam('package', '');
        $tab = Zend_Controller_Front::getInstance()->getRequest()->getParam('tab', 1);
        $subTab = Zend_Controller_Front::getInstance()->getRequest()->getParam('subTab', 1);

        $this->_appBuilderParams = Engine_Api::_()->getApi('core', 'siteiosapp')->getSettingsFile();
        if (empty($package)) {
            $this->addElement('Select', 'package', array(
                'label' => 'Select Your Mobile Apps Subscription Plan',
                'required' => true,
                'allowEmpty' => false,
                'multiOptions' => array(
                    '' => '',
                    'starter' => 'Mobile Starter',
                    'pro' => 'Mobile Pro'
                ),
                'value' => $package,
                'onchange' => 'selectPackage()',
            ));
        } else {
            if ($tab == 1) {
                $this->tabOneForm($package);
            } elseif ($tab == 2) {
                $this->tabTwoForm($subTab);
            } elseif ($tab == 3) {
                $this->tabThreeForm();
            } else if ($tab == 5) {
                $this->tabFiveForm();
            } else if ($tab == 6) {
                $this->tabSixForm();
            } else if ($tab == 7) {
                $this->tabSevenForm();
            } else if ($tab == 8) {
                $this->tabEightForm();
            }
        }
    }

    public function tabOneForm($package) {
        if (($package === 'pro')) {
            $this->addElement('Dummy', 'ios_developer_account_details', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="ios_developer_account_details" class="siteiosapp_form_heading">Apple iOS Developer Account Details</h3><span style="font-weight: bold;">'),
            ));
            $this->ios_developer_account_details->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('Dummy', 'ios_developer_account_details_credentials', array(
                'label' => ' iTunes account login details',
                'description' => '<div class="tooltip_main">Make sure that you have enrolled to the "Apple Developer Program" from <a href="https://developer.apple.com/programs/ios" target="_blank">here</a>. <span class="tooltip"><span class="tooltiptext">Once you enroll and make payment to iTunes, you will be able to see a page like <a target="_blank" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/account.png" target="_blank">this</a> when login into your Apple Developer <a href="https://developer.apple.com/account/ " target="_blank">Account.</a> Without enrollment of your iTunes account, we will not be able to create your app. </span><a class="admin help" href="javascript:void(0)"></a></span></div>',
                'required' => true,
                'allowEmpty' => false,
                'value' => 1
            ));
            $this->ios_developer_account_details_credentials->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Text', 'apple_ios_developer_login_email', array(
                'required' => true,
                'placeholder' => 'Email',
                'allowEmpty' => false,
                'validators' => array(array('EmailAddress', 1)),
                'filters' => array('StringTrim')
            ));

            $this->addElement('Text', 'apple_ios_developer_login_password', array(
                'placeholder' => 'Password',
                'required' => true,
                'allowEmpty' => false
            ));

            $this->addElement('Radio', 'publish_app', array(
                'label' => 'Publish App on iTunes',
                'multiOptions' => array(
                    0 => 'No, do not publish the app on iTunes App Store and send me .ipa file',
                    1 => 'Yes, publish the app on iTunes App Store'
                ),
                'value' => 1,
                'onchange' => 'showUdid()',
            ));
            $this->publish_app->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Text', 'phone_udid', array(
                'label' => 'iPhone / iPad UDID',
                'description' => 'Enter the UDID of the iPhone or iPad on which you want to test the iOS App. Please <a href="https://www.youtube.com/watch?v=clSYqMADG3Y" target="_blank">click here</a> to see how to get the UDID.'
            ));
            $this->phone_udid->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        }

        $this->addElement('Dummy', 'app_details', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_details" class="siteiosapp_form_heading">App Submission Details</h3>'),
        ));
        $this->app_details->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'package_name', array(
            'label' => 'App ID',
            'description' => "Enter the iTunes App Store App ID (i.e: com.xyz.seiosnativeapp). Here xyz should be your website name. Package name should be three words only",
            'value' => Engine_Api::_()->getApi('core', 'siteiosapp')->getPackageNameFile(1),
            'onblur' => 'PackageUrlBlur();',
        ));
        $this->package_name->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'team_id', array(
            'label' => 'Team ID',
            'description' => "Enter the iTunes App Store Team ID. You can take reference from here: <a href='https://developer.apple.com/account/#/membership' target='_blank'>Click here</a>",
            
        ));
        $this->team_id->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'team_name', array(
            'label' => 'Team Name',
            'description' => "Enter the iTunes App Store Team Name. You can take reference from here: <a href='https://developer.apple.com/account/#/membership' target='_blank'>Click here</a>",
            
        ));
        $this->team_name->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'title', array(
            'label' => 'App Title',
            'description' => 'The app name must be at least two characters and no more than 75 bytes, assuming single-byte characters. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Title.png" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false,
            'maxlength' => 100,
            'validators' => array(
                array('stringLength', false, array(0, 100))
            )
        ));
        $this->title->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'bundle_display_name', array(
            'label' => 'Bundle Display Name',
            'description' => 'This is the text that shows up under your app icon on an iPhone or iPad. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Bundle.png" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->bundle_display_name->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Textarea', 'description', array(
            'label' => 'App Description',
            'description' => '<div class="tooltip_main">Descriptions are limited to 4000 single-byte characters. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Description.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a> <span class="tooltip"><span class="tooltiptext">The description should be in plain text, with line breaks as needed. HTML formatting isn’t recognized. Make sure to check your text for spelling or grammar errors.</span><a class="admin help" href="void(0)"></a></span></div>',
            'required' => true,
            'allowEmpty' => false,
            'validators' => array(
                array('stringLength', false, array(0, 4000))
            )
        ));
        $this->description->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'default_language', array(
            'label' => 'Language',
            'description' => 'The language of the metadata. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Url.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->default_language->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'keywords', array(
            'label' => 'Keywords',
            'description' => '<div class="tooltip_main">One or more localized keywords that describe your app. Separate search terms with comma.<span class="tooltip"><span class="tooltiptext">At least one keyword of greater than two characters is required. You can provide up to 100 bytes of content. Your app is searchable by app name and company name, so you do not need to duplicate these values in the keyword list. Names of other apps or companies are not allowed.</span><a class="admin help" href="void(0)"></a></span></div>',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->keywords->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'category', array(
            'label' => 'Categories',
            'description' => "Choose relevant category for your app. For ex. choose Sports category for Bikes based community <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/Rating.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a>. <br/>For a list of categories, please visit: <a href='http://www.idev101.com/code/Distribution/categories.html' target='_blank'> here</a> and <a href='https://developer.apple.com/library/ios/documentation/LanguagesUtilities/Conceptual/iTunesConnect_Guide/Chapters/FirstSteps.html#//apple_ref/doc/uid/TP40011225-CH19-SW8' target='_blank'> here</a>.",
            'required' => true,
            'allowEmpty' => false,
        ));
        $this->category->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'primary_category', array(
            'placeholder' => 'Primary Category',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'secondary_category', array(
            'placeholder' => 'Secondary Category',
        ));
        $this->secondary_category->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Select', 'rating', array(
            'label' => 'Rating',
            'description' => 'Below you can select that your app should be available to which age group. Not sure which one to select, click <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/ratinginfo.png" target="_blank"> here </a> for help. To know more about the ratings, have a look at the detailed <a href="https://techcrunch.com/2009/06/29/heres-how-iphone-app-store-ratings-work-hint-they-dont/" target="_blank">here </a><a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Rating.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false,
            'multiOptions' => array(
                '4+' => '4+',
                '9+' => '9+',
                '12+' => '12+',
                '17+' => '17+'
            ),
        ));
        $this->rating->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        
        $this->addElement('File', 'firebase_google_services', array(
            'label' => 'Google Services File',
            'description' => "This file is required for Push Notifications. Upload the file that you've downloaded while following <a href='https://youtu.be/0PNvUN9YfZY' target='_blank'>video</a> for Project Number.",
        ));
        $this->firebase_google_services->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'contact_details', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="contact_details" class="siteiosapp_form_heading">Contact Details</h3>'),
            'description' => 'Contact information of the person in your organization who should be contacted if the App Review team has any questions or needs additional information.'
        ));
        $this->contact_details->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'first_name', array(
            'label' => 'First Name',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'last_name', array(
            'label' => 'Last Name',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'email_contact_details', array(
            'label' => 'Email',
            'required' => true,
            'allowEmpty' => false,
            'validators' => array(array('EmailAddress', 1)),
            'filters' => array('StringTrim')
        ));

        $this->addElement('Text', 'phone', array(
            'label' => 'Phone Number',
            'required' => true,
            'allowEmpty' => false,
        ));


        $this->addElement('Textarea', 'address', array(
            'label' => 'Address',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'city', array(
            'label' => 'City',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'state', array(
            'label' => 'State',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'zip_code', array(
            'label' => 'Zip Code',
            'required' => true,
            'allowEmpty' => false,
        ));

        //TAKING COUNTRIES OBJECT
        $locale = Zend_Registry::get('Zend_Translate')->getLocale();
        $countries = Zend_Locale::getTranslationList('territory', $locale, 2);
        foreach ($countries as $keys => $tempCountry) {
            $country[$keys] = $tempCountry;
        }
        $this->addElement('Select', 'country', array(
            'label' => 'Country',
            'multiOptions' => $country
        ));

        $this->addElement('Text', 'support_url', array(
            'label' => 'Support URL',
            'description' => "<div class='tooltip_main'>The website support URL you want to provide for users who have questions regarding the app.<span class='tooltip'><span class='tooltiptext'>You can also provide the URL of the contact page of your website. The support URL must lead to actual contact information so that your users can contact you regarding app issues, general feedback, and feature enhancement requests. The URL can specify a localized site.Include the entire URL, including the protocol.</span><a class='admin help' href='javascript:void(0)'target='_blank'></a></span></div>",
            'required' => true,
            'allowEmpty' => false,
        ));
        $this->support_url->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


        $this->addElement('Text', 'marketing_url', array(
            'label' => 'Marketing URL',
            'description' => "<div class='tooltip_main'>The website where users can get more information about the app <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/Url.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a>.<span class='tooltip'><span class='tooltiptext'>The URL can specify a localized site.Include the entire URL, including the protocol.</span><a class='admin help' href='javascript:void(0)'target='_blank'></a></span></div>"
        ));
        $this->marketing_url->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'privacy_url', array(
            'label' => 'Privacy Policy URL',
            'description' => "<div class='tooltip_main'>A URL that links to your company's privacy policy. <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/Url.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a><span class='tooltip'><span class='tooltiptext'>Privacy policy URLs are required for all apps that offer auto-renewable or free subscriptions and for apps that are set to Made for Kids. Customers see this URL on their invoice and on the subscription confirmation email they receive</span><a class='admin help' href='javascript:void(0)'target='_blank'></a></span></div>"
        ));
        $this->privacy_url->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'copyright', array(
            'label' => 'Copyright',
            'description' => "The name of the person or entity that owns the exclusive rights to the app, preceded by the year the rights were obtained (for example, 2014 Example, Inc.). The copyright symbol is added automatically. <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/Url.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a>",
            'required' => true,
            'allowEmpty' => false,
        ));
        $this->copyright->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'app_default_settings', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_default_settings" class="siteiosapp_form_heading">Default App Settings</h3>'),
        ));
        $this->app_default_settings->getDecorator('Label')->setOptions(array('escape' => false));
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $url = $view->url(array('module' => 'siteapi', 'controller' => 'settings'), 'admin_default', true);
        $this->addElement('Radio', 'siteapi_validate_ssl', array(
            'label' => 'Protocol Selection',
            'description' => '<div class="tooltip_main">It is suggested to run your website on https.<span class="tooltip"><span class="tooltiptext">If you are still working to run your website on https then you should wait to send us mobile application request until site run on https.<a href="' . $url . '#siteapi_ssl_verification" target="_blank"> Read More..</a></span><a class="admin help" href="void(0)" target="_blank"></a></span></div>',
            'multiOptions' => array(
                0 => 'Http',
                1 => 'Https'
            ),
            'required' => true,
            'allowEmpty' => false
        ));
        $this->siteapi_validate_ssl->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $consumerCalling = $view->url(array('module' => 'siteapi', 'controller' => 'consumers', 'action' => 'manage'), 'admin_default', true);
        $this->addElement('Dummy', 'api_key', array(
            'label' => 'API Keys',
            'description' => '<a href="' . $consumerCalling . '" target="_blank">Create</a> and Enter API Consumer key and Consumer Secret. This is required for communication between your server and mobile apps.<span class="tooltip">',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->api_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'api_consumer_key', array(
            'placeholder' => 'API Consumer Key',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->api_consumer_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'api_consumer_secret', array(
            'placeholder' => 'API Consumer Secret',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->api_consumer_secret->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $mapGuidelines = $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'map-guidelines'), 'admin_default', true);
        $this->addElement('Text', 'map_key', array(
            'label' => 'Google Places API Key',
            'description' => '<div class="tooltip_main">This is used for location features like Check-in etc. in the app. Please visit the <a href="' . $mapGuidelines . '" target="_blank">Guidelines</a> for configuring Google Places API key.<span class="tooltip"><span class="tooltiptext">We recommend you to enable the billing feature for this API calling as google allow free usage only up to a certain limit, after which it does not give the required response resulting in blank pages. <a href="https://support.google.com/cloud/answer/6158867" target="_blank"> Read More..</a></span><a class="admin help" href="void(0)"></a></span></div>',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.google.map.key')
        ));
        $this->map_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        // Giphy integration api key work
        $this->addElement('Text', "giphy_api_key", array(
            'label' => 'GIPHY API Key',
            'description' => "Enter the GIPHY API key. [Note: You can create GIPHY API Key from <a target='_blank' href='https://developers.giphy.com/dashboard/?create=true'>here</a>. If you already have the key, then simply get it from <a target='_blank' href='https://developers.giphy.com/dashboard'>here</a>.]",
            'allowEmpty' => false,
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegifplayer.giphy.apikey', ''),
        ));

        $this->giphy_api_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'screenshot_modules', array(
            'label' => 'Modules Name for the screenshots:',
            'placeholder' => 'Ex. Blogs, Videos, Groups etc',
            'description' => 'Provide module names which are important and most active on your network, for which we need to upload screenshots in App Store. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/modules.jpg" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a> <br>',
        ));
        $this->screenshot_modules->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('cometchat')) {
            $this->addElement('Hidden', 'commit_chat_package', array(
                'label' => 'CometChat Package Name',
                'description' => 'Enter the package name of your CometChat. If you are not having it then please contact to the CometChat team. [Note: To integrate your CometChat app with your SocialEngine app, you should have your CometChat app already built and published on iTunes.]'
            ));
        }

        $this->addElement('Radio', 'paid_subscription', array(
            'label' => 'Enable Paid Subscription ?',
            'description' => "<div class='tooltip_main'>Do you want to enable Paid Subscription plans in your mobile app ? <span class='tooltip'><span class='tooltiptext'>Note: This can be enabled only if Paid Subscription plan is enabled on your website. To enable it in app, please request a agreement from <a href='https://itunesconnect.apple.com/WebObjects/iTunesConnect.woa/da/jumpTo?page=contracts'>here</a>.</span><a class='admin help' href = ''></a></span></div>",
            'multiOptions' => array(
                1 => "Yes",
                0 => "No"
            ),
            'value' => 0
        ));
        $this->paid_subscription->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('primemessenger')) {
            $validateMessengerSubscription = $this->validateMessengerSubscription();
            if ($validateMessengerSubscription) {
                $this->addElement('Radio', 'enable_primemessenger', array(
                    'description' => 'Enable Prime Messenger for the App?',
                    'label' => 'Display Messenger',
                    'multiOptions' => array(
                        1 => "Yes",
                        0 => "No"
                    ),
                    'value' => 1
                ));
                $this->enable_primemessenger->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

                $this->addElement('Radio', 'channelize_version', array(
                    'description' => 'Do you want to create the app from which version?',
                    'label' => 'Channelize Version',
                    'multiOptions' => array(
                        0 => "v1",
                        1 => "v2"
                    ),
                    'value' => 1
                ));
                $this->channelize_version->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
            }
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('music')) {
            $this->addElement('Radio', 'enable_background_service', array(
                'label' => 'Music Play in Background',
                'description' => "<div class='tooltip_main'>For the Music Plugin’s features in the app, when users play a music playlist and browse to other parts of your app, or browse to other apps, then do you want that music to be played in the background? <span class='tooltip'><span class='tooltiptext'>If you select “Yes”, then your iOS App could be reject at the time of first submission, with Apple demanding explanation for requirement of music playing in background. So, we recommend that you choose “No” for first time submission of the app, and can choose “Yes” for next app upgrade release.</span><a class='admin help' href = ''></a></span></div>",
                'multiOptions' => array(
                    1 => "Yes",
                    0 => "No"
                ),
                'value' => 0
            ));
            $this->getElement('enable_background_service')->getDecorator('Description')->setEscape(false);
        }

        $onlySearch = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/header_search.png" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>';
        $appname = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/header_app.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>';
        $this->addElement('Radio', 'isshow_app_name', array(
            'label' => 'Header UI in app',
            'escape' => false,
            'multiOptions' => array(
                0 => 'Display only the Search Bar in the complete app header ' . $onlySearch,
                1 => 'App Name in the header with search icon ' . $appname
            ),
            'value' => 0
        ));

        $this->addElement('Radio', 'showcase_app', array(
            'label' => 'Allow Showcasing Apps ?',
            'description' => "Do you want to allow us to showcase your app on our SocialApps.tech website, like blog posts and newsletters.",
            'multiOptions' => array(
                1 => "Yes",
                0 => "No"
            ),
            'value' => 0
        ));
        $this->showcase_app->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'social_website_details', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="social_website_details" class="siteiosapp_form_heading">Social Login and Share</h3>'),
        ));
        $this->social_website_details->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'facebook_app_id', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_facebookLogin.tpl',
                        'class' => 'form element'
                    )))
        ));

        $isSocialLoginEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelogin');
        if ($isSocialLoginEnabled) {
            $this->addElement('Text', 'google_app_id', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_googleLogin.tpl',
                            'class' => 'form element'
                        )))
            ));
        }

        $this->addElement('Text', 'apple_app_id', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_appleLogin.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'facebook_access_permission', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_facebookAccessPermission.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'facebook_app_display_name', array(
            'label' => 'Facebook App Name',
            'description' => 'Find it from <a href="https://developers.facebook.com" target="_blank"> Developer Account </a> > My Apps > Settings <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/facebook_dispay_name.png" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>'
        ));
        $this->facebook_app_display_name->getDecorator('description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        
        $enableLivestreamingModule = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('livestreamingvideo');
       if($enableLivestreamingModule)
       {
            $this->addElement('Dummy', 'live_broadcast_settings', array(
                        'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="live_broadcast_settings" class="siteiosapp_form_heading">Live Broadcast Settings</h3><span style="font-weight: bold;">'),
                    ));

            $this->live_broadcast_settings->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('Radio', 'enable_broadcast', array(
                'description' => 'Do you want to integrate live broadcasting?',
                'multiOptions' => array(
                    "1" => "Yes",
                    "0" => "No"
                ),
                'value' => 0,
                'label' => "Integrate Live Broadcasting?",
                 'onchange' => 'liveBroadcast()'
            ));

            $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
            $URL = $view->url(array('module' => 'livestreamingvideo', 'controller' => 'settings', 'action' => 'index'), 'admin_default', true);
            $description = sprintf(Zend_Registry::get('Zend_Translate')->_('Please enter the agora id at %1sGlobal Settings%2s of Live Broadcasting Plugin.'), "<a href='" . $URL . "' target='_blank'>", "</a>");
            
            $this->addElement('Text', 'agora_app_id', array(
                'label' => "Enter Agora Project ID?",
                'description' =>  $description,
                'attribs'    => array('readonly' => true)
            ));
            
            $this->getElement('agora_app_id')->getDecorator('Description')->setEscape(false);

            $url_description = sprintf(Zend_Registry::get('Zend_Translate')->_('Please enter the agora server url at %1sGlobal Settings%2s of Live Broadcasting Plugin.'), "<a href='" . $URL . "' target='_blank'>", "</a>");

            $this->addElement('Text', 'live_stream_url', array(
                'label' => "Agora Server URL?",
                'description' => $url_description,
                'attribs'    => array('readonly' => true)
            ));

            $this->live_stream_url->getDecorator('Description')->setOption('escape', false);

       }
        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    public function tabTwoForm($subTab) {
        if ($subTab == 1) {
            $this->addElement('Dummy', 'app_color_code', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_color_code" class="siteiosapp_form_heading">App Branding Colors</h3>'),
            ));
            $this->app_color_code->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('Text', 'app_header_color', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeHeaderColor.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Text', 'navigation_text_color', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeNavigationTextColor.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Text', 'button_color', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeButtonColor.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Dummy', 'graphic_assets', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="graphic_assets" class="siteiosapp_form_heading">Graphic Assets</h3><br />'),
                'description' => 'You can <a href="https://www.socialengineaddons.com/sites/default/files/Sample_Graphics_Assets_iOS_App.rar">download</a> sample Graphic Assets for your reference. You can also purchase our "Building Graphic Assets for Mobile Apps" <a href="http://www.socialengineaddons.com/services/building-graphic-assets-ios-ios-mobile-apps" target="_blank"> service</a> if you want us to create all graphics for your iOS and Android Apps.'
            ));
            $this->graphic_assets->getDecorator('Label')->setOptions(array('escape' => false));
            $this->graphic_assets->getDecorator('Description')->setOptions(array('escape' => false));

            $this->addElement('Text', 'normal_font', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("Font-Style for Normal Text"),
                'description' => 'Click <a href="http://iosfonts.com/" target="_blank"> here</a> to get font name.',
                'required' => true,
                'allowEmpty' => false,
                'value' => 'Helvetica Neue'
            ));
            $this->normal_font->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Text', 'bold_font', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("Font-Style for Bold Text"),
                'description' => 'Click<a href="http://iosfonts.com/" target="_blank"> here</a> to get font name.',
                'required' => true,
                'allowEmpty' => false,
                'value' => 'Arial-BoldMT'
            ));
            $this->bold_font->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Radio', 'image_upload_type', array(
                'label' => 'Graphics Upload and Resizing Process:',
                'description' => 'Change Description: This setting is useful for the next steps in the form. “Automatic” option is suggested where you need to upload just few images of maximum size and system will resize them to required sizes and upload in the form.',
                'multiOptions' => array(
                    1 => 'Automatic',
                    0 => 'Manual'
                ),
                'value' => 1,
            ));
            $this->image_upload_type->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
            $this->addElement('Button', 'submit', array(
                'label' => 'Save Changes and Continue',
                'type' => 'submit',
                'ignore' => true,
            ));
        } elseif ($subTab == 2) {
            $this->addElement('Dummy', 'app_icon', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_icon" class="siteiosapp_form_heading">App Icons</h3>'),
            ));
            $this->app_icon->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('File', 'large_app_icon', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('PNG in 1024 x 1024 px.'),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'notification_icon_large', array(
                'label' => 'PNG in 512 x 512 px (Transparent)',
                'description' => 'Icon should be of white color with transparent background.',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
                $this->addElement('File', 'app_icon_21', array(
                    'label' => 'PNG in 20 x 20 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_1', array(
                    'label' => 'PNG in 29 x 29 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_2', array(
                    'label' => 'PNG in 40 x 40 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_3', array(
                    'label' => 'PNG in 50 x 50 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_4', array(
                    'label' => 'PNG in 57 x 57 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_5', array(
                    'label' => 'PNG in 58 x 58 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_6', array(
                    'label' => 'PNG in 60 x 60 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_7', array(
                    'label' => 'PNG in 72 x 72 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_8', array(
                    'label' => 'PNG in 76 x 76 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_9', array(
                    'label' => 'PNG in 80 x 80 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_16', array(
                    'label' => 'PNG in 87 x 87 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_10', array(
                    'label' => 'PNG in 100 x 100 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_11', array(
                    'label' => 'PNG in 114 x 114 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_12', array(
                    'label' => 'PNG in 120 x 120 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_13', array(
                    'label' => 'PNG in 144 x 144 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_14', array(
                    'label' => 'PNG in 152 x 152 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_17', array(
                    'label' => 'PNG in 167 x 167 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_15', array(
                    'label' => 'PNG in 180 x 180 px ',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));
            }

            $this->addElement('Dummy', 'splash_screen', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="splash_screen" class="siteiosapp_form_heading">Splash Screen Images - Type</h3>'),));
            $this->splash_screen->getDecorator('Label')->setOptions(array('escape' => false));

            $png = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Splash.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>';
            $gif = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Splash.gif" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>';
            $this->addElement('Radio', 'welcome_image_type', array(
                'label' => 'Splash Screen Image Type',
                'description' => ' Choose the type of image you want to show in your app on App Launch.',
                'escape' => false,
                'multiOptions' => array(
                    1 => 'PNG ' . $png,
                    0 => 'GIF ' . $gif
                ),
                'value' => 1,
                'onchange' => 'welcomeImageTypeChange()'
            ));
            $this->welcome_image_type->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Text', 'animation_time', array(
                'label' => 'Animation Time of GIF (in seconds)',
                'description' => 'Enter the GIF Image Animation Time. Suggested time for animation is "4-5 seconds"',
                'value' => 4,
            ));


            $this->addElement('Dummy', 'splash_screen_portrait', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="splash_screen_portrait" class="siteiosapp_form_heading">Splash Screen Images - Portrait</h3>'),
                'description' => Zend_Registry::get('Zend_Translate')->_('This image is displayed as a first screen on the app launch.'),
            ));
            $this->splash_screen_portrait->getDecorator('Label')->setOptions(array('escape' => false));
            $this->splash_screen_portrait->getDecorator('Description')->setOptions(array('escape' => false));

            $this->addElement('File', 'splash_portrait_2', array(
                'label' => ' in 640 x 960 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_3', array(
                'label' => ' in 640 x 1136 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_4', array(
                'label' => ' in 768 x 1024 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_6', array(
                'label' => ' in 750 x 1334 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_7', array(
                'label' => ' in 1242 x 2208 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_8', array(
                'label' => ' in 1125 x 2436 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_9', array(
                'label' => ' in 1242 x 2688 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_10', array(
                'label' => ' in 1170 x 2532 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_11', array(
                'label' => ' in 828 x 1792 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_12', array(
                'label' => ' in 1284 x 2778 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
            $this->addElement('File', 'splash_portrait_13', array(
                'label' => ' in 1080 x 2340 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('Button', 'submit', array(
                'label' => 'Save Changes and Continue',
                'type' => 'submit',
                'ignore' => true,
            ));
        } elseif ($subTab == 3) {
            $this->tabFourForm();
        }
    }

    public function tabThreeForm() {
        $this->addElement('Dummy', 'app_layout', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h2>App Dashboard Selection</h2><br>'),
            'description' => Zend_Registry::get('Zend_Translate')->_('1st and 5th Menus of Tab Bar are fixed and you can choose the rest of the menus and their images to display in Tab Bar. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Tabs.png" target="_blank">Click </a>here for reference. You can use default images / upload your own images / upload from <a target="_blank" class="mleft5" title="View Screenshot" href="https://icons8.com/web-app/new-icons/all" target="_blank">here </a>for the Tab Bar Menus.'),
        ));
        $this->app_layout->getDecorator('Description')->setOptions(array('escape' => false));
        $this->app_layout->getDecorator('Label')->setOptions(array('escape' => false));


        $this->addElement('Radio', 'default_dashboard', array(
            'label' => 'Use Default Menus and Images',
            'description' => '2nd, 3rd and 4th Tab Bar default Menus and Images are for Friend Requests, Messages and Notifications. Do you want to use the default menus ?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => 1,
            'onChange' => 'showDashboardOptions()'
        ));
        $this->default_dashboard->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


        $this->addElement('Hidden', 'app_dashboard_menu_setting', array(
            'label' => 'App Dashboard',
            'description' => 'Two types of Dashboards are available in iOS mobile app. Drawable Dashboard <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Drawable_Menu.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a> and Tab Bar <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Tab_Bar_Dashboard.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>. Choose one of your choice for your iOS app.',
            'multiOptions' => array(
                1 => 'Tab bar Menu'
            ),
            'value' => 1,
        ));

        $menusTable = Engine_Api::_()->getDbtable('menus', 'siteiosapp');
        $select1 = $menusTable->select()
                ->from($menusTable->info('name'), array('menu_id', 'name', 'dashboard_label', 'url'))
                ->where("name is not null")
                ->where("module is not null")
                ->where("status = ?", 1);

        $select2 = $menusTable->select()
                ->from($menusTable->info('name'), array('menu_id', 'name', 'dashboard_label', 'url'))
                ->where("LENGTH(url) > 1")
                ->where("name is null")
                ->where("module is null")
                ->where("status = ?", 1);

        $select = $menusTable->select()
                ->union(array($select1, $select2));

        $result = $select->query()->fetchALL();

        $tabsMultiOptions = array();

        // Filter the extensions and add into array
        $blockedMenus = array();
        $blockedMenus[] = "home";
        $blockedMenus[] = "core_main_global_search";
        $blockedMenus[] = "com.secometchat.app";
        $blockedMenus[] = "signout";

        foreach ($result as $row => $value) {
            if ($value['name'] == 'core_mini_friend_request')
                $secondControllerMenuId = $value['menu_id'];

            if ($value['name'] == 'core_mini_messages')
                $thirdControllerMenuId = $value['menu_id'];

            if ($value['name'] == 'core_mini_notification')
                $fourthControllerMenuId = $value['menu_id'];

            if (in_array($value['name'], $blockedMenus))
                continue;

            $tabsMultiOptions[$value['menu_id']] = $value['dashboard_label'];
        }

        // Set array for view and browse layout for sitereview
        $viewArray = array();
        $viewArray[1] = "Blog View";
        $viewArray[2] = "Classified 1 View";
        $viewArray[3] = "Classified 2 View";

        $browseArray = array();
        $browseArray[1] = "List View";
        $browseArray[2] = "Grid View";
        $browseArray[3] = "Matrix View";

        // (ends) Set array for view and browse layout for sitereview
        $this->addElement('Dummy', 'secondController_dummy', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="secondController_dummy" class="siteiosapp_form_heading">Second Tab Menu</h3>')));
        $this->secondController_dummy->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Select', 'secondController', array(
            'label' => 'Second tab menu',
            'description' => "Select the menu which will be shown as the Second tab in iOS tab bar.",
            'multiOptions' => $tabsMultiOptions,
            'value' => $secondControllerMenuId,
            'onchange' => 'listingTypeChanges()',
        ));

        $this->addElement('Hidden', 'secondControllermenuname', array(
            'value' => 'user',
            'order' => 111111,
        ));

        $this->addElement('Hidden', 'secondControllerUrl', array(
            'value' => 'user',
            'order' => 222222,
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'secondControllerImage1', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 18 x 18 px"),
                'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'secondControllerImage2', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 36 x 36 px"),
                'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }

        $this->addElement('File', 'secondControllerImage3', array(
            'label' => Zend_Registry::get('Zend_Translate')->_("PNG in Icon 54 x 54p px"),
            'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));


        $secondControllerImageDefaultFilePath = Zend_Registry::get('Zend_View')->layout()->staticBaseUrl . 'application/modules/Siteiosapp/externals/images/second.png';

        $thirdControllerImageDefaultFilePath = Zend_Registry::get('Zend_View')->layout()->staticBaseUrl . 'application/modules/Siteiosapp/externals/images/third.png';

        $fourthControllerImageDefaultFilePath = Zend_Registry::get('Zend_View')->layout()->staticBaseUrl . 'application/modules/Siteiosapp/externals/images/fourth.png';

        $this->addElement('Select', 'globalViewType', array(
            'label' => 'Profile View Type for second tab',
            'description' => "Select the profile page view type of this listing",
            'multiOptions' => $viewArray,
        ));

        $this->addElement('Select', 'globalBrowseType', array(
            'label' => 'Listing Browse Type for second tab',
            'description' => "Select the browse type of the Listing",
            'multiOptions' => $browseArray,
        ));

        $this->addElement('Dummy', 'thirdController_dummy', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="thirdController_dummy" class="siteiosapp_form_heading">Third Tab Menu</h3>'),
        ));
        $this->thirdController_dummy->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Select', 'thirdController', array(
            'label' => 'Third tab menu',
            'description' => "Select the menu which will be shown as the Third tab in iOS tab bar",
            'multiOptions' => $tabsMultiOptions,
            'value' => $thirdControllerMenuId,
            'onchange' => 'listingTypeChanges()',
        ));

        $this->addElement('Hidden', 'thirdControllermenuname', array(
            'value' => 'messages',
            'order' => 333333,
        ));

        $this->addElement('Hidden', 'thirdControllerUrl', array(
            'value' => 'messages',
            'order' => 444444,
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'thirdControllerImage1', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 18 x 18 px"),
                'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'thirdControllerImage2', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 36 x 36 px"),
                'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }

        $this->addElement('File', 'thirdControllerImage3', array(
            'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 54 x 54 px"),
            'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Select', 'globalViewType1', array(
            'label' => 'Profile View Type for third tab',
            'description' => "Select the profile page view type of this listing",
            'multiOptions' => $viewArray,
        ));

        $this->addElement('Select', 'globalBrowseType1', array(
            'label' => 'Listing Browse Type for third tab',
            'description' => "Select the browse type of the Listing",
            'multiOptions' => $browseArray,
        ));

        $this->addElement('Dummy', 'fourthController_dummy', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="fourthController_dummy" class="siteiosapp_form_heading">Fourth Tab Menu</h3>'),
        ));
        $this->fourthController_dummy->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Select', 'fourthController', array(
            'label' => 'Fourth tab menu',
            'description' => "Select the menu which will be shown as the Fourth tab in ios tab bar",
            'multiOptions' => $tabsMultiOptions,
            'value' => $fourthControllerMenuId,
            'onchange' => 'listingTypeChanges()',
        ));

        $this->addElement('Hidden', 'fourthControllermenuname', array(
            'value' => 'activity',
            'order' => 555555,
        ));

        $this->addElement('Hidden', 'fourthControllerUrl', array(
            'value' => 'activity',
            'order' => 666666,
        ));
        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'fourthControllerImage1', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 18 x 18 px"),
                'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'fourthControllerImage2', array(
                'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 36 x 36 px"),
                'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }
        $this->addElement('File', 'fourthControllerImage3', array(
            'label' => Zend_Registry::get('Zend_Translate')->_("PNG in 54 x 54 px"),
            'Description' => Zend_Registry::get('Zend_Translate')->_(" Upload the icon which we need to show in the tab "),
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Select', 'globalViewType2', array(
            'label' => 'Profile View Type for fourth tab',
            'description' => "Select the profile page view type of this listing",
            'multiOptions' => $viewArray,
        ));

        $this->addElement('Select', 'globalBrowseType2', array(
            'label' => 'Listing Browse Type for fourth tab',
            'description' => "Select the browse type of the Listing",
            'multiOptions' => $browseArray,
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    public function tabFourForm() {
        $this->_appBuilderParams = Engine_Api::_()->getApi('core', 'siteiosapp')->getSettingsFile();
        $background = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/social.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>';
        $plain = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/slideshow_type.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>';
        $this->addElement('Radio', 'slide_show_type', array(
            'label' => 'Slideshow Type',
            'multiOptions' => array(
                1 => 'With Background Images ' . $background,
                0 => 'With Plain Background ' . $plain,
            ),
            'escape' => false,
            'value' => 1,
            'onchange' => 'slideshowType()'
        ));
        $this->slide_show_type->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'app_button_color', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_appButtonColor.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Dummy', 'slideshow_first_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_first_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - First Slide</h3>'),
        ));
        $this->slideshow_first_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_1', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_1.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_1', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_1.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_1_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_1_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_1', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_second_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_second_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Second Slide</h3>'),
        ));
        $this->slideshow_second_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_2', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_2.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_2', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_2.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_2_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_2_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_2', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_third_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_third_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Third Slide</h3>'),
        ));
        $this->slideshow_third_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_3', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_3.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_3', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_3.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_3_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_3_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_3', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_four_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_four_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Fourth Slide</h3>'),
        ));
        $this->slideshow_four_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_4', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_4.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_4', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_4.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_4_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_4_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_4', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_five_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_five_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Fifth Slide</h3>'),
        ));
        $this->slideshow_five_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_5', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_5.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_5', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_5.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_5_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_5_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_5', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_six_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_six_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Sixth Slide</h3>'),
        ));
        $this->slideshow_six_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_6', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_6.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_6', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_6.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_6_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_6_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_6', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_seven_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_seven_plain_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Seventh Slide</h3>')));
        $this->slideshow_seven_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_7', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_7.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_7', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_7.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_7_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_7_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_7', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_first_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_first_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - First Slide</h3>'),
            'description' => 'Introductory slideshow images are the ones displayed on the welcome screen. At least one slideshow image is mandatory.<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteiosapp/externals/images/Slideshow.PNG" target="_blank"><img src="application/modules/Siteiosapp/externals/images/eye.png" /></a>',
        ));
        $this->slideshow_first_slide->getDecorator('Label')->setOptions(array('escape' => false));
        $this->slideshow_first_slide->getDecorator('Description')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_slide_1_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_1_description', array(
            'label' => 'Description',
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'slideshow_slide_image_1_1', array(
                'label' => 'PNG in 640 x 1136 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'slideshow_slide_image_1_2', array(
                'label' => 'PNG in 750 x 1334 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }

        $this->addElement('File', 'slideshow_slide_image_1_3', array(
            'label' => 'PNG in 1242 x 2208 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        
        $this->addElement('Dummy', 'slideshow_second_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_second_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Second Slide</h3>'),
        ));
        $this->slideshow_second_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_slide_2_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_2_description', array(
            'label' => 'Description',
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'slideshow_slide_image_2_1', array(
                'label' => 'PNG in 640 x 1136 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'slideshow_slide_image_2_2', array(
                'label' => 'PNG in 750 x 1334 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }

        $this->addElement('File', 'slideshow_slide_image_2_3', array(
            'label' => 'PNG in 1242 x 2208 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));


        $this->addElement('Dummy', 'slideshow_third_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_third_slide" class="siteiosapp_form_heading">Introductory Slideshow Details - Third Slide</h3>'),
        ));
        $this->slideshow_third_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_slide_3_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_3_description', array(
            'label' => 'Description',
        ));


        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'slideshow_slide_image_2_1', array(
                'label' => 'PNG in 640 x 1136 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'slideshow_slide_image_2_2', array(
                'label' => 'PNG in 750 x 1334 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }

        $this->addElement('File', 'slideshow_slide_image_2_3', array(
            'label' => 'PNG in 1242 x 2208 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));
        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
            $this->addElement('File', 'slideshow_slide_image_3_1', array(
                'label' => 'PNG in 640 x 1136 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'slideshow_slide_image_3_2', array(
                'label' => 'PNG in 750 x 1334 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        }

        $this->addElement('File', 'slideshow_slide_image_3_3', array(
            'label' => 'PNG in 1242 x 2208 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    public function tabFiveForm() {
        // Language File Upload Options
        $this->addElement('Dummy', 'language_assets', array(
            'Label' => Zend_Registry::get('Zend_Translate')->_('<h3>Language Assets [Optional]</h3><br />You can download sample "Language File" for your reference from here: "<a href="http://mobiledemo.socialengineaddons.com/public/admin/Sample_iOS_English_Language.csv">http://mobiledemo.socialengineaddons.com/public/admin/Sample_iOS_English_Language.csv</a>". Below, you can uplaod the language files.<br /><br />'
                    . 'You need to add your changes at right side phrases of CSV file. For example if you want to change "Browse as a Guest" of French csv file then do changes at right side of ";" <br /><br /> '
                    . '<span style="font-weight:bold;">Text before your changes</span><br />'
                    . '&nbsp;&nbsp;&nbsp;"browse_as_guest";"Browse as a Guest"<br /><br />'
                    . '<span style="font-weight:bold;">Text after your changes in French</span><br />'
                    . '&nbsp;&nbsp;&nbsp;"browse_as_guest";"Parcourir en tant qu\'invité"'
                    . '<br /><br /> Note: If you are not uploading any language file here then, English will be default language for your App.'),
        ));
        $this->language_assets->getDecorator('Label')->setOptions(array('escape' => false));


        $getLanguages = Engine_Api::_()->getApi('Core', 'siteapi')->getLanguages(true);
        if (isset($getLanguages)) {

            foreach ($getLanguages as $key => $label) {

                $this->addElement('File', $key, array(
                    'label' => 'Upload Language File For: [' . $label . ']',
                    'validators' => array(
                        array('Extension', false, 'csv')
                    )
                ));
            }
        }
        // Langauge work ends

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    public function tabSixForm() {
        $communityPluginEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('communityad');
        if ($communityPluginEnabled)
            $description = "Please select the type of advertisment you want to enable for your app.In addition to the above selected Ad Type, you will also be able to choose to show “Community Ads” and “Sponsered Stories” in the Ad Placement areas.<a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/Ads.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a>";
        else
            $description = "Please select the type of advertisment you want to enable for your app.<a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/Ads.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a>";
        $this->addElement('Radio', 'adv_type', array(
            'label' => 'Advertisment Type',
            'description' => $description,
            'multiOptions' => array(
                1 => 'Facebook Ads',
            ),
            'value' => 1,
            'onchange' => 'advertismentType()'
        ));
        $this->adv_type->getDecorator('description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'google_ad_placement_id', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_advertismentType.tpl',
                        'class' => 'form element',
                    )))
        ));

        $this->addElement('Text', 'ad_placement_id', array(
            'label' => 'Placement ID',
            'description' => 'Display Facebook Ads in Activity Feeds and Content Browse Pages at desired position in your app and earn revenue from your app.<a href = "https://youtu.be/Y31ZwKIvkNE" target = "_blank"> Create </a>and Enter "Placement ID" from “Add Network” section of your Facebook Developer <a href="https://developers.facebook.com/" target="_blank">account </a>. In order to avoid issues, please disable Videos Ads by following the <a href = "https://youtu.be/ZveBcxK6GU0" target = "_blank">video</a>.'
        ));
        $this->ad_placement_id->getDecorator('description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    public function tabSevenForm() {
        $this->removeElement('required_fields');
        if (!empty($this->_doWeHaveLatestVersion)) {
            // Language File Upload Options
            $this->addElement('Dummy', 'download_text', array(
                'Label' => Zend_Registry::get('Zend_Translate')->_('<div class="seaocore_tip"><span><p>You do not have the latest version of the above listed plugins, Please upgrade all listed modules to the latest version to enable its integration with iOS Mobile Application.</p></span></div><br />'),
            ));
            $this->download_text->getDecorator('Label')->setOptions(array('escape' => false));
        } else {
            // Language File Upload Options
            $this->addElement('Dummy', 'download_text', array(
                'Label' => Zend_Registry::get('Zend_Translate')->_('<h3>Download Tar File</h3><p>
                Before downloading this file, please ensure that you have filled all the App Submission Details correctly. This tar file contains all the details required for building your iOS App.
            </p><br />'),
            ));
            $this->download_text->getDecorator('Label')->setOptions(array('escape' => false));
        }

        $getWebsiteName = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));
        $websiteStr = str_replace(".", "-", $getWebsiteName);
        if (empty($this->_doWeHaveLatestVersion) && is_dir(APPLICATION_PATH . DIRECTORY_SEPARATOR . 'public/' . 'ios-' . $websiteStr . '-app-builder')) {

            $this->addElement('Text', 'ios_app_rejection_confirmation', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_rejectionConfirmation.tpl',
                            'class' => 'form element'
                        )))
            ));

            // Element: Download TAR
            $this->addElement('Cancel', 'download_tar', array(
                'label' => 'Download tar',
                'type' => 'cancel',
                'ignore' => true,
                'onclick' => 'Smoothbox.open("' . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'download')) . '")',
                'decorators' => array('ViewHelper'),
            ));
        }
    }

    public function tabEightForm() {
        $this->addElement('Dummy', 'people_suggestion', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3>People You May Know Suggestions</h3>'),
        ));
        $this->people_suggestion->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Radio', 'display_suggestion', array(
            'label' => 'Friends Suggestions',
            'description' => "Do you want to display ‘People You May Know’ suggestions in activity feed? <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteiosapp/externals/images/PeopleSuggestions.PNG' target='_blank'><img src='application/modules/Siteiosapp/externals/images/eye.png' /></a>",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => 1,
        ));
        $this->display_suggestion->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'suggestion_placement', array(
            'label' => 'Placement of Suggestions Block',
            'description' => "After how many feeds you want to show people you may know suggestion ? <div class='tooltip'><span class='tooltiptext'>Note: This Placement count and Advertisement Placement should not be same, otherwise only one of them will be visible in Activity Feed. Make sure that its not N, as you have set this position for ads as well.</span></div>",
            'value' => 5,
        ));
        $this->suggestion_placement->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'suggestion_count', array(
            'label' => 'Number of Suggestions',
            'description' => "How many suggestions you want to display in Activity Feed in the suggestions block?",
            'value' => 3,
        ));
        $this->suggestion_count->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    protected function validateMessengerSubscription() {
        $apiURL = 'http://channelize.io/rest/V1/api/hasMobileApps';
        $website = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));

        $apiKey = Engine_Api::_()->getApi('settings', 'core')->getSetting('primemessenger.apikey', '');
       
        if (empty($apiKey))
            return false;

        //Todo -: Get Ref Id from Prime messenger plugin and call isactive function 
        $tempAdminMenuPost = array(
            'key' => base64_encode($apiKey)
        );

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $apiURL);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 0);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $tempAdminMenuPost);
        ob_start();
        curl_exec($ch);
        curl_close($ch);
        $getCurlResponse = ob_get_contents();
        ob_end_clean();

        if (strstr($getCurlResponse, 'error::'))
            return false;

        return $getCurlResponse;
    }

}
