<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitelazyload
 * @copyright  Copyright 2018-2019 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: ItemPhoto.php 2018-12-05 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitelazyload_View_Helper_ItemPhoto extends Engine_View_Helper_HtmlImage
{

  protected $_noPhotos;
  protected $_classPrefix = '';
  protected $_url;
  protected $_attribs = array();
  protected $_placeholder = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsQAAA7EAZUrDhsAAAANSURBVBhXYzh8+PB/AAffA0nNPuCLAAAAAElFTkSuQmCC';

  public function itemPhoto($item, $type = 'thumb.profile', $alt = "", $attribs = array())
  {
    return $this->setAttributes($item, $type, $attribs)->htmlImage($this->_url, $alt, $this->_attribs);
  }

  public function setAttributes($item, $type = 'thumb.profile', $attribs = array())
  {
    if( !($item instanceof Core_Model_Item_Abstract) ) {
      throw new Zend_View_Exception("Item must be a valid item");
    }

    // Get url
    $src = $item->getPhotoUrl($type);
    $safeName = ( $type ? str_replace('.', '_', $type) : 'main' );
    $attribs['class'] = ( isset($attribs['class']) ? $attribs['class'] . ' ' : '' );
    if (empty($attribs['nolazy'])) {
      $attribs['class'] .= '_site_lazyload _site_lazyload_init' . ' ';
      if ($this->getTestMode()) {
        $attribs['class'] .= '_site_lazyload_testmode' . ' ';
      }
      $attribs['data-was-processed'] = 'false';
    }
    $attribs['class'] .= $this->_classPrefix . $safeName . ' ';
    $attribs['class'] .= $this->_classPrefix . 'item_photo_' . $item->getType() . ' ';

    // Default image
    if( !$src ) {
      $src = $this->getNoPhoto($item, $safeName);
      $attribs['class'] .= $this->_classPrefix . 'item_nophoto ';
    }
    if (empty($attribs['nolazy'])) {
      $this->_url = $this->_placeholder;
      $attribs['data-src'] = $src;
      $attribs['data-safe-src'] = $src;
    } else {
      $this->_url = $src;
      unset($attribs['nolazy']);
    }
    $this->_attribs = $attribs;
    return $this;
  }

  public function getNoPhoto($item, $type)
  {
    $type = ( $type ? str_replace('.', '_', $type) : 'main' );

    if( ($item instanceof Core_Model_Item_Abstract ) ) {
      $item = $item->getType();
    } else if( !is_string($item) ) {
      return '';
    }

    if( !Engine_Api::_()->hasItemType($item) ) {
      return '';
    }

    // Load from registry
    if( null === $this->_noPhotos ) {
      // Process active themes
      $themesInfo = Zend_Registry::get('Themes');
      foreach( $themesInfo as $themeName => $themeInfo ) {
        if( !empty($themeInfo['nophoto']) ) {
          foreach( (array) $themeInfo['nophoto'] as $itemType => $moreInfo ) {
            if( !is_array($moreInfo) ) {
              continue;
            }
            if( !empty($this->_noPhotos[$itemType]) ) {
              $moreInfo = array_merge((array) $this->_noPhotos[$itemType], $moreInfo);
            }
            $this->_noPhotos[$itemType] = $moreInfo;

          }
        }
      }
    }

    // Use default
    if( !isset($this->_noPhotos[$item][$type]) ) {
      $shortType = $item;
      if( strpos($shortType, '_') !== false ) {
        list($null, $shortType) = explode('_', $shortType, 2);
      }
      $module = Engine_Api::_()->inflect(Engine_Api::_()->getItemModule($item));
      $this->_noPhotos[$item][$type] = //$this->view->baseUrl() . '/' .
        $this->view->layout()->staticBaseUrl . 'application/modules/' .
        $module .
        '/externals/images/nophoto_' .
        $shortType . '_'
        . $type . '.png';
    }

    return $this->_noPhotos[$item][$type];
  }

  public function getTestMode() {
    if (isset($this->_testMode)) {
      return $this->_testMode;
    }

    $settings = Engine_Api::_()->getApi('settings','core');
    $mode = $settings->getSetting('sitelazyload.mode', 'enable');
    if ($mode == 'testmode') {
      $viewer = Engine_Api::_()->user()->getViewer();
      $email = $settings->getSetting('sitelazyload.email');
      if ($viewer && $viewer->getIdentity() && $viewer->email == $email) {
        $this->_testMode = true;
        return $this->_testMode;
      }
    }
    $this->_testMode = false;
    return $this->_testMode;
  }

}
