<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitelinkedin
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Header.php 2019-08-28 15:11:20Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitelinkedin_Form_Admin_Settings_Header extends Engine_Form {

  public function init() {
    $this->setTitle("Manage Header");
    $this->setDescription("Here you can manage settings related to header.");

    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $isSitemenuEnable = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemenu');
    $isStoreproductEnable = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreproduct');

    $imgOptions = Engine_Api::_()->sitelinkedin()->getImages(array('' => 'Text-only (No logo)'));;
    

    $this->addElement('Select', 'sitelinkedin_header_logo_image', array(
      'label' => 'Select Logo',
      'description' => 'Select the logo for your website. [Note: Logo must be uploaded prior from Admin Panel → Appearance → File & Media Manager.]',
      'multiOptions' => $imgOptions,
      'value' => $coreSettings->getSetting('sitelinkedin.header.logo.image', ''),
    ));

    $this->addElement('Select', 'sitelinkedin_header_landing_logo_image', array(
      'label' => 'Select Landing Page Logo',
      'description' => 'Select the landing page logo for your website. [Note: Logo must be uploaded prior from Admin Panel → Appearance → File & Media Manager.]',
      'multiOptions' => $imgOptions,
      'value' => $coreSettings->getSetting('sitelinkedin.header.landing.logo.image', ''),
    ));

    $headerOptions = array(
      'logo' => 'Site Logo',
      'mini_menu' => 'Mini Menu',
      'main_menu' => 'Main Menu ',
      'search_box' => 'Search Box',
    );

    $deafultHeaderOptions = array(
      'logo',
      'mini_menu',
      'main_menu',
      'search_box',
      'sociallink'
    );

    $this->addElement('MultiCheckbox', 'sitelinkedin_header_loggedin_widgets', array(
      'label' => 'Header Elements for Logged In Members',
      'description' => 'Select the elements you want to display in header section for logged in members.',
      'multiOptions' => $headerOptions,
      'value' => $coreSettings->getSetting('sitelinkedin.header.loggedin.widgets', $deafultHeaderOptions),
    ));

    $this->addElement('MultiCheckbox', 'sitelinkedin_header_loggedout_widgets', array(
      'label' => 'Header Elements for Non-Logged In Members',
      'description' => 'Select the options you want to display in header section for non-logged in / guest members. Please note Sign In and Join Now button will show even when you choose to not show Mini Menu.',
      'multiOptions' => $headerOptions,
      'value' => $coreSettings->getSetting('sitelinkedin.header.loggedout.widgets', $deafultHeaderOptions),
    ));

    $this->addElement('MultiCheckbox', 'sitelinkedin_header_landing_widgets', array(
      'label' => 'Header Elements for Landing Page',
      'description' => 'Select the options you want to display in header section for landing page. Please note Sign In and Join Now button will show even when you choose to not show Mini Menu.',
      'multiOptions' => $headerOptions,
      'value' => $coreSettings->getSetting('sitelinkedin.header.landing.widgets', array(
        'logo',
      )),
    ));

    $this->addElement('radio', 'sitelinkedin_header_display_location', array(
      'label' => "Display Location field",
      'description' => "Do you want to enable 'Location' field, using which users can set their default location?",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettings->getSetting('sitelinkedin.header.display.location', 0),
    ));

    if ($isSitemenuEnable) {
      $this->addElement('Radio', 'sitelinkedin_header_sitemainmenu_enable', array(
        'label' => 'Enable Adv. Main Menu',
        'description' => 'Do you want to enable adv. main menu widget?',
        'multiOptions' => array(
          '1' => 'Yes',
          '0' => 'No'
        ),
        'value' => $coreSettings->getSetting('sitelinkedin.header.sitemainmenu.enable', 1),
      ));
      $this->addElement('Radio', 'sitelinkedin_header_siteminimenu_enable', array(
        'label' => 'Enable Adv. Mini Menu',
        'description' => 'Do you want to enable adv. mini menu widget?',
        'multiOptions' => array(
          '1' => 'Yes',
          '0' => 'No'
        ),
        'onchange' => 'sitemenuWidgetOptions()',
        'value' => $coreSettings->getSetting('sitelinkedin.header.siteminimenu.enable', 1),
      ));

      if ($isStoreproductEnable) {
        $this->addElement('radio', 'sitelinkedin_header_display_cart', array(
          'label' => 'Do you want to show cart icon?',
          'description' => '(Note: After enabling this setting, caching of Main Menu will not work on your website.)',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => $coreSettings->getSetting('sitelinkedin.header.display.cart', 1),
        ));
      }
    }
    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }

}
