<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitelinkedin
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: EditColors.php 2019-08-28 15:11:20Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
# Load the libraries. Do it manually if you don't like this way.
include APPLICATION_PATH . '/application/libraries/Scaffold/libraries/Bootstrap.php';
error_reporting(E_ALL);
ini_set('display_errors', true);

class Sitelinkedin_Form_Admin_Themes_EditColors extends Engine_Form {

  protected $_theme;
  protected $_updateMethod;

  public function setTheme($theme) {
    $this->_theme = $theme;
  }

  public function setUpdateMethod($method) {
    $this->_updateMethod = $method;
  }

  public function init() {
    $this
      ->setTitle('Update Color Scheme')
      ->setDescription('Here you can manage color scheme for your website.');
    // Show layout to only logged in users
    $this->addElement('Select', 'sitelinkedin_update_method', array(
      'label' => 'Color Updation Method',
      'description' => "Select the method which you want to use to update color scheme.",
      'multiOptions' => array(
        'single' => 'Update the colors for specific elements solely',
        'group' => 'Update the colors wherever they are being used',
      ),
      'value' => ($this->_updateMethod) ? $this->_updateMethod : 'single',
      'onchange' => 'spwThemeUpdateMethod(this.value)'
    ));

    $this->addElement('Dummy', 'sitelinkedin_header_constants_label', array(
      'label' => 'Heading Color',
    ));
    $this->addElement('Dummy', 'sitelinkedin_footer_constants_label', array(
      'label' => 'Footer Colors',
    ));
    $this->addElement('Dummy', 'sitelinkedin_body_constants_label', array(
      'label' => 'Body Colors',
    ));
    //ADD HERE THE LEBEL REPLACEMENT FOR THE CONSTANTS
    $constantLebels = array('sitelinkedin_body_header_color' => 'Heading Font Color',
      'sitelinkedin_body_font_color_light' => 'Body Font Color Light',
      'sitelinkedin_body_input_background_color' => 'Input Box Background Color',
      'sitelinkedin_body_input_font_color' => 'Input Box Font Color',
      'sitelinkedin_body_input_border_color' => 'Input Box Border Color',
      'sitelinkedin_body_comments_background_color' => 'Comments Box Background Color',
      'sitelinkedin_body_list_background_color' => 'Listview Background Color',
      'sitelinkedin_body_list_background_color_alt' => 'Listview Background Color Alt',
      'sitelinkedin_body_list_background_color_on_hover' => 'Listview Background Color On Hover',
      'sitelinkedin_header_minimenu_items_background_color' => 'Mini Menu Items Background Color',
      'sitelinkedin_header_minimenu_items_background_color_on_hover' => 'Mini Menu Items Background Color On Hover',
    );

    $colors = array();
    $headerConstants = array();
    $footerConstants = array();
    $bodyConstants = array();
    foreach ($this->getColorConstants() as $name => $value) {
      $colors[$value] = $value;
      $constantType = explode('_', $name)[1];
      $labelString = $name;
      if ($constantType == 'header') {
        $headerConstants[] = $name;
        $labelString = str_replace('sitelinkedin_header_', '', $name);
      } else if ($constantType == 'footer') {
        $footerConstants[] = $name;
        $labelString = str_replace('sitelinkedin_footer_', '', $name);
      } else if ($constantType == 'body') {
        $bodyConstants[] = $name;
        $labelString = str_replace('sitelinkedin_body_', '', $name);
      }

      $labelString = ucwords(preg_replace('/[^a-z-0-9]/', ' ', $labelString));
      $labelString = str_replace('Landingpage', 'Landing Page', $labelString);
      $labelString = str_replace('Cta', 'CTA', $labelString);
      if (array_key_exists($name, $constantLebels)) {
        $labelString = $constantLebels[$name];
      }

      $this->addElement('Text', $name, array(
        'label' => ucwords(preg_replace('/[^a-z-0-9]/', ' ', $name)),
        'decorators' => array(array('ViewScript', array(
              'viewScript' => '_formColor.tpl',
              'class' => 'sitelinkedin_constant_color_single_element form element',
              'name' => $name,
              'value' => $value,
              'label' => $labelString,
              'style' => 'width: 24%; display: inline-block; box-sizing: border-box;'
            )))
      ));
    }
    $this->addDisplayGroup(array_merge(array('sitelinkedin_header_constants_label'), $headerConstants), 'sitelinkedin_header_constants');
    $this->addDisplayGroup(array_merge(array('sitelinkedin_footer_constants_label'), $footerConstants), 'sitelinkedin_footer_constants');
    $this->addDisplayGroup(array_merge(array('sitelinkedin_body_constants_label'), $bodyConstants), 'sitelinkedin_body_constants');
    foreach ($colors as $name => $value) {
      $name = 'spwgroupcolor-' . md5($name);
      $this->addElement('Text', $name, array(
        'label' => "Color: " . $value,
        'decorators' => array(array('ViewScript', array(
              'viewScript' => '_formColor.tpl',
              'class' => 'sitelinkedin_constant_color_group_element form element',
              'name' => $name,
              'value' => $value,
              'label' => "Color: " . $value,
              'style' => 'width: 24%; display: inline-block; box-sizing: border-box;'
            )))
      ));
    }
    // Add submit button
    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }

  public function getColorConstants() {
    $path = APPLICATION_PATH . '/application/themes/sitelinkedin/' . $this->_theme . '/colorConstants.css';
    $elements = array();
    if (file_exists($path)) {
      $css = new Scaffold_CSS($path);
      $css->string = '@constants {' . $css->string . '}';
      $found = $css->find_at_group('constants');
      $elements = $found['values'];
    }
    $skipConstants = array(
      'sitelinkedin_body_landingpage_cta_overlay_background_color',
      'sitelinkedin_body_landingpage_cta_list_background_color',
      'sitelinkedin_body_landingpage_cta_list_background_color_hover',
      'sitelinkedin_body_landingpage_cta_list_link_color',
      'sitelinkedin_body_landingpage_video_overlay_background_color',
      'sitelinkedin_body_landingpage_category_link_color',
      'sitelinkedin_body_landingpage_category_link_color_hover',
      'sitelinkedin_body_landingpage_category_background_color',
      'sitelinkedin_body_landingpage_category_background_color_hover',
      'sitelinkedin_body_panel_menu_bg_color',
      'sitelinkedin_body_panel_menu_label_color',
      'sitelinkedin_theme_secondary_color'
    );
    return is_array($elements) ? array_diff_key($elements, array_flip($skipConstants)) : $elements;
  }

}
