<?php

class Sitelivestreaming_Form_Admin_Global extends Engine_Form {

  public function init() {

    $this->setTitle('Global Settings')
          ->setDescription('These settings will affect all members in your community.');

    $settings = Engine_Api::_()->getApi('settings', 'core');
    
    $this->addElement('Text', 'livestreamingvideo_agora_app_id', array(
        'label' => 'Agora App ID',
        'description' => 'Create an <a href="https://www.agora.io/en" target="_blank"> Account on Agora </a> > Create a Project > and you will get Project ID that you need to fill above.',
        'required' => true,
        'value' => $settings->getSetting('livestreamingvideo_agora_app_id', ''),
    ));

    $this->livestreamingvideo_agora_app_id->getDecorator('Description')->setOption('escape', false)->setOption('placement', 'append');

    $this->addElement('Text', 'livestreamingvideo_agora_app_certificate', array(
        'label' => 'Agora App Certificate',
        'description' => 'Enter primary Certificate.',
        'required' => true,
        'value' => $settings->getSetting('livestreamingvideo_agora_app_certificate', ''),
    ));

    $this->livestreamingvideo_agora_app_certificate->getDecorator('Description')->setOption('escape', false)->setOption('placement', 'append');

    $this->addElement('Text', 'livestreamingvideo_url', array(
      'label' => 'Agora Server URL',
      'description' => 'Enter Agora Recording Server URL.<br><b>Note:</b> Agora Url must be with https if your SE website is SSL certified and must end with Slash("/"). For Example, http://localhost:3000/',
      'required' => true,
      'validators' => array(
        array('Regex', true, array('/\/$/')),
      ),
       'value' => $settings->getSetting('livestreamingvideo.url'),
    ));

    $this->livestreamingvideo_url->getValidator('Regex')->setMessage('Url Must end with Slash("/")');
    $this->livestreamingvideo_url->getDecorator('Description')->setOption('escape', false)->setOption('placement', 'append');

    $this->addElement('Radio', 'livestreamingvideo_theme_mode', array(
        'label' => 'Theme Mode',
        'description' => 'Select Theme Mode for this plugin.',
        'multiOptions' => array(
          'dark' => 'Dark Mode',
          'light' => 'Light Mode',
        ),
        'value' => $settings->getSetting('livestreamingvideo.theme.mode', 'dark'),
      ));

    $this->addElement('Radio', 'livestreamingvideo_reactions', array(
        'label' => 'Do you want to use default GIF as reactions for this plugin?',
        'description' => 'Do you want to use default GIF reactions for this plugin for like, love, angry, haha, wow, sad ?',
        'multiOptions' => array(
          1 => 'Yes',
          0 => 'No',
        ),
        'value' => $settings->getSetting('livestreamingvideo.reactions', 1),
    ));

    $this->addElement('File', 'livestreamingvideo_background_photo', array(
        'label' => 'Chat Background Image',
        'description' => 'Choose a background image to be displayed for the chat section. [Note: If you do not upload an image, then the default image will be displayed.]'
      ));

    $this->livestreamingvideo_background_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');

    $fileId = $settings->getSetting('livestreamingvideo.background.photo', 0);
    $photoUrl = Engine_Api::_()->sitelivestreaming()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_photo', array(
          'label' => 'Remove Image.'
      ));
    }

    $this->addElement('File', 'livestreamingvideo_join_photo', array(
        'label' => 'Join Stream Background Image',
        'description' => 'Choose a background image to be displayed on the Join screen. [Note: If you do not upload an image, then the default image will be displayed.]'
      ));

    $this->livestreamingvideo_join_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');

    $joinFileId = $settings->getSetting('livestreamingvideo.join.photo', 0);
    $joinPhotoUrl = Engine_Api::_()->sitelivestreaming()->getPhotoUrl($joinFileId);
    if( $joinPhotoUrl ) {
      $this->addElement('Dummy', 'join_photo_preview', array(
        'description' => '<img src="' . $joinPhotoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->join_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_join_photo', array(
          'label' => 'Remove Image.'
      ));
    }

    // Add submit button
    $this->addElement('Button', 'submit', array(
         'label' => 'Save Changes',
         'type' => 'submit',
         'ignore' => true
     ));
  }
}
?>