<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemagento
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2017-06-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Sitemagento_Api_Core extends Core_Api_Abstract {

    /**
     *
     * @param $title: String which are require for truncate
     * @return string
     */
    public function truncateStr($title, $truncateLimit = 15) {
        $tmpBody = strip_tags($title);
        return ( Engine_String::strlen($tmpBody) > $truncateLimit ? Engine_String::substr($tmpBody, 0, $truncateLimit) . '..' : $tmpBody );
    }

    /**
     * Getting the Magento host name, which configured by siteadmin.
     *
     * @return string
     */
    public function getMagentoHostUrl() {
        $hostType = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemagento.hostType', 'http');
        $host = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemagento.api.host', '');
        if (empty($host)) {
            return '#';
        }
        $host = $hostType . '://' . $host;
        $host = rtrim($host, "/");
        return $host;
    }

    /**
     * Create Magento user in SocialEngine.
     *
     * @param $data: array of the user information, which user need to be create in SocialEngine.
     */
    public function doSignup($data) {
        $info['email'] = $data['email'];
        $info['password'] = $data['password'];
        $info['passconf'] = $data['password'];
        $info['displayname'] = $data['firstname'] . ' ' . $data['lastname'];
        $info['username'] = preg_replace('/[^A-Za-z0-9]/', '', $data['email']);
        $info['profile_type'] = 1; // Admin Given
        $info['timezone'] = 'US/Pacific'; // Admin Given
        $info['language'] = 'en'; // Admin Given
        $info['terms'] = 1;
        $info['local'] = 'en';

        $settings = Engine_Api::_()->getApi('settings', 'core');
        $emailadmin = ($settings->getSetting('user.signup.adminemail', 0) == 1);
        $random = ($settings->getSetting('user.signup.random', 0) == 1);

        $users_table = Engine_Api::_()->getDbtable('users', 'user');
        if ($emailadmin) {
            // the signup notification is emailed to the first SuperAdmin by default
            $users_select = $users_table->select()
                    ->where('level_id = ?', 1)
                    ->where('enabled >= ?', 1);
            $super_admin = $users_table->fetchRow($users_select);
        }

        $user = Engine_Api::_()->getDbtable('users', 'user')->createRow();
        $user->setFromArray($info);
        $user->save();
        Engine_Api::_()->user()->setViewer($user);

        // Increment signup counter
        Engine_Api::_()->getDbtable('statistics', 'core')->increment('user.creations');

        if ($user->verified && $user->enabled) {
            // Create activity for them
            Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($user, $user, 'signup');
            // Set user as logged in if not have to verify email
            Engine_Api::_()->user()->getAuth()->getStorage()->write($user->getIdentity());
        }

        $mailType = null;
        $mailParams = array(
            'host' => $_SERVER['HTTP_HOST'],
            'email' => $user->email,
            'date' => time(),
            'recipient_title' => $user->getTitle(),
            'recipient_link' => $user->getHref(),
            'recipient_photo' => $user->getPhotoUrl('thumb.icon'),
            'object_link' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(), 'user_login', true),
        );

        // Add password to email if necessary
        if ($random) {
            $mailParams['password'] = $data['password'];
        }

        // Mail stuff
        switch ($settings->getSetting('user.signup.verifyemail', 0)) {
            case 0:
                // only override admin setting if random passwords are being created
                if ($random) {
                    $mailType = 'core_welcome_password';
                }
                if ($emailadmin) {
                    $mailAdminType = 'notify_admin_user_signup';

                    $mailAdminParams = array(
                        'host' => $_SERVER['HTTP_HOST'],
                        'email' => $user->email,
                        'date' => date("F j, Y, g:i a"),
                        'recipient_title' => $super_admin->displayname,
                        'object_title' => $user->displayname,
                        'object_link' => $user->getHref(),
                    );
                }
                break;

            case 1:
                // send welcome email
                $mailType = ($random ? 'core_welcome_password' : 'core_welcome');
                if ($emailadmin) {
                    $mailAdminType = 'notify_admin_user_signup';

                    $mailAdminParams = array(
                        'host' => $_SERVER['HTTP_HOST'],
                        'email' => $user->email,
                        'date' => date("F j, Y, g:i a"),
                        'recipient_title' => $super_admin->displayname,
                        'object_title' => $user->getTitle(),
                        'object_link' => $user->getHref(),
                    );
                }
                break;

            case 2:
                // verify email before enabling account
                $verify_table = Engine_Api::_()->getDbtable('verify', 'user');
                $verify_row = $verify_table->createRow();
                $verify_row->user_id = $user->getIdentity();
                $verify_row->code = md5($user->email
                        . $user->creation_date
                        . $settings->getSetting('core.secret', 'staticSalt')
                        . (string) rand(1000000, 9999999));
                $verify_row->date = $user->creation_date;
                $verify_row->save();

                $mailType = ($random ? 'core_verification_password' : 'core_verification');

                $mailParams['object_link'] = Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
                    'action' => 'verify',
                    'email' => $user->email,
                    'verify' => $verify_row->code
                        ), 'user_signup', true);

                if ($emailadmin) {
                    $mailAdminType = 'notify_admin_user_signup';

                    $mailAdminParams = array(
                        'host' => $_SERVER['HTTP_HOST'],
                        'email' => $user->email,
                        'date' => date("F j, Y, g:i a"),
                        'recipient_title' => $super_admin->displayname,
                        'object_title' => $user->getTitle(),
                        'object_link' => $user->getHref(),
                    );
                }
                break;

            default:
                // do nothing
                break;
        }

        if ($mailType) {
            // Moved to User_Plugin_Signup_Fields
            Engine_Api::_()->getApi('mail', 'core')->sendSystem(
                    $user, $mailType, $mailParams
            );
        }

        if ($mailAdminType) {
            // Moved to User_Plugin_Signup_Fields
            Engine_Api::_()->getApi('mail', 'core')->sendSystem(
                    $user, $mailType, $mailParams
            );
        }
    }

    /**
     * Create Magento user in "sitemagento_users" tables.
     * 
     * @param $data: Array of the user informtion, which will create in "sitemagento_users" table.
     */
    public function createUser($data) {
        if (!empty($data['user_id'])) {
            $viewer = Engine_Api::_()->getItem('user', $data['user_id']);
        } else {
            $viewer = Engine_Api::_()->user()->getViewer();
        }

//        $websiteId = Engine_Api::_()->sitemagento()->getWebsite('id');

        $firstName = $data['firstname'];
        $lastName = $data['lastname'];

        $existUesr = Engine_Api::_()->getDbtable("users", "sitemagento")->existUser(array('se_user_id' => $viewer->getIdentity()));

        if (empty($existUesr)) {
            Engine_Api::_()->getDbtable("users", "sitemagento")->setUser(array("mage_user_id" => $data['id'], "se_user_id" => $viewer->getIdentity(), "name" => $firstName . ' ' . $lastName, "enable" => true));
        } else {
            //Engine_Api::_()->getDbtable("users", "siteestore")->update(array("mage_user_id" => $data['id'], "se_user_id" => $viewer->getIdentity(), "name" => $firstName . ' ' . $lastName, "enable" => true), array('se_user_id =?' => $viewer->getIdentity()));
        }

        return;
    }

    public function getProductPrice($product) {
        $price = array('is_special' => false, 'general' => 0, 'special' => 0);
        $is_special = false;
        $special_price = 0;
        $fromDate = '';
        $toDate = '';
        if (isset($product['product']) && !empty($product['product']['special_from_date']) && !empty($product['product']['special_to_date'])) {
            $fromDate = $product['product']['special_from_date'];
            $toDate = $product['product']['special_to_date'];
            $is_special = $this->findSpecialPrice($fromDate, $toDate);
            $special_price = $product['product']['special_price'];
        } elseif (!empty($product['custom_attributes'])) {
            foreach ($product['custom_attributes'] as $cattirbute) {
                if ($cattirbute['attribute_code'] == 'special_from_date') {
                    $fromDate = $cattirbute['value'];
                } elseif ($cattirbute['attribute_code'] == 'special_to_date') {
                    $toDate = $cattirbute['value'];
                } elseif ($cattirbute['attribute_code'] == 'special_price') {
                    $special_price = $cattirbute['value'];
                }
            }
            if (!empty($fromDate) && !empty($toDate)) {
                $is_special = $this->findSpecialPrice($fromDate, $toDate);
            }
        }
        $price['is_special'] = $is_special;
        $price['general'] = isset($product['product']) ? $product['product']['price'] : $product['price'];
        $price['special'] = $special_price;
        return $price;
    }

    function findSpecialPrice($fromDate, $toDate) {
        $toDate = date('Y-m-d H:i:s', mktime(0, 0, 0, date('m', strtotime($toDate)), date('d', strtotime($toDate)) + 1, date('Y', strtotime($toDate))));
        return strtotime($fromDate) <= time() && strtotime($toDate) > time();
    }

    public function getCatalogImageUrl() {
        return '/pub/media/catalog/product';
    }

    function checkProductImage($images) {
        $host = Engine_Api::_()->sitemagento()->getMagentoHostUrl();
        $host = $host . $this->getCatalogImageUrl();
        $imagePath = '';
        foreach ($images as $image) {
            if ($image == 'no_selection') {
                continue;
            }
            $image = $host . $image;
            $imageArray = @getimagesize($image);
            if (is_array($imageArray) && count($imageArray) > 0) {
                $imagePath = $image;
                break;
            }
        }
        return $imagePath;
    }

    /*
     * Get cart information for logged in user
     */

    function getCartInfo() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $quoteId = 0;
        //Check User is logged in or not

        if (empty($viewer_id)) {
            if (isset($_COOKIE['quote_id']) && !empty($_COOKIE['quote_id'])) {
                $quoteId = $_COOKIE['quote_id'];
            } else {
                return array();
            }
        }
	if(empty($viewer_id) && empty($quoteId)){
		return array();
	}
$customerId = 0;
	if(empty($quoteId)){
        //Get Magento User details
        $getUsersInfo = Engine_Api::_()->getDbTable('users', 'sitemagento')->getUser(array('se_user_id' => $viewer_id));
        $getUsersInfo = end($getUsersInfo);
        $customerId = !empty($getUsersInfo['mage_user_id']) ? $getUsersInfo['mage_user_id'] : 0;
        //Check for Magento User exist or not
        if (empty($customerId)) {
            return array();
        }
}
        $packet = array(
            'apiType' => 'getCartInfo',
            'method' => 'GET',
            'queryParameters' => array(
                'customer_id' => $customerId,
                'quote_id' => $quoteId
            )
        );
	
        $cartInfo = array();
        $response = Engine_Api::_()->getApi('Request', 'sitemagento')->client_api_connect($packet);

        if ($response['is_error'] == false && !empty($response['response_output']) && !empty($response['response_output'][0]['items'])) {
            $cart = $response['response_output'][0];
            $products = array();
            $count = count($cart['items']);
            foreach ($cart['items'] as $item) {
                $product = array();
                $product['id'] = $item['product_id'];
                $product['name'] = htmlentities($item['name']);
                $product['sku'] = $item['sku'];
                $product['items_qty'] = (int) $item['qty'];
                $product['price'] = number_format((float) $item['base_price'], 2, '.', ',');
                $product['url'] = $item['product']['url'];
                $imageUrls = array(
                    'image' => $item['product']['image'],
                    'small_image' => $item['product']['small_image'],
                    'thumbnail' => $item['product']['thumbnail'],
                    'swatch_image' => $item['product']['swatch_image'],
                );
                $product['image_url'] = Engine_Api::_()->sitemagento()->checkProductImage($imageUrls);
                $products[$count] = $product;
                $count--;
            }

            $cartInfo['items_count'] = (int) $cart['items_count'];
            $cartInfo['items_qty'] = (int) $cart['items_qty'];
            $cartInfo['base_currency_code'] = $cart['base_currency_code'];
            $cartInfo['base_currency_symbol'] = $cart['base_currency_symbol'];
            $cartInfo['base_grand_total'] = number_format((float) $cart['base_grand_total'], 2, '.', ',');
            $cartInfo['base_subtotal'] = number_format((float) $cart['base_subtotal'], 2, '.', ',');
            $cartInfo['checkout_url'] = $cart['checkout_url'];
            $cartInfo['items'] = $products;
        }

        return $cartInfo;
    }

    public function getImages($product) {
        $attributes = array();
        $images = array();
        foreach ($product['custom_attributes'] as $cattirbute) {
            $attributes[$cattirbute['attribute_code']] = $cattirbute['value'];
        }
        if (!empty($attributes['image']) && $attributes['image'] != 'no_selection') {
            $images[] = $attributes['image'];
        }
        if (!empty($attributes['small_image']) && $attributes['small_image'] != 'no_selection') {
            $images[] = $attributes['small_image'];
        }
        if (!empty($attributes['thumbnail']) && $attributes['thumbnail'] != 'no_selection') {
            $images[] = $attributes['thumbnail'];
        }
        if (!empty($attributes['swatch_image']) && $attributes['swatch_image'] != 'no_selection') {
            $images[] = $attributes['swatch_image'];
        }
        return $images;
    }

}
