<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemagento
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Request.php 2017-06-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Sitemagento_Api_Request extends Core_Api_Abstract {

    protected $_token;

    /**
     * Get Objects of Rest client.
     *
     * @param $host: Host name, which rest client required.
     * @return object
     */
    protected function getProxy() {
        $client = new Zend_Http_Client();
        $client->setConfig(array(
            'strictredirects' => true,
            'timeout' => 1000,
        ));
        return $client;
    }

    /**
     * REST bridge url.
     *
     * @return string
     */
    public function getBridgeUrl($serviceName) {
        $host = Engine_Api::_()->sitemagento()->getMagentoHostUrl();
        $serviceUrl = '';
        switch ($serviceName) {
            case 'version':
                $serviceUrl = '';
                break;
            case 'integrationToken':
                $serviceUrl = '/rest/V1/integration/admin/token';
                break;
            case 'setCredentials' :
                $serviceUrl = '/rest/V1/seint/setextcredentials';
                break;
            case 'createCustomer' :
            case 'deleteCustomer' :
                $serviceUrl = '/rest/V1/customers';
                break;
            case 'authenticateCustomer' :
                $serviceUrl = '/rest/V1/customers/authenticate';
                break;
            case 'changePassword' :
                $serviceUrl = '/rest/V1/customers/me/changePassword';
                break;
            case 'getCategories' :
                $serviceUrl = '/rest/V1/categories';
                break;
            case 'getCategoriesWithUrl' :
                $serviceUrl = '/rest/V1/seint/getCategories';
                break;
            case 'getProducts' :
                $serviceUrl = '/rest/V1/products';
                break;
            case 'getCurrency' :
                $serviceUrl = '/rest/V1/directory/currency';
                break;
            case 'getBestSellers' :
                $serviceUrl = '/rest/V1/seint/bestseller';
                break;
            case 'getProductInfo' :
                $serviceUrl = '/rest/V1/products/T-shirt';
                break;
            case 'getCartInfo' :
                $serviceUrl = '/rest/V1/seint/getCartInfo';
                break;
            case 'setSettings' :
                $serviceUrl = '/rest/V1/seint/setSettings';
                break;
            case 'getProductsPrice' :
                $serviceUrl = '/rest/V1/seint/getProductsPrice';
                break;
            case 'addItemWishlist' :
                $serviceUrl = '/rest/V1/seint/addWishlistForCustomer';
                break;
            default:
        }
        if (empty($serviceUrl)) {
            //Throw exception
            //Invalid service name
        }
        $serviceUrl = $host . $serviceUrl;
        return $serviceUrl;
    }

    public function getToken($params = array()) {
        $client = $this->getProxy();

        $apiUrl = $this->getBridgeUrl('integrationToken');
        if (isset($params['host'])) {
            $apiUrl = $params['host'] . '/rest/V1/integration/admin/token';
        }
        $client->setUri($apiUrl);
        $credentials = array();
        if (isset($params['username']) && isset($params['password'])) {
            $credentials = array(
                'username' => $params['username'],
                'password' => $params['password']
            );
        } else {
            $settingApi = Engine_Api::_()->getApi('settings', 'core');

            $credentials = array(
                'username' => $settingApi->getSetting('sitemagento.api.user', ''),
                'password' => $settingApi->getSetting('sitemagento.api.pass', '')
            );
        }
        $response = $client->setRawData(json_encode($credentials), 'application/json')
                ->request('POST');
        $responseData = array('is_error' => false, 'error_message' => '', 'response_output' => '');
        if ($response->isError()) {
            $responseData['is_error'] = true;
            $responseData['error_message'] = $response->getMessage();
        }
        $responseData['response_output'] = json_decode($response->getBody());
        return $responseData;
    }

    public function client_api_connect($params) {
        $host = Engine_Api::_()->sitemagento()->getMagentoHostUrl();
        if ($host == '#') {
            return array('is_error' => true, 'error_message' => 'Please Configure the Magento Integration', 'response_output' => array());
        }
        $responseData = array('is_error' => false, 'error_message' => '', 'response_output' => '');
        $apiType = isset($params['apiType']) ? $params['apiType'] : 'version';
        $reqMethod = isset($params['method']) ? strtoupper($params['method']) : 'POST';
        $apiUrl = $this->getBridgeUrl($apiType);
        $parameters = array();
        $otherParameters = array();
        if (isset($params['parameters'])) {
            $parameters = $params['parameters'];
        }
        if (isset($params['otherparameters'])) {
            $otherParameters = $params['otherparameters'];
        }
        if ($reqMethod == 'GET' && count($parameters) > 0) {
            $params = array();
            foreach ($parameters as $param) {
                $params[] = urlencode($param);
            }
            $extParams = implode('/', $params);
            $apiUrl = $apiUrl . '/' . $extParams;
            $apiUrl = rtrim($apiUrl, "/");
        } elseif (($reqMethod == 'PUT' || $reqMethod == 'DELETE') && count($otherParameters) > 0) {
            $extParams = implode('/', $otherParameters);
            $apiUrl = $apiUrl . '/' . $extParams;
            $apiUrl = rtrim($apiUrl, "/");
        }
        if (isset($params['queryParameters']) && count($params['queryParameters']) > 0) {
            $queryParameters = http_build_query($params['queryParameters']);
            $apiUrl .='?' . $queryParameters;
        }
        $token = $this->_token;
        if (!$this->_token) {
            $tokenResponse = $this->getToken();
            if ($tokenResponse['is_error']) {
                $responseData['is_error'] = true;
                $responseData['error_message'] = $tokenResponse['error_message'];
                return $responseData;
            }
            $this->_token = $token = $tokenResponse['response_output'];
        }
        
        $client = $this->getProxy();
        $client->setUri($apiUrl);
        $client->setHeaders('Authorization', "Bearer $token");

        $response = $client->setRawData(json_encode($parameters), 'application/json')
                ->request($reqMethod);

        if ($response->isError()) {
            $responseData['is_error'] = true;
            $responseData['error_message'] = $response->getMessage();
        }
        $responseData['response_output'] = json_decode($response->getBody(), true);
        return $responseData;
    }

}

?>