<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemulticurrency
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemulticurrency_Api_Core extends Core_Api_Abstract {

    public function autoImportRates() {

        $importEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemulticurrency.import.enabled', 0);
        if (empty($importEnable))
            return;
        $table = Engine_Api::_()->getDbTable('rateimports', 'sitemulticurrency');
        $tableName = $table->info('name');
        $coreSettings = Engine_Api::_()->getApi('settings', 'core');

        $select = $table->select()
                ->from($tableName)
                ->where('status IS NULL')
                ->where('creation_date IS NULL');
        $data = $table->fetchRow($select);

        $startDate = $coreSettings->getSetting('sitemulticurrency.import.start.time');
        $duration = Engine_Api::_()->sitemulticurrency()->getDuration();

        //IF THERE IS NO SCHEDULE DATE AVAILABLE IN DATABASE THAN INSERT FIRST DATE
        if (empty($data)) {
            $table->insert(array('scheduled_date' => $startDate));
            return;
        } else {
            $scheduledDate = $data->scheduled_date;
            $presentTime = date('Y-m-d H:i:s');

            if ($presentTime >= $scheduledDate) {
                $status = $this->getLatestRates();
                $table->update(array('creation_date' => date('Y-m-d H:i:s'), 'status' => $status), array('creation_date IS NULL', 'status IS NULL'));

                $nextScheduleDate = date("Y-m-d H:i:s", strtotime('+' . $duration . 'seconds'));
                $table->insert(array('scheduled_date' => $nextScheduleDate));
            }
        }
    }

    // IMPORT RATES AND STORE THEM IN DATABASE
    public function getLatestRates() {

        $currencyTable = Engine_Api::_()->getDbtable('currencyrates', 'sitemulticurrency');
        $db = $currencyTable->getAdapter();
        $db->beginTransaction();
        $currencyRatesData = array();
        $status = 1;

        try {  
            $service = new Seaocore_Service_Curl();
            $service->setURl('http://www.floatrates.com/daily/usd.json');
            $currencyRatesData = $service->get();
            if(empty($currencyRatesData)){
                return false;
            }
            $ratesArray = array(); 
            foreach ($currencyRatesData as $currencyCode => $currencyDetails) {
                $ratesArray[strtoupper($currencyCode)] = $currencyDetails['rate'];
            }
            if(count($ratesArray)==0)
                    return false;
            $ratesArray['USD'] = 1;//Because we fetch the rates for the USD currency

            //ARRAY OF CODES ONLY
            $currencyFromApi = array();
            $currencyFromApi = array_keys($ratesArray);

            //ARRAY OF CODES ALREADY STORED IN DATABASE
            $savedCurrency = Engine_Api::_()->getDbtable('currencyrates', 'sitemulticurrency')->getCurrencyCodes();

            //CURRENCIES WHICH HAVE BEEN REMOVED FROM API
            $differ = array_diff($savedCurrency, $currencyFromApi);

            //DELETE THE REOMVED CURRENCIES FROM DATABASE 
            if (!empty($differ))
                $currencyTable->delete(array('code IN(?)' => $differ));

            $localeObject = Zend_Registry::get('Locale');
            $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
            $support_link = $view->htmlLink('www.socialengineaddons.com/user', 'SocialEngineAddOns Client Area');

            //TO INCREASE THE TIME OUT AND MEMORY LIMIT 
            set_time_limit(200);
            ini_set('memory_limit', -1);
            $savedCurrency = Engine_Api::_()->getDbtable('currencyrates', 'sitemulticurrency')->getCurrencyCodes();
            //STORE THE NEW CURRENCIES OR UPDATE THE EXISTING
            foreach ($ratesArray as $code => $rate) {

                $rateRounded = round($rate, 6);
                $currencyName = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $code);

                //IF CURRENCY NAME DONOT EXISTS THAN CODE WILL BE IT'S NAME
                if (empty($currencyName))
                    $currencyName = $code;

                if (in_array($code, $savedCurrency)) {

                    $currencyTable->update(array('global_rate' => $rateRounded, 'applied_rate' => $rateRounded, 'updation_date' => date('Y-m-d H:i:s')), array('code = ?' => $code));
                } else {
                    $currencyTable->insert(array('code' => $code, 'currency_name' => $currencyName, 'global_rate' => $rateRounded, 'applied_rate' => $rateRounded, 'creation_date' => date('Y-m-d H:i:s'), 'updation_date' => date('Y-m-d H:i:s')));
                }
            }
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $status = 0;
            //SEND THE MAIL TO THE EMAIL PROVIDED IN IMPORT SETTINGS 
            $errorEmailType = 'CURRENCY_RATES_IMPORT_FAILED_EMAIL';
            $email = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemulticurrency.import.email', 'admin@bigsteptech.com');
            $errorMessage = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemulticurrency.import.message', 'error');
            if (!empty($email) && !empty($errorMessage)) {
                Engine_Api::_()->getApi('mail', 'core')->sendSystem($email, $errorEmailType, array(
                    'member_name' => 'Admin',
                    'import_date' => date('Y-m-d H:i:s'),
                    'support_link' => $support_link,
                    'error_message' => $errorMessage,
                ));
            }
        }
        return $status;
    }

  //PROVIDE THE PRICE STRING WITH SELECTED CURRENCY 
    public function convertCurrencyRate($price, $priceOnly = 0, $search = 0,$from = null) {
        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $localeObject = Zend_Registry::get('Locale');

        //BASE CURRENCY
        if(empty($from)){
            $from = $coreSettings->getSetting('payment.currency', 'USD');
        }
        $to = Zend_Controller_Front::getInstance()->getRequest()->getParam('user_display_currency', null);

        //TAKE THE DISPLAY CURRENCY FROM CACHE IF USER NOT CHANGED THE CURRENCY
        if (empty($to)) {
            $to = $this->getSelectedCurrency();
        }
        if ($from == $to) {
            $newPrice = $price;
        } else {
            $table = Engine_Api::_()->getDbTable('currencyrates', 'sitemulticurrency');
            if (!empty($search)) {
                $temp = $from;
                $from = $to;
                $to = $temp;
            }
            $appliedRate = $table->getConversionRate($from, $to);
            $newPrice = $price * $appliedRate;
        }
        
        $defaultParams['precision'] = 2;
        if($to == 'BHD') {
            $defaultParams['precision'] = 3;
        }
        $defaultParams['locale'] = Zend_Registry::get('Locale');
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        if (empty($viewer_id)) {
            $defaultParams['locale'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.locale.locale', 'auto');
        }
     
        if (!empty($priceOnly))
            return round($newPrice, $defaultParams['precision']);

        //IF CURRENCY DONOT HAVE SYMBOL IT'S CODE WILL BE USED AS SYMBOL
        $symbol = Zend_Locale_Data::getContent($localeObject, 'currencysymbol', $to);
        if (!empty($symbol) && $to != 'INR') {
            $priceStr = Zend_Registry::get('Zend_View')->locale()->toCurrency($newPrice, $to, $defaultParams);
        } else {
            $newPrice = round($newPrice, $defaultParams['precision']);
            //RUPEES SYMBOL NOT AVAILABLE IN ZEND LIBRARY 
            if($to == 'INR') {
               $inrSymbol = '₹';
               $priceStr = $inrSymbol.$newPrice;
            } else {
               $priceStr = $to . " " . $newPrice; 
            } 
        }
        return $priceStr;
    }

    //PROVIDE THE DURATION IN SECONDS OF IMPORT SELECTED IN IMPORT SETTINGS
    public function getDuration() {
        $frequency = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemulticurrency.import.frequency', 'daily');
        if ($frequency == 'daily')
            $duration = 24 * 60 * 60;
        else if ($frequency == 'weekly')
            $duration = 7 * 24 * 60 * 60;
        else if ($frequency == 'monthly')
            $duration = 30 * 24 * 60 * 60;

        return $duration;
    }

    //GIVES THE COOKIE CURRENCY OR DEFAULT CURRENCY
    public function getSelectedCurrency($returnSymbol = 0) {
        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        //SELECTED CURRENCIES
        $alreadyAllowed = (array) $coreSettings->getSetting('sitemulticurrency.allowed.currency', $coreSettings->getSetting('payment.currency', 'USD'));
        //FROM DATABASE TABLE
        $savedCurrency = Engine_Api::_()->getDbtable('currencyrates', 'sitemulticurrency')->getCurrencyCodes();


        if (isset($_COOKIE['cookie_currency'])) {
            $currnecyCode = $_COOKIE['cookie_currency'];
        } else {
            $currnecyCode = "";
        }
        if (empty($currnecyCode) || !in_array($currnecyCode, $alreadyAllowed) || !in_array($currnecyCode, $savedCurrency)) {
            $currnecyCode = $coreSettings->getSetting('sitemulticurrency.default.display.currency', $coreSettings->getSetting('payment.currency', 'USD'));
        }
        if (!empty($returnSymbol)) {
            $localeObject = Zend_Registry::get('Locale');
            $symbol = Zend_Locale_Data::getContent($localeObject, 'currencysymbol', $currnecyCode);
            if (empty($symbol))
                return $currnecyCode;
            $currnecyCode = $symbol;
        }
        return $currnecyCode;
    }

    function getSelectedCountry($withCurrencyCode = false) {

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        //SELECTED CURRENCIES
        $alreadyAllowed = (array) $coreSettings->getSetting('sitemulticurrency.allowed.currency', $coreSettings->getSetting('payment.currency', 'USD'));
        //FROM DATABASE TABLE
        $savedCurrency = Engine_Api::_()->getDbtable('currencyrates', 'sitemulticurrency')->getCurrencyCodes();

        if (isset($_COOKIE['cookie_currency'])) {
            $currnecyCode = $_COOKIE['cookie_currency'];
        } else {
            $currnecyCode = "";
        }

        if ( empty($currnecyCode) || !in_array($currnecyCode, $alreadyAllowed) ||!in_array($currnecyCode, $savedCurrency)) {
            $currnecyCode = $coreSettings->getSetting('sitemulticurrency.default.display.currency', $coreSettings->getSetting('payment.currency', 'USD'));
        }

        if (isset($_COOKIE['countryCode'])) {
            $countryCode = $_COOKIE['countryCode'];
        } else {
            $countryCode = "";
        }
        $currencyRegions = Zend_Locale_Data::getList(null, 'currencytoregion');
        $currency = isset($currencyRegions[$countryCode])? $currencyRegions[$countryCode]:'';
        if (empty($countryCode) || empty($currency) || !in_array($currency, $alreadyAllowed) || !in_array($currency, $savedCurrency)) {
            //FIRST COUNTRY MATCHING THE CURRENCY 
            $selectedCurrency = $this->getSelectedCurrency();
            $countryCode = array_search($selectedCurrency, $currencyRegions);
        }
        if ($withCurrencyCode) {
            return $countryCode . '_' . $currnecyCode;
        }
        return $countryCode;
    }

}
