<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemulticurrency
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Manage.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemulticurrency_Form_Admin_Manage_Manage extends Engine_Form {

    public function init() {

        $this->setTitle('Manage Currencies')
                ->setDescription('This page lists all the currencies and the base currency which you want to be available for site members. You can set the base currency against which exchange rates are quoted for different currencies. Select multiple currencies which you want to be available for showcasing the price of products, event tickets, subscriptions, listing types and other integrated plugin features.')
                ->setName('manage_currency')
                ->setMethod('POST');

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $localeObject = Zend_Registry::get('Locale');
        $baseCurrency = $coreSettings->getSetting('payment.currency', 'USD');
        $baseCurrencyName = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $baseCurrency);

        //CURRENCIES WHICH ARE SAVED WITH THEIR GLOBAL RATES-FETCH FROM DATABASE
        $savedCurrencyCodes = Engine_Api::_()->getDbtable('currencyrates', 'sitemulticurrency')->getCurrencyCodes();

        $totalCurrency = array();
        if (!empty($savedCurrencyCodes)) {
            foreach ($savedCurrencyCodes as $key => $value) {
                $fullname = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $value);
                if (empty($fullname))
                    $fullname = $value;
                $totalCurrency[$value] = $fullname;
            }
        } else {
            $totalCurrency[$baseCurrency] = $baseCurrencyName;
        }

        //ALLOWED CURRENCIES FOR THE USER SIDE(GIVE THE ARGUMENT 1 IF YOU WANT CURRENCY WITH NAME) 
        $alreadyAllowed = Engine_Api::_()->getDbTable('currencyrates', 'sitemulticurrency')->getAllowedCurrencies(1);

        $remainingCurrency = array();
        $remainingCurrency = array_diff($totalCurrency, $alreadyAllowed);

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $field = 'base_currency_link';
        $this->addElement('Dummy', "$field", array(
            'label' => 'Base Currency',
            'description' => "<span id = 'base_currency_code'>" . $baseCurrencyName . "</span> <br> <a href='" . $view->url(array('module' => 'payment', 'controller' => 'settings'), 'admin_default', true) . "'>Click here</a> to change base currency.",
            'ignore' => true,
        ));
        $this->$field->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

        $this->addElement('Multiselect', 'sitemulticurrency_all_currency', array(
            'label' => 'Select Currencies',
            'description' => 'Select the currencies that you want to show on your site.',
            'attribs' => array('style' => 'height:300px; width:200px'),
            'registerInArrayValidator' => false,
            'multiOptions' => $remainingCurrency,
            'ignore' => true,
        ));
        $this->addElement('Button', 'add', array(
            'label' => 'Add >>',
            'type' => 'button',
        ));
        $this->addElement('Button', 'remove', array(
            'label' => '<< Remove',
            'type' => 'button',
        ));
        $this->addDisplayGroup(array('add', 'remove'), 'add_remove_button', array(
            'decorators' => array(
                'FormElements',
                'DivDivDivWrapper',
            ),
        ));
        $this->addElement('Multiselect', 'sitemulticurrency_allowed_currency', array(
            'label' => 'Allowed Currencies',
            'description' => 'Selected currencies will be listed  here.<br>',
            'attribs' => array('style' => 'height:300px; width:200px'),
            'registerInArrayValidator' => false,
            'multiOptions' => $alreadyAllowed,
            'value' => $alreadyAllowed,
        ));

        $this->sitemulticurrency_allowed_currency->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        $this->addElement('Select', 'sitemulticurrency_default_display_currency', array(
            'label' => 'Default Currency',
            'description' => "Please select the default currency that you want to show on your site when website loads. [You can make a default Currency from the allowed currencies only]",
            'multiOptions' => $alreadyAllowed,
            'registerInArrayValidator' => false,
            'attribs' => array('style' => 'width:350px'),
            'value' => $coreSettings->getSetting('sitemulticurrency.default.display.currency', $baseCurrency)
        ));
        $this->addElement('Button', 'save', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

}
