<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemulticurrency
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Import.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemulticurrency_Form_Admin_Settings_Import extends Engine_Form {

    public function init() {

        $this->setTitle('Currencies Import Settings')
                ->setDescription("This page lists all the settings related to the automatic currencies rate updates using 'http://www.floatrates.com' webservice. Here, you can enable / disable the automatic currencies rate update option and set the frequency updation along with its other related settings.")
                ->setName('import_settings');

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $this->addElement('Radio', 'sitemulticurrency_import_enabled', array(
            'label' => 'Enable Currencies Import',
            'description' => 'Do you want to update currencies rate automatically?',
            'onclick' => 'showSettings(this.value)',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No',
            ),
            'value' => $coreSettings->getSetting('sitemulticurrency.import.enabled',0),
        ));
        $this->addElement('Select', 'sitemulticurrency_import_frequency', array(
            'label' => 'Frequency',
            'attribs' => array('style' => 'width:300px;'),
            'multiOptions' => array('daily' => 'Daily', 'weekly' => 'Weekly', 'monthly' => 'Monthly'
            ),
            'value' => $coreSettings->getSetting('sitemulticurrency.import.frequency', 'daily'),
        ));
         
        //REMOVED REMAINDER FROM DATE MINUTES ELEMENT 
        $minutesRemainder = date('i')%10; 
        $newTime = strtotime('-'.$minutesRemainder.' minutes');
        $presentDatetime =  date('Y-m-d h:i:s', $newTime); 

        $start_time = new Engine_Form_Element_CalendarDateTime('sitemulticurrency_import_start_time');
        $start_time->setLabel("Time");
        $start_time->setValue($coreSettings->getSetting('sitemulticurrency.import.start.time', $presentDatetime));
        $this->addElement($start_time);
        $this->addElement('Text', 'sitemulticurrency_import_email', array(
            'label' => 'Error E-mail Recipient (Optional)',
            'placeholder' => 'Enter email here',
            'attribs' => array('style' => 'width:290px;'),
            'filters' => array('StringTrim'),
            'validators' => array('EmailAddress'),
            'value' => $coreSettings->getSetting('sitemulticurrency.import.email', ''),
        ));
        $this->addElement('textarea', 'sitemulticurrency_import_message', array(
            'label' => 'Error Message',
            'attribs' => array('style' => 'width:100px;'),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemulticurrency.import.message', 'Currency import api gets failed to fetch currency rates.'),
        ));
        $this->addElement('Button', 'save', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}
