<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Api_Core
{

  //TO RETURN THE OBJECT USIGN NEW ITEM TYPE
  public function getSitemusic_pl($playlist_id)
  {
    return Engine_Api::_()->getItem('sitemusic_playlist', $playlist_id);
  }

  public function getSitemusic_userpl($user_playlist_id)
  {
    return Engine_Api::_()->getItem('sitemusic_user_playlist', $user_playlist_id);
  }

  public function getItemTable($type)
  {
    if($type == 'sitemusic_pl') {
      return Engine_Api::_()->getDbTable('playlists', 'sitemusic');
    } elseif($type == 'sitemusic_userpl') {
      return Engine_Api::_()->getDbTable('userPlaylists', 'sitemusic');
    } 
    $class = Engine_Api::_()->getItemTableClass($type);
    return Engine_Api::_()->loadClass($class);
  }

  public function isArtistEnabled()
  {
    $isEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.artist', 1);
    if( $isEnable ) {
      return Engine_Api::_()->authorization()->isAllowed('sitemusic_artist', null, 'view');
    }
    return $isEnable;
  }

  public function isPlaylistEnabled()
  {
    $isEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.playlist', 1);
    if( $isEnable ) {
      return Engine_Api::_()->authorization()->isAllowed('sitemusic_userpl', null, 'view');
    }
    return $isEnable;
  }

  public function enableContentBasedPrivacy()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.content.basedPrivacy', 1);
  }

  public function isPlaylistCreate()
  {
    if( $this->isPlaylistEnabled() ) {
      return Engine_Api::_()->authorization()->isAllowed('sitemusic_userpl', null, 'create');
    }
    return false;
  }

  public function enableAlbumRating()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.albumrating', 1);
  }

  public function enableSongRating()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.songrating', 1);
  }

  public function enablePlaylistRating()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.playlistrating', 1);
  }

  public function enableArtistRating()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.artistrating', 1);
  }

  public function enableRating()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.rating', 1);
  }

  public function enableAlbumShare()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.albumshare', 1);
  }

  public function enableSongShare()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.songshare', 1);
  }

  public function enablePlaylistShare()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.playlistshare', 1);
  }

  public function enableArtistShare()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.artistshare', 1);
  }

  public function enableShare()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.share', 1);
  }

  public function enableAlbumFavourite()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.albumfavourite', 1);
  }

  public function enableSongFavourite()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.songfavourite', 1);
  }

  public function enablePlaylistFavourite()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.playlistfavourite', 1);
  }

  public function enableArtistFavourite()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.artistfavourite', 1);
  }

  public function enableFavourite()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.favourite', 1);
  }

  public function enableArtistAutoApproval()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.artist.auto.approval', 1);
  }

  public function enableStatsCountOnZero()
  {
    return Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.stats.onzero', 1);
  }

  public function getAuthorisedSelect($select)
  {
    $authorisedSelect = array();
    $viewer = Engine_Api::_()->user()->getViewer();
    if( !$viewer->getIdentity() ) {
      return $select;
    }

    $netMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
    $viewerNetwork = $netMembershipTable->getMembershipsOfIds($viewer);
    if( empty($viewerNetwork) ) {
      return $select;
    }

    // authorizing viewer privilege for 'owner_network' privacy
    foreach( $select->getTable()->fetchAll($select) as $item ) {
      if( $item->view_privacy == 'owner_network' && !in_array($viewer->level_id, $this->_excludedLevels) ) {
        if( Engine_Api::_()->authorization()->isAllowed($item, $viewer, 'view') ) {
          $authorisedSelect[] = $item;
        }
      } else {
        $authorisedSelect[] = $item;
      }
    }
    return $authorisedSelect;
  }

  public function getRating($item_id, $resourceType)
  {
    $table = Engine_Api::_()->getDbTable('ratings', 'sitemusic');
    $rating_sum = $table->select()
      ->from($table->info('name'), new Zend_Db_Expr('SUM(rating)'))
      ->group('resource_id')
      ->where('resource_id = ?', $item_id)
      ->where('resource_type = ?', $resourceType)
      ->query()
      ->fetchColumn(0)
    ;

    $total = $this->ratingCount($item_id, $resourceType);
    if( $total ) {
      $rating = $rating_sum / $this->ratingCount($item_id, $resourceType);
    } else {
      $rating = 0;
    }

    return $rating;
  }

//  public function getRatings($item_id)
//  {
//    $table = Engine_Api::_()->getDbTable('ratings', 'sitemusic');
//    $rName = $table->info('name');
//    $select = $table->select()
//      ->from($rName)
//      ->where($rName . '.resource_id = ?', $item_id);
//    $row = $table->fetchAll($select);
//    return $row;
//  }

  public function checkRated($item_id, $user_id, $resourceType)
  {
    $table = Engine_Api::_()->getDbTable('ratings', 'sitemusic');

    $rName = $table->info('name');
    $select = $table->select()
      ->setIntegrityCheck(false)
      ->where('resource_id = ?', $item_id)
      ->where('user_id = ?', $user_id)
      ->where('resource_type = ?', $resourceType)
      ->limit(1);
    $row = $table->fetchAll($select);
    if( count($row) > 0 ) {
      return 1;
    }
    return 0;
  }

  public function setRating($item_id, $user_id, $rating, $resourceType)
  {
    $table = Engine_Api::_()->getDbTable('ratings', 'sitemusic');
    $rName = $table->info('name');
    $select = $table->select()
      ->from($rName)
      ->where($rName . '.resource_id = ?', $item_id)
      ->where($rName . '.user_id = ?', $user_id)
      ->where($rName . '.resource_type = ?', $resourceType);
    $row = $table->fetchRow($select);
    if( empty($row) ) {
      // create rating
      Engine_Api::_()->getDbTable('ratings', 'sitemusic')->insert(array(
        'resource_type' => $resourceType,
        'resource_id' => $item_id,
        'user_id' => $user_id,
        'rating' => $rating
      ));
    }
  }

  public function ratingCount($item_id, $resourceType)
  {
    $table = Engine_Api::_()->getDbTable('ratings', 'sitemusic');
    $rName = $table->info('name');
    $select = $table->select()
      ->from($rName)
      ->where($rName . '.resource_id = ?', $item_id)
      ->where($rName . '.resource_type = ?', $resourceType);
    $row = $table->fetchAll($select);
    $total = count($row);
    return $total;
  }

  public function setPhoto($resource, $photo)
  {
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
      $fileName = $file;
    } else if( $photo instanceof Storage_Model_File ) {
      $file = $photo->temporary();
      $fileName = $photo->name;
    } else if( $photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id) ) {
      $tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
      $file = $tmpRow->temporary();
      $fileName = $tmpRow->name;
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
      $fileName = $photo['name'];
    } else if( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
      $fileName = $photo;
    } else {
      throw new User_Model_Exception('invalid argument passed to setPhoto');
    }

    if( !$fileName ) {
      $fileName = $file;
    }
    $name = basename($file);
    $extension = ltrim(strrchr($fileName, '.'), '.');
    $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => $resource->getType(),
      'parent_id' => $resource->getIdentity(),
      'name' => $fileName,
    );

    // Save
    $filesTable = Engine_Api::_()->getDbtable('files', 'storage');

    // Resize image (main)
    $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(720, 720)
      ->write($mainPath)
      ->destroy();

    // Resize image (normal)
    $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(320, 240)
      ->write($normalPath)
      ->destroy();

    // Store
    try {
      $iMain = $filesTable->createFile($mainPath, $params);
      $iIconNormal = $filesTable->createFile($normalPath, $params);

      $iMain->bridge($iIconNormal, 'thumb.normal');
    } catch( Exception $e ) {
      // Remove temp files
      @unlink($mainPath);
      @unlink($normalPath);
      // Throw
      if( $e->getCode() == Storage_Model_DbTable_Files::SPACE_LIMIT_REACHED_CODE ) {
        throw new Album_Model_Exception($e->getMessage(), $e->getCode());
      } else {
        throw $e;
      }
    }

    // Remove temp files
    @unlink($mainPath);
    @unlink($normalPath);

    // Update row
    $resource->modified_date = date('Y-m-d H:i:s');
    $resource->photo_id = $iMain->file_id;
    $resource->save();

    // Delete the old file?
    if( !empty($tmpRow) ) {
      $tmpRow->delete();
    }

    return $resource;
  }

  public function setCoverPhoto($resource, $photo)
  {
    if( !$resource instanceof Core_Model_Item_Abstract ) {
      return;
    }
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
    } elseif( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
    } elseif( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
    } else {
      throw new Sitemusic_Model_Exception('Invalid argument passed to setPhoto: ' . print_r($photo, 1));
    }
    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => $resource->getType(),
      'parent_id' => $resource->getIdentity()
    );

    // Save
    $storage = Engine_Api::_()->storage();

    // Resize image (main)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(720, 720)
      ->write($path . '/m_' . $name)
      ->destroy();

    // Store
    $iMain = $storage->create($path . '/m_' . $name, $params);

    // Remove temp files
    @unlink($path . '/m_' . $name);


    // Update row
    $resource->photo_id = $iMain->getIdentity();
    $resource->save();

    return $resource;
  }

// get information and pass this information to player
//for music player
  public function changeSongsToJsonString($songs)
  {
    if( empty($songs) ) {
      return;
    }
    $songInfo = array();
    $albumTitle = "";
    $songInfoArray = array();
    $i = 0;
    foreach( $songs as $song ) {
      $checkFavourite = Engine_Api::_()->getApi('favourite', 'sitemusic')->hasFavourite($song->getType(), $song->getIdentity());
      if( empty($checkFavourite) ) {
        $fav = 0;
        $favId = 0;
      } else {
        $fav = 1;
        $favId = $checkFavourite[0]['favourite_id'];
      }
      $artists = $song->getArtist();
      $artistTitle = '';
      foreach( $artists as $artist ) {
        if( $artistTitle ) {
          $aT = $artist['title'];
          $artistTitle = $artistTitle . ' ' . $aT;
        } else {
          $artistTitle = $artist['title'];
        }
      }
      $artistTitle = $this->filterString($artistTitle);
      $albumInfo = $song->getAlbum();
      if( $albumInfo ) {
        $albumTitle = $this->filterString($albumInfo->title);
      }
      $photoUrl = $song->getIconPhoto();
      if( empty($photoUrl) ) {
        $front = Zend_Controller_Front::getInstance();
        $baseUrl = $front->getBaseUrl();
        $photoUrl = $baseUrl . '/application/modules/Sitemusic/externals/images/nophoto_playlist_song_thumb_normal.png';
      }
      $title = $this->filterString($song->title);
      $songUrl = $song->getFilePath();
      $songLength = $song->song_length;
      $songInfo = array("name" => $title, "artist" => $artistTitle, "album" => $albumTitle, "url" => $songUrl, "cover_art_url" => $photoUrl, "songId" => $song->getIdentity(), "hasFavourite" => $fav, "favouriteId" => $favId, "songLength" => $songLength);
      $songInfoArray[$i] = $songInfo;
      $i++;
    }
    $songInfoArray = json_encode($songInfoArray);
    return $songInfoArray;
  }

  public function createZip($resourceType, $resourceId)
  {
    $table = Engine_Api::_()->getItem($resourceType, $resourceId);
    $rows = $table->getSongs(true);

    if( empty($rows) ) {
      return;
    }
    $objectId = array();
    $fileId = array();
    foreach( $rows as $row ) {
      $objectId[] = $row->getIdentity();
      $fileId[] = $row->file_id;
    }

    if( empty($fileId) ) {
      return false;
    }

    $title = $table->title;
    $title = preg_replace('/\s+/', '_', $title);
    $title = substr($title, 0, 15);
    $fileStorage = Engine_Api::_()->getDbTable('files', 'storage');
    $select = $fileStorage->select();
    $select->where('file_id IN(?)', $fileId);
    $fileRows = $fileStorage->fetchAll($select);
    $filepath = APPLICATION_PATH . "/public/sitemusicZip/";
    if( !is_writable($filepath) ) {
      mkdir($filepath);
    }
    $zip = new ZipArchive();
    if( $zip->open($filepath . $title . '.zip', ZipArchive::CREATE) !== TRUE ) {
      echo("cannot open <$filepath>\n");
    }
    ini_set('memory_limit', '200M');
    foreach( $fileRows as $fRow ) {
      $path = $fRow->storage_path;
      $fileName = $fRow->name;
      $file = file_get_contents($path);
      $zip->addFromString($fileName, $file);
      if(file_exists($filepath . $title . '.zip')) {
        chmod($filepath . $title . '.zip', 0777);
      }
    }
    $zip->close();
    $table->download_count = ++$table->download_count;
    $table->save();
    return $filepath . $title . '.zip';
  }

  // get information and pass this information to player
  public function songInfoForPlayer($song)
  {
    if( empty($song) ) {
      return;
    }
    // check string if single or double quote are available
    $albumTitle = "";
    $title = $this->filterString($song->title);
    $songId = $song->getIdentity();
    $songUrl = $song->getFilePath();
    $artists = $song->getArtist();
    $artistTitle = '';
    foreach( $artists as $artist ) {
      if( $artistTitle ) {
        $aT = $artist['title'];
        $artistTitle = $artistTitle . ' ' . $aT;
      } else {
        $artistTitle = $artist['title'];
      }
    }
    $artistTitle = $this->filterString($artistTitle);
    $albumInfo = $song->getAlbum();
    if( $albumInfo ) {
      $albumTitle = $this->filterString($albumInfo->title);
    }
    $songLength = $song->song_length;
    $checkFavourite = Engine_Api::_()->getApi('favourite', 'sitemusic')->hasFavourite($song->getType(), $song->getIdentity());
    if( empty($checkFavourite) ) {
      $fav = 0;
      $favId = 0;
    } else {
      $fav = 1;
      $favId = $checkFavourite[0]['favourite_id'];
    }
    $photoUrl = $song->getIconPhoto();
    if( empty($photoUrl) ) {
      $front = Zend_Controller_Front::getInstance();
      $baseUrl = $front->getBaseUrl();
      $photoUrl = $baseUrl . '/application/modules/Sitemusic/externals/images/nophoto_playlist_song_thumb_normal.png';
    }
    $songInfo = array("title" => $title, "artist" => $artistTitle, "album" => $albumTitle, "url" => $songUrl, "cover_art_url" => $photoUrl, "songId" => $song->getIdentity(), "hasFavourite" => $fav, "favouriteId" => $favId, "songLength" => $songLength);
    $jsonSong = implode(',', $songInfo);
    return $jsonSong;
  }

  // change single or double quote to in special character
  public function filterString($string)
  {
    if( strpos($string, "'") ) {
      $string = str_replace("'", "!@#$", $string);
    }
    if( strpos($string, '"') ) {
      $string = str_replace('"', "!@#$%", $string);
    }
    if( strpos($string, ",") ) {
      $string = str_replace(",", "!@#$*", $string);
    }
    return $string;
  }

  public function setMetaKeywords($params = array())
  {
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $siteinfo = $view->layout()->siteinfo;
    $keywords = "";

    if( isset($params['meta_keywords']) && !empty($params['meta_keywords']) ) {
      if( !empty($keywords) )
        $keywords .= ', ';
      $keywords .= $params['meta_keywords'];
    }

    $siteinfo['keywords'] = $keywords;
    $view->layout()->siteinfo = $siteinfo;
  }

  public function checkMetaKeywords($object)
  {
    $params = $object->params;
    if( !empty($params) ) {
      $params = Zend_Json::decode($params);
      if( $params['meta_keywords'] ) {
        //SET META KEYWORDS
        Engine_Api::_()->sitemusic()->setMetaKeywords($params);
      }
    }
  }

  public function isEditPrivacy($parent_type = null, $parent_id = null, $item = null)
  {
    $viewer = Engine_Api::_()->user()->getViewer();

    if( $parent_type == 'sitepage_page' && Engine_Api::_()->hasItemType('sitepage_page') ) {
      $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
      $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'edit');
      $issamcreate = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'samcreate');
      if( empty($issamcreate) && empty($isManageAdmin) ) {
        return false;
      }
    } else if( $parent_type == 'sitegroup_group' && Engine_Api::_()->hasItemType('sitegroup_group') ) {
      $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
      $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
      $issamcreate = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'samcreate');
      if( empty($issamcreate) && empty($isManageAdmin) ) {
        return false;
      }
    } else {
      if( $viewer->getIdentity() != $item->getOwner()->getIdentity() && !$item->authorization()->isAllowed($viewer, 'edit') )
        return false;
    }
    return true;
  }

  public function canDeletePrivacy($parent_type = null, $parent_id = null, $item = null)
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    if( !empty($viewer_id) ) {
      $level_id = $viewer->level_id;
    } else {
      $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
    }
    if( $parent_type == 'sitepage_page' && Engine_Api::_()->hasItemType('sitepage_page') ) {
      $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
      //START MANAGE-ADMIN CHECK
      $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'edit');
      if( $viewer_id != $sitepage->owner_id && !$isManageAdmin ) {
        return false;
      } else {
        return true;
      }
    } elseif( $parent_type == 'sitebusiness_business' && Engine_Api::_()->hasItemType('sitebusiness_business') ) {
      $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parent_id);
      //START MANAGE-ADMIN CHECK
      $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
      if( $viewer_id != $sitebusiness->owner_id && !$isManageAdmin ) {
        return false;
      } else {
        return true;
      }
    } elseif( $parent_type == 'sitegroup_group' && Engine_Api::_()->hasItemType('sitegroup_group') ) {
      $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
      //START MANAGE-ADMIN CHECK
      $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
      if( $viewer_id != $sitegroup->owner_id && !$isManageAdmin ) {
        return false;
      } else {
        return true;
      }
    } else {

      if( !$item->authorization()->isAllowed($viewer, 'delete') )
        return false;
    }

    return true;
  }

  //Handle song upload
  public function createSong($file, $params = array())
  {
    if( is_array($file) ) {
      if( !is_uploaded_file($file['tmp_name']) )
        throw new Sitemusic_Model_Exception('Invalid upload or file too large');
      $filename = $file['name'];
    } else if( is_string($file) ) {
      $filename = $file;
    } else if( $file ) {
      $name = $file->name;
      $filename = $file->storage_path;
      $file = $file->storage_path;
    } else {
      throw new Sitemusic_Model_Exception('Invalid upload or file too large');
    } $ffmpeg_path = Engine_Api::_()->getApi('settings', 'core')->sitemusic_ffmpeg_path;
    $checkFfmpeg = $this->checkFfmpeg($ffmpeg_path);
    if( !$ffmpeg_path || !$checkFfmpeg ) {
//Check file extension
      if( !preg_match('/\.(mp3|m4a|aac|mp4|wav)$/iu', $filename) )
        throw new Sitemusic_Model_Exception('Invalid file type');
    } //Upload to storage system
    if( isset($name) && !empty($name) ) {
      $params = array_merge(array('type' => 'song', 'name' => $name, 'parent_type' => 'siemusic_playlist_song', 'parent_id' => Engine_Api::_()->user()->getViewer()->getIdentity(), 'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(), 'extension' => substr($filename, strrpos($filename, '.') + 1)), $params);
    } else {
      $params = array_merge(array('type' => 'song', 'name' => $filename, 'parent_type' => 'siemusic_playlist_song', 'parent_id' => Engine_Api::_()->user()->getViewer()->getIdentity(), 'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(), 'extension' => substr($filename, strrpos($filename, '.') + 1)), $params);
    }
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR;
    $file = Engine_Api::_()->storage()->create($file, $params);
    return $file;
  }

  public function checkFfmpeg($ffmpeg_path)
  {
    if( !$ffmpeg_path )
      return false;
    if( !function_exists('shell_exec') ) {
      return false;
    }
    if( !function_exists('exec') ) {
      return false;
    }
    if( !@file_exists($ffmpeg_path) || !@is_executable($ffmpeg_path) ) {
      $output = null;
      $return = null;
      exec(APPLICATION_PATH.$ffmpeg_path . ' -version', $output, $return);
      if( $return > 0 ) {
        return false;
      }
    }
    return true;
  }

  public function getSongOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "songRating" => "Rating",
      "genre" => "Genre",
      "songLikeCount" => "Like Count",
      "songCommentCount" => "Comment Count",
      "songFavouriteCount" => "Favourite Count",
      "songLike" => "Like",
      "songShare" => "Share",
      "songDownload" => "Download",
      "songDownloadCount" => "Download Count",
      "songQueue" => "Add to Queue",
      "songInfo" => "Info",
      "songFavourite" => "Favourite",
      "addToPlaylist" => "Add to Playlist",
      "songPlay" => "Play",
      "playCount" => "Play Count",
      "songLabel" => "Label",
      "albumName" => "Album's Name",
    );
    return $multiOptions;
  }

  public function getAlbumOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "albumFavourite" => "Favourite",
      "albumLike" => "Like",
      "albumRating" => "Rating",
      "albumComment" => "Comment",
      "albumShare" => "Share",
      "albumQueue" => "Add to Queue",
      "albumInfo" => "info",
      "albumPlay" => "Play",
      "albumPlayCount" => "Play Count",
      "albumFavouriteCount" => "Favourite Count",
      "albumDownloadCount" => "Download Count",
      "albumCommentCount" => "Comment Count",
      "albumLikeCount" => "Like Count",
      "albumLabel" => "Labels",
      "albumCategory" => "Category",
      "songCount" => "Songs Count",
    );
    return $multiOptions;
  }

  public function getAlbumListViewOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "albumName" => "Album Name(with song)",
      "songLike" => "Like",
      "songRating" => "Rating",
      "songDownload" => "Download",
      "genre" => "Genre",
      "songFavourite" => "Favourite",
      "songPlay" => "Play",
      "songRating" => "Rating",
      "songQueue" => "Queue",
      "songShare" => "Share",
      "addToPlaylist" => "Add to Playlist",
    );
    return $multiOptions;
  }

  public function getArtistOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "artistFavourite" => "Favourite",
      "artistRating" => "Rating",
      "songCount" => "Songs Count",
      "artistFollow" => "Follow Button",
      "artistLike" => "Like",
      "artistLabel" => "Labels",
      "artistFavouriteCount" => "Favourite Count",
      "artistLikeCount" => "Like Count"
    );
    return $multiOptions;
  }

  public function getPlaylistOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "playlistFavourite" => "Playlist Favourite",
      "playlistLike" => "Like",
      "playlistRating" => "Rating",
      "playlistComment" => "Comment",
      "playlistShare" => "Share",
      "playlistPlay" => "Play",
      "playlistFavouriteCount" => "Favourite Count",
      "playlistLikeCount" => "Like Count",
      "playlistCommentCount" => "Comment Count",
      "playlistLabel" => "Label",
      "playlistQueue" => "Add to Queue",
      "songCount" => "Songs Count",
    );
    return $multiOptions;
  }

  public function getUserPlaylistViewOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "songLike" => "Like",
      "playlistQueue" => "Add to Queue",
      "songDownload" => "Download",
      "songFavourite" => "Favourite",
      "songRating" => "Rating",
      "songPlay" => "Play",
      "songQueue" => "Queue",
      "songRating" => "Rating",
      "genre" => "Genre",
      "playlistSongDelete" => "Delete",
      "songShare" => "Share",
      "addToPlaylist" => "Add to Playlist",
      "albumName" => "Album's Name",
    );
    return $multiOptions;
  }

  /**
   * Gets a url slug for string
   *
   * @return string The slug
   */
  public function getSlug($str, $limit = 64)
  {

    $str = self::replaceSpecialChars($str);

    if( strlen($str) > $limit ) {
      $str = Engine_String::substr($str, 0, $limit) . '...';
    }

    $slugString = $str;

    //CASE 1:
    $search = array('À', 'Á', 'Â', 'Ã', 'Ä', 'Å', 'Æ', 'Ç', 'È', 'É', 'Ê', 'Ë', 'Ì', 'Í', 'Î', 'Ï', 'Ð', 'Ñ', 'Ò', 'Ó', 'Ô', 'Õ', 'Ö', 'Ø', 'Ù', 'Ú', 'Û', 'Ü', 'Ý', 'ß', 'à', 'á', 'â', 'ã', 'ä', 'å', 'æ', 'ç', 'è', 'é', 'ê', 'ë', 'ì', 'í', 'î', 'ï', 'ñ', 'ò', 'ó', 'ô', 'õ', 'ö', 'ø', 'ù', 'ú', 'û', 'ü', 'ý', 'ÿ', 'Ā', 'ā', 'Ă', 'ă', 'Ą', 'ą', 'Ć', 'ć', 'Ĉ', 'ĉ', 'Ċ', 'ċ', 'Č', 'č', 'Ď', 'ď', 'Đ', 'đ', 'Ē', 'ē', 'Ĕ', 'ĕ', 'Ė', 'ė', 'Ę', 'ę', 'Ě', 'ě', 'Ĝ', 'ĝ', 'Ğ', 'ğ', 'Ġ', 'ġ', 'Ģ', 'ģ', 'Ĥ', 'ĥ', 'Ħ', 'ħ', 'Ĩ', 'ĩ', 'Ī', 'ī', 'Ĭ', 'ĭ', 'Į', 'į', 'İ', 'ı', 'Ĳ', 'ĳ', 'Ĵ', 'ĵ', 'Ķ', 'ķ', 'Ĺ', 'ĺ', 'Ļ', 'ļ', 'Ľ', 'ľ', 'Ŀ', 'ŀ', 'Ł', 'ł', 'Ń', 'ń', 'Ņ', 'ņ', 'Ň', 'ň', 'ŉ', 'Ō', 'ō', 'Ŏ', 'ŏ', 'Ő', 'ő', 'Œ', 'œ', 'Ŕ', 'ŕ', 'Ŗ', 'ŗ', 'Ř', 'ř', 'Ś', 'ś', 'Ŝ', 'ŝ', 'Ş', 'ş', 'Š', 'š', 'Ţ', 'ţ', 'Ť', 'ť', 'Ŧ', 'ŧ', 'Ũ', 'ũ', 'Ū', 'ū', 'Ŭ', 'ŭ', 'Ů', 'ů', 'Ű', 'ű', 'Ų', 'ų', 'Ŵ', 'ŵ', 'Ŷ', 'ŷ', 'Ÿ', 'Ź', 'ź', 'Ż', 'ż', 'Ž', 'ž', 'ſ', 'ƒ', 'Ơ', 'ơ', 'Ư', 'ư', 'Ǎ', 'ǎ', 'Ǐ', 'ǐ', 'Ǒ', 'ǒ', 'Ǔ', 'ǔ', 'Ǖ', 'ǖ', 'Ǘ', 'ǘ', 'Ǚ', 'ǚ', 'Ǜ', 'ǜ', 'Ǻ', 'ǻ', 'Ǽ', 'ǽ', 'Ǿ', 'ǿ');
    $replace = array('A', 'A', 'A', 'A', 'A', 'A', 'AE', 'C', 'E', 'E', 'E', 'E', 'I', 'I', 'I', 'I', 'D', 'N', 'O', 'O', 'O', 'O', 'O', 'O', 'U', 'U', 'U', 'U', 'Y', 's', 'a', 'a', 'a', 'a', 'a', 'a', 'ae', 'c', 'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i', 'n', 'o', 'o', 'o', 'o', 'o', 'o', 'u', 'u', 'u', 'u', 'y', 'y', 'A', 'a', 'A', 'a', 'A', 'a', 'C', 'c', 'C', 'c', 'C', 'c', 'C', 'c', 'D', 'd', 'D', 'd', 'E', 'e', 'E', 'e', 'E', 'e', 'E', 'e', 'E', 'e', 'G', 'g', 'G', 'g', 'G', 'g', 'G', 'g', 'H', 'h', 'H', 'h', 'I', 'i', 'I', 'i', 'I', 'i', 'I', 'i', 'I', 'i', 'IJ', 'ij', 'J', 'j', 'K', 'k', 'L', 'l', 'L', 'l', 'L', 'l', 'L', 'l', 'l', 'l', 'N', 'n', 'N', 'n', 'N', 'n', 'n', 'O', 'o', 'O', 'o', 'O', 'o', 'OE', 'oe', 'R', 'r', 'R', 'r', 'R', 'r', 'S', 's', 'S', 's', 'S', 's', 'S', 's', 'T', 't', 'T', 't', 'T', 't', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'W', 'w', 'Y', 'y', 'Y', 'Z', 'z', 'Z', 'z', 'Z', 'z', 's', 'f', 'O', 'o', 'U', 'u', 'A', 'a', 'I', 'i', 'O', 'o', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'A', 'a', 'AE', 'ae', 'O', 'o');
    $str = str_replace($search, $replace, $str);

    $str = preg_replace('/([a-z])([A-Z])/', '$1 $2', $str);
    $str = strtolower($str);
    $str = preg_replace('/[^a-z0-9-]+/i', '-', $str);
    $str = preg_replace('/-+/', '-', $str);
    $str = trim($str, '-');

    //CASE 2:
    if( empty($str) || $str == '-' ) {
      setlocale(LC_CTYPE, 'pl_PL.utf8');
      $str = @iconv('UTF-8', 'ASCII//TRANSLIT', $slugString);
      $str = strtolower($str);
      $str = strtr($str, array('&' => '-', '"' => '-', '&' . '#039;' => '-', '<' => '-', '>' => '-', '\'' => '-'));
      $str = preg_replace('/^[^a-z0-9]{0,}(.*?)[^a-z0-9]{0,}$/si', '\\1', $str);
      $str = preg_replace('/[^a-z0-9\-]/', '-', $str);
      $str = preg_replace('/[\-]{2,}/', '-', $str);

      //CASE 3:
      if( empty($str) || $str == '-' ) {

        $cyrillicArray = array(
          "Є" => "YE", "І" => "I", "Ї" => "YI", "Ѓ" => "G", "і" => "i", "№" => "#", "є" => "ye", "ѓ" => "g",
          "А" => "A", "Б" => "B", "В" => "V", "Г" => "G", "Д" => "D",
          "Е" => "E", "Ё" => "YO", "Ж" => "ZH",
          "З" => "Z", "И" => "I", "Й" => "J", "К" => "K", "Л" => "L",
          "М" => "M", "Н" => "N", "О" => "O", "П" => "P", "Р" => "R",
          "С" => "S", "Т" => "T", "У" => "U", "Ф" => "F", "Х" => "X",
          "Ц" => "C", "Ч" => "CH", "Ш" => "SH", "Щ" => "SHH", "Ъ" => "'",
          "Ы" => "Y", "Ь" => "", "Э" => "E", "Ю" => "YU", "Я" => "YA",
          "а" => "a", "б" => "b", "в" => "v", "г" => "g", "д" => "d",
          "е" => "e", "ё" => "yo", "ж" => "zh",
          "з" => "z", "и" => "i", "ї" => "yi", "й" => "j", "к" => "k", "л" => "l",
          "м" => "m", "н" => "n", "о" => "o", "п" => "p", "р" => "r",
          "с" => "s", "т" => "t", "у" => "u", "ф" => "f", "х" => "x",
          "ц" => "c", "ч" => "ch", "ш" => "sh", "щ" => "shh", "ъ" => "",
          "ы" => "y", "ь" => "", "э" => "e", "ю" => "yu", "я" => "ya", "«" => "", "»" => "", "—" => "-"
        );

        $str = strtr($slugString, $cyrillicArray);
        $str = preg_replace('/\W+/', '-', $str);
        $str = strtolower(trim($str, '-'));
      }
    }

    if( !$str ) {
      $str = '-';
    }

    return $str;
  }

  function replaceSpecialChars($string)
  {

    if( !preg_match('/[\x80-\xff]/', $string) ) {
      return $string;
    }

    if( self::isUTF8Encoding($string) ) {
      $charsArray = array(
        chr(194) . chr(170) => 'a', chr(194) . chr(186) => 'o',
        chr(195) . chr(128) => 'A', chr(195) . chr(129) => 'A',
        chr(195) . chr(130) => 'A', chr(195) . chr(131) => 'A',
        chr(195) . chr(132) => 'A', chr(195) . chr(133) => 'A',
        chr(195) . chr(134) => 'AE', chr(195) . chr(135) => 'C',
        chr(195) . chr(136) => 'E', chr(195) . chr(137) => 'E',
        chr(195) . chr(138) => 'E', chr(195) . chr(139) => 'E',
        chr(195) . chr(140) => 'I', chr(195) . chr(141) => 'I',
        chr(195) . chr(142) => 'I', chr(195) . chr(143) => 'I',
        chr(195) . chr(144) => 'D', chr(195) . chr(145) => 'N',
        chr(195) . chr(146) => 'O', chr(195) . chr(147) => 'O',
        chr(195) . chr(148) => 'O', chr(195) . chr(149) => 'O',
        chr(195) . chr(150) => 'O', chr(195) . chr(153) => 'U',
        chr(195) . chr(154) => 'U', chr(195) . chr(155) => 'U',
        chr(195) . chr(156) => 'U', chr(195) . chr(157) => 'Y',
        chr(195) . chr(158) => 'TH', chr(195) . chr(159) => 's',
        chr(195) . chr(160) => 'a', chr(195) . chr(161) => 'a',
        chr(195) . chr(162) => 'a', chr(195) . chr(163) => 'a',
        chr(195) . chr(164) => 'a', chr(195) . chr(165) => 'a',
        chr(195) . chr(166) => 'ae', chr(195) . chr(167) => 'c',
        chr(195) . chr(168) => 'e', chr(195) . chr(169) => 'e',
        chr(195) . chr(170) => 'e', chr(195) . chr(171) => 'e',
        chr(195) . chr(172) => 'i', chr(195) . chr(173) => 'i',
        chr(195) . chr(174) => 'i', chr(195) . chr(175) => 'i',
        chr(195) . chr(176) => 'd', chr(195) . chr(177) => 'n',
        chr(195) . chr(178) => 'o', chr(195) . chr(179) => 'o',
        chr(195) . chr(180) => 'o', chr(195) . chr(181) => 'o',
        chr(195) . chr(182) => 'o', chr(195) . chr(184) => 'o',
        chr(195) . chr(185) => 'u', chr(195) . chr(186) => 'u',
        chr(195) . chr(187) => 'u', chr(195) . chr(188) => 'u',
        chr(195) . chr(189) => 'y', chr(195) . chr(190) => 'th',
        chr(195) . chr(191) => 'y', chr(195) . chr(152) => 'O',
        chr(196) . chr(128) => 'A', chr(196) . chr(129) => 'a',
        chr(196) . chr(130) => 'A', chr(196) . chr(131) => 'a',
        chr(196) . chr(132) => 'A', chr(196) . chr(133) => 'a',
        chr(196) . chr(134) => 'C', chr(196) . chr(135) => 'c',
        chr(196) . chr(136) => 'C', chr(196) . chr(137) => 'c',
        chr(196) . chr(138) => 'C', chr(196) . chr(139) => 'c',
        chr(196) . chr(140) => 'C', chr(196) . chr(141) => 'c',
        chr(196) . chr(142) => 'D', chr(196) . chr(143) => 'd',
        chr(196) . chr(144) => 'D', chr(196) . chr(145) => 'd',
        chr(196) . chr(146) => 'E', chr(196) . chr(147) => 'e',
        chr(196) . chr(148) => 'E', chr(196) . chr(149) => 'e',
        chr(196) . chr(150) => 'E', chr(196) . chr(151) => 'e',
        chr(196) . chr(152) => 'E', chr(196) . chr(153) => 'e',
        chr(196) . chr(154) => 'E', chr(196) . chr(155) => 'e',
        chr(196) . chr(156) => 'G', chr(196) . chr(157) => 'g',
        chr(196) . chr(158) => 'G', chr(196) . chr(159) => 'g',
        chr(196) . chr(160) => 'G', chr(196) . chr(161) => 'g',
        chr(196) . chr(162) => 'G', chr(196) . chr(163) => 'g',
        chr(196) . chr(164) => 'H', chr(196) . chr(165) => 'h',
        chr(196) . chr(166) => 'H', chr(196) . chr(167) => 'h',
        chr(196) . chr(168) => 'I', chr(196) . chr(169) => 'i',
        chr(196) . chr(170) => 'I', chr(196) . chr(171) => 'i',
        chr(196) . chr(172) => 'I', chr(196) . chr(173) => 'i',
        chr(196) . chr(174) => 'I', chr(196) . chr(175) => 'i',
        chr(196) . chr(176) => 'I', chr(196) . chr(177) => 'i',
        chr(196) . chr(178) => 'IJ', chr(196) . chr(179) => 'ij',
        chr(196) . chr(180) => 'J', chr(196) . chr(181) => 'j',
        chr(196) . chr(182) => 'K', chr(196) . chr(183) => 'k',
        chr(196) . chr(184) => 'k', chr(196) . chr(185) => 'L',
        chr(196) . chr(186) => 'l', chr(196) . chr(187) => 'L',
        chr(196) . chr(188) => 'l', chr(196) . chr(189) => 'L',
        chr(196) . chr(190) => 'l', chr(196) . chr(191) => 'L',
        chr(197) . chr(128) => 'l', chr(197) . chr(129) => 'L',
        chr(197) . chr(130) => 'l', chr(197) . chr(131) => 'N',
        chr(197) . chr(132) => 'n', chr(197) . chr(133) => 'N',
        chr(197) . chr(134) => 'n', chr(197) . chr(135) => 'N',
        chr(197) . chr(136) => 'n', chr(197) . chr(137) => 'N',
        chr(197) . chr(138) => 'n', chr(197) . chr(139) => 'N',
        chr(197) . chr(140) => 'O', chr(197) . chr(141) => 'o',
        chr(197) . chr(142) => 'O', chr(197) . chr(143) => 'o',
        chr(197) . chr(144) => 'O', chr(197) . chr(145) => 'o',
        chr(197) . chr(146) => 'OE', chr(197) . chr(147) => 'oe',
        chr(197) . chr(148) => 'R', chr(197) . chr(149) => 'r',
        chr(197) . chr(150) => 'R', chr(197) . chr(151) => 'r',
        chr(197) . chr(152) => 'R', chr(197) . chr(153) => 'r',
        chr(197) . chr(154) => 'S', chr(197) . chr(155) => 's',
        chr(197) . chr(156) => 'S', chr(197) . chr(157) => 's',
        chr(197) . chr(158) => 'S', chr(197) . chr(159) => 's',
        chr(197) . chr(160) => 'S', chr(197) . chr(161) => 's',
        chr(197) . chr(162) => 'T', chr(197) . chr(163) => 't',
        chr(197) . chr(164) => 'T', chr(197) . chr(165) => 't',
        chr(197) . chr(166) => 'T', chr(197) . chr(167) => 't',
        chr(197) . chr(168) => 'U', chr(197) . chr(169) => 'u',
        chr(197) . chr(170) => 'U', chr(197) . chr(171) => 'u',
        chr(197) . chr(172) => 'U', chr(197) . chr(173) => 'u',
        chr(197) . chr(174) => 'U', chr(197) . chr(175) => 'u',
        chr(197) . chr(176) => 'U', chr(197) . chr(177) => 'u',
        chr(197) . chr(178) => 'U', chr(197) . chr(179) => 'u',
        chr(197) . chr(180) => 'W', chr(197) . chr(181) => 'w',
        chr(197) . chr(182) => 'Y', chr(197) . chr(183) => 'y',
        chr(197) . chr(184) => 'Y', chr(197) . chr(185) => 'Z',
        chr(197) . chr(186) => 'z', chr(197) . chr(187) => 'Z',
        chr(197) . chr(188) => 'z', chr(197) . chr(189) => 'Z',
        chr(197) . chr(190) => 'z', chr(197) . chr(191) => 's',
        chr(200) . chr(152) => 'S', chr(200) . chr(153) => 's',
        chr(200) . chr(154) => 'T', chr(200) . chr(155) => 't',
        chr(226) . chr(130) . chr(172) => 'E',
        chr(194) . chr(163) => '',
        chr(198) . chr(160) => 'O', chr(198) . chr(161) => 'o',
        chr(198) . chr(175) => 'U', chr(198) . chr(176) => 'u',
        chr(225) . chr(186) . chr(166) => 'A', chr(225) . chr(186) . chr(167) => 'a',
        chr(225) . chr(186) . chr(176) => 'A', chr(225) . chr(186) . chr(177) => 'a',
        chr(225) . chr(187) . chr(128) => 'E', chr(225) . chr(187) . chr(129) => 'e',
        chr(225) . chr(187) . chr(146) => 'O', chr(225) . chr(187) . chr(147) => 'o',
        chr(225) . chr(187) . chr(156) => 'O', chr(225) . chr(187) . chr(157) => 'o',
        chr(225) . chr(187) . chr(170) => 'U', chr(225) . chr(187) . chr(171) => 'u',
        chr(225) . chr(187) . chr(178) => 'Y', chr(225) . chr(187) . chr(179) => 'y',
        chr(225) . chr(186) . chr(162) => 'A', chr(225) . chr(186) . chr(163) => 'a',
        chr(225) . chr(186) . chr(168) => 'A', chr(225) . chr(186) . chr(169) => 'a',
        chr(225) . chr(186) . chr(178) => 'A', chr(225) . chr(186) . chr(179) => 'a',
        chr(225) . chr(186) . chr(186) => 'E', chr(225) . chr(186) . chr(187) => 'e',
        chr(225) . chr(187) . chr(130) => 'E', chr(225) . chr(187) . chr(131) => 'e',
        chr(225) . chr(187) . chr(136) => 'I', chr(225) . chr(187) . chr(137) => 'i',
        chr(225) . chr(187) . chr(142) => 'O', chr(225) . chr(187) . chr(143) => 'o',
        chr(225) . chr(187) . chr(148) => 'O', chr(225) . chr(187) . chr(149) => 'o',
        chr(225) . chr(187) . chr(158) => 'O', chr(225) . chr(187) . chr(159) => 'o',
        chr(225) . chr(187) . chr(166) => 'U', chr(225) . chr(187) . chr(167) => 'u',
        chr(225) . chr(187) . chr(172) => 'U', chr(225) . chr(187) . chr(173) => 'u',
        chr(225) . chr(187) . chr(182) => 'Y', chr(225) . chr(187) . chr(183) => 'y',
        chr(225) . chr(186) . chr(170) => 'A', chr(225) . chr(186) . chr(171) => 'a',
        chr(225) . chr(186) . chr(180) => 'A', chr(225) . chr(186) . chr(181) => 'a',
        chr(225) . chr(186) . chr(188) => 'E', chr(225) . chr(186) . chr(189) => 'e',
        chr(225) . chr(187) . chr(132) => 'E', chr(225) . chr(187) . chr(133) => 'e',
        chr(225) . chr(187) . chr(150) => 'O', chr(225) . chr(187) . chr(151) => 'o',
        chr(225) . chr(187) . chr(160) => 'O', chr(225) . chr(187) . chr(161) => 'o',
        chr(225) . chr(187) . chr(174) => 'U', chr(225) . chr(187) . chr(175) => 'u',
        chr(225) . chr(187) . chr(184) => 'Y', chr(225) . chr(187) . chr(185) => 'y',
        chr(225) . chr(186) . chr(164) => 'A', chr(225) . chr(186) . chr(165) => 'a',
        chr(225) . chr(186) . chr(174) => 'A', chr(225) . chr(186) . chr(175) => 'a',
        chr(225) . chr(186) . chr(190) => 'E', chr(225) . chr(186) . chr(191) => 'e',
        chr(225) . chr(187) . chr(144) => 'O', chr(225) . chr(187) . chr(145) => 'o',
        chr(225) . chr(187) . chr(154) => 'O', chr(225) . chr(187) . chr(155) => 'o',
        chr(225) . chr(187) . chr(168) => 'U', chr(225) . chr(187) . chr(169) => 'u',
        chr(225) . chr(186) . chr(160) => 'A', chr(225) . chr(186) . chr(161) => 'a',
        chr(225) . chr(186) . chr(172) => 'A', chr(225) . chr(186) . chr(173) => 'a',
        chr(225) . chr(186) . chr(182) => 'A', chr(225) . chr(186) . chr(183) => 'a',
        chr(225) . chr(186) . chr(184) => 'E', chr(225) . chr(186) . chr(185) => 'e',
        chr(225) . chr(187) . chr(134) => 'E', chr(225) . chr(187) . chr(135) => 'e',
        chr(225) . chr(187) . chr(138) => 'I', chr(225) . chr(187) . chr(139) => 'i',
        chr(225) . chr(187) . chr(140) => 'O', chr(225) . chr(187) . chr(141) => 'o',
        chr(225) . chr(187) . chr(152) => 'O', chr(225) . chr(187) . chr(153) => 'o',
        chr(225) . chr(187) . chr(162) => 'O', chr(225) . chr(187) . chr(163) => 'o',
        chr(225) . chr(187) . chr(164) => 'U', chr(225) . chr(187) . chr(165) => 'u',
        chr(225) . chr(187) . chr(176) => 'U', chr(225) . chr(187) . chr(177) => 'u',
        chr(225) . chr(187) . chr(180) => 'Y', chr(225) . chr(187) . chr(181) => 'y',
        chr(201) . chr(145) => 'a',
        chr(199) . chr(149) => 'U', chr(199) . chr(150) => 'u',
        chr(199) . chr(151) => 'U', chr(199) . chr(152) => 'u',
        chr(199) . chr(141) => 'A', chr(199) . chr(142) => 'a',
        chr(199) . chr(143) => 'I', chr(199) . chr(144) => 'i',
        chr(199) . chr(145) => 'O', chr(199) . chr(146) => 'o',
        chr(199) . chr(147) => 'U', chr(199) . chr(148) => 'u',
        chr(199) . chr(153) => 'U', chr(199) . chr(154) => 'u',
        chr(199) . chr(155) => 'U', chr(199) . chr(156) => 'u',
      );

      $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

      if( !empty($viewer_id) )
        $locale = Engine_Api::_()->user()->getViewer()->locale;
      else
        $locale = 'en_US';
      try {
        $locale = Zend_Locale::findLocale($locale);
      } catch( Exception $e ) {
        $locale = 'en_US';
      }

      //CHANGES FOR SOME SPECIFIC LOCALES
      if( $locale == 'de_DE' ) {
        $charsArray[chr(195) . chr(132)] = 'Ae';
        $charsArray[chr(195) . chr(164)] = 'ae';
        $charsArray[chr(195) . chr(150)] = 'Oe';
        $charsArray[chr(195) . chr(182)] = 'oe';
        $charsArray[chr(195) . chr(156)] = 'Ue';
        $charsArray[chr(195) . chr(188)] = 'ue';
        $charsArray[chr(195) . chr(159)] = 'ss';
      } elseif( $locale == 'da_DK' ) {
        $charsArray[chr(195) . chr(134)] = 'Ae';
        $charsArray[chr(195) . chr(166)] = 'ae';
        $charsArray[chr(195) . chr(152)] = 'Oe';
        $charsArray[chr(195) . chr(184)] = 'oe';
        $charsArray[chr(195) . chr(133)] = 'Aa';
        $charsArray[chr(195) . chr(165)] = 'aa';
      }

      $string = strtr($string, $charsArray);
    } else {
      $charsArray = array();
      $charsArray['find'] = chr(128) . chr(131) . chr(138) . chr(142) . chr(154) . chr(158)
        . chr(159) . chr(162) . chr(165) . chr(181) . chr(192) . chr(193) . chr(194)
        . chr(195) . chr(196) . chr(197) . chr(199) . chr(200) . chr(201) . chr(202)
        . chr(203) . chr(204) . chr(205) . chr(206) . chr(207) . chr(209) . chr(210)
        . chr(211) . chr(212) . chr(213) . chr(214) . chr(216) . chr(217) . chr(218)
        . chr(219) . chr(220) . chr(221) . chr(224) . chr(225) . chr(226) . chr(227)
        . chr(228) . chr(229) . chr(231) . chr(232) . chr(233) . chr(234) . chr(235)
        . chr(236) . chr(237) . chr(238) . chr(239) . chr(241) . chr(242) . chr(243)
        . chr(244) . chr(245) . chr(246) . chr(248) . chr(249) . chr(250) . chr(251)
        . chr(252) . chr(253) . chr(255);

      $charsArray['replace'] = "EfSZszYcYuAAAAAACEEEEIIIINOOOOOOUUUUYaaaaaaceeeeiiiinoooooouuuuyy";

      $string = strtr($string, $charsArray['find'], $charsArray['replace']);
      $doubleCharsArray = array();
      $doubleCharsArray['find'] = array(chr(140), chr(156), chr(198), chr(208), chr(222), chr(223), chr(230), chr(240), chr(254));
      $doubleCharsArray['replace'] = array('OE', 'oe', 'AE', 'DH', 'TH', 'ss', 'ae', 'dh', 'th');
      $string = str_replace($doubleCharsArray['find'], $doubleCharsArray['replace'], $string);
    }

    return $string;
  }

  function isUTF8Encoding($string)
  {

    $stringLength = strlen($string);

    for( $i = 0; $i < $stringLength; $i++ ) {
      $asciiValue = ord($string[$i]);
      if( $asciiValue < 0x80 )
        $n = 0;
      elseif( ($asciiValue & 0xE0) == 0xC0 )
        $n = 1;
      elseif( ($asciiValue & 0xF0) == 0xE0 )
        $n = 2;
      elseif( ($asciiValue & 0xF8) == 0xF0 )
        $n = 3;
      elseif( ($asciiValue & 0xFC) == 0xF8 )
        $n = 4;
      elseif( ($asciiValue & 0xFE) == 0xFC )
        $n = 5;
      else
        return false;

      for( $j = 0; $j < $n; $j++ ) {
        if( ( ++$i == $stringLength) || ((ord($string[$i]) & 0xC0) != 0x80) ) {
          return false;
        }
      }
    }

    return true;
  }

  /**
   * Get Truncation String
   *
   * @param string $text
   * @param int $limit
   * @return truncate string
   */
  public function sitemusicTruncateText($string, $limit)
  {


    //IF LIMIT IS EMPTY
    if( empty($limit) ) {
      $limit = 16;
    }

    //RETURN TRUNCATED STRING
    $string = strip_tags($string);
    return ( Engine_String::strlen($string) > $limit ? Engine_String::substr($string, 0, ($limit - 3)) . '...' : $string );
  }

  public function checkSitemobileMode($mode = 'fullsite-mode')
  {
    if( Engine_Api::_()->hasModuleBootstrap('sitemobile') ) {
      return (bool) (Engine_API::_()->sitemobile()->getViewMode() === $mode);
    } else {
      return (bool) ('fullsite-mode' === $mode);
    }
  }

  public function isMobile()
  {
    $mobileEnable = false;
    $request = Zend_Controller_Front::getInstance()->getRequest();
    // Code for Mobile Compatibilty Plugins. We are not excuting the our plugin code in case of mode='mobile' or mode === 'touch'.
    $session = new Zend_Session_Namespace('standard-mobile-mode');
    if( array_key_exists('HTTP_USER_AGENT', $_SERVER) ) {
      // Reference from "Detect mobile browser (smartphone)" and URL : http://www.serveradminblog.com/2011/01/detect-mobile-browser-smartphone/
      $useragent = strtolower($_SERVER['HTTP_USER_AGENT']);
      if
      (
        preg_match('/imageuploader|android|blackberry|compal|fennec|hiptop|iemobile/i', $useragent) ||
        preg_match('/ip(hone|od|ad)|kindle|lge|maemo|midp|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\//i', $useragent) ||
        preg_match('/pocket|psp|symbian|treo|up\.(browser|link)|vodafone|windows (ce|phone)|xda/i', $useragent)
      )
        $mobileEnable = true;
      if( preg_match('/imageuploader|android|avantgo|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i', $useragent) || preg_match('/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|e\-|e\/|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(di|rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|xda(\-|2|g)|yas\-|your|zeto|zte\-/i', substr($useragent, 0, 4)) )
        $mobileEnable = true;
    }
    $mobile = false;
    if( !$mobileEnable && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('mobi') ) {
      $mobile = $request->getParam("mobile");
      $session = new Zend_Session_Namespace('mobile');

      if( $mobile == "1" ) {
        $mobileEnable = true;
        $session->mobile = true;
      } elseif( $mobile == "0" ) {
        $mobileEnable = false;
        $session->mobile = false;
      } else {
        if( isset($session->mobile) ) {
          $mobileEnable = (bool) $session->mobile;
        } else {
          // CHECK TO SEE IF MOBILE
          if( Engine_Api::_()->mobi()->isMobile() ) {
            $mobileEnable = true;
            $session->mobile = true;
          } else {
            $mobileEnable = false;
            $session->mobile = false;
          }
        }
      }
    }
    return $mobileEnable;
  }

  public function getOldVersionImages($array){
        // Get available files
        $imgOptions = array();
        $imgOptions = $array;
        $imageExtensions = array('gif', 'jpg', 'jpeg', 'png');

        $it = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
        foreach ($it as $file) {
            if ($file->isDot() || !$file->isFile())
                continue;
            $basename = basename($file->getFilename());
            if (!($pos = strrpos($basename, '.')))
                continue;
            $ext = strtolower(ltrim(substr($basename, $pos), '.'));
            if (!in_array($ext, $imageExtensions))
                continue;
            $imgOptions['public/admin/' . $basename] = $basename;
        }
        return $imgOptions;
    }


    public function getNewVersionImages($array){
        $params = array();
        $params['extension'] = array('gif', 'jpg', 'jpeg', 'png');
        $filesTable = Engine_Api::_()->getDbTable('files','core');
        $select = $filesTable->getFiles($params);
        $fileData = $filesTable->fetchAll($select);
        $imgOptions = array();
        if(!empty($array))
            $imgOptions = $array;
        else
            $imgOptions = array('0' => $default);
        foreach ($fileData as $key => $value) {
            $imgOptions[$value->storage_path] =  $value->name;
        }
        return $imgOptions;
    }

    public function getImages($array = array('0' => 'No Image')){
        $coreVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core')->version;
        $checkVersion = Engine_Api::_()->seaocore()->checkVersion($coreVersion, '5.0.0');
        // changes in calling of function on the basis of core version
        if($checkVersion) {
          return $this->getNewVersionImages($array);
        } else {
          return $this->getOldVersionImages($array);
        }
    }

}