<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Favourite.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Api_Following
{

  public function addFollow(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    $table = Engine_Api::_()->getDbtable('follows', 'sitemusic');
    if( empty($table) ) {
      return;
    }
    $followTable = $table->createRow();
    $followTable->resource_id = $resource->getIdentity();
    $followTable->resource_type = $resource->getType();
    $followTable->poster_type = $poster->getType();
    $followTable->poster_id = $poster->getIdentity();
    return $followTable->save();
  }

  public function removeFollowCount($followId)
  {
    $followCountRow = Engine_Api::_()->getItem('sitemusic_user_follow_count', $followId);
    if( empty($followCountRow) ) {
      return;
    }
    if( $followCountRow->follow_count == 1 ) {
      $followCountRow->delete();
    } else {
      $followCountRow->follow_count--;
      $followCountRow->save();
    }
  }

  public function getFollowing($entityType = '')
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewerId = $viewer->getIdentity();

    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
    if( empty($followTable) ) {
      return;
    }
    $fName = $followTable->info('name');

    if( $entityType == 'Artist' || $entityType == 'Album' ) {
      if( $entityType == 'Artist' ) {
        $entity = 'artists';
        $entityId = 'artist_id';
        $resourceType = 'sitemusic_artist';
      } elseif( $entityType == 'Album' ) {
        $entity = 'playlists';
        $entityId = 'playlist_id';
        $resourceType = 'sitemusic_pl';
      }
      $table = Engine_Api::_()->getDbTable($entity, 'sitemusic');
      $tName = $table->info('name');
      $select = $table->select()
        ->from($tName);
      $select->join($fName, "$tName.$entityId = $fName.resource_id", '');
      $select->where('poster_id = ?', $viewerId)
        ->where('resource_type = ?', $resourceType);
    } else {
      $table = Engine_Api::_()->getDbTable('users', 'user');
      $tName = $table->info('name');
      $entityId = 'user_id';
      $resourceType = 'user';

      $select = $table->select()
        ->from($tName);
      $select->join($fName, "$tName.$entityId = $fName.resource_id", '');
      $select->where('poster_id = ?', $viewerId)
        ->where('resource_type = ?', $resourceType);
    }
    return Zend_Paginator::factory($select);
  }

  public function isFollow(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
    if( empty($followTable) ) {
      return;
    }
    $select = $followTable->select()->from($followTable->info('name'), 'follow_id');
    $select->where('poster_type = ?', $poster->getType())
      ->where('poster_id = ?', $poster->getIdentity())
      ->where('resource_type = ?', $resource->getType())
      ->where('resource_id = ?', $resource->getIdentity())
      ->limit(1);
    return ($select->query()->fetchColumn());
  }

  public function removeFollowForUser(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster, $followId)
  {
    $followTable = Engine_Api::_()->getItem('sitemusic_follow', $followId);
    if( empty($followTable) ) {
      return;
    }
    if( $followTable ) {
      $followTable->delete();
    }
  }

}
