<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Favourite.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Api_GeneralWidget extends Core_Api_Abstract
{

  public function getGeneralPaginator($entityType, $params = array())
  {
    if( $entityType == 'Playlist' ) {
      $entity = 'userPlaylists';
      $resourceType = 'sitemusic_userpl';
      $entityId = 'userplaylist_id';
    } elseif( $entityType == 'Song' ) {
      $entity = 'playlistSongs';
      $entityId = 'song_id';
      $resourceType = 'sitemusic_playlist_song';
    } elseif( $entityType == 'Artist' ) {
      $entity = 'artists';
      $entityId = 'artist_id';
      $resourceType = 'sitemusic_artist';
    } else {
      $entity = 'playlists';
      $entityId = 'playlist_id';
      $resourceType = 'sitemusic_pl';
    }
    $likeTable = Engine_Api::_()->getDbTable('likes', 'core');
    $table = Engine_Api::_()->getDbTable($entity, 'sitemusic');
    $tName = $table->info('name');
    $select = $table->select()->from($tName);
    $select->distinct(true);
    if( $params['content_type'] == 'Most_Popular' ) {
      if( $params['popular_type'] == 'like_count' ) {
        $select->order("like_count DESC");
      } else {
        $select->order("comment_count DESC");
      }
    } elseif( $params['content_type'] == 'Latest' ) {
      if( $params['latest_sort'] == 'creation_date' ) {
        $select->order($entityId . ' DESC');
      } else {
        $select->order('modified_date DESC');
      }
    } elseif( $params['content_type'] == 'Most_Liked' ) {
      $name = $likeTable->info('name');
      $select->join($name, "$tName.$entityId= $name.resource_id", array(''));
      $select->where($name . '.resource_type = ?', $resourceType);
      $select->order('like_count DESC');
    } elseif( $params['content_type'] == 'Most_Favourite' ) {
      $select->where($tName . '.favourite_count != ?', 0);
      $select->order($tName . '.favourite_count  DESC');
    } elseif( $params['content_type'] == 'Most_Followed' ) {
      $select->order($tName . '.follow_count  DESC');
    } elseif( $params['content_type'] == 'Most_Downloaded' ) {
      $select->order($tName . '.download_count  DESC');
    } elseif( $params['content_type'] == 'Most_Rated' ) {
      $select->order($tName . '.rating_count  DESC');
    } elseif( $params['content_type'] == 'Most_Played' ) {
      $select->order($tName . '.play_count  DESC');
    } else {
      $select->group("resource_id");
      if( $params['trending_type'] == 'like' ) {
        $likeDatetimeTable = Engine_Api::_()->getDbTable('likeDatetimes', 'sitemusic');
        $likeDateTimeTableName = $likeDatetimeTable->info('name');

        $name = $likeTable->info('name');
        $select->join($name, "$tName.$entityId= $name.resource_id", array(''));
        $select->join($likeDateTimeTableName, "$likeDateTimeTableName.like_id = $name.like_id", array(''));
        $select->where($name . '.resource_type = ?', $resourceType);
        // select trending from like table
        $select = $this->selectTrendingDuration($params, $select, $likeDateTimeTableName);
      } else {
        $commentTable = Engine_Api::_()->getDbTable('comments', 'core');
        $name = $commentTable->info('name');
        $select->join($name, "$tName.$entityId = $name.resource_id", array(''));
        $select->where($name . '.resource_type = ?', $resourceType);
        // select trending from comment table
        $select = $this->selectTrendingDuration($params, $select, $name);
      }
    }

    if( Engine_Api::_()->getApi('core', 'sitemusic')->enableContentBasedPrivacy() ) {
      $select = $this->addConditionalCheck($entityType, $select, true, $tName);
    }

    $select = $this->addConditionalCheck($entityType, $select, null, $tName);
    $paginator = Zend_Paginator::factory($select);
    $count = $paginator->getTotalItemCount();

    if( $count == 0 && $params['content_type'] == 'Trending' ) {
      $select = $table->select()->from($tName);
      $select->order($entityId . ' DESC');

      $select = $this->addConditionalCheck($entityType, $select, null, $tName);

      if( Engine_Api::_()->getApi('core', 'sitemusic')->enableContentBasedPrivacy() ) {
        $select = $this->addConditionalCheck($entityType, $select, true, $tName);
      }
      $select->distinct(true);
      $paginator = Zend_Paginator::factory($select);
      return $paginator;
    }
    return $paginator;
  }

  public function addConditionalCheck($entityType, $select, $isContentBasedPrivacyOn = null, $tName)
  {
    $playlistSongTable = Engine_Api::_()->getDbTable('playlistSongs', 'sitemusic');
    $psName = $playlistSongTable->info('name');
    $playlistTable = Engine_Api::_()->getDbTable('playlists', 'sitemusic');
    $pName = $playlistTable->info('name');

    if( $isContentBasedPrivacyOn ) {
      if( $entityType == 'Album' ) {
        $select->where('song_count != ?', 0);
        $param = array('search' => 1);
        $select = $this->getItemsSelect($select, $param, $tName);
      } elseif( $entityType == 'Playlist' ) {
        $select->where('song_count != ?', 0);
        $select = $this->getItemsSelect($select, null, $tName);
      } elseif( $entityType == 'Song' ) {
        $select->join($pName, "$pName.playlist_id = $psName.playlist_id", '');
        $select = $this->getItemsSelect($select, null, $pName);
      }
      return $select;
    }

    if( $entityType == 'Artist' ) {
      $select->where('approved = ?', 1);
    }
    if( $entityType == 'Song' ) {
      $select->where('status = ?', 1);
      $select->where($psName . '.approved = ?', 1);
    }

    if( $entityType == 'Album' ) {

      $select->join($psName, "$pName.playlist_id = $psName.playlist_id", '');
      $select->where($pName . '.approved = ?', 1);
      $select->where($psName . '.status = ?', 1);
    }
    return $select;
  }

  public function getItemsSelect($select, $params = array(), $tName = null)
  {
    $registeredPrivacy = array('everyone', 'registered');
    $viewer = Engine_Api::_()->user()->getViewer();
    if( $viewer->getIdentity() && !in_array($viewer->level_id, $this->_excludedLevels) ) {
      $viewerId = $viewer->getIdentity();
      $netMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $netMembershipTable->getMembershipsOfIds($viewer);
      if( !empty($viewerNetwork) ) {
        array_push($registeredPrivacy, 'owner_network');
      }

      $friendsIds = $viewer->membership()->getMembersIds();
      $friendsOfFriendsIds = $friendsIds;
      foreach( $friendsIds as $friendId ) {
        $friend = Engine_Api::_()->getItem('user', $friendId);
        $friendMembersIds = $friend->membership()->getMembersIds();
        $friendsOfFriendsIds = array_merge($friendsOfFriendsIds, $friendMembersIds);
      }
    }
    if( !$viewer->getIdentity() ) {
      $select->where("view_privacy = ?", 'everyone');
    } elseif( !in_array($viewer->level_id, $this->_excludedLevels) ) {
      $select->Where($tName . ".owner_id = ?", $viewerId)
        ->orwhere("view_privacy IN (?)", $registeredPrivacy);
      if( !empty($friendsIds) ) {
        $select->orWhere("view_privacy = 'owner_member' AND " . $tName . ".owner_id IN (?)", $friendsIds);
      }
      if( !empty($friendsOfFriendsIds) ) {
        $select->orWhere("view_privacy = 'owner_member_member' AND " . $tName . ".owner_id IN (?)", $friendsOfFriendsIds);
      }
      if( empty($viewerNetwork) && !empty($friendsOfFriendsIds) ) {
        $select->orWhere("view_privacy = 'owner_network' AND " . $tName . ".owner_id IN (?)", $friendsOfFriendsIds);
      }

      $subquery = $select->getPart(Zend_Db_Select::WHERE);
      $select->reset(Zend_Db_Select::WHERE);
      $select->where(implode(' ', $subquery));
    }

    if( isset($params['search']) ) {
      $select->where("search = ?", $params['search']);
    }
    return $select;
  }

  protected function selectTrendingDuration($params, $select, $name)
  {
    $week = date('Y-m-d H:i:s', time() - (7 * 86400));
    $twoWeek = date('Y-m-d H:i:s', time() - (14 * 86400));
    $month = date('Y-m-d H:i:s', time() - (30 * 86400));

    if( $params['trending_sort'] == 'last_month' ) {
      $select->where($name . '.creation_date >= ?', $month);
    } elseif( $params['trending_sort'] == 'last_week' ) {
      $select->where($name . '.creation_date >= ?', $week);
    } else {
      $select->where($name . '.creation_date >= ?', $twoWeek);
    }
    return $select;
  }

}
