<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Rated.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Api_Rated
{

  public function getRated($entityType = '', $info = array())
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewerId = $viewer->getIdentity();

    if( $entityType == 'Playlist' ) {
      $entity = 'userPlaylists';
      $resourceType = 'sitemusic_userpl';
      $entityId = 'userplaylist_id';
    } elseif( $entityType == 'Song' ) {
      $entity = 'playlistSongs';
      $entityId = 'song_id';
      $resourceType = 'sitemusic_playlist_song';
    } elseif( $entityType == 'Artist' ) {
      $entity = 'artists';
      $entityId = 'artist_id';
      $resourceType = 'sitemusic_artist';
    } else {
      $entity = 'playlists';
      $entityId = 'playlist_id';
      $resourceType = 'sitemusic_pl';
    }
    $table = Engine_Api::_()->getDbTable($entity, 'sitemusic');
    $tName = $table->info('name');
    $ratingTable = Engine_Api::_()->getDbtable('ratings', 'sitemusic');
    $rName = $ratingTable->info('name');
    $select = $table->select()
      ->from($tName);

    if( isset($info['album_category']) && $info['album_category'] != 'all' ) {
      $select->where('category_id = ?', $info['album_category']);
    }

    if( isset($info['genre_id']) && $info['genre_id'] != 'all' ) {
      $select->where('genre_id = ?', $info['genre_id']);
    }

    $select->join($rName, "$tName.$entityId = $rName.resource_id", '');
    $select->where($rName.'.user_id = ?', $viewerId)
      ->where('resource_type = ?', $resourceType);
    return Zend_Paginator::factory($select);
  }

  public function setRatingScore($itemId, $resourceType, $ratingCount, $ratingPer)
  {
    if( $resourceType == 'sitemusic_pl' ) {
      $entity = 'playlists';
    } elseif( $resourceType == 'sitemusic_artist' ) {
      $entity = 'artists';
    } elseif( $resourceType == 'sitemusic_playlist_song' ) {
      $entity = 'playlistSongs';
    } elseif( $resourceType == 'sitemusic_userpl' ) {
      $entity = 'userPlaylists';
    }
    $entityTable = Engine_Api::_()->getDbTable($entity, 'sitemusic');
    $select = $entityTable->select()->from($entityTable->info('name'), array('count(rating_count) as totalRatingCount'));
    $totalRatingCount = $select->query()->fetchColumn();
    $ratingScore = (($ratingCount / $totalRatingCount) * 100 + 2 * $ratingPer);

    $item = Engine_Api::_()->getItem($resourceType, $itemId);
    if( $ratingScore ) {
      $item->rating_score = $ratingScore;
      $item->save();
    }
  }

}
