<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: create.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_AddAlbumSong extends Engine_Form
{

  protected $_playlist;
  protected $_roles = array(
    'everyone' => 'Everyone',
    'registered' => 'All Registered Members',
    'owner_network' => 'Friends and Networks',
    'owner_member_member' => 'Friends of Friends',
    'owner_member' => 'Friends Only',
    'owner' => 'Just Me'
  );

  public function init()
  {
    $playlistId = $this->_attribs['playlist_id'];
    $coreVersion = $this->_attribs['core_version'];
    // Init form
    $this
      ->setTitle('Add New Songs')
      ->setAttrib('id', 'form-upload-sitemusic')
      ->setAttrib('name', 'playlist_create')
      ->setAttrib('enctype', 'multipart/form-data')
      ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
    ;

    $url = false;
    $viewer = Engine_Api::_()->user()->getViewer();
    // checking url upload is enable or not
    $urlEnable = Engine_Api::_()->authorization()->isAllowed('sitemusic_pl', $viewer->level_id, 'url');
    $isUrlEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_url', 1);

    if( $isUrlEnable ) {
      if( $urlEnable ) {
        $url = true;
      }
    }
    $uploadUrl = Zend_Controller_Front::getInstance()->getRouter()->assemble(array()) . '?ul=1';

    $data = array(
      'fileIdsElement' => 'fancyuploadfileids',
      'remoteFile' => $url,
      'populateFiles' => '',
      'linkDescription' => 'Click ‘Add Music’ to select one or more songs from your device.',
    );

    $this->addElement('SeaoFancyUpload', 'file', array(
      'url' => $uploadUrl,
      'fileType' => 'audio',
      'data' => $data,
    ));

    $this->addElement('Hidden', 'fancyuploadfileids', array(
      'order' => '123'
    ));

    // Init submit
    $this->addElement('Button', 'submit', array(
      'label' => 'Save music to Album',
      'type' => 'submit',
    ));
  }

  public function clearUploads()
  {
    $this->getElement('fancyuploadfileids')->setValue('');
  }

  public function saveValues($playlistId)
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $level_id = $viewer->level_id;
    $playlist = null;
    $values = $this->getValues();
    if( $playlistId ) {
      $playlist = Engine_Api::_()->getItem('sitemusic_pl', $playlistId);
      $totalSong = 0;
      $songIds = array();


      foreach( explode(' ', $values['fancyuploadfileids']) as $file_id ) {
        $file_id = trim($file_id);
        if( !empty($file_id) ) {
          if( $viewer->getIdentity() != $playlist->getOwner()->getIdentity() ) {
            $songApprove = 0;
          } else {
            $songApprove = 1;
          }
          $song = $playlist->addSong($file_id, $songApprove);
          $totalSong++;
          if( $song ) {
            $songIds[] = $song->getIdentity();
          }
        }
      }
      $totSong = $playlist->song_count;
      $playlist->song_count = $totalSong + $totSong;
      $playlist->save();

      $values['playlist'] = $playlist;
      $values['song_ids'] = $songIds;
      return $values;
    }
  }

}
