<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AlbumGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_AlbumGeneral extends Sitemusic_Form_Admin_Widget_Script_Album
{

  public function init()
  {
    parent::init();

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Choose Label',
        'multiOptions' => $labelOption,
      ));
    }

    $albumCategoryTable = Engine_Api::_()->getDbtable('albumcategories', 'sitemusic');
    $albumType = $albumCategoryTable->getCategoriesAssoc();
    $albumOption = array("all" => "All");
    if( !empty($albumType) ) {
      $albumOption = $albumOption + $albumType;
      $this->addElement('Select', 'album_category', array(
        'label' => 'Music Album Category',
        'multiOptions' => $albumOption,
      ));
    }

    $this->addElement('MultiCheckbox', 'album_layout_views', array(
      'label' => 'Select the view types for music albums.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "gridZZZview" => "Grid View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Mini List View",
      ),
      'onclick' => 'onLayoutSelect()',
    ));

    $this->addElement('Radio', 'albumDefaultLayout', array(
      'label' => 'Select a default view type for music albums.',
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "gridZZZview" => "Grid View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Mini List View",
      )
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width For Grid View.',
      'value' => '180',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

    $this->addElement('Text', 'cardViewWidth', array(
      'label' => 'Column width For Card View.',
      'value' => '371',
    ));

    $this->addElement('Text', 'cardViewHeight', array(
      'label' => 'Column height For Card View.',
      'value' => '402',
    ));

    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $albumOptions = $coreApi->getAlbumOptions();
    $albumViewOptions = $coreApi->getAlbumListViewOptions();

    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the music albums in this block.',
      'multiOptions' => $albumOptions
    ));

    $this->addElement('MultiCheckbox', 'showSongOptions', array(
      'label' => 'Choose the option that you want to be available for the songs displaying in list view/card view of music albums in this block.',
      'multiOptions' => $albumViewOptions
    ));


    $multiTabs = array(
      'Trending' => 'Trending',
      'Latest' => 'Latest',
      'MostZZZLiked' => 'Most Liked',
      'MostZZZPopular' => 'Most Popular',
      'MostZZZFavourite' => 'Most Favourite',
      'MostZZZDownloaded' => 'Most Downloaded',
      'MostZZZFollowed' => 'Most Followed',
      'MostZZZRated' => 'Most Rated'
    );

    if( !(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_enable_download', 1)) ) {
      unset($multiTabs['MostZZZDownloaded']);
    }

    $this->addElement('MultiCheckbox', 'ajaxTabs', array(
      'label' => 'Select the tabs that you want to be available in this block.',
      'required' => true,
      'multiOptions' => $multiTabs,
      'onclick' => 'onMultiCheckBoxSelect()',
    ));

    $this->addElement('Select', 'trendingType', array(
      'label' => 'Trending Criteria.',
      'multiOptions' => array(
        "like" => "Like",
        "comment" => "Comment",
      ),
      'value' => 'like',
    ));

    $this->addElement('Select', 'trendingSort', array(
      'label' => 'Trending Duration.',
      'multiOptions' => array(
        "last_week" => "Last Week",
        "last_twoweek" => "Last Two Weeks",
        "last_month" => "Last Month",
      ),
      'value' => 'last_week',
    ));

    $this->addElement('Select', 'latestSort', array(
      'label' => 'Latest By.',
      'multiOptions' => array(
        "creation_date" => "Creation Date",
        "modified_date" => "Modified Date",
      ),
      'value' => 'creation_date',
    ));

    $this->addElement('Select', 'popularType', array(
      'label' => 'Popular Criteria.',
      'multiOptions' => array(
        "like_count" => "Like Count",
        "comment_count" => "Comment Count",
      ),
      'value' => 'like_count',
    ));

    $this->addElement('Text', 'listTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Player View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'cardTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Card View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Grid View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit in Mini List View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

        $this->addElement('Text', 'Trending', array(
      'label' => 'Trending Tab (order)',
      'value' => 1,
    ));

    $this->addElement('Text', 'Latest', array(
      'label' => 'Latest Tab (order)',
      'value' => 2,
    ));

    $this->addElement('Text', 'MostZZZPopular', array(
      'label' => 'Most Popular Tab (order)',
      'value' => 3,
    ));

    $this->addElement('Text', 'MostZZZLiked', array(
      'label' => 'Most Liked Tab (order)',
      'value' => 4,
    ));

    $this->addElement('Text', 'MostZZZFavourite', array(
      'label' => 'Most Favourite Tab (order)',
      'value' => 5,
    ));

    if( Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_enable_download', 1) ) {
      $this->addElement('Text', 'MostZZZDownloaded', array(
        'label' => 'Most Downloaded Tab (order)',
        'value' => 6,
      ));
    }

    $this->addElement('Text', 'MostZZZFollowed', array(
      'label' => 'Most Followed Tab (order)',
      'value' => 7,
    ));

    $this->addElement('Text', 'MostZZZRated', array(
      'label' => 'Most Rated Tab (order)',
      'value' => 8,
    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>
<script type="text/javascript">

  en4.core.runonce.add(function () {
    onMultiCheckBoxSelect();
    onLayoutSelect();

  });
  function onMultiCheckBoxSelect()
  {
    if ($('ajaxTabs-Trending').checked)
    {
      $('trendingType-wrapper').style.display = 'block';
      $('trendingSort-wrapper').style.display = 'block';
    } else {
      $('trendingType-wrapper').style.display = 'none';
      $('trendingSort-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-Latest').checked)
    {
      $('latestSort-wrapper').style.display = 'block';
    } else {
      $('latestSort-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-MostZZZPopular').checked)
    {
      $('popularType-wrapper').style.display = 'block';
    } else {
      $('popularType-wrapper').style.display = 'none';
    }
  }

  function onLayoutSelect()
  {
    if ($('album_layout_views-listZZZview').checked) {
      $('albumDefaultLayout-listZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-listZZZview').disabled = true;
    }
    if ($('album_layout_views-gridZZZview').checked) {
      $('albumDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('album_layout_views-cardZZZview').checked) {
      $('albumDefaultLayout-cardZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-cardZZZview').disabled = true;
    }
    if ($('album_layout_views-thumbnailZZZview').checked) {
      $('albumDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-thumbnailZZZview').disabled = true;
    }

    if ($('album_layout_views-listZZZview').checked || $('album_layout_views-cardZZZview').checked) {
      $('showSongOptions-wrapper').style.display = 'block';
    } else {
      $('showSongOptions-wrapper').style.display = 'none';
    }
  }

</script>