<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: ArtistGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_ArtistGeneral extends Core_Form_Admin_Widget_Standard
{

  public function init()
  {
    parent::init();

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Choose Label',
        'multiOptions' => $labelOption,
      ));
    }

    $this->addElement('MultiCheckbox', 'artist_layout_views', array(
      'label' => 'Select the view types for artists.',
      'multiOptions' => array(
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      ),
      'onclick' => 'onLayoutSelect()',
    ));

    $this->addElement('Radio', 'artistDefaultLayout', array(
      'label' => 'Select a default view type for artists.',
      'required' => true,
      'multiOptions' => array(
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      )
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width for Grid View.',
      'value' => '180',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

    $artistOptions = Engine_Api::_()->getApi('core', 'sitemusic')->getArtistOptions();
    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the artists in this block.',
      'multiOptions' => $artistOptions
    ));

    $this->addElement('MultiCheckbox', 'ajaxTabs', array(
      'label' => 'Select the tabs that you want to be available in this block.',
      'required' => true,
      'multiOptions' => array(
        'Trending' => 'Trending',
        'MostZZZLiked' => 'Most Liked',
        'MostZZZPopular' => 'Most Popular',
        'MostZZZFavourite' => 'Most Favourite',
        'MostZZZFollowed' => 'Most Followed',
        'MostZZZRated' => 'Most Rated'
      ),
      'onclick' => 'onMultiCheckBoxSelect()',
      'value' => array('Trending', 'MostZZZLiked', 'MostZZZPopular')
    ));

    $this->addElement('Select', 'trendingType', array(
      'label' => 'Trending Criteria',
      'multiOptions' => array(
        "like" => "Like",
        "comment" => "Comment",
      ),
      'value' => 'like',
    ));

    $this->addElement('Select', 'trendingSort', array(
      'label' => 'Trending Duration',
      'multiOptions' => array(
        "last_week" => "Last Week",
        "last_twoweek" => "Last Two Weeks",
        "last_month" => "Last Month",
      ),
      'value' => 'last_week',
    ));

    $this->addElement('Select', 'popularType', array(
      'label' => 'Popular Criteria',
      'multiOptions' => array(
        "like_count" => "Like Count",
        "comment_count" => "Comment Count",
      ),
      'value' => 'like_count',
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Mini List View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit in Grid View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'Trending', array(
      'label' => 'Trending Tab (order)',
      'value' => 1,
    ));

    $this->addElement('Text', 'MostZZZPopular', array(
      'label' => 'Most Popular Tab (order)',
      'value' => 2,
    ));

    $this->addElement('Text', 'MostZZZLiked', array(
      'label' => 'Most Liked Tab (order)',
      'value' => 3,
    ));

    $this->addElement('Text', 'MostZZZFavourite', array(
      'label' => 'Most Favourite Tab (order)',
      'value' => 4,
    ));

    $this->addElement('Text', 'MostZZZFollowed', array(
      'label' => 'Most Followed Tab (order)',
      'value' => 5,
    ));

    $this->addElement('Text', 'MostZZZRated', array(
      'label' => 'Most Rated Tab (order)',
      'value' => 6,
    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of item to show)',
      'value' => 5,
    ));
  }

}
?>

<script type="text/javascript">

  en4.core.runonce.add(function () {
    onMultiCheckBoxSelect();
    onLayoutSelect();

  });
  function onMultiCheckBoxSelect()
  {
    if ($('ajaxTabs-Trending').checked)
    {
      $('trendingType-wrapper').style.display = 'block';
      $('trendingSort-wrapper').style.display = 'block';
    } else {
      $('trendingType-wrapper').style.display = 'none';
      $('trendingSort-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-MostZZZPopular').checked)
    {
      $('popularType-wrapper').style.display = 'block';
    } else {
      $('popularType-wrapper').style.display = 'none';
    }
  }

  function onLayoutSelect()
  {
    if ($('artist_layout_views-gridZZZview').checked) {
      $('artistDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('artistDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('artist_layout_views-thumbnailZZZview').checked) {
      $('artistDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('artistDefaultLayout-thumbnailZZZview').disabled = true;
    }
  }

</script>