<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Album.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_Browse_Album extends Sitemusic_Form_Admin_Widget_Script_Album
{

  public function init()
  {
    parent::init();

    $integratedModules = Engine_Api::_()->getDbtable('modules', 'sitemusic')->getIntegratedModulesArray();
    if( count($integratedModules) > 1 ) {
      $this->addElement('Select', 'item_type', array(
        'label' => '',
        'multiOptions' => $integratedModules,
      ));
    }

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Label',
        'multiOptions' => $labelOption,
      ));
    }

    $this->addElement('MultiCheckbox', 'album_layout_views', array(
      'label' => 'Select the view types for music albums.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "gridZZZview" => "Grid View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Mini List View",
      ),
      'onclick' => 'onLayoutSelect()'
    ));

    $this->addElement('Radio', 'albumDefaultLayout', array(
      'label' => 'Select a default view type for music albums.',
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "gridZZZview" => "Grid View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Mini List View",
      )
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column Width for Grid View.',
      'value' => '167',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

//    $this->addElement('Text', 'gridViewHeight', array(
//      'label' => 'Column Height For Grid View.',
//      'value' => '328',
//    ));

    $this->addElement('Text', 'cardViewWidth', array(
      'label' => 'Column Width for Card View.',
      'value' => '371',
    ));

    $this->addElement('Text', 'cardViewHeight', array(
      'label' => 'Column Height for Card View.',
      'value' => '402',
    ));
    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $albumOptions = $coreApi->getAlbumOptions();
    $albumViewOptions = $coreApi->getAlbumListViewOptions();

    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the music albums in this block.',
      'multiOptions' => $albumOptions
    ));

    $this->addElement('MultiCheckbox', 'showSongOptions', array(
      'label' => 'Choose the option that you want to be available for the songs displaying in list view/card view of music albums in this block.',
      'multiOptions' => $albumViewOptions
    ));

    $this->addElement('Radio', 'default_sort', array(
      'label' => 'Default ordering in browse music album',
      'multiOptions' => array(
        'creationDate' => 'All music albums in descending order of creation',
        'ascendingOrder' => 'All music album in ascending order of creation',
        'alphabetic' => 'All music album in alphabetical order'),
      'value' => 'creationDate'
    ));

    $this->addElement('Text', 'listTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Player View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'cardTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Card View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Grid View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Mini List View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Radio', 'Show “View More”', array(
      'label' => 'Show view more',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>
<script>
  en4.core.runonce.add(function () {
    window.setTimeout(onLayoutSelect, 1000);
  });

  function onLayoutSelect()
  {
    var listView = $('album_layout_views-listZZZview');
    var gridView = $('album_layout_views-gridZZZview');
    var cardView = $('album_layout_views-cardZZZview');
    var thumbnailView = $('album_layout_views-thumbnailZZZview');


    if ($('album_layout_views-listZZZview').checked) {
      $('albumDefaultLayout-listZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-listZZZview').disabled = true;
    }
    if ($('album_layout_views-gridZZZview').checked) {
      $('albumDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('album_layout_views-cardZZZview').checked) {
      $('albumDefaultLayout-cardZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-cardZZZview').disabled = true;
    }
    if ($('album_layout_views-thumbnailZZZview').checked) {
      $('albumDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-thumbnailZZZview').disabled = true;
    }

    if ($('album_layout_views-listZZZview').checked || $('album_layout_views-cardZZZview').checked) {
      $('showSongOptions-wrapper').style.display = 'block';
    } else {
      $('showSongOptions-wrapper').style.display = 'none';
    }
  }
</script>