<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AlbumGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_Carousel_CarouselWidget extends Core_Form_Admin_Widget_Standard
{

  public function init()
  {
    parent::init();

    $entities = Engine_Api::_()->getDbtable('entities', 'sitemusic')->getEntity();
    if( !empty($entities) ) {
      $this->addElement('MultiCheckbox', 'ajaxTabs', array(
        'label' => 'Choose the music entities that you want to be available in this block.',
        'multiOptions' => $entities,
        'onclick' => 'onMultiCheckBoxSelect()',
      ));
    }

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Grid View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $albumCategoryTable = Engine_Api::_()->getDbtable('albumcategories', 'sitemusic');
    $albumType = $albumCategoryTable->getCategoriesAssoc();
    $albumOption = array("all" => "All");
    if( !empty($albumType) ) {
      $albumOption = $albumOption + $albumType;
    }
    $this->addElement('Select', 'albumcategory_id', array(
      'label' => 'Album Category',
      'multiOptions' => $albumOption,
    ));

    $songCategoryTable = Engine_Api::_()->getDbtable('songcategories', 'sitemusic');
    $genereType = $songCategoryTable->getCategoriesAssoc();
    if( !empty($genereType) ) {
      $subType = $songCategoryTable->getSubCategoriesAssoc($genereType);
    }
    $genreOption = array("All" => "All");
    if( !empty($subType) ) {
      $genreOption = $genreOption + $subType;
    }
    $this->addElement('Select', 'genre_id', array(
      'label' => 'Genre',
      'multiOptions' => $genreOption,
    ));

    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $albumOptions = $coreApi->getAlbumOptions();
    $albumOptions = $coreApi->getAlbumOptions();

    $this->addElement('MultiCheckbox', 'albumShowOptions', array(
      'label' => 'Choose the option that you want to be available for the block.',
      'multiOptions' => array(
        "albumFavourite" => "Album Favourite",
        "albumLike" => "Album Like",
        "albumRating" => "Album Rating",
        "albumShare" => "Album Share",
        "albumQueue" => "Add To Queue",
        "albumInfo" => "Album Info",
        "albumPlay" => "Album Play",
        "albumPlayCount" => "Album Play Count",
        "albumFavouriteCount" => "Album Favourite Count",
        "albumDownloadCount" => "Album Download Count",
        "albumCommentCount" => "Album Comment Count",
        "albumLikeCount" => "Like Count",
        "albumLabel" => "Album Label",
        "songCount" => "Song Count",
      )
    ));

    $this->addElement('Text', 'carouselHeight', array(
      'label' => 'Column height for Image.',
      'value' => '200',
    ));

    $songOptions = Engine_Api::_()->getApi('core', 'sitemusic')->getSongOptions();
    $this->addElement('MultiCheckbox', 'songShowOptions', array(
      'label' => 'Choose the option that you want to be available for the block.',
      'multiOptions' => $songOptions
    ));

    $this->addElement('MultiCheckbox', 'playlistShowOptions', array(
      'label' => 'Choose the option that you want to be available for the block.',
      'multiOptions' => array(
        "playlistFavourite" => "Playlist Favourite",
        "playlistLike" => "Playlist Like",
        "playlistRating" => "Playlist Rating",
        "playlistShare" => "Playlist Share",
        "playlistPlay" => "Playlist Play",
        "playlistFavouriteCount" => "Playlist Favourite Count",
        "playlistLikeCount" => "Like Count",
        "playlistCommentCount" => "Playlist Comment Count",
        "playlistLabel" => "Playlist Label",
        "songCount" => "Song Count",
      )
    ));

    $artistOptions = Engine_Api::_()->getApi('core', 'sitemusic')->getArtistOptions();
    $this->addElement('MultiCheckbox', 'artistShowOptions', array(
      'label' => 'Choose the option that you want to be available for the block.',
      'multiOptions' => $artistOptions
    ));


    $this->addElement('Text', 'Album', array(
      'label' => 'Album Tab (order)',
      'value' => 1,
    ));

    $this->addElement('Text', 'Playlist', array(
      'label' => 'Playlist Tab (order)',
      'value' => 2,
    ));

    $this->addElement('Text', 'Song', array(
      'label' => 'Song Tab (order)',
      'value' => 3,
    ));

    $this->addElement('Text', 'Artist', array(
      'label' => 'Aritst Tab (order)',
      'value' => 4,
    ));

    $this->addElement('Radio', 'autoPlay', array(
      'label' => 'Do you want to auto play the items in carousel?',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'
      ),
      'value' => 0,
    ));


    $this->addElement('Text', 'slideItemlimitM', array(
      'label' => 'How many items do you want to display in one slide of Mobile devices?',
      'description' => '(number of items to show)',
      'value' => 1,
    ));

    $this->addElement('Text', 'slideItemlimitT', array(
      'label' => 'How many items do you want to display in one slide of Tablets (Screen size of about 500px)',
      'description' => '(number of items to show)',
      'value' => 2,
    ));

    $this->addElement('Text', 'slideItemlimit', array(
      'label' => 'How many items do you want to display in one slide of Full Screen (About 1000px)',
      'description' => '(number of items to show)',
      'value' => 3,
    ));

    $this->addElement('Radio', 'seeAll', array(
      'label' => 'Do you want to display ‘See All’ option in carousel?',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'
      ),
      'value' => 1,
    ));

    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 10,
    ));
  }

}
?>
<script type="text/javascript">

  en4.core.runonce.add(function () {
    window.setTimeout(onMultiCheckBoxSelect, 1000);
  });
  function onMultiCheckBoxSelect()
  {
    if ($('ajaxTabs-album').checked) {
      $('albumShowOptions-wrapper').style.display = 'block';
      $('Album-wrapper').style.display = 'block';
      if ($('albumcategory_id-wrapper')) {
        $('albumcategory_id-wrapper').style.display = 'block';
      }
      if ($('trendingType-wrapper')) {
        $('trendingType-wrapper').style.display = 'block';
      }
      if ($('trendingSort-wrapper')) {
        $('trendingSort-wrapper').style.display = 'block';
      }
      if ($('latestSort-wrapper')) {
        $('latestSort-wrapper').style.display = 'block';
      }
      if ($('popularType-wrapper')) {
        $('popularType-wrapper').style.display = 'block';
      }
    } else {
      $('albumShowOptions-wrapper').style.display = 'none';
      $('Album-wrapper').style.display = 'none';
      if ($('albumcategory_id-wrapper')) {
        $('albumcategory_id-wrapper').style.display = 'none';
      }
      if ($('trendingType-wrapper')) {
        $('trendingType-wrapper').style.display = 'none';
      }
      if ($('trendingSort-wrapper')) {
        $('trendingSort-wrapper').style.display = 'none';
      }
      if ($('latestSort-wrapper')) {
        $('latestSort-wrapper').style.display = 'none';
      }
      if ($('popularType-wrapper')) {
        $('popularType-wrapper').style.display = 'none';
      }
    }

    if ($('ajaxTabs-artist').checked) {
      $('artistShowOptions-wrapper').style.display = 'block';
      $('Artist-wrapper').style.display = 'block';
    } else {
      $('artistShowOptions-wrapper').style.display = 'none';
      $('Artist-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-playlist').checked) {
      $('playlistShowOptions-wrapper').style.display = 'block';
      $('Playlist-wrapper').style.display = 'block';
    } else {
      $('playlistShowOptions-wrapper').style.display = 'none';
      $('Playlist-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-song').checked) {
      $('songShowOptions-wrapper').style.display = 'block';
      $('Song-wrapper').style.display = 'block';
      $('genre_id-wrapper').style.display = 'block';
    } else {
      $('songShowOptions-wrapper').style.display = 'none';
      $('Song-wrapper').style.display = 'none';
      $('genre_id-wrapper').style.display = 'none';
    }
  }

</script>