<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PlaylistGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_User_Playlist extends Sitemusic_Form_Admin_Widget_Script_Playlist
{

  public function init()
  {
    parent::init();

    $this->addElement('MultiCheckbox', 'playlist_layout_views', array(
      'label' => 'Choose the view types for playlist that you want to be available for the widget.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "cardZZZview" => "Card View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Thumbnail View"
      ),
      'onclick' => 'onLayoutSelect()'
    ));

    $this->addElement('Radio', 'playlistDefaultLayout', array(
      'label' => 'Choose the default view types for playlist that you want to be available for the widget.',
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "cardZZZview" => "Card View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Thumbnail View"
      ),
      'value' => 'list_view',
    ));

    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $playlistOptions = $coreApi->getPlaylistOptions();
    $playlistViewOptions = $coreApi->getUserPlaylistViewOptions();

    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the block.',
      'multiOptions' => $playlistOptions
    ));

    $this->addElement('MultiCheckbox', 'showSongOptions', array(
      'label' => 'Choose the option that you want to be available for the songs displaying in list view/card view of playlists in this block.',
      'multiOptions' => $playlistViewOptions
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width For Grid View.',
      'value' => '180',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

    $this->addElement('Text', 'cardViewWidth', array(
      'label' => 'Column width for Card View.',
      'value' => '279',
    ));

    $this->addElement('Text', 'cardViewHeight', array(
      'label' => 'Column height for Card View.',
      'value' => '328',
    ));

    $this->addElement('Text', 'titleTruncationLimit', array(
      'label' => 'Title Truncation Limit',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Grid View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));



    $this->addElement('Radio', 'default_sort', array(
      'label' => 'Default ordering of playlists',
      'multiOptions' => array(
        'creationDate' => 'All playlists in descending order of creation',
        'ascendingOrder' => 'All playlists in ascending order of creation',
        'alphabetic' => 'All playlists in alphabetical order'),
      'value' => 'creationDate'
    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>

<script>
  en4.core.runonce.add(function () {
    window.setTimeout(onLayoutSelect, 1000);
  });

  function onLayoutSelect()
  {
    var listView = $('playlist_layout_views-listZZZview');
    var cardView = $('playlist_layout_views-cardZZZview');
    var thumbnailView = $('playlist_layout_views-thumbnailZZZview');

    if ($('playlist_layout_views-listZZZview').checked) {
      $('playlistDefaultLayout-listZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-listZZZview').disabled = true;
    }
    if ($('playlist_layout_views-gridZZZview').checked) {
      $('playlistDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('playlist_layout_views-cardZZZview').checked) {
      $('playlistDefaultLayout-cardZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-cardZZZview').disabled = true;
    }
    if ($('playlist_layout_views-thumbnailZZZview').checked) {
      $('playlistDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-thumbnailZZZview').disabled = true;
    }

//    if (!(listView.checked) && !(cardView.checked) && !(thumbnailView.checked)) {
//      $('showOptions-playlistLike').parentElement.style.display = 'block';
//      $('showOptions-songRating').parentElement.style.display = 'block';
//      $('showOptions-songLike').parentElement.style.display = 'block';
//      if ($('showOptions-songDownload')) {
//        $('showOptions-songDownload').parentElement.style.display = 'block';
//      }
//      $('showOptions-songRating').parentElement.style.display = 'block';
//      $('showOptions-songFavourite').parentElement.style.display = 'block';
//      $('showOptions-songPlay').parentElement.style.display = 'block';
//      $('showOptions-songQueue').parentElement.style.display = 'block';
//      $('showOptions-songShare').parentElement.style.display = 'block';
//      $('showOptions-addToPlaylist').parentElement.style.display = 'block';
//      $('showOptions-songCount').parentElement.style.display = 'block';
//      $('showOptions-songFavouriteCount').parentElement.style.display = 'block';
//      $('showOptions-albumName').parentElement.style.display = 'block';
//      $('showOptions-playlistSongDelete').parentElement.style.display = 'block';
//    }
//
//    if (listView.checked) {
//      $('showOptions-playlistLike').parentElement.style.display = 'block';
//      $('showOptions-songRating').parentElement.style.display = 'block';
//      $('showOptions-songLike').parentElement.style.display = 'block';
//      if ($('showOptions-songDownload')) {
//        $('showOptions-songDownload').parentElement.style.display = 'block';
//      }
//      $('showOptions-songRating').parentElement.style.display = 'block';
//      $('showOptions-songFavourite').parentElement.style.display = 'block';
//      $('showOptions-songPlay').parentElement.style.display = 'block';
//      $('showOptions-songQueue').parentElement.style.display = 'block';
//      $('showOptions-songShare').parentElement.style.display = 'block';
//      $('showOptions-addToPlaylist').parentElement.style.display = 'block';
//      $('showOptions-songCount').parentElement.style.display = 'block';
//      $('showOptions-songFavouriteCount').parentElement.style.display = 'block';
//      $('showOptions-albumName').parentElement.style.display = 'block';
//      $('showOptions-playlistSongDelete').parentElement.style.display = 'block';
//
//    }
//
//    if (cardView.checked && !(listView.checked)) {
//      $('showOptions-songLike').parentElement.style.display = 'none';
//      $('showOptions-songPlay').parentElement.style.display = 'block';
//      $('showOptions-songFavourite').parentElement.style.display = 'block';
//      $('showOptions-songQueue').parentElement.style.display = 'block';
//      $('showOptions-songShare').parentElement.style.display = 'block';
//      $('showOptions-addToPlaylist').parentElement.style.display = 'block';
//      $('showOptions-songCount').parentElement.style.display = 'block';
//      $('showOptions-songFavouriteCount').parentElement.style.display = 'block';
//      $('showOptions-playlistLike').parentElement.style.display = 'block';
//      $('showOptions-songRating').parentElement.style.display = 'block';
//      if ($('showOptions-songDownload')) {
//        $('showOptions-songDownload').parentElement.style.display = 'block';
//      }
//      $('showOptions-albumName').parentElement.style.display = 'block';
//      $('showOptions-playlistSongDelete').parentElement.style.display = 'block';
//    }
//
//    if (thumbnailView.checked && !(listView.checked) && !(cardView.checked)) {
//      $('showOptions-playlistLike').parentElement.style.display = 'none';
//      $('showOptions-songRating').parentElement.style.display = 'none';
//      $('showOptions-playlistComment').parentElement.style.display = 'none';
//      $('showOptions-songLike').parentElement.style.display = 'none';
//      if ($('showOptions-songDownload')) {
//        $('showOptions-songDownload').parentElement.style.display = 'block';
//      }
//      $('showOptions-songRating').parentElement.style.display = 'none';
//      $('showOptions-songFavourite').parentElement.style.display = 'none';
//      $('showOptions-songPlay').parentElement.style.display = 'none';
//      $('showOptions-songQueue').parentElement.style.display = 'none';
//      $('showOptions-songShare').parentElement.style.display = 'none';
//      $('showOptions-addToPlaylist').parentElement.style.display = 'none';
//      $('showOptions-songCount').parentElement.style.display = 'none';
//      $('showOptions-songFavouriteCount').parentElement.style.display = 'none';
//      $('showOptions-albumName').parentElement.style.display = 'none';
//      $('showOptions-playlistSongDelete').parentElement.style.display = 'none';
//    }

    if ($('playlist_layout_views-listZZZview').checked || $('playlist_layout_views-cardZZZview').checked) {
      $('showSongOptions-wrapper').style.display = 'block';
    } else {
      $('showSongOptions-wrapper').style.display = 'none';
    }

    if (thumbnailView.checked || cardView.checked) {
      if ($('showOptions-songDownload')) {
        $('showOptions-songDownload').parentElement.style.display = 'block';
      }
    }
  }
</script>