<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: create.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Create extends Engine_Form
{

  protected $_playlist;
  protected $_roles = array(
    'everyone' => 'Everyone',
    'registered' => 'All Registered Members',
    'owner_network' => 'Friends and Networks',
    'owner_member_member' => 'Friends of Friends',
    'owner_member' => 'Friends Only',
    'owner' => 'Just Me'
  );

  public function init()
  {
    $auth = Engine_Api::_()->authorization()->context;
    $user = Engine_Api::_()->user()->getViewer();
    $level_id = $user->level_id;

    if( isset($this->_attribs['othersPlgingCreation']) ) {
      $othersPlgingCreationParams = $this->_attribs['othersPlgingCreation'];
    }
    // Init form
    $this
      ->setTitle('Add New Songs')
      ->setAttrib('id', 'form-upload-sitemusic')
      ->setAttrib('name', 'playlist_create')
      ->setAttrib('enctype', 'multipart/form-data')
      ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
    ;
    $playlistTable = Engine_Api::_()->getDbtable('playlists', 'sitemusic');
    $albumList = $playlistTable->getCategoriesAssoc();
    $othersPlugin = false;
    if( isset($othersPlgingCreationParams['parent_type']) && isset($othersPlgingCreationParams['parent_id']) ) {
      $othersModuleAlbumList = $playlistTable->getAlbumOptionForOtherPlugin($othersPlgingCreationParams);
      $othersPlugin = true;
    }
    $albumOptions = array("0" => "Create New Album");
    if( !empty($albumList) ) {
      $albumOptions = $albumOptions + $albumList;
    }

    // for others plugin integraion
    if( $othersPlugin ) {
      $albumOptions = array("0" => "Create New Album");
    }
    if( !empty($othersModuleAlbumList) && isset($othersModuleAlbumList) ) {
      $albumOptions = $albumOptions + $othersModuleAlbumList;
    }
    $this->addElement('Select', 'album_option', array(
      'label' => 'Choose Album',
      'multiOptions' => $albumOptions,
      'onchange' => 'javascript:onTypeChange(this.value);',
    ));

    // Init name
    $this->addElement('Text', 'title', array(
      'label' => 'Album Name',
      'maxlength' => '63',
      'filters' => array(
        //new Engine_Filter_HtmlSpecialChars(),
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '63')),
      )
    ));

//    $isCategoryRequired = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.category.required', 0);
//    if( $isCategoryRequired ) {
//      $categoryLabel = 'Album Category*';
//    } else {
//      $categoryLabel = 'Album Category';
//    }

    $albumCategoryTable = Engine_Api::_()->getDbtable('albumcategories', 'sitemusic');
    $albumType = $albumCategoryTable->getCategoriesAssoc();
    $albumCategoryOption = array("0" => "Choose Category");
    if( !empty($albumType) ) {
      $albumCategoryOption = $albumCategoryOption + $albumType;
    }

    $this->addElement('Select', 'category_id', array(
      'label' => 'Album Category',
      'multiOptions' => $albumCategoryOption,
    ));

    // Init descriptions
    $this->addElement('Textarea', 'description', array(
      'label' => 'Album Description',
      'maxlength' => '300',
      'filters' => array(
        'StripTags',
        //new Engine_Filter_HtmlSpecialChars(),
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '300')),
        new Engine_Filter_EnableLinks(),
      ),
    ));
//'decorators' => array('ViewHelper', array('Description', array('placement' => 'PREPEND', 'escape' => false))),
    // AUTHORIZATIONS
    $availableLabels = $this->_roles;

    // Element: auth_view
    $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitemusic_pl', $user, 'auth_view_album');
    $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));

    if( !empty($viewOptions) && count($viewOptions) >= 1 ) {
      // Make a hidden field
      if( count($viewOptions) == 1 ) {
        $this->addElement('hidden', 'auth_view_album', array('value' => key($viewOptions)));
        // Make select box
      } else {
        $this->addElement('Select', 'auth_view_album', array(
          'label' => 'View Privacy',
          'description' => 'Who may view this album?',
          'multiOptions' => $viewOptions,
          'value' => key($viewOptions),
        ));
        $this->auth_view_album->getDecorator('Description')->setOption('placement', 'append');
      }
    }

    // Element: auth_coment_albm
    $commentOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitemusic_pl', $user, 'auth_coment_albm');
    $commentOptions = array_intersect_key($availableLabels, array_flip($commentOptions));

    if( !empty($commentOptions) && count($commentOptions) >= 1 ) {
      // Make a hidden field
      if( count($commentOptions) == 1 ) {
        $this->addElement('hidden', 'auth_coment_albm', array('value' => key($commentOptions)));
        // Make select box
      } else {
        $this->addElement('Select', 'auth_coment_albm', array(
          'label' => 'Comment Privacy',
          'description' => 'Who may comment on this album?',
          'multiOptions' => $commentOptions,
          'value' => key($commentOptions),
        ));
        $this->auth_coment_albm->getDecorator('Description')->setOption('placement', 'append');
      }
    }


    if( Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_enable_download', 1) ) {
      // Element: auth_download
      $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitemusic_pl', $user, 'auth_dload_album');
      $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));

      if( !empty($viewOptions) && count($viewOptions) >= 1 ) {
        // Make a hidden field
        if( count($viewOptions) == 1 ) {
          $this->addElement('hidden', 'auth_download', array('value' => key($viewOptions)));
          // Make select box
        } else {
          $this->addElement('Select', 'auth_download', array(
            'label' => 'Download Privacy',
            'description' => 'Who may download this album?',
            'multiOptions' => $viewOptions,
            'value' => key($viewOptions),
          ));
          $this->auth_download->getDecorator('Description')->setOption('placement', 'append');
        }
      }
    }

    // Element: auth_upload_song in album
    $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitemusic_pl', $user, 'auth_upload_song');
    $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));

    if( !empty($viewOptions) && count($viewOptions) >= 1 ) {
      // Make a hidden field
      if( count($viewOptions) == 1 ) {
        $this->addElement('hidden', 'auth_upload_song', array('value' => key($viewOptions)));
        // Make select box
      } else {
        $this->addElement('Select', 'auth_upload_song', array(
          'label' => 'Upload Song Privacy',
          'description' => 'Who may upload song in this album?',
          'multiOptions' => $viewOptions,
          'value' => key($viewOptions),
        ));
        $this->auth_upload_song->getDecorator('Description')->setOption('placement', 'append');
      }
    }


    // Init search checkbox
    $this->addElement('Checkbox', 'search', array(
      'label' => "Show this album in search results",
      'value' => 1,
      'checked' => true,
    ));


    $this->addElement('Select', 'published', array(
      'label' => 'Status',
      'multiOptions' => array("1" => "Published", "0" => "Saved As Draft"),
      'description' => 'If this music is published, it cannot be switched back to draft mode.'
    ));
    $this->published->getDecorator('Description')->setOption('placement', 'append');

    // Init playlist art
    $this->addElement('File', 'art', array(
      'label' => 'Album Artwork',
    ));
    $this->art->addValidator('Extension', false, 'jpg,png,gif,jpeg');

    // Init playlist cover photo
    $this->addElement('File', 'coverphoto', array(
      'label' => 'Album Cover Photo',
    ));

    $this->coverphoto->addValidator('Extension', false, 'jpg,png,gif,jpeg');

    $url = false;
    $viewer = Engine_Api::_()->user()->getViewer();
    // checking url upload is enable or not
 
    $urlEnable = Engine_Api::_()->authorization()->isAllowed('sitemusic_pl', $viewer->level_id, 'url');
    $isUrlEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_url', 1);

    if( $isUrlEnable ) {
      if( $urlEnable ) {
        $url = true;
      }
    }
    $uploadUrl = Zend_Controller_Front::getInstance()->getRouter()->assemble(array()) . '?ul=1';

    $data = array(
      'fileIdsElement' => 'fancyuploadfileids',
      'remoteFile' => $url,
      'populateFiles' => '',
      'linkDescription' => 'Click ‘Add Music’ to select one or more songs from your device.',
    );

    $this->addElement('SeaoFancyUpload', 'file', array(
      'url' => $uploadUrl,
      'fileType' => 'audio',
      'data' => $data,
    ));


//
    // Init hidden file IDs
    $this->addElement('Hidden', 'fancyuploadfileids', array(
      'order' => '123'
    ));

    // Init submit
    $this->addElement('Button', 'submit', array(
      'label' => 'Save Music to Album',
      'type' => 'submit',
    ));
  }

  public function clearUploads()
  {
    if( $this->getElement('fancyuploadfileids') ) {
      $this->getElement('fancyuploadfileids')->setValue('');
    }
  }

  public function saveValues()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $level_id = $viewer->level_id;
    $playlist = null;
    $values = $this->getValues();
    if( isset($values['album_option']) && $values['album_option'] == 0 ) {
      $translate = Zend_Registry::get('Zend_Translate');
      if( !empty($values['playlist_id']) ) {
        $playlist = Engine_Api::_()->getItem('sitemusic_pl', $values['playlist_id']);
      } else {
        if( empty($values['title']) || empty($values['description']) ) {
          $this->addError('Please fill the title and description fields as  a required filled.');
          $this->clearUploads();
          return;
        }
        $isCategoryRequired = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.category.required', 0);
        if( $values['category_id'] == 0 && $isCategoryRequired ) {
          $this->addError('Please choose the category, it is a required field.');
          $this->clearUploads();
          return;
        }
        $playlist = $this->_playlist = Engine_Api::_()->getDbtable('playlists', 'sitemusic')->createRow();
        $playlist->title = htmlspecialchars(trim($values['title']), ENT_QUOTES, 'UTF-8');
        if( empty($playlist->title) )
          $playlist->title = $translate->_('_MUSIC_UNTITLED_PLAYLIST');
        $playlist->description = trim($values['description']);
        $playlist->search = $values['search'];
        $playlist->view_privacy = $values['auth_view_album'];
        if( isset($values['auth_download']) ) {
          $playlist->download_privacy = $values['auth_download'];
        }
        $playlist->owner_type = 'user';
        $playlist->owner_id = $viewer->getIdentity();
        $playlist->published = $values['published'];
        $playlist->category_id = $values['category_id'];
        $playlist->save();
      }

      if( $playlist->song_count ) {
        $totalSong = $playlist->song_count;
      } else {
        $totalSong = 0;
      }
      $albumApproval = Engine_Api::_()->authorization()->getPermission($level_id, 'sitemusic_pl', "approved_album");
      if( $albumApproval ) {
        $playlist->approved = 1;
        $songApprove = 1;
      }
      if( $totalSong == 0 && $values['fancyuploadfileids'] == '' ) {
        $this->addError('Please upload atleast one song in this album.');
        $this->clearUploads();
        return;
      }
      // for Total Songs Allow in a album
      $totalAllowSongs = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_pl', 'sm_max_albumSong');
      if( $totalAllowSongs ) {
        if( $values['fancyuploadfileids'] ) {
          $limitExceed = $playlist->totalAllowSongsLimitExceed($totalAllowSongs, $values['fancyuploadfileids'], $totalSong);
        }
        if( $limitExceed ) {
          $this->addError('Your have cross the total songs uploaded limit.Upload Songs in a album limit is ' . $totalAllowSongs);
          $this->clearUploads();
          return;
        }
      }
      $fileIds = trim($values['fancyuploadfileids']);
      $song = null;
      $songIds = null;
      foreach( explode(' ', $fileIds) as $file_id ) {
        $file_id = trim($file_id);
        if( !empty($file_id) )
          $song = $playlist->addSong($file_id, $songApprove);
        $totalSong++;
        if( $song ) {
          $songIds[] = $song->getIdentity();
        }
      }
      if( $songIds ) {
        $values['songIds'] = $songIds;
      }
      $playlist->song_count = $totalSong;
      $playlist->save();
      // Authorizations
      $auth = Engine_Api::_()->authorization()->context;
      $prev_allow_comment = $prev_allow_view = $prev_allow_download = $prev_allow_upload = false;
      foreach( $this->_roles as $role => $role_label ) {
        // allow viewers
        if( $values['auth_view_album'] == $role || $prev_allow_view ) {
          $auth->setAllowed($playlist, $role, 'view', true);
          $prev_allow_view = true;
        } else
          $auth->setAllowed($playlist, $role, 'view', 0);

        // allow comments
        if( isset($values['auth_coment_albm']) && ($values['auth_coment_albm'] == $role) || $prev_allow_comment ) {
          $auth->setAllowed($playlist, $role, 'comment', true);
          $prev_allow_comment = true;
        } else
          $auth->setAllowed($playlist, $role, 'comment', 0);

        if( isset($values['auth_download']) ) {
          // allow download
          if( $values['auth_download'] == $role || $prev_allow_download ) {
            $auth->setAllowed($playlist, $role, 'download', true);
            $prev_allow_download = true;
          } else
            $auth->setAllowed($playlist, $role, 'download', 0);
        }
        // allow upload song
        if( $values['auth_upload_song'] == $role || $prev_allow_upload ) {
          $auth->setAllowed($playlist, $role, 'upload_song', true);
          $prev_allow_upload = true;
        } else
          $auth->setAllowed($playlist, $role, 'upload_song', 0);
      }

      // Rebuild privacy
      $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
      foreach( $actionTable->getActionsByObject($playlist) as $action ) {
        $actionTable->resetActivityBindings($action);
      }



      if( !empty($values['art']) ) {
        $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($playlist, $this->art);
        $playlist->photo_id = $photo->photo_id;
      }

      $values['playlist'] = $playlist;
      return $values;
    } else {
      // if(!isset($values['album_option'])) {
      //   return;
      // }
      $playlist = Engine_Api::_()->getItem('sitemusic_pl', $values['playlist_id']);
      if( empty($playlist) ) {
        return;
      }
      $totalSong = 0;
      $songIds = array();
      $totSong = $playlist->song_count;

      $albumApproval = Engine_Api::_()->authorization()->getPermission($level_id, 'sitemusic_pl', "approved_album");
      if( $albumApproval ) {
        $songApprove = 1;
      }

      // for Total Songs Allow in a album
      $totalAllowSongs = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_pl', 'sm_max_albumSong');
      if( $totalAllowSongs ) {
        if( $values['fancyuploadfileids'] ) {
          $limitExceed = $playlist->totalAllowSongsLimitExceed($totalAllowSongs, $values['fancyuploadfileids'], $totSong);
        } elseif( $values['file'] && ($this->getElement('upload_file')) ) {
          $limitExceed = $playlist->totalAllowSongsLimitExceed($totalAllowSongs, $values['file'], $totSong);
        }
        if( $limitExceed ) {
          $this->addError('Your have cross the total songs uploaded limit.Upload Songs in a album limit is ' . $totalAllowSongs);
          $this->clearUploads();
          return;
        }
      }

      $fileIds = trim($values['fancyuploadfileids']);
      foreach( explode(' ', $fileIds) as $file_id ) {
        $file_id = trim($file_id);
        if( !empty($file_id) )
          $song = $playlist->addSong($file_id, $songApprove);
        $totalSong++;
        if( $song ) {
          $songIds[] = $song->getIdentity();
        }
      }

      if( !empty($values['art']) ) {
        $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($playlist, $this->art);
        $playlist->photo_id = $photo->photo_id;
      }

      $playlist->song_count = $totalSong + $totSong;
      $playlist->save();
      $values['playlist'] = $playlist;
      $values['song_ids'] = $songIds;
      return $values;
    }
  }

}