<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Artist.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_Artist extends Core_Model_Item_Abstract
{

  protected $_searchTriggers = false;
  protected $_route = 'sitemusic_general';

  public function getTitle()
  {
    return $this->title;
  }

  public function getSongs()
  {
    $playlistSongTable = Engine_Api::_()->getDbTable('playlistSongs', 'sitemusic');
    $psName = $playlistSongTable->info('name');
    $songArtistTable = Engine_Api::_()->getDbTable('songartists', 'sitemusic');
    //songartist table name

    $saName = $songArtistTable->info('name');
    $songArtist = $songArtistTable->select();
    $songArtist->where('artist_id = ?', $this->getIdentity());
    $result = $songArtist->query()->fetchAll();
    if( $result ) {
      foreach( $result as $row ) {
        $id[] = $row['song_id'];
      }
      $psSelect = $playlistSongTable->select();
      $psSelect->where('song_id IN (?)', $id);
      return ($playlistSongTable->fetchAll($psSelect));
    }
  }

  public function totalSongs()
  {
    $songArtistTable = Engine_Api::_()->getDbTable('songartists', 'sitemusic');
    $saName = $songArtistTable->info('name');
    $songArtist = $songArtistTable->select()->from($saName, array("COUNT(*) as count"));
    $songArtist->where('artist_id = ?', $this->getIdentity());
    $totalSongs = ($songArtist->query()->fetch());
    return $totalSongs['count'];
  }

  public function getUsedCount()
  {
    $blogTable = Engine_Api::_()->getItemTable('blog');
    return $blogTable->select()
        ->from($blogTable, new Zend_Db_Expr('COUNT(blog_id)'))
        ->where('category_id = ?', $this->category_id)
        ->query()
        ->fetchColumn();
  }

  public function getHref($params = array())
  {
    $slug = $this->getSlug();

    $params = array_merge(array(
      'route' => 'sitemusic_item_view',
      'reset' => true,
      //'user_id' => $this->owner_id,
      'controller' => 'artists',
      'item_id' => $this->artist_id,
      'slug' => $slug,
      ), $params);
    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);
    return Zend_Controller_Front::getInstance()->getRouter()
        ->assemble($params, $route, $reset);
  }

  public function getRichContent($view = false, $params = array())
  {
    $view = Zend_Registry::get('Zend_View');
    $view = clone $view;
    $view->clearVars();
    $view->addScriptPath('application/modules/Sitemusic/views/scripts/');
    $view->artist = $this;
    $content = '';
// $view == false means that this rich content is requested from the activity feed
    $content .= $view->render('_artistActivityFeed.tpl');
    return $content;
  }

  public function setCoverPhoto($photo)
  {
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
    } elseif( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
    } elseif( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
    } else {
      throw new Sitemusic_Model_Exception('Invalid argument passed to setPhoto: ' . print_r($photo, 1));
    }

    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => 'sitemusic_artist',
      'parent_id' => $this->getIdentity()
    );

    // Save
    $storage = Engine_Api::_()->storage();

    // Resize image (main)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(720, 720)
      ->write($path . '/m_' . $name)
      ->destroy();

    // Resize image (icon)
    $image = Engine_Image::factory();
    $image->open($file);

    $size = min($image->height, $image->width);
    $x = ($image->width - $size) / 2;
    $y = ($image->height - $size) / 2;

    $image->resample($x, $y, $size, $size, 48, 48)
      ->write($path . '/is_' . $name)
      ->destroy();

    // Store
    $iMain = $storage->create($path . '/m_' . $name, $params);
//    $iProfile = $storage->create($path . '/p_' . $name, $params);
//    $iIconNormal = $storage->create($path . '/in_' . $name, $params);
//    $iSquare = $storage->create($path . '/is_' . $name, $params);

    $iMain->bridge($iMain, 'thumb.profile');
  //  $iMain->bridge($iIconNormal, 'thumb.normal');
    //   $iMain->bridge($iSquare, 'thumb.icon');
    // Remove temp files
//    @unlink($path . '/p_' . $name);
    @unlink($path . '/m_' . $name);
//    @unlink($path . '/in_' . $name);
//    @unlink($path . '/is_' . $name);
    // Update row
    $this->modified_date = date('Y-m-d H:i:s');
    $this->cover_photo_id = $iMain->getIdentity();
    $this->save();
    return $this;
  }

  public function follows()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('follows', 'sitemusic'));
  }

  // Interfaces

  /**
   * Gets a proxy object for the comment handler
   *
   * @return Engine_ProxyObject
   * */
  public function comments()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
  }

  /**
   * Gets a proxy object for the like handler
   *
   * @return Engine_ProxyObject
   * */
  public function likes()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
  }

  function isEditable()
  {
    return $this->authorization()->isAllowed(null, 'edit');
  }

}
