<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Modules.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Modules extends Engine_Db_Table {

    protected $_name = 'sitemusic_modules';
    protected $_rowClass = 'Sitemusic_Model_Module';

    public function getModuleTitle($name) {
        $coreTable = Engine_Api::_()->getDbtable('modules', 'core');
        $coreTableName = $coreTable->info('name');
        $select = $coreTable->select()
                ->from($coreTableName, array('title'))
                ->where('name =?', $name);
        $title = $select->query()->fetchColumn();
        return $title;
    }

    public function getIntegratedModules($params = array()) {

        $coreModuleTable = Engine_Api::_()->getDbtable('modules', 'core');
        $moduleTableName = $this->info('name');
        $coreModuleTableName = $coreModuleTable->info('name');
        $select = $this->select()->setIntegrityCheck(false)
                ->from($moduleTableName, array('*'))
                ->join($coreModuleTableName, $coreModuleTableName . '.name = ' . $moduleTableName . '.resource_module', array())
                ->where($coreModuleTableName . '.enabled =?', 1);


        if (isset($params['enabled']) && !empty($params['enabled'])) {
            $select->where($moduleTableName . '.enabled =?', 1);
        }

        if (isset($params['resource_module']) && !empty($params['resource_module'])) {
            $select->where($moduleTableName . '.resource_module =?', $params['resource_module']);
        }

        if (isset($params['resource_type']) && !empty($params['resource_type'])) {
            $select->where($moduleTableName . '.resource_type =?', $params['resource_type']);
        }

        $results = $this->fetchAll($select)->toArray();

        if (empty($results) && isset($params['checked']) && !empty($params['checked'])) {
            return false;
        }

        if (empty($results)) {
            return false;
        }
        return $results;
    }

    public function getIntegratedItemTitle($resource_module, $resource_type) {

        $title = $this->select()
                        ->from($this->info('name'), 'resource_title')
                        ->where('resource_module =?', $resource_module)
                        ->where('resource_type =?', $resource_type)
                        ->query()->fetchColumn();

        if (empty($title))
            $title = $this->getModuleTitle($resource_module);
        return $title;
    }

    public function getIntegratedModulesArray()
    {
      $data = array('' => '');
      $modules = $this->getIntegratedModules();
      if($modules) {
        foreach( $modules as $module ) {
          $data[$module['resource_type']] = $module['resource_title'];
        }
      }
      return $data;
    }

}
