<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Playlists.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Playlists extends Engine_Db_Table
{

  protected $_name = 'sitemusic_playlists';
  protected $_rowClass = 'Sitemusic_Model_Playlist';

  public function getCategoriesAssoc()
  {
    $viewerId = Engine_Api::_()->user()->getViewer()->getIdentity();
    $stmt = $this->select()
      ->from($this, array('playlist_id', 'title'))
      ->where('owner_id = ?', $viewerId)
      ->order('title ASC')
      ->query();

    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['playlist_id']] = $category['title'];
    }
    return $data;
  }

  public function getAlbumOptionForOtherPlugin($params)
  {
    $viewerId = Engine_Api::_()->user()->getViewer()->getIdentity();
    $stmt = $this->select()
      ->from($this, array('playlist_id', 'title'))
      ->where('owner_id = ?', $viewerId)
      ->where('parent_type = ?', $params['parent_type'])
      ->where('parent_id = ?', $params['parent_id'])
      ->order('title ASC')
      ->query();

    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['playlist_id']] = $category['title'];
    }
    return $data;
  }

  public function getSpecialPlaylist(User_Model_User $user, $type)
  {
    $allowedTypes = array('profile', 'wall', 'message');
    if( !in_array($type, $allowedTypes) ) {
      throw new Album_Model_Exception('Unknown special album type');
    }
    //$typeIndex = array_search($type, $allowedTypes);

    $select = $this->select()
      ->where('owner_type = ?', $user->getType())
      ->where('owner_id = ?', $user->getIdentity())
      ->where('special = ?', $type)
      ->order('playlist_id ASC')
      ->limit(1);

    $playlist = $this->fetchRow($select);

    // Create if it doesn't exist yet
    if( null === $playlist ) {
      $translate = Zend_Registry::get('Zend_Translate');

      $playlist = $this->createRow();
      $playlist->owner_type = 'user';
      $playlist->owner_id = $user->getIdentity();
      $playlist->special = $type;

      if( $type == 'message' ) {
        $playlist->title = $translate->_('_MUSIC_MESSAGE_PLAYLIST');
        $playlist->search = 0;
      } else {
        $playlist->title = $translate->_('_MUSIC_DEFAULT_PLAYLIST');
        $playlist->search = 1;
      }

      $playlist->save();

      // Authorizations
      if( $type != 'message' ) {
        $auth = Engine_Api::_()->authorization()->context;
        $auth->setAllowed($playlist, 'everyone', 'albumView', true);
        $auth->setAllowed($playlist, 'everyone', 'albumComment', true);
      }
    }

    return $playlist;
  }

  public function getAlbumSelect($params = array())
  {
    $labelMapTable = Engine_Api::_()->getDbTable('labelMaps', 'sitemusic');
    $lmName = $labelMapTable->info('name');
    $playlistSongTable = Engine_Api::_()->getDbTable('playlistSongs', 'sitemusic');
    $psName = $playlistSongTable->info('name');
    $pName = $this->info('name');
    $followTable = Engine_Api::_()->getDbTable("settings", "core");
    $followName = $followTable->info('name');
    $select = $this->select()
      ->from($pName);


        // USER SEARCH
    if( !empty($params['user']) ) {
      if( is_object($params['user']) ) {
        $select->where($pName . '.owner_id = ?', $params['user']->getIdentity());
      } elseif( is_numeric($params['user']) ) {
        $select->where($pName . '.owner_id = ?', $params['user']);
      }
      if( !empty($params['searchBit']) ) {
        $select->where('search = 1');
      }
    } else if( isset($params['users']) && is_array($params['users']) ) {
      if( empty($params['users']) ) {
        return $select->where('1 != 1');
      }
      $select->where($pName . '.owner_id IN(?)', $params['users']);
      if( !empty($params['searchBit']) ) {
        $select->where('search = 1');
      }
    } else if( !empty($params['adminView']) ) {
      $select->joinLeft($psName, "$pName.playlist_id = $psName.playlist_id", '');
    } else if( !empty($params['only_my']) ) {
      $select->where($pName . '.owner_id = ?', $params['only_my']);
    } else {
      if( Engine_Api::_()->getApi('core', 'sitemusic')->enableContentBasedPrivacy() ) {
        $param = array('search' => 1);
        //privacy related work
       $select =  Engine_Api::_()->getApi('generalWidget', 'sitemusic')->getItemsSelect($select, $param, $pName);
      }
    }

    //album category

    if( !empty($params['albumcategory_id']) && $params['albumcategory_id'] != 'all' ) {
      $select->where('category_id = ?', $params['albumcategory_id']);
    }

    //albumIds
    if( !empty($params['albumIds']) ) {
      $select->where($pName . '.playlist_id IN(?)', $params['albumIds']);
    }

    //search
    if( !empty($params['search']) ) {
      $select->where($pName . '.title LIKE ?', "%{$params['search']}%");
    }
    // SORT
    if( !empty($params['sort']) ) {
      $sort = $params['sort'];
      if( 'recent' == $sort ) {
        $select->order('creation_date DESC');
      } else if( 'popular' == $sort ) {
        $select->order("play_count DESC");
      } else if( 'liked' == $sort ) {
        $select->order("like_count DESC");
      } else if( 'downloaded' == $sort ) {
        $select->order("download_count DESC");
      } else if( 'favourite' == $sort ) {
        $select->order("favourite_count DESC");
      } else if( 'alphabetic' == $sort ) {
        $select->order($pName . '.title ASC');
      } else if( $sort == 'creationDate' ) {
        $select->order('creation_date DESC');
      } else if( $sort == 'ascendingOrder' ) {
        $select->order('creation_date ASC');
      }
    } else if( !empty($params['order']) && !empty($params['order_direction']) ) {
      $select->order($params['order'] . ' ' . $params['order_direction']);
    } else
      $select->order('creation_date DESC');

    // alphabet search
    if( !empty($params['alphabet']) && $params['alphabet'] != 'ViewAll' ) {
      if( $params['alphabet'] != '#' ) {
        $select->where($pName . '.title LIKE ?', "{$params['alphabet']}%");
      } else {
        $select->
          WHERE($pName . ".title LIKE '%0%'
    OR " . $pName . ".title LIKE '%1%'
    OR " . $pName . ".title LIKE '%2%'
    OR " . $pName . ".title LIKE '%3%'
    OR " . $pName . ".title LIKE '%4%'
    OR " . $pName . ".title LIKE '%5%'
    OR " . $pName . ".title LIKE '%6%'
    OR " . $pName . ".title LIKE '%7%'
    OR " . $pName . ".title LIKE '%8%'
    OR " . $pName . ".title LIKE '%9%'
  ");
      }
    }

    if( !empty($params['title']) ) {
      $select->where($pName . '.title LIKE ?', "%{$params['title']}%");
    }
    if( !empty($params['ownerName']) ) {
      $select->where($pName . '.owner_id = ?', $params['owner_id']);
    }
    if( !empty($params['albumType']) && $params['albumType'] != 'all' ) {
      $select->where('category_id = ?', $params['albumType']);
    }
    if( !empty($params['labelType']) && $params['labelType'] != 'all' && !empty($params['type']) ) {
      $select->join($lmName, "$pName.playlist_id = $lmName.resource_id", '');
      $select->where('label_id = ?', $params['labelType'])
        ->where('resource_type = ?', $params['type']);
    }
    if( !empty($params['published']) ) {
      $select->where('published = ?', $params['published']);
    }

    $week = date('Y-m-d H:i:s', time() - (7 * 86400));
    $month = date('Y-m-d H:i:s', time() - (30 * 86400));
    $sixMonth = date('Y-m-d H:i:s', time() - (30 * 6 * 86400));
    $year = date('Y-m-d H:i:s', time() - (365 * 86400));
    if( !empty($params['creationDate']) ) {
      if( $params['creationDate'] == 'last week' ) {
        $select->where('creation_date >= ?', $week);
      } elseif( $params['creationDate'] == 'last month' ) {
        $select->where('creation_date >= ?', $month);
      } elseif( $params['creationDate'] == 'last 6 month' ) {
        $select->where('creation_date >= ?', $sixMonth);
      } elseif( $params['creationDate'] == 'last 12 month' ) {
        $select->where('creation_date >= ?', $year);
      }
    }
    // for admin
    if( empty($params['admin']) && empty($params['notCheckApprove']) ) {
      $select->where('song_count != ?', 0);
      $select->where($pName . '.approved = ?', 1);
      $select->join($psName, "$pName.playlist_id = $psName.playlist_id", '');
      $select->where($psName . '.status = ?', 1);
    }
    // for others plugin
    if( !empty($params['parent_type']) ) {
      $select->where('parent_type = ?', $params['parent_type']);
    }
    if( !empty($params['parent_id']) ) {
      $select->where('parent_id = ?', $params['parent_id']);
    }
    $select->distinct(true);
    return $select;
  }

  public function getPaginator(array $params)
  {
    return Zend_Paginator::factory($this->getAlbumSelect($params));
  }

}
