<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Songcategories.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Songcategories extends Engine_Db_Table
{

  protected $_rowClass = 'Sitemusic_Model_Songcategory';
  protected $_categories = array();

  /**
   * Return subcaregories
   *
   * @param int category_id
   * @return all sub categories
   */
  public function getSubCategories($category_id, $fetchColumns = array())
  {

    //RETURN IF CATEGORY ID IS EMPTY
    if( empty($category_id) ) {
      return;
    }

    //MAKE QUERY
    $select = $this->select();

    if( !empty($fetchColumns) ) {
      $select->from($this->info('name'), $fetchColumns);
    }

    $select->where('cat_dependency = ?', $category_id)
      ->order('cat_order');
    //RETURN RESULTS
    return $this->fetchAll($select);
  }

  public function getSubCategoriesOnly()
  {

    //MAKE QUERY
    $select = $this->select();

    $select->where('cat_dependency != ?', 0)
      ->order('cat_order');
    //RETURN RESULTS
    $data = array();
    $result = $this->fetchAll($select);
    foreach( $result as $row ) {
      $data[$row['songcategory_id']] = $row['category_name'];
    }
    return $data;
  }

  /**
   * Return categories
   *
   * @param array $category_ids
   * @return all categories
   */
  public function getCategories($category_ids = null, $count_only = 0, $listingtype_id = 0, $sponsored = 0, $cat_depandancy = 0, $limit = 0, $orderBy = 'cat_order', $visibility = 0, $fetchColumns = array())
  {

    //MAKE QUERY
    $select = $this->select();

    //GET CATEGORY TABLE NAME
    $categoryTableName = $this->info('name');

    $listingTypeTable = Engine_Api::_()->getDbTable('songcategories', 'sitemusic');
    $listingTypeTableName = $listingTypeTable->info('name');

    if( $orderBy == 'category_name' ) {
      $select->order('category_name');
    } else {
      $select->order('cat_order');
    }

    if( !empty($cat_depandancy) ) {
      $select->where('cat_dependency = ?', 0);
    }

    if( !empty($count_only) ) {
      $select->from($this->info('name'), 'category_id');
    } elseif( !empty($fetchColumns) ) {
      $select->from($categoryTableName, $fetchColumns);
    }

    if( !empty($count_only) ) {
      return $select->query()->fetchColumn();
    }

    //RETURN DATA
    return $this->fetchAll($select);
  }

  public function getCategoriesAssoc()
  {
    $stmt = $this->select()
      ->from($this, array('songcategory_id', 'category_name'))
      // ->order('category_name ASC')
      ->where('cat_dependency = ?', 0)
      ->query();

    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['songcategory_id']] = $category['category_name'];
    }
    return $data;
  }

  public function getSubCategoriesAssoc($parms = array())
  {
    $genreData = array();
    foreach( $parms as $key => $value ) {
      $ids[] = $key;
      $cat[] = $value;
    }
    $i = 0;
    foreach( $ids as $songCategoryId ) {
      $stmt = $this->select()
        ->from($this)
        ->where('cat_dependency = ?', $songCategoryId)
        ->query();

      $subcategory_name = array();
      foreach( $stmt->fetchAll() as $category ) {
        $data[$category['songcategory_id']] = $parms[$songCategoryId] . '>>' . $category['category_name'];
      }
      if( empty($data) ) {
        $data[$songCategoryId] = $parms[$songCategoryId];
      }
      $genreData = $genreData + $data;
      unset($data);
    }
    return $genreData;
  }

  public function setDefaultImages($toPath, $fromPath, $columnName)
  {
    @mkdir(APPLICATION_PATH . $toPath, 0777);
    $dir = APPLICATION_PATH . $fromPath;
    $public_dir = APPLICATION_PATH . $toPath;
    $fieArr = array();
    if( is_dir($dir) && is_dir($public_dir) ) {
      $files = scandir($dir);
      foreach( $files as $file ) {
        if( strstr($file, '.png') || strstr($file, '.jpg') || strstr($file, '.gif') ) {
          $fieArr[] = $file;
          @copy(APPLICATION_PATH . "$fromPath/$file", APPLICATION_PATH . "$toPath/$file");
        }
      }
      @chmod(APPLICATION_PATH . $toPath, 0777);
    }
    //MAKE QUERY
    $select = $this->select()->from($this->info('name'), array('songcategory_id', 'category_name', $columnName));
    $categories = $this->fetchAll($select);
    //UPLOAD DEFAULT ICONS
    foreach( $categories as $category ) {
      $categoryName = Engine_Api::_()->sitemusic()->getSlug($category->category_name, 225);
      $iconName = false;
      foreach( $fieArr as $f ) {
        if( strstr($f, $categoryName) ) {
          $iconName = $f;
          break;
        }
      }

      if( $iconName == false )
        continue;
      @chmod(APPLICATION_PATH . $toPath, 0777);
      $file = array();
      if( $columnName == 'photo_id' && !empty($category->photo_id) ) {
        continue;
      } else if( $columnName == 'file_id' && !empty($category->file_id) ) {
        continue;
      } else if( $columnName == 'banner_id' && !empty($category->banner_id) ) {
        continue;
      }

      $file['tmp_name'] = APPLICATION_PATH . "$toPath/$iconName";
      $file['name'] = $iconName;
      if( file_exists($file['tmp_name']) ) {
        $name = basename($file['tmp_name']);
        $path = dirname($file['tmp_name']);
        $mainName = $path . '/' . $file['name'];

        @chmod($mainName, 0777);

        $photo_params = array(
          'parent_id' => $category->songcategory_id,
          'parent_type' => "sitemusic_songcategory",
        );

        $extension = ltrim(strrchr(basename($name), '.'), '.');
        // Resize image (main)
        $bigBannerPath = $path . DIRECTORY_SEPARATOR . $name . '_b-i.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file['tmp_name'])
          ->resize(1200, 700)
          ->write($bigBannerPath)
          ->destroy();

        // Resize image (profile)
        $smallBannerPath = $path . DIRECTORY_SEPARATOR . $name . '_s-i.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file['tmp_name'])
          ->resize(350, 200)
          ->write($smallBannerPath)
          ->destroy();

       // Save
        $filesTable = Engine_Api::_()->getDbtable('files', 'storage');

        // Store
        $bigBanner = $filesTable->createSystemFile($bigBannerPath);
        $smallBanner = $filesTable->createSystemFile($smallBannerPath);
        $bigBanner->bridge($smallBanner, 'thumb.normal');

        // Remove temp files
        @unlink($bigBannerPath);
        @unlink($smallBannerPath);




  //      $photoFile = Engine_Api::_()->storage()->create($mainName, $photo_params);
        //UPDATE FILE ID IN CATEGORY TABLE
        if( !empty($bigBanner->file_id) ) {
          if( $columnName == 'photo_id' ) {
            $category->photo_id = $bigBanner->file_id;
          }
          $category->save();
        }
      }
    }
    //REMOVE THE CREATED PUBLIC DIRECTORY
    if( is_dir(APPLICATION_PATH . $toPath) ) {
      $files = scandir(APPLICATION_PATH . $toPath);
      foreach( $files as $file ) {
        $is_exist = file_exists(APPLICATION_PATH . "$toPath/$file");
        if( $is_exist ) {
          @unlink(APPLICATION_PATH . "$toPath/$file");
        }
      }
      @rmdir(APPLICATION_PATH . $toPath);
    }
  }

  public function uploadDefaultImages()
  {
    $genreImagesToPath = "/temporary/songs-genre_images";
    $genreImagesfromPath = "/application/modules/Sitemusic/externals/images/songs-genre";
    $this->setDefaultImages($genreImagesToPath, $genreImagesfromPath, 'photo_id');
  }

}
