<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: UserPlaylists.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_UserPlaylists extends Engine_Db_Table
{

  protected $_name = 'sitemusic_user_playlists';
  protected $_primary = 'userplaylist_id';
  protected $_rowClass = 'Sitemusic_Model_UserPlaylist';

  public function getPaginator(array $params)
  {
    return Zend_Paginator::factory($this->getPlaylistSelect($params));
  }

  public function getPlaylistSelect($params = array())
  {
    $songArtistTable = Engine_Api::_()->getItemTable('sitemusic_songartist');
    $labelMapTable = Engine_Api::_()->getDbTable('labelMaps', 'sitemusic');
    $playlistTable = Engine_Api::_()->getDbTable('playlists', 'sitemusic');
    $lmName = $labelMapTable->info('name');
    $saName = $songArtistTable->info('name');
    $pName = $playlistTable->info('name');
    $psName = $this->info('name');
    $select = $this->select()
      ->from($psName);

    //For Search
    if( !empty($params['search']) ) {
      $select->where('title LIKE ?', "%{$params['search']}%");
    }

    //albumIds
    if( !empty($params['playlistIds']) ) {
      $select->where('userplaylist_id IN(?)', $params['playlistIds']);
    }
    // alphabet search
    if( !empty($params['alphabet']) && $params['alphabet'] != 'ViewAll' ) {
      if( $params['alphabet'] != '#' ) {
        $select->where('title LIKE ?', "{$params['alphabet']}%");
      } else {
        $select->
          WHERE("title LIKE '%0%'
    OR title LIKE '%1%'
    OR title LIKE '%2%'
    OR title LIKE '%3%'
    OR title LIKE '%4%'
    OR title LIKE '%5%'
    OR title LIKE '%6%'
    OR title LIKE '%7%'
    OR title LIKE '%8%'
    OR title LIKE '%9%'
  ");
      }
    }
    // SORT
    if( !empty($params['sort']) ) {
      $sort = $params['sort'];
      if( 'recent' == $sort ) {
        $select->order('creation_date DESC');
      } else if( 'popular' == $sort ) {
        $select->order("play_count DESC");
      } else if( 'liked' == $sort ) {
        $select->order("like_count DESC");
      } else if( 'favourite' == $sort ) {
        $select->order("favourite_count DESC");
      } else if( 'alphabetic' == $sort ) {
        $select->order('title ASC');
      } else if( $sort == 'creationDate' ) {
        $select->order('creation_date DESC');
      } else if( $sort == 'ascendingOrder' ) {
        $select->order('creation_date ASC');
      }
    } else if( !empty($params['order']) && !empty($params['order_direction']) ) {
      $select->order($params['order'] . ' ' . $params['order_direction']);
    } else
      $select->order('creation_date DESC');
    // USER SEARCH
    if( !empty($params['user']) ) {
      if( is_object($params['user']) ) {
        $select->where('owner_id = ?', $params['user']->getIdentity());
      } elseif( is_numeric($params['user']) ) {
        $select->where('owner_id = ?', $params['user']);
      }
//      if( !empty($params['searchBit']) ) {
//        $select->where('search = 1');
//      }
    } else if( isset($params['users']) && is_array($params['users']) ) {
      if( empty($params['users']) ) {
        return $select->where('1 != 1');
      }
      $select->where('owner_id IN(?)', $params['users']);
//      if( !empty($params['searchBit']) ) {
//        $select->where('search = 1');
//      }
    } else if( !empty($params['adminView']) ) {
      $select->joinLeft($psName, "$pName.playlist_id = $psName.playlist_id", '');
    } else if( !empty($params['only_my']) ) {
      $select->where('owner_id = ?', $params['only_my']);
    } else {
      $select->where('song_count > ?', 0);
      if( Engine_Api::_()->getApi('core', 'sitemusic')->enableContentBasedPrivacy() ) {
        //privacy related work
        Engine_Api::_()->getApi('generalWidget', 'sitemusic')->getItemsSelect($select,null,$psName);
      }
    }
    //For Manage
    if( !empty($params['title']) ) {
      $select->where('title LIKE ?', "%{$params['title']}%");
    }
    if( !empty($params['ownerName']) ) {
      $select->where('owner_id = ?', $params['owner_id']);
    }
    if( !empty($params['labelType']) && $params['labelType'] != 'all' && !empty($params['type']) ) {
      $select->join($lmName, "$psName.userplaylist_id = $lmName.resource_id", '');
      $select->where('label_id = ?', $params['labelType'])
        ->where('resource_type = ?', $params['type']);
    }
    if( !empty($params['artist']) && $params['artist'] != 'all' ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $query = $db->select()
        ->from($saName)
        ->where('artist_id = ?', $params['artist']);
      $row = $query->query()->fetchAll();
      foreach( $row as $result ) {
        $song_id[] = $result['song_id'];
      }
      $song_id = implode(',', $song_id);
      $select->where('song_id in (' . $song_id . ')');
    }
    $week = date('Y-m-d H:i:s', time() - (7 * 86400));
    $month = date('Y-m-d H:i:s', time() - (30 * 86400));
    $sixMonth = date('Y-m-d H:i:s', time() - (30 * 6 * 86400));
    $year = date('Y-m-d H:i:s', time() - (365 * 86400));
    if( !empty($params['creationDate']) ) {
      if( $params['creationDate'] == 'last week' ) {
        $select->where('creation_date >= ?', $week);
      } elseif( $params['creationDate'] == 'last month' ) {
        $select->where('creation_date >= ?', $month);
      } elseif( $params['creationDate'] == 'last 6 month' ) {
        $select->where('creation_date >= ?', $sixMonth);
      } elseif( $params['creationDate'] == 'last 12 month' ) {
        $select->where('creation_date >= ?', $year);
      }
    }
    return $select;
  }

}
