<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Playlist.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_Playlist extends Core_Model_Item_Abstract
{
  protected $_type = 'sitemusic_pl';

  public function getTitle()
  {
    if( $this->special == 'wall' ) {
      return Zend_Registry::get('Zend_Translate')->_('_MUSIC_DEFAULT_PLAYLIST');
    } else if( $this->special == 'message' ) {
      return Zend_Registry::get('Zend_Translate')->_('_MUSIC_MESSAGE_PLAYLIST');
    } else if( !empty($this->title) ) {
      return $this->title;
    }
  }

  /**
   * Gets an absolute URL to the page to view this item
   *
   * @return string
   */
  public function getHref($params = array())
  {
    $slug = $this->getSlug();
    $params = array_merge(array(
      'route' => 'sitemusic_item_view',
      //  'controller' => 'playlist',
      'reset' => true,
      //'user_id' => $this->owner_id,
      'item_id' => $this->playlist_id,
      'slug' => $slug,
      ), $params);
    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);
    return Zend_Controller_Front::getInstance()->getRouter()
        ->assemble($params, $route, $reset);
  }

  public function getRichContent($view = false, $params = array())
  {
    $view = Zend_Registry::get('Zend_View');
    $view = clone $view;
    $view->clearVars();
    if( !$this->approved ) {
      return;
    }
    $view->addScriptPath('application/modules/Sitemusic/views/scripts/');
    $content = '';
    $view->item = $this;
    $content .= $view->render('_album-playlistActivityFeed.tpl');
    return $content;
  }

  /**
   * Gets a proxy object for the comment handler
   *
   * @return Engine_ProxyObject
   * */
  public function comments()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
  }

  /**
   * Gets a proxy object for the like handler
   *
   * @return Engine_ProxyObject
   * */
  public function likes()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
  }

  public function getCommentCount()
  {
    return $this->comments()->getCommentCount();
  }

  public function getParent($recurseType = null)
  {
    return $this->getOwner($recurseType);
  }

  // get all songs event private ones
  public function getAllSongs($checkStatus = null, $file_id = null)
  {
    $table = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
    $select = $table->select()
      ->where('playlist_id = ?', $this->getIdentity())
      ->order('order ASC');
    if( !empty($file_id) )
      $select->where('file_id = ?', $file_id);
    return $table->fetchAll($select);
  }

// get all songs not private ones
  public function getSongs($checkStatus = null, $file_id = null)
  {
    $table = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
    $select = $table->select()
      ->where('playlist_id = ?', $this->getIdentity());
    if( $checkStatus ) {
      $select->where('status = ?', 1);
      $select->where('approved = ?', 1);
    }
    $select->order('order ASC');
    if( !empty($file_id) )
      $select->where('file_id = ?', $file_id);
    return $table->fetchAll($select);
  }

  public function getSong($file_id)
  {
    $table = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
    $select = $table->select()
      ->where('playlist_id = ?', $this->getIdentity())
      ->where('approved = ?', 1)
      ->order('order ASC');
    if( !empty($file_id) )
      $select->where('file_id = ?', $file_id);

    $row = $select->query()->fetch();
    return $row['song_id'];
  }

  public function addSong($file_id, $approved = null)
  {
    include_once('id3/getid3.php');
    $getID3 = new getID3;

    if( $file_id instanceof Sitemusic_Model_PlaylistSong ) {
      $file_id = $file_id->file_id;
    }
    if( $file_id instanceof Storage_Model_File ) {
      $file = $file_id;
      $file_id = $file->getIdentity();
    } else {
      $file = Engine_Api::_()->getItem('storage_file', $file_id);
    }
    $dbAdapter = Engine_Db_Table::getDefaultAdapter();
    $query = $dbAdapter->select()
      ->from('engine4_storage_files')
      ->where('file_id = ?', $file_id)
    ;
    $q = $query->query()->fetch();
    $songPath = $q['storage_path'];
    $extension = $q['extension'];
    $songCategoryId = null;
//    foreach( $query->query()->fetchAll() as $q ) {
//      $songPath = $q['storage_path'];
//    }
    $ThisFileInfo = $getID3->analyze($songPath);
    $meta = $getID3->analyze($songPath);
    $len = @$ThisFileInfo['playtime_string'];
    if( empty($len) ) {
      $len = 0;
    }
    $songInfo = null;

    if( !empty($meta['id3v2']['comments']) ) {
      $songInfo = $meta['id3v2']['comments'];
    }

    if( !empty($songInfo) ) {
      $artist = null;
      $genere = null;
      if( isset($songInfo['artist'][0]) ) {
        $artist = $songInfo['artist'][0];
      }

      if(isset($songInfo['genre']) && isset($songInfo['genre'][0]) ) {
        $genere = $songInfo['genre'][0];
      }
      if( !empty($artist) ) {
 
      $artistName = (explode(",", $artist));
      $count = count($artistName);
      }
    }

    if( !empty($genere) ) {
      $query1 = $dbAdapter->select()
        ->from('engine4_sitemusic_songcategories', array('songcategory_id', 'category_name'))
        ->where('category_name = ?', $genere)
      ;
      foreach( $query1->query()->fetchAll() as $q ) {
        $songCategoryId = $q['songcategory_id'];
        $category_name = $q['category_name'];
      }
    }
    $playlistId = $this->getIdentity();

    if( $file ) {
      $file_id = $file->getIdentity();
      $playlistSong = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic')->createRow();
      $playlistSong->playlist_id = $playlistId;
      $playlistSong->file_id = $file_id;
      $songTitleWithKey = preg_replace('/\.(mp3|m4a|aac|mp4)$/i', '', $file->name);
      $songTitle = substr($songTitleWithKey, strpos($songTitleWithKey, "-") + 1);
      $playlistSong->title = $songTitle ? $songTitle : $songTitleWithKey;
      $playlistSong->order = count($this->getSongs());
      $playlistSong->song_length = $len;
      $playlistSong->owner_id = Engine_Api::_()->user()->getViewer()->getIdentity();
      if( $approved ) {
        $playlistSong->approved = $approved;
      }

//      if( $songInfo['lyricist'][0] ) {
//        $playlistSong->lyrics = $songInfo['lyricist'][0];
//      }
      $artistParamArray = array();
      if( !isset($songCategoryId) ) {
        $metaInfo['genre'] = isset($songInfo['genre']) ? $songInfo['genre'][0] : null;
      } else {
        $playlistSong->genre_id = $songCategoryId;
      }
      $artistTitleString = '';
      if( isset($artistName) ) {
        foreach( $artistName as $artist ) {
          if( !empty($artistTitleString) ) {
            $artistTitleString .= ',';
          }
          $artistParamArray[] = $artist;
          $artistTitleString .= $artist;
        }
        //   $metaInfo['artist'] = $artistTitleString;
      }

      if( !empty($metaInfo) ) {
        $info = Zend_Json::encode($metaInfo);
        $playlistSong->params = $info;
      }
      $songId = $playlistSong->save();
    }

    if( $extension != 'mp3' ) {
      Engine_Api::_()->getDbtable('jobs', 'core')->addJob('sitemusic_encode', array(
        'song_id' => $songId,
      ));
      //    $this->_process($playlistSong);
    } else {
      $playlistSong->status = 1;
      $playlistSong->save();
    }
    $songArtistTable = Engine_Api::_()->getItemTable('sitemusic_songartist');
    $newArtistId = $songArtistTable->checkArtistMapping($artistParamArray, $songId, $playlistId);
// Storing song artwork image from id3
// Check the music temporary directory
    $tmpDir = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary' . DIRECTORY_SEPARATOR . 'music';
    if( !is_dir($tmpDir) ) {
      if( !mkdir($tmpDir, 0777, true) ) {
        throw new Sitemusic_Model_Exception('Music temporary directory did not exist and could not be created.');
      }
    }
    if( !is_writable($tmpDir) ) {
      throw new Sitemusic_Model_Exception('Music temporary directory is not writable.');
    }

    if( !empty($meta['id3v2']['APIC'][0]['data']) ) {
      $imgName = "song_$songId.jpg";
      $imgPath = $tmpDir . $imgName;
      $artwork = $meta['id3v2']['APIC'][0]['data'];

      if( isset($artwork) ) {
        file_put_contents($imgPath, $artwork);
      }
      Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($playlistSong, $imgPath);
      @unlink($imgPath);
    }

    return $playlistSong;
  }

  public function setProfile()
  {
    $table = Engine_Api::_()->getDbtable('playlists', 'sitemusic')->update(array(
      'profile' => 0,
      ), array(
      'owner_id = ?' => $this->owner_id,
      'playlist_id != ' . $this->getIdentity(),
    ));
    $this->profile = !$this->profile;
    $this->save();
  }

  public function setPhoto($photo)
  {
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
    } else if( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
    } else {
      throw new Sitemusic_Model_Exception('Invalid argument passed to setPhoto: ' . print_r($photo, 1));
    }

    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => 'sitemusic_pl',
      'parent_id' => $this->getIdentity()
    );

// Save
    $storage = Engine_Api::_()->storage();

// Resize image (profile)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(200, 400)
      ->write($path . '/p_' . $name)
      ->destroy();

// Resize image (normal)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(250, 300)
      ->write($path . '/in_' . $name)
      ->destroy();

// Resize image (icon)
    $image = Engine_Image::factory();
    $image->open($file);

    $size = min($image->height, $image->width);
    $x = ($image->width - $size) / 2;
    $y = ($image->height - $size) / 2;

    $image->resample($x, $y, $size, $size, 48, 48)
      ->write($path . '/is_' . $name)
      ->destroy();

// Store
//    $iMain = $storage->create($path . '/m_' . $name, $params);
//    $iProfile = $storage->create($path . '/p_' . $name, $params);
    $iIconNormal = $storage->create($path . '/in_' . $name, $params);
    $iSquare = $storage->create($path . '/is_' . $name, $params);

//    $iMain->bridge($iProfile, 'thumb.profile');
    $iMain->bridge($iIconNormal, 'thumb.normal');
    $iMain->bridge($iSquare, 'thumb.icon');

// Remove temp files
//    @unlink($path . '/p_' . $name);
//    @unlink($path . '/m_' . $name);
    @unlink($path . '/in_' . $name);
    @unlink($path . '/is_' . $name);

// Update row
    $this->modified_date = date('Y-m-d H:i:s');
    $this->photo_id = $iMain->getIdentity();
    $this->save();

    return $this;
  }

  public function setCoverPhoto($photo)
  {
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
    } else if( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
    } else {
      throw new Sitemusic_Model_Exception('Invalid argument passed to setPhoto: ' . print_rg($photo, 1));
    }
    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => 'sitemusic_pl',
      'parent_id' => $this->getIdentity()
    );

// Save
    $storage = Engine_Api::_()->storage();

// Resize image (main)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(720, 720)
      ->write($path . '/m_' . $name)
      ->destroy();

// Resize image (profile)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(200, 400)
      ->write($path . '/p_' . $name)
      ->destroy();

// Resize image (icon)
    $image = Engine_Image::factory();
    $image->open($file);

    $size = min($image->height, $image->width);
    $x = ($image->width - $size) / 2;
    $y = ($image->height - $size) / 2;

// Store
    $iMain = $storage->create($path . '/m_' . $name, $params);
    $iProfile = $storage->create($path . '/p_' . $name, $params);

    $iMain->bridge($iProfile, 'thumb.profile');

// Remove temp files
    @unlink($path . '/p_' . $name);
    @unlink($path . '/m_' . $name);

// Update row
    $this->modified_date = date('Y-m-d H:i:s');
    $this->cover_photo_id = $iMain->getIdentity();
    $this->save();

    return $this;
  }

  public function totalSongs()
  {
    $playlistSongTable = Engine_Api::_()->getDbTable('playlistSongs', 'sitemusic');
    $psName = $playlistSongTable->info('name');
    $select = $playlistSongTable->select()->from($psName, array("COUNT(*) as count"));
    $select->where('playlist_id = ?', $this->getIdentity());
    $totalSongs = ($select->query()->fetch());
    return $totalSongs['count'];
  }

  public function getAlbumCategory()
  {
    $albumCategory = Engine_Api::_()->getItem('sitemusic_albumcategory', $this->category_id);
    if( $albumCategory ) {
      return $albumCategory;
    }
  }

  function isUrlEnable()
  {
    return $this->authorization()->isAllowed(null, 'url');
  }

  function isViewable()
  {
    return $this->authorization()->isAllowed(null, 'view');
  }

  function isEditable()
  {
    return $this->authorization()->isAllowed(null, 'edit');
  }

  function isDeletable()
  {
    return $this->authorization()->isAllowed(null, 'delete');
  }

  function isCommentable()
  {
    return $this->authorization()->isAllowed(null, 'comment');
  }

  function isuploadSong()
  {
    return $this->authorization()->isAllowed(null, 'upload_song');
  }

  function isDownloadable()
  {
    return $this->authorization()->isAllowed(null, 'download');
  }

  public function getLabel()
  {
    $db = Engine_Db_Table::getDefaultAdapter();
    $query1 = $db->select()
      ->from('engine4_sitemusic_label_map')
      ->where('resource_id = ?', $this->getIdentity());
    foreach( $query1->query()->fetchAll() as $q ) {
      $labelId = $q['label_id'];
    }
    if( $labelId ) {
      $query1 = $db->select()
        ->from('engine4_sitemusic_labels')
        ->where('label_id = ?', $labelId);
      foreach( $query1->query()->fetchAll() as $q ) {
        $labelName = $q['label_name'];
      }
    } else {
      return;
    }
    return $labelName;
  }

  public function follows()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('follows', 'sitemusic'));
  }

  // get unapprove songs list
  public function getUnapproveSongs()
  {
    $table = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
    $select = $table->select()
      ->where('playlist_id = ?', $this->getIdentity())
      ->where('approved = ?', 0);
    return $table->fetchAll($select);
  }

  public function sendMailNotification($albumOwner, $totalSong)
  {
    // create an object for view
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $viewer = Engine_Api::_()->user()->getViewer();
    $httpVar = _ENGINE_SSL ? 'https://' : 'http://';
    $url = $httpVar . $_SERVER['HTTP_HOST'] . $view->url(array('controller' => 'albums', 'action' => 'unapprove-songs', 'item_id' => $this->getIdentity()), 'sitemusic_general', true);
    $urlPath = "<a style='color: rgb(59, 89, 152); text-decoration: none;' href='" . $url . "'>" . $view->translate('click here') . "</a>";
    $mailId = $albumOwner->email;
    $subject = 'Song added to Music Album ' . $this->title;
    $message = $viewer->displayname . ' has added ' . $totalSong . ' song(s) in your music album ' . $this->title;
    $message .= 'You can approve / disapprove the song being added in your album.';
    $message .= $urlPath . ' for approve/disapprove';

    $email = Engine_Api::_()->getApi('settings', 'core')->core_mail_from;
    Engine_Api::_()->getApi('mail', 'core')->sendSystem($mailId, 'APPROVAL_SONG_NOTIFICATION', array(
      'subject' => $subject,
      'message' => $message,
      'email' => $email,
      'queue' => false
    ));
  }

  public function totalAllowSongsLimitExceed($totalAllowSongs, $totalSongs, $totalUpSongs = null)
  {
    $isString = is_string($totalSongs);
    if( $isString ) {
      $totalSongs = explode(' ', $totalSongs);
      if( isset($totalSongs) ) {
        $totalSongCount = count($totalSongs);
        if( $totalUpSongs ) {
          $totalSongCount = $totalSongCount + $totalUpSongs;
        }
      }
    } elseif( is_array($totalSongs) ) {
      $totalSongCount = count($totalSongs);
      if( $totalUpSongs ) {
        $totalSongCount = $totalSongCount + $totalUpSongs;
      }
    } elseif( is_numeric($totalSongs) ) {
      $totalSongCount = $totalSongs;
      if( $totalUpSongs ) {
        $totalSongCount = $totalSongCount + $totalUpSongs;
      }
    }
    if( $totalSongCount ) {
      if( $totalSongCount > $totalAllowSongs ) {
        return true;
      }
    }
  }

}
