<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PlaylistSong.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_PlaylistSong extends Core_Model_Item_Abstract
{

  public function getShortType($inflect = false)
  {
    return 'song'; // helps core_model_item get to primary key "song_id" (it adds "_id")
  }

  public function getTitle()
  {
    if( !empty($this->title) ) {
      return $this->title;
    } else {
      $translate = Zend_Registry::get('Zend_Translate');
      return $translate->translate('Untitled Song');
    }
  }

  public function setTitle($newTitle)
  {
    $this->title = $newTitle;
    $this->save();
    return $this;
  }

  public function getFilePath()
  {
    $file = Engine_Api::_()->getItem('storage_file', $this->file_id);
    if( $file ) {
      return $file->map();
    }
  }

  public function tags()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('tags', 'core'));
  }

  public function getHref($params = array())
  {
    $slug = $this->getSlug();

    $params = array_merge(array(
      'route' => 'sitemusic_item_view',
      'reset' => true,
      //'user_id' => $this->owner_id,
      'controller' => 'songs',
      'item_id' => $this->song_id,
      'slug' => $slug,
      ), $params);
    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);
    return Zend_Controller_Front::getInstance()->getRouter()
        ->assemble($params, $route, $reset);
  }

  public function getParent($recurseType = null)
  {
    return Engine_Api::_()->getItem('sitemusic_pl', $this->playlist_id);
  }

  public function getOwner($recurseType = null)
  {
    $owner = Engine_Api::_()->getItem('user', $this->owner_id);

    return $owner;
  }

  public function getRichContent($view = false, $params = array())
  {
    $view = Zend_Registry::get('Zend_View');
    $view = clone $view;
    $view->clearVars();
    $view->addScriptPath('application/modules/Sitemusic/views/scripts/');
    $view->song = $this;
    $view->config = 'All';
    $content = '';
    $content .= $view->render('_songActivityFeed.tpl');
    return $content;
  }

  /**
   * Returns languagified play count
   */
  public function playCountLanguagified()
  {
    return vsprintf(Zend_Registry::get('Zend_Translate')->_(array('%s play', '%s play', $this->play_count)), Zend_Locale_Format::toNumber($this->play_count)
    );
  }

  /**
   * Deletes songs from the Storage engine if no other playlists are
   * using the file, and from the playlist
   *
   * @return null
   */
  public function deleteUnused()
  {
    $file = Engine_Api::_()->getItem('storage_file', $this->file_id);
    if( $file ) {
      $table = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
      $count = $table->select()
        ->from($table->info('name'), 'count(*) as count')
        ->where('file_id = ?', $file->getIdentity())
        ->query()
        ->fetchColumn(0);
      if( $count <= 1 ) {
        try {
          $file->remove();
        } catch( Exception $e ) {

        }
      }
    }
    $this->delete();
  }

  public function getAuthorizationItem()
  {
    return $this->getParent();
  }

  public function getAlbum()
  {
    $result = Engine_Api::_()->getItem('sitemusic_pl', $this->playlist_id);
    return $result;
  }

  public function getArtist()
  {
    $songArtistTable = Engine_Api::_()->getDbTable('songartists', 'sitemusic');
    $saName = $songArtistTable->info('name');
    $artistTable = Engine_Api::_()->getDbTable('artists', 'sitemusic');
    $aName = $artistTable->info('name');
    $select = $artistTable->select()->from($aName);
    //   $songArtist = $songArtistTable->select();
    $select->join($saName, "$aName.artist_id = $saName.artist_id", '');
    $select->where('song_id = ?', $this->getIdentity());
    $artist = $select->query()->fetchAll();
    return $artist;
  }

  public function getArtistObject($params)
  {
    if( isset($params['artist_id']) ) {
      $artist = Engine_Api::_()->getItem('sitemusic_artist', $params['artist_id']);
      return $artist;
    } else {
      return false;
    }
  }

  public function getArtistSelect()
  {
    $songArtistTable = Engine_Api::_()->getDbTable('songartists', 'sitemusic');
    $saName = $songArtistTable->info('name');
    $artistTable = Engine_Api::_()->getDbTable('artists', 'sitemusic');
    $aName = $artistTable->info('name');
    $select = $artistTable->select()->from($aName);
    $select->join($saName, "$aName.artist_id = $saName.artist_id", '');
    $select->where('song_id = ?', $this->getIdentity());
    return $select;
  }

  public function getGenre()
  {
    $playlistSongTable = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
    $psName = $playlistSongTable->info('name');
    $scTable = Engine_Api::_()->getDbtable('songcategories', 'sitemusic');
    $scName = $scTable->info('name');

    $select = $scTable->select()
      ->from($scName);
    $select->join($psName, "$psName.genre_id = $scName.songcategory_id", '');
    $select->where('songcategory_id = ?', $this->genre_id)
      ->where('song_id = ?', $this->getIdentity());
    $result = $select->query()->fetch();
    return $result;
  }

  public function songInfo()
  {
    $title = $this->title;
    $artist = $this->getArtist();
    $artistTitle = $artist['title'];
    $album = $this->getAlbum();
    if( $album ) {
      $albumTitle = $album->title;
    }
    $photoUrl = $this->getIconPhoto();
    $path = $this->getFilePath();
    $httpVar = _ENGINE_SSL ? 'https://' : 'http://';
    $songUrl = $httpVar . $_SERVER['HTTP_HOST'] . $path;
    $songInfo = array('name' => $title, 'artist' => $artistTitle, 'album' => $albumTitle, 'url' => $songUrl, 'cover_art_url' => $photoUrl);
    $song = json_encode($songInfo);
    return $song;
  }

  public function getIconPhoto()
  {
    if( $this->photo_id ) {
      $file = Engine_Api::_()->getItem('storage_file', $this->photo_id);
      if( $file ) {
        return $file->map();
      }
    }
    return;
  }

  public function hasLike()
  {
    $likeTable = Engine_Api::_()->getDbtable('likes', 'core');
    $select = $likeTable->select()
      ->where('resource_id = ?', $this->getIdentity())
      ->where('resource_type = ?', $this->getType());
    $result = $select->query()->fetch();
    return $result['like_id'];
  }

  /**
   * Gets a proxy object for the comment handler
   *
   * @return Engine_ProxyObject
   * */
  public function comments()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
  }

  /**
   * Gets a proxy object for the like handler
   *
   * @return Engine_ProxyObject
   * */
  public function isDisplayable()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewerId = $viewer->getIdentity();
    $album = Engine_Api::_()->getItem('sitemusic_pl', $this->playlist_id);

    if( $this->approved ) {
      return 1;
    } elseif( $viewerId == $this->owner_id ) {
      return 1;
    } elseif( $viewerId == $album->owner_id ) {
      return 1;
    } else {
      return 0;
    }
  }

  public function getArtistNameString()
  {
    $songArtistTable = Engine_Api::_()->getItemTable('sitemusic_songartist');
    $artistInfo = array();
    $artistInfo = $songArtistTable->getArtist($this->getIdentity());

    $artistTitleString = null;
    if( !empty($artistInfo) && isset($artistInfo) ) {
      foreach( $artistInfo as $artist ) {
        if( !empty($artistTitleString) ) {
          $artistTitleString .= ',';
        }
        $artistTitleString .= $artist['title'];
      }
      return $artistTitleString;
    } else {
      $params = $this->params;
      if( !empty($params) ) {
        $params = Zend_Json::decode($params);
        if( isset($params['artist']) ) {
          $artistTitleString = $params['artist'];
        }
        return $artistTitleString;
      }
    }
  }

  public function getTags()
  {
    $tagMapsTable = Engine_Api::_()->getDbtable('tagMaps', 'core');
    $tmName = $tagMapsTable->info('name');
    $tagsTable = Engine_Api::_()->getDbtable('tags', 'core');
    $tName = $tagsTable->info('name');
    $select = $tagsTable->select()->from($tName);
    $select
      ->join($tmName, "$tName.tag_id = $tmName.tag_id", '')
      ->where($tmName . '.resource_type = ?', $this->getType())
      ->where($tmName . '.resource_id = ?', $this->getIdentity())
    ;
    return $select->query()->fetchAll();
  }

  public function likes()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
  }

  function isEditable()
  {
    return $this->authorization()->isAllowed(null, 'edit');
  }

  function isDeletable()
  {
    return $this->authorization()->isAllowed(null, 'delete');
  }

  function isCommentable()
  {
    return $this->authorization()->isAllowed(null, 'comment');
  }

  function isDownloadable()
  {
    return $this->getParent()->authorization()->isAllowed(null, 'download');
  }

}
