<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: UserPlaylist.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_UserPlaylist extends Core_Model_Item_Abstract
{
  protected $_type = 'sitemusic_userpl';
  // Interfaces

  public function getSongAssoc()
  {
    $songs = $this->getSongs();
    $data = array();
    foreach( $songs as $song ) {
      $data[$song['song_id']] = $song['title'];
    }
    return $data;
  }

  public function getTitle()
  {
    if( !empty($this->title) ) {
      return $this->title;
    }
  }

  /**
   * Gets an absolute URL to the page to view this item
   *
   * @return string
   */
  public function getHref($params = array())
  {
    $slug = $this->getSlug();

    $params = array_merge(array(
      'route' => 'sitemusic_item_view',
      'reset' => true,
      //'user_id' => $this->owner_id,
      'controller' => 'playlists',
      'item_id' => $this->userplaylist_id,
      'slug' => $slug,
      ), $params);
    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);
    return Zend_Controller_Front::getInstance()->getRouter()
        ->assemble($params, $route, $reset);
  }

  public function getRichContent($view = false, $params = array())
  {
    $view = Zend_Registry::get('Zend_View');
    $view = clone $view;
    $view->clearVars();
    $view->addScriptPath('application/modules/Sitemusic/views/scripts/');

    $view->item = $this;
    $content = '';
    $content .= $view->render('_album-playlistActivityFeed.tpl');
    return $content;
  }

  /**
   * Gets a proxy object for the comment handler
   *
   * @return Engine_ProxyObject
   * */
  public function comments()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
  }

  /**
   * Gets a proxy object for the like handler
   *
   * @return Engine_ProxyObject
   * */
  public function likes()
  {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
  }

  public function getCommentCount()
  {
    return $this->comments()->getCommentCount();
  }

  public function getParent($recurseType = null)
  {
    return $this->getOwner($recurseType);
  }

  public function addSong($params)
  {
    $table = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
    $songUserTable = $table->createRow();
    $songUserTable->userplaylist_id = $params['userplaylist_id'];
    $songUserTable->song_id = $params['song_id'];
    $songUserTable->save();
    $this->song_count = ++$this->song_count;
    $this->save();
  }

  public function getSongs($file_id = null)
  {
    $table = Engine_Api::_()->getDbtable('UserPlaylistSongs', 'sitemusic');
    $select = $table->select()
      ->where('userplaylist_id = ?', $this->getIdentity())
      ->order('userplaylist_id ASC');
    $songs = $table->fetchAll($select);
    $songIds = array();
    if( !count($songs) ) {
      return;
    }
    foreach( $songs as $song ) {
      $songIds[] = $song['song_id'];
    }
    $psTable = Engine_Api::_()->getDbtable('PlaylistSongs', 'sitemusic');
    $psSelect = $psTable->select()
      ->where('song_id IN (?)', $songIds)
      ->order('song_id ASC');
    return $psTable->fetchAll($psSelect);
  }

  public function getSong($file_id)
  {
    return Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic')->fetchRow(array(
        'playlist_id = ?' => $this->getIdentity(),
        'file_id = ?' => $file_id,
    ));
  }

  public function setPhoto($photo)
  {
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
    } else if( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
    } else {
      throw new Sitemusic_Model_Exception('Invalid argument passed to setPhoto: ' . print_r($photo, 1));
    }

    $name = basename($file);
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => 'sitemusic_pl',
      'parent_id' => $this->getIdentity()
    );

    // Save
    $storage = Engine_Api::_()->storage();

    // Resize image (main)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(720, 720)
      ->write($path . '/m_' . $name)
      ->destroy();

    // Resize image (profile)
//    $image = Engine_Image::factory();
//    $image->open($file)
//      ->resize(200, 400)
//      ->write($path . '/p_' . $name)
//      ->destroy();

    // Resize image (normal)
    $image = Engine_Image::factory();
    $image->open($file)
      ->resize(140, 160)
      ->write($path . '/in_' . $name)
      ->destroy();

    // Resize image (icon)
    $image = Engine_Image::factory();
    $image->open($file);

    $size = min($image->height, $image->width);
    $x = ($image->width - $size) / 2;
    $y = ($image->height - $size) / 2;

    $image->resample($x, $y, $size, $size, 48, 48)
      ->write($path . '/is_' . $name)
      ->destroy();

    // Store
    $iMain = $storage->create($path . '/m_' . $name, $params);
//    $iProfile = $storage->create($path . '/p_' . $name, $params);
    $iIconNormal = $storage->create($path . '/in_' . $name, $params);
    $iSquare = $storage->create($path . '/is_' . $name, $params);

//    $iMain->bridge($iProfile, 'thumb.profile');
    $iMain->bridge($iIconNormal, 'thumb.normal');
    $iMain->bridge($iSquare, 'thumb.icon');

    // Remove temp files
//    @unlink($path . '/p_' . $name);
    @unlink($path . '/m_' . $name);
    @unlink($path . '/in_' . $name);
    @unlink($path . '/is_' . $name);

    // Update row
    $this->modified_date = date('Y-m-d H:i:s');
    $this->photo_id = $iMain->getIdentity();
    $this->save();

    return $this;
  }

  public function setProfile()
  {
    $table = Engine_Api::_()->getDbtable('playlists', 'sitemusic')->update(array(
      'profile' => 0,
      ), array(
      'owner_id = ?' => $this->owner_id,
      'playlist_id != ' . $this->getIdentity(),
    ));
    $this->profile = !$this->profile;
    $this->save();
  }

  public function totalSongs()
  {
    $upSongTable = Engine_Api::_()->getDbTable('userPlaylistSongs', 'sitemusic');
    $upName = $upSongTable->info('name');
    $select = $upSongTable->select()->from($upName, array("COUNT(*) as count"));
    $select->where('userplaylist_id = ?', $this->getIdentity());
    $totalSongs = ($select->query()->fetch());
    return $totalSongs['count'];
  }

  function isViewable()
  {
    return $this->authorization()->isAllowed(null, 'view');
  }

  function isEditable()
  {
    return $this->authorization()->isAllowed(null, 'edit');
  }

  function isDeletable()
  {
    return $this->authorization()->isAllowed(null, 'delete');
  }

  function isCommentable()
  {
    return $this->authorization()->isAllowed(null, 'comment');
  }

}
