<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    AdminLevelController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_AdminLevelController extends Core_Controller_Action_Admin
{

  public function init()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sm_admin_main', array(), 'sm_admin_main_level');
  }

  public function indexAction()
  {
    $isArtistEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.artist', 1);
    if( !$isArtistEnable ) {
      $this->view->artistNotEnable = true;
    }
    $isPlaylistEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.playlist', 1);
    if( !$isPlaylistEnable ) {
      $this->view->playlistNotEnable = true;
    }

    // Get level id
    if( null !== ($id = $this->_getParam('level_id', $this->_getParam('id'))) ) {
      $level = Engine_Api::_()->getItem('authorization_level', $id);
    } else {
      $level = Engine_Api::_()->getItemTable('authorization_level')->getDefaultLevel();
    }

    if( !$level instanceof Authorization_Model_Level ) {
      throw new Engine_Exception('missing level');
    }

    $id = $level->level_id;

    // Make form
    $this->view->form = $form = new Sitemusic_Form_Admin_Settings_Level(array(
      'public' => ( in_array($level->type, array('public')) ),
      'moderator' => ( in_array($level->type, array('admin', 'moderator')) ),
    ));
    $form->level_id->setValue($id);
    $values = $form->getValues();
    $userplaylist = array("playlist_view" => '', "playlist_create" => '', "playlist_edit" => '', "playlist_delete" => '', "sm_max_playlist" => '',
      "sm_max_plSong" => '', "auth_view_pl" => '', "auth_comment_pl" => '', "playlist_comment" => '');

    $album = array("album_view" => '', "album_create" => '', "album_edit" => '', "album_delete" => '', "approved_album" => '',
      "sm_max_albumSong" => '', "auth_view_album" => '', "auth_coment_albm" => '', "auth_dload_album" => '', "album_comment" => '', "auth_upload_song" => '', 'upload_song' => '', 'url' => '', 'redirect_page' => '', 'download' => '');

    $song = array("song_edit" => '', "song_delete" => '', "auth_comment_song" => '', "song_comment" => '');

    $artist = array("artist_view" => '', "artist_comment" => '', "artist_edit" => '');

    $permissionsTable = Engine_Api::_()->getDbtable('permissions', 'authorization');
    $playlistValues = array();
    $albumValues = array();
    $artistValues = array();
    foreach( $values as $key => $value ) {
      if( array_key_exists($key, $userplaylist) ) {
        $key = str_replace("playlist_", "", $key);
        $upValue = array($key => $value);
        $playlistValues = array_merge($playlistValues, $upValue);
      } elseif( array_key_exists($key, $album) ) {
        $key = str_replace("album_", "", $key);
        $pValue = array($key => $value);
        $albumValues = array_merge($albumValues, $pValue);
      } elseif( array_key_exists($key, $artist) ) {
        $key = str_replace("artist_", "", $key);
        $aValue = array($key => $value);
        $artistValues = array_merge($artistValues, $aValue);
      }
    }

    $playlistAllowValues = $permissionsTable->getAllowed('sitemusic_userpl', $id, array_keys($playlistValues));
    $albumAllowValues = $permissionsTable->getAllowed('sitemusic_pl', $id, array_keys($albumValues));
    $artistAllowValues = $permissionsTable->getAllowed('sitemusic_artist', $id, array_keys($artistValues));
    $playlistPopulateValues = array();
    $albumPopulateValues = array();
    $artistPopulateValues = array();
    $option = array('edit', 'comment', 'view', 'create', 'delete');
    $up = array();
    $p = array();
    $a = array();
    foreach( $playlistAllowValues as $key => $value ) {
      if( in_array($key, $option) )
        $key = 'playlist_' . $key;
      $up = array($key => $value);
      $playlistPopulateValues = array_merge($playlistPopulateValues, $up);
    }
    foreach( $albumAllowValues as $key => $value ) {
      if( in_array($key, $option) )
        $key = 'album_' . $key;
      $p = array($key => $value);
      $albumPopulateValues = array_merge($albumPopulateValues, $p);
    }

    foreach( $artistAllowValues as $key => $value ) {
      if( in_array($key, $option) )
        $key = 'artist_' . $key;
      $a = array($key => $value);
      $artistPopulateValues = array_merge($artistPopulateValues, $a);
    }

    $form->populate($albumPopulateValues);
    $form->populate($artistPopulateValues);
    $form->populate($playlistPopulateValues);

    // Check post
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    // Check validitiy
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Form elements with NonBoolean values
    $nonBooleanSettings = $form->nonBooleanFields();

    $db = $permissionsTable->getAdapter();
    $db->beginTransaction();
    //  $values = $this->getRequest()->getPost();
    $values = $form->getValues();
    //   die;
    try {
      foreach( $values as $key => $value ) {
        if( array_key_exists($key, $userplaylist) ) {
          $key = str_replace("playlist_", "", $key);
          $upValue = array($key => $value);
          $permissionsTable->setAllowed('sitemusic_userpl', $id, $upValue, '', $nonBooleanSettings);
        } elseif( array_key_exists($key, $album) ) {
          $key = str_replace("album_", "", $key);
          $pValue = array($key => $value);
          $permissionsTable->setAllowed('sitemusic_pl', $id, $pValue, '', $nonBooleanSettings);
        } elseif( array_key_exists($key, $artist) ) {
          $key = str_replace("artist_", "", $key);
          $aValue = array($key => $value);
          $permissionsTable->setAllowed('sitemusic_artist', $id, $aValue, '', $nonBooleanSettings);
        }
      }
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    $form->addNotice('Your changes have been saved.');
  }

}
