<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    AlbumController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_AlbumsController extends Core_Controller_Action_Standard
{

  public function init()
  {
    // Get subject
    if( null !== ($playlistId = $this->_getParam('item_id')) &&
      null !== ($playlist = Engine_Api::_()->getItem('sitemusic_pl', $playlistId)) &&
      $playlist instanceof Sitemusic_Model_Playlist &&
      !Engine_Api::_()->core()->hasSubject() ) {
      Engine_Api::_()->core()->setSubject($playlist);
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }

    // Get viewer info
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = $viewer->getIdentity();
  }

  public function indexAction()
  {
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return;
    }

    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_albums_index");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function createAction()
  {
//     only members can upload music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'create')->isValid() ) {
      return;
    }
    $viewer = Engine_Api::_()->user()->getViewer();
//
    $this->_helper->content
      // ->setNoRender()
      ->setEnabled()
    ;
    // catch uploads from FLASH fancy-uploader and redirect to uploadSongAction()
    if( $this->getRequest()->getQuery('ul', false) ) {
      return $this->_forward('upload', 'songs', null, array('format' => 'json'));
    }

//others plugin integration work
    $parentType = $this->_getParam('parent_type');
    $parentId = $this->_getParam('parent_id');

    // for others plugin(group,pages etc) music album creation optins
    $othersPluginCreation = array('parent_type' => $parentType, 'parent_id' => $parentId);

    // Get form
    $this->view->form = $form = new Sitemusic_Form_Create(array('othersPlgingCreation' => $othersPluginCreation));
    $this->view->playlist_id = $this->_getParam('playlist_id', '0');

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }


    $db = Engine_Api::_()->getDbTable('playlists', 'sitemusic')->getAdapter();

    $db->beginTransaction();
    try {
      $values = $this->view->form->saveValues();
      $this->view->playlist = $playlist = $values['playlist'];
      if( empty($playlist) ) {
        return;
      }
      $songIds = null;
      if( isset($values['song_ids']) ) {
      $songIds = $values['song_ids'];
      }
      if( !empty($songIds) ) {
        $songIds = implode(',', $songIds);
      }
      if( !empty($_FILES['coverphoto']['name']) ) {
        $photoFileIcon = $playlist->setCoverPhoto($form->coverphoto);
        $playlist->cover_photo_id = $photoFileIcon->cover_photo_id;
      }


      //WHO WILL BE THE PARENT OF MUSIC ALBUM CREATED THROUGH THE OTHER MODULES
      //    $albumOwnerSetting = Engine_Api::_()->getApi('settings', 'core')->getSetting("sitemusic.playlist.leader.owner.$parentType", 1);
      if( !empty($parentId) && !empty($parentType) ) {
        $playlist->parent_type = $parentType;
        $playlist->parent_id = $parentId;
      } else {
        $playlist->parent_type = 'user';
        $playlist->parent_id = Engine_Api::_()->user()->getViewer()->getIdentity();
      }

      // Add activity only if music is published
      if( $playlist['published'] == 1 && $playlist->search ) {


        if( $parentType == 'sitepage_page' ) {
          $sitepage = Engine_Api::_()->getItem('sitepage_page', $parentId);
          $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $sitepage, 'sitemusic_sitepage_music_new');
        } else if( $parentType == 'sitebusiness_business' ) {
          $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parentId);
          $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $sitebusiness, 'sitemusic_sitebusiness_music_new');
        } else if( $parentType == 'sitegroup_group' ) {
          $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parentId);
          $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $sitegroup, 'sitemusic_sitegroup_music_new');
        } else {
          $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $playlist, 'sitemusic_album_new', null, array('count' => $playlist['song_count']));
        }
        // make sure action exists before attaching the music to the activity
        if( $action && $playlist->approved ) {
          Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $playlist);
        }
      }
      $playlist->save();
      $db->commit();
    } catch( Exception $e ) {
      if( APPLICATION_ENV === 'development' ) {
        $db->rollback();
        throw $e;
      } else {
        return $this->exceptionWrapper($e, $form, $db);
      }
    }


    $pageRedirect = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_pl', 'redirect_page');

    if( $pageRedirect == 'edit-album' ) {
      $this->_helper->redirector->gotoRoute(array('item_id' => $playlist->playlist_id, 'controller' => 'albums', 'action' => 'edit'));
    } elseif( $pageRedirect == 'view' ) {
      $this->_helper->redirector->gotoRoute(array('controller' => 'albums', 'action' => 'view', 'item_id' => $playlist->playlist_id,), 'sitemusic_item_view', true);
    } elseif( $pageRedirect == 'manage' ) {
      $this->_helper->redirector->gotoRoute(array('controller' => 'manage', 'action' => 'album'));
    } else {
      $this->_helper->redirector->gotoRoute(array('controller' => 'songs', 'action' => 'editinfo', 'item_id' => $playlist->playlist_id,), 'sitemusic_item_specific', true);
    }
  }

  public function viewAction()
  {
    // Check permission
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = $viewer->getIdentity();
    $this->view->subject = $playlist = Engine_Api::_()->getItem('sitemusic_pl', $this->_getParam('item_id'));
    // is rating enable
    $this->view->isRatingEnable = $enableRating = Engine_Api::_()->sitemusic()->enableAlbumRating();

    if( !$this->_helper->requireSubject()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireAuth()->setAuthParams($playlist, null, 'view')->isValid() ) {
      return;
    }

    if( !$playlist || !$playlist->getIdentity() ||
      (!($playlist->published) && $viewerId != $playlist->getOwner()->getIdentity() ) ) {
      return $this->_helper->requireSubject->forward();
    }

    $this->view->resource_type = $playlist->getType();
    $this->view->resource_id = $this->_getParam('item_id');

    if( $playlist->category_id ) {
      $albumCategoryId = $playlist->category_id;
      $albumCategory = Engine_Api::_()->getItem('sitemusic_albumcategory', $albumCategoryId);
      if( $albumCategory ) {
        //CHECK AND SET META KEYWORDS
        Engine_Api::_()->sitemusic()->checkMetaKeywords($albumCategory);
      }
    }

    // Prepare data
    $playlistTable = Engine_Api::_()->getDbtable('playlists', 'sitemusic');

    $this->view->album = $playlist;
    $this->view->owner = $owner = $playlist->getOwner();
    $this->view->viewer = $viewer;

    if( !$playlist->isOwner($viewer) ) {
      $playlistTable->update(array(
        'view_count' => new Zend_Db_Expr('view_count + 1'),
        ), array(
        'playlist_id = ?' => $playlist->getIdentity(),
      ));
    }

    $this->view->viewer_id = $viewer->getIdentity();
    $this->view->rating_count = Engine_Api::_()->sitemusic()->ratingCount($playlist->getIdentity(), $playlist->getType());
    $this->view->album = $playlist;
    $this->view->rated = Engine_Api::_()->sitemusic()->checkRated($playlist->getIdentity(), $viewer->getIdentity(), $playlist->getType());
    // Get styles
    $table = Engine_Api::_()->getDbtable('styles', 'core');
    $style = $table->select()
      ->from($table, 'style')
      ->where('type = ?', 'user_blog')
      ->where('id = ?', $owner->getIdentity())
      ->limit(1)
      ->query()
      ->fetchColumn();
    if( !empty($style) ) {
      try {
        $this->view->headStyle()->appendStyle($style);
      }
      // silence any exception, exceptin in development mode
      catch( Exception $e ) {
        if( APPLICATION_ENV === 'development' ) {
          throw $e;
        }
      }
    }

    // Render
    $this->_helper->content
      //->setNoRender()
      ->setEnabled()
    ;
  }

  public function editAction()
  {
    // catch uploads from FLASH fancy-uploader and redirect to uploadSongAction()
    if( $this->getRequest()->getQuery('ul', false) ) {
      return $this->_forward('upload', 'songs', null, array('format' => 'json'));
    }

    $this->_helper->content
      // ->setNoRender()
      ->setEnabled()
    ;

    // only members can upload music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireSubject('sitemusic_pl')->isValid() ) {
      return;
    }
    $redirect = $this->_getParam('redirect');
    if( !empty($redirect) ) {
      $str = $this->_getParam('str');
      $route = '/admin/sitemusic/manage' . $str;
    }
    $playlistId = $this->_getParam('item_id');
    $viewer = Engine_Api::_()->user()->getViewer();
    // Get playlist
    $this->view->playlist = $playlist = Engine_Api::_()->core()->getSubject('sitemusic_pl');

    if( !$this->_helper->requireAuth()->setAuthParams($playlist, null, 'view')->isValid() ) {
      return;
    }

    $songTable = Engine_Api::_()->getItemTable('sitemusic_playlist_song');
//    $this->view->songIds = $songIds = $songTable->oldSongIds($playlistId);
    // Get form
    $this->view->form = $form = new Sitemusic_Form_Create();

    // only user and admins and moderators can edit
    if( !$this->_helper->requireAuth()->setAuthParams($playlist, null, 'edit')->isValid() ) {
      return;
    }

    // Make form
    $this->view->form = $form = new Sitemusic_Form_Edit(array("playlist" => $playlist));
//    echo $playlist->category_id;
//    die;
    $form->populateWithObject($playlist);

    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    //others plugin integration work
    $parentType = $this->_getParam('parent_type');
    $parentId = $this->_getParam('parent_id');

    $values = $this->getRequest()->getPost();
    $db = Engine_Api::_()->getDbTable('playlists', 'sitemusic')->getAdapter();
    $db->beginTransaction();
    try {
      $values = $form->saveValues();
      $playlist = $values['playlist'];
      if( empty($playlist) ) {
        return;
      }
      $ids = $values['songIds'];

      if( !empty($_FILES['coverphoto']['name']) ) {
        $photoFileIcon = $playlist->setCoverPhoto($form->coverphoto);
        $playlist->cover_photo_id = $photoFileIcon->cover_photo_id;
      }

      //WHO WILL BE THE PARENT OF MUSIC ALBUM CREATED THROUGH THE OTHER MODULES
      //     $albumOwnerSetting = Engine_Api::_()->getApi('settings', 'core')->getSetting("sitemusic.playlist.leader.owner.$parentType", 1);
      if( !empty($parentId) && !empty($parentType) ) {
        $playlist->parent_type = $parentType;
        $playlist->parent_id = $parentId;
      } else {
        $playlist->parent_type = 'user';
        $playlist->parent_id = Engine_Api::_()->user()->getViewer()->getIdentity();
      }

      if( isset($ids) && !empty($ids) && $playlist['published'] == 0 && $playlist->search ) {
        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $playlist, 'sitemusic_album_new', null, array('count' => count($ids)));

        // make sure action exists before attaching the music to the activity
        if( $action ) {
          Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $playlist);
        }

        $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
        $followers = $followTable->getFollowers('sitemusic_pl', $playlist->getIdentity(), $viewer->getIdentity());
        if( $followers ) {
          foreach( $followers as $result ) {
            $userId = $result['poster_id'];
            $user = Engine_Api::_()->getItem('user', $userId);
            Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $playlist, 'album_new');
          }
        }
      }
      $playlist->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }


    $pageRedirect = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_pl', 'redirect_page');


    if( $pageRedirect == 'edit-album' ) {
      $this->_helper->redirector->gotoRoute(array('item_id' => $playlist->playlist_id, 'controller' => 'albums', 'action' => 'edit'));
    } elseif( $pageRedirect == 'view' ) {
      $this->_helper->redirector->gotoRoute(array('controller' => 'albums', 'action' => 'view', 'item_id' => $playlist->playlist_id,), 'sitemusic_item_view', true);
    } elseif( $pageRedirect == 'manage' ) {
      $this->_helper->redirector->gotoRoute(array('controller' => 'manage', 'action' => 'album'), 'sitemusic_general', true);
    } elseif( !empty($redirect) && $redirect == 'admin' ) {
      $this->_helper->redirector->gotoUrl($route);
    } else {
      if( is_array($ids) )
      $ids = implode(',', $ids);
      
      if( !empty($ids) ) {
        $this->_helper->redirector->gotoRoute(array('song_id' => $ids, 'controller' => 'songs', 'action' => 'editinfo'));
      } else {
        $this->_helper->redirector->gotoRoute(array('controller' => 'songs', 'action' => 'editinfo', 'item_id' => $playlist->playlist_id,), 'sitemusic_item_specific', true);
      }
    }


//
//    $ids = implode(',', $ids);
//    if( !empty($ids) ) {
//      $this->_helper->redirector->gotoRoute(array('song_id' => $ids, 'controller' => 'song', 'action' => 'editinfo'));
//    } elseif( !empty($redirect) && $redirect == 'admin' ) {
//      $this->_helper->redirector->gotoUrl($route);
//    } else {
//      $this->_helper->redirector->gotoRoute(array('controller' => 'manage', 'action' => 'album'));
//    }
  }

  public function sortAction()
  {
    if( !$this->_helper->requireSubject('sitemusic_pl')->isValid() ) {
      $this->view->status = false;
      $this->view->error = $this->view->translate('Invalid playlist');
      return;
    }

    // Get playlist
    $this->view->playlist = $playlist = Engine_Api::_()->core()->getSubject('sitemusic_pl');
    $this->view->playlist_id = $playlistId = $playlist->getIdentity();

    // only user and admins and moderators can edit
    if( !$this->_helper->requireAuth()->setAuthParams($playlist, null, 'album_edit')->isValid() ) {
      $this->view->status = false;
      $this->view->error = $this->view->translate('Not allowed to edit this playlist');
      return;
    }


    $songs = $playlist->getSongs();
    $order = explode(',', $this->getRequest()->getParam('order'));
    foreach( $order as $i => $item ) {
      $songId = substr($item, strrpos($item, '_') + 1);
      foreach( $songs as $song ) {
        if( $song->song_id == $songId ) {
          $song->order = $i;
          $song->save();
        }
      }
    }

    $this->view->songs = $playlist->getSongs()->toArray();
  }

  public function deleteAction()
  {
    // In smoothbox
    $id = $this->_getParam('id');
    $type = $this->_getParam('resource_type');
    $this->view->playlist_id = $id;
    // Check post
    if( $this->getRequest()->isPost() ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      $table = Engine_Api::_()->getItem('sitemusic_pl', $id);
      if( empty($table) ) {
        return;
      }
      try {
        // delete the playlist into the database
        $table->delete();
        $db->commit();
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => true,
        'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'manage', 'action' => 'album'), "sitemusic_general", true),
        'parentRedirectTime' => '2',
        'format' => 'smoothbox',
        'messages' => array('Music Album Deleted Successfully')
      ));
    }
  }

  public function favouriteAction()
  {

    //GET THE VIEWER.
    $viewer = Engine_Api::_()->user()->getViewer();

    //GET THE VALUE OF RESOURCE ID AND RESOURCE TYPE AND FAVOURITE ID.
    $this->view->resource_id = $resource_id = $this->_getParam('resource_id');
    $this->view->resource_type = $resource_type = $this->_getParam('resource_type');
    $favourite_id = $this->_getParam('favourite_id');
    $status = $this->_getParam('smoothbox', 1);
    $this->view->status = true;
    //GET THE FAVOURITE BUTTON SETTINGS.
    $this->view->favourite_setting_button = Engine_Api::_()->getApi('settings', 'core')->getSetting('favourite.setting.button');

    //GET THE CURRENT UESRID AND SETTINGS.
    $this->view->viewer_id = $loggedin_user_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if( (empty($loggedin_user_id) ) ) {
      return;
    }
    //CHECK THE FAVOURITE ID.
    if( empty($favourite_id) ) {

      //CHECKING IF USER HAS MAKING DUPLICATE ENTRY OF FAVOURITING AN APPLICATION.
      $favourite_id_temp = Engine_Api::_()->getApi('favourite', 'sitemusic')->hasFavourite($resource_type, $resource_id);
      //CHECK THE THE ITEM IS FAVOURITED OR NOT.
      if( empty($favourite_id_temp[0]['favourite_id']) ) {

        $favouriteTable = Engine_Api::_()->getItemTable('sitemusic_favourite');
        $notify_table = Engine_Api::_()->getDbtable('notifications', 'activity');
        $db = $favouriteTable->getAdapter();
        $db->beginTransaction();
        try {
//            //ADD FAVOURITE
          $favourite_id = $favouriteTable->addFavourite($resource, $viewer)->favourite_id;
          //PASS THE FAVOURITE ID VALUE.
          $this->view->favourite_id = $favourite_id;
          $db->commit();
        } catch( Exception $e ) {
          $db->rollBack();
          throw $e;
        }
        $favourite_msg = Zend_Registry::get('Zend_Translate')->_('Successfully Favourited.');
      } else {
        $this->view->favourite_id = $favourite_id_temp[0]['favourite_id'];
      }
    } else {

      //START DELETE NOTIFICATION
      Engine_Api::_()->getDbtable('notifications', 'activity')->delete(array('type = ?' => 'favourited', 'subject_id = ?' => $viewer->getIdentity(), 'subject_type = ?' => $viewer->getType(), 'object_type = ?' => $resource_type, 'object_id = ?' => $resource_id));
      //END DELETE NOTIFICATION
      ////START UNFAVOURITE WORK.
      //HERE 'PAGE OR LIST PLUGIN' CHECK WHEN UNFAVOURITE
      if( !empty($resource) && isset($resource->favourite_count) ) {
        $resource->favourite_count--;
        $resource->save();
      }
      $contentTable = Engine_Api::_()->getDbTable('favourites', 'sitemusic')->delete(array('favourite_id =?' => $favourite_id));
      //END UNFAVOURITE WORK.
      $favourite_msg = Zend_Registry::get('Zend_Translate')->_('Successfully Unfavourited.');
    }
    if( empty($status) ) {
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => true,
        'parentRefresh' => true,
        'messages' => array($favourite_msg)
        )
      );
    }
    //HERE THE CONTENT TYPE MEANS MODULE NAME
    $num_of_contenttype = Engine_Api::_()->getApi('favourite', 'sitemusic')->favouriteCount($resource_type, $resource_id);
    $favourites_number = $this->view->translate(array('%s favourite', '%s favourites', $num_of_contenttype), $this->view->locale()->toNumber($num_of_contenttype));
    $this->view->num_of_favourite = "<a href='javascript:void(0);' onclick='showSmoothBox(); return false;' >" . $favourites_number . "</a>";
  }

  public function homeAction()
  {
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_albums_home");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function getAlbumOfTheDayAction()
  {
    $data = array();
    $playlistTable = Engine_Api::_()->getDbtable('playlists', 'sitemusic');
    $select = $playlistTable->select()
        ->where('title  LIKE ? ', '%' . $this->_getParam('text') . '%')
        ->where('approved = ?', 1)
        ->where('search = ?', 1)
        ->order('title ASC')->limit('10');
    $albums = $playlistTable->fetchAll($select);

    foreach( $albums as $album ) {
      $albumPhoto = $this->view->itemPhoto($album, 'thumb.icon');
      $data[] = array(
        'id' => $album->playlist_id,
        'label' => $album->title,
        'photo' => $albumPhoto
      );
    }
    return $this->_helper->json($data);
  }

  public function albumInfoAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    if( !$this->_helper->requireUser()->isValid() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You must be logged in.');
      return;
    }
    $this->view->enableStatsCountOnZero = Engine_Api::_()->sitemusic()->enableStatsCountOnZero();

    $itemId = $this->_getParam('item_id');
    $playlist = Engine_Api::_()->getItem('sitemusic_pl', $itemId);
    $this->view->playlist = $playlist;
    if( $playlist->category_id ) {
      $albumCategory = Engine_Api::_()->getItem('sitemusic_albumcategory', $playlist->category_id);
      if( $albumCategory ) {
        $this->view->category_name = $albumCategory->category_name;
      }
    }
  }

  //new song added by others album
  public function appendSongAction()
  {
    $this->_helper->layout->setLayout('default-simple');
//     only members can upload music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    $playlistId = $this->_getParam('playlist_id');

    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'create')->isValid() ) {
      return;
    }
    // Get viewer info
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = $viewer->getIdentity();

    // Get the core module version
    $this->view->coreVersion = $coreVersion = Engine_Api::_()->getDbtable('modules', 'core')->select()
      ->from('engine4_core_modules', 'version')
      ->where('name = ?', 'core')
      ->query()
      ->fetchColumn();

    // catch uploads from FLASH fancy-uploader and redirect to uploadSongAction()
    if( $this->getRequest()->getQuery('ul', false) ) {
      return $this->_forward('upload', 'songs', null, array('format' => 'json'));
    }

    if( version_compare($coreVersion, '4.10.0rc1') >= 0 ) {
      $this->view->isNewVersion = 1;
    } else {
      $this->view->isNewVersion = 0;
    }

    // Get form
    $this->view->form = $form = new Sitemusic_Form_AddAlbumSong(array('core_version' => $coreVersion, 'playlist_id' => $playlistId));
    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }


    $db = Engine_Api::_()->getDbTable('playlists', 'sitemusic')->getAdapter();

    $db->beginTransaction();
    try {
      $values = $this->view->form->saveValues($playlistId);
      $this->view->playlist = $playlist = $values['playlist'];
      $songIds = $values['song_ids'];

      if( !empty($songIds) ) {
        $totalSong = count($songIds);
        $songIds = implode(',', $songIds);
      } else {
        return;
      }
      $db->commit();
    } catch( Exception $e ) {
      if( APPLICATION_ENV === 'development' ) {
        $db->rollback();
        throw $e;
      } else {
        return $this->exceptionWrapper($e, $form, $db);
      }
    }
    $albumOwner = $playlist->getOwner();
    // mail notification work
    $playlist->sendMailNotification($albumOwner, $totalSong);

    $user = $playlist->getOwner();
    if( $user->getIdentity() != $viewer->getIdentity() ) {
      Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $playlist, 'album_new', array('count' => $totalSong));
    }

    if( !empty($songIds) ) {
      return $this->_forward('success', 'utility', 'core', array(
          'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('song_id' => $songIds, 'item_id' => $playlist->playlist_id, 'controller' => 'songs', 'action' => 'editinfo'), "sitemusic_general", true),
          'messages' => Array('Songs are being uploaded.')
      ));
    }
  }

  public function unapproveSongsAction()
  {
    $this->_helper->content
      // ->setNoRender()
      ->setEnabled()
    ;
    // Get navigation
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitemusic_main');

    // Get viewer info
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = $viewer->getIdentity();
    $this->view->songShowOptions = null;
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $playlistId = $this->_getParam('item_id');


    $this->view->playlist = $album = Engine_Api::_()->getItem('sitemusic_pl', $playlistId);

    if( !$this->_helper->requireAuth()->setAuthParams($album, null, 'view')->isValid() ) {
      return;
    }

    if( !$this->_helper->requireSubject()->isValid() ) {
      return;
    }

    if( !$this->_helper->requireAuth()->setAuthParams($album, $viewer, 'view')->isValid() ) {
      return;
    }

    if( empty($album) ) {
      return $this->_helper->requireSubject->forward();
    }

    $unapproveSongs = $album->getUnapproveSongs();
    $this->view->paginator = $paginator = zend_paginator::factory($unapproveSongs);
  }

  protected function _forwardCustom($action, $controller = null, $module = null, array $params = null)
  {
    // Parent
    $request = $this->getRequest();

    if( null !== $params ) {
      $request->setParams($params);
    }

    if( null !== $controller ) {
      $request->setControllerName($controller);

      // Module should only be reset if controller has been specified
      if( null !== $module ) {
        $request->setModuleName($module);
      }
    }

    $request->setActionName($action);
    if( Engine_API::_()->seaocore()->isSiteMobileModeEnabled() ) {
      $sr_response = Engine_Api::_()->sitemobile()->setupRequest($request);
    }
    $request->setDispatched(false);
  }

}
