<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ArtistController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_ArtistsController extends Core_Controller_Action_Standard
{

  public function init()
  {
    $enableArtist = Engine_Api::_()->sitemusic()->isArtistEnabled();
    if( empty($enableArtist) ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
  }

  public function indexAction()
  {
    // Check auth
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_artist', null, 'view')->isValid() ) {
      return;
    }
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_artists_index");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function viewAction()
  {
    // Check permission
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer->getIdentity();
    $this->view->subject = $artist = Engine_Api::_()->getItem('sitemusic_artist', $this->_getParam('item_id'));
    if( $artist ) {
      Engine_Api::_()->core()->setSubject($artist);
    }
    if( !$this->_helper->requireSubject()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_artist', $viewer, 'view')->isValid() ) {
      return;
    }
    $this->view->resource_type = $artist->getType();
    $this->view->resource_id = $this->_getParam('item_id');
    // Prepare data
    $artistTable = Engine_Api::_()->getDbtable('artists', 'sitemusic');

    $this->view->artist = $artist;
    $this->view->owner = $owner = $artist->getOwner();
    $this->view->rating_count = Engine_Api::_()->sitemusic()->ratingCount($artist->getIdentity(), $artist->getType());
    $this->view->artist = $artist;
    $this->view->rated = Engine_Api::_()->sitemusic()->checkRated($artist->getIdentity(), $viewer->getIdentity(), $artist->getType());
    // Get styles
    $table = Engine_Api::_()->getDbtable('styles', 'core');
    $style = $table->select()
      ->from($table, 'style')
      ->where('type = ?', 'user_blog')
      ->where('id = ?', $owner->getIdentity())
      ->limit(1)
      ->query()
      ->fetchColumn();
    if( !empty($style) ) {
      try {
        $this->view->headStyle()->appendStyle($style);
      }
      // silence any exception, exceptin in development mode
      catch( Exception $e ) {
        if( APPLICATION_ENV === 'development' ) {
          throw $e;
        }
      }
    }

    // Render
    $this->_helper->content
      //->setNoRender()
      ->setEnabled()
    ;
  }

  public function followAction()
  {
    //CHECK USER VALIDATION
    if( !$this->_helper->requireUser()->isValid() )
      return;

    //GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    $resource_id = $this->_getParam('resource_id');
    $resource_type = $this->_getParam('resource_type');
    $follow_id = $this->_getParam('follow_id');
    $status = $this->_getParam('smoothbox', 1);
    $this->view->status = true;
    //GET FOLLOW TABLE
    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
    $follow_name = $followTable->info('name');

    //GET OBJECT
    $resource = Engine_Api::_()->getItem($resource_type, $resource_id);

    if( empty($follow_id) ) {

      //CHECKING IF USER HAS MAKING DUPLICATE ENTRY OF LIKING AN APPLICATION.
      if( $resource->getType() == 'user' )
        $follow_id_temp = Engine_Api::_()->getDbtable('follows', 'sitemusic')->isFollow($resource, $viewer);
      else
        $follow_id_temp = $resource->follows()->isFollow($viewer);
      if( empty($follow_id_temp) ) {
        if( !empty($resource) ) {
          $follow_id = $followTable->addFollow($resource, $viewer);
          if( $viewer_id != $resource->getOwner()->getIdentity() ) {

            if( $resource_type ) {
              $object_type = $resource->getType();
              $object_id = $resource->getIdentity();
              $subject_type = $viewer->getType();
              $subject_id = $viewer->getIdentity();
              $notificationType = 'follow_' . $resource_type;
              $notificationcreated = '%"notificationfollow":"1"%';
              $notificationFriendCreated = '%"notificationfollow":"2"%';
              $db = Zend_Db_Table_Abstract::getDefaultAdapter();
              if( $resource->getType() != 'user' ) {
                Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($resource->getOwner(), $viewer, $resource, 'follow_album');
              } else {
                Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($resource->getOwner(), $viewer, $resource, 'follow_album_owner');
              }
              $friendId = Engine_Api::_()->user()->getViewer()->membership()->getMembershipsOfIds();
            }
          }
        }

        $this->view->follow_id = $follow_id;

        $follow_msg = $this->view->translate('Successfully Followd.');
      }
    } else {
      if( !empty($resource) ) {
        $followTable->removeFollow($resource, $viewer);

        if( $viewer_id != $resource->getOwner()->getIdentity() ) {

          if( $resource_type == 'sitepage_page' || $resource_type == 'sitebusiness_business' || $resource_type == 'sitegroup_group' || $resource_type == 'sitestore_store' ) {
            Engine_Api::_()->getDbtable('notifications', 'activity')->delete(array('object_type = ?' => "$resource_type", 'object_id = ?' => $resource_id, 'subject_id = ?' => $resource_id, 'subject_type = ?' => "$resource_type", 'user_id = ?' => $viewer_id));
            foreach( $manageAdminsIds as $value ) {
              $user_subject = Engine_Api::_()->user()->getUser($value['user_id']);
              //DELETE NOTIFICATION
              $notification = Engine_Api::_()->getDbtable('notifications', 'activity')->getNotificationByObjectAndType($user_subject, $resource, 'follow_' . $resource_type);
              if( $notification ) {
                $notification->delete();
              }
            }
          } elseif( $resource_type == 'sitereview_wishlist' ) {
            //DELETE NOTIFICATION
            $notification = Engine_Api::_()->getDbtable('notifications', 'activity')->getNotificationByObjectAndType($resource->getOwner(), $resource, 'follow_' . $resource_type);
            if( $notification ) {
              $notification->delete();
            }
          }

          //DELETE ACTIVITY FEED
          $action_id = Engine_Api::_()->getDbtable('actions', 'activity')
            ->select()
            ->from('engine4_activity_actions', 'action_id')
            ->where('type = ?', "follow_$resource_type")
            ->where('subject_id = ?', $viewer_id)
            ->where('subject_type = ?', 'user')
            ->where('object_type = ?', $resource_type)
            ->where('object_id = ?', $resource->getIdentity())
            ->query()
            ->fetchColumn();

          if( !empty($action_id) ) {
            $activity = Engine_Api::_()->getItem('activity_action', $action_id);
            if( !empty($activity) ) {
              $activity->delete();
            }
          }
        }
      }
      $follow_msg = $this->view->translate('Successfully Unfollowd.');
    }

    if( empty($status) ) {
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => true,
        'parentRefresh' => true,
        'messages' => array($follow_msg))
      );
    }

    //HERE THE CONTENT TYPE MEANS MODULE NAME
    $follow_count = Engine_Api::_()->getDbtable('follows', 'sitemusic')->numberOfFollow($resource_type, $resource_id);
    $followers = $this->view->translate(array('%s follower', '%s followers', $follow_count), $this->view->locale()->toNumber($follow_count));

    $this->view->follow_count = "<a href='javascript:void(0);' onclick='showSmoothBox(); return false;' >" . $followers . "</a>";
  }

  public function favouriteAction()
  {

    //GET THE VIEWER.
    $viewer = Engine_Api::_()->user()->getViewer();

    //GET THE VALUE OF RESOURCE ID AND RESOURCE TYPE AND FAVOURITE ID.
    $this->view->resource_id = $resource_id = $this->_getParam('resource_id');
    $this->view->resource_type = $resource_type = $this->_getParam('resource_type');
    $favourite_id = $this->_getParam('favourite_id');
    $status = $this->_getParam('smoothbox', 1);
    $this->view->status = true;
    //GET THE FAVOURITE BUTTON SETTINGS.
    $this->view->favourite_setting_button = Engine_Api::_()->getApi('settings', 'core')->getSetting('favourite.setting.button');

    //GET THE CURRENT UESRID AND SETTINGS.
    $this->view->viewer_id = $loggedin_user_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if( (empty($loggedin_user_id) ) ) {
      return;
    }
    //CHECK THE FAVOURITE ID.
    if( empty($favourite_id) ) {

      //CHECKING IF USER HAS MAKING DUPLICATE ENTRY OF FAVOURITING AN APPLICATION.
      $favourite_id_temp = Engine_Api::_()->getApi('favourite', 'sitemusic')->hasFavourite($resource_type, $resource_id);
      //CHECK THE THE ITEM IS FAVOURITED OR NOT.
      if( empty($favourite_id_temp[0]['favourite_id']) ) {

        $favouriteTable = Engine_Api::_()->getItemTable('sitemusic_favourite');
        $notify_table = Engine_Api::_()->getDbtable('notifications', 'activity');
        $db = $favouriteTable->getAdapter();
        $db->beginTransaction();
        try {
//            //ADD FAVOURITE
          $favourite_id = $favouriteTable->addFavourite($resource, $viewer)->favourite_id;
          //PASS THE FAVOURITE ID VALUE.
          $this->view->favourite_id = $favourite_id;
          $db->commit();
        } catch( Exception $e ) {
          $db->rollBack();
          throw $e;
        }
        $favourite_msg = Zend_Registry::get('Zend_Translate')->_('Successfully Favourited.');
      } else {
        $this->view->favourite_id = $favourite_id_temp[0]['favourite_id'];
      }
    } else {

      //START DELETE NOTIFICATION
      Engine_Api::_()->getDbtable('notifications', 'activity')->delete(array('type = ?' => 'favourited', 'subject_id = ?' => $viewer->getIdentity(), 'subject_type = ?' => $viewer->getType(), 'object_type = ?' => $resource_type, 'object_id = ?' => $resource_id));
      //END DELETE NOTIFICATION
      ////START UNFAVOURITE WORK.
      //HERE 'PAGE OR LIST PLUGIN' CHECK WHEN UNFAVOURITE
      if( !empty($resource) && isset($resource->favourite_count) ) {
        $resource->favourite_count--;
        $resource->save();
      }
      $contentTable = Engine_Api::_()->getDbTable('favourites', 'sitemusic')->delete(array('favourite_id =?' => $favourite_id));
      //END UNFAVOURITE WORK.
      $favourite_msg = Zend_Registry::get('Zend_Translate')->_('Successfully Unfavourited.');
    }
    if( empty($status) ) {
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => true,
        'parentRefresh' => true,
        'messages' => array($favourite_msg)
        )
      );
    }
    //HERE THE CONTENT TYPE MEANS MODULE NAME
    $num_of_contenttype = Engine_Api::_()->getApi('favourite', 'sitemusic')->favouriteCount($resource_type, $resource_id);
    $favourites_number = $this->view->translate(array('%s favourite', '%s favourites', $num_of_contenttype), $this->view->locale()->toNumber($num_of_contenttype));
    $this->view->num_of_favourite = "<a href='javascript:void(0);' onclick='showSmoothBox(); return false;' >" . $favourites_number . "</a>";
  }

  public function rateAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $user_id = $viewer->getIdentity();
    $resourceType = 'sitemusic_artist';
    $rating = $this->_getParam('rating');
    $item_id = $this->_getParam('item_id');

    $table = Engine_Api::_()->getDbtable('ratings', 'sitemusic');
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      Engine_Api::_()->sitemusic()->setRating($item_id, $user_id, $rating, $resourceType);

      $artist = Engine_Api::_()->getItem('sitemusic_artist', $item_id);
      $artist->rating_count = $result = Engine_Api::_()->sitemusic()->getRating($artist->getIdentity(), $resourceType);
      $artist->save();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $total = Engine_Api::_()->sitemusic()->ratingCount($artist->getIdentity(), $resourceType);

    $data = array();
    $data[] = array(
      'total' => $total,
      'rating' => $rating,
    );
    return $this->_helper->json($data);
  }

  public function getArtistOfTheDayAction()
  {
    $data = array();
    $artistTable = Engine_Api::_()->getDbtable('artists', 'sitemusic');
    $select = $artistTable->select()
        ->where('title  LIKE ? ', '%' . $this->_getParam('text') . '%')
        ->where('approved = ?', 1)
        ->order('title ASC')->limit('10');
    $artists = $artistTable->fetchAll($select);

    foreach( $artists as $artist ) {
      $artistPhoto = $this->view->itemPhoto($artist, 'thumb.icon');
      $data[] = array(
        'id' => $artist->artist_id,
        'label' => $artist->title,
        'photo' => $artistPhoto
      );
    }
    return $this->_helper->json($data);
  }

  public function editArtistInfoAction()
  {
    $artistIdParam = $this->_getParam('artist_ids');
//    $artistIds = json_decode($artistIdParam);
    $artistIds = explode(' ', $artistIdParam);
    $viewer = Engine_Api::_()->user()->getViewer();

    $artistTable = Engine_Api::_()->getItemTable('sitemusic_artist');
    if( isset($artistIds) ) {
      $select = $artistTable->select();
      $select->where('artist_id IN(?)', $artistIds);
      $this->view->paginator = $paginator = Zend_Paginator::factory($select);
    }
//    $this->view->paginator = $paginator = $artistTable->getPaginator(array(
//      'artist_id' => $artistIds));

    $this->view->form = $form = new Sitemusic_Form_ArtistInfo();
    foreach( $paginator as $pObj ) {
      $artistId = $pObj['artist_id'];
      $subForm = new Sitemusic_Form_EditArtistInfo(array('elementsBelongTo' => $pObj->getGuid()));
      $artist = Engine_Api::_()->getItem('sitemusic_artist', $artistId);
//      $loop = 0;
//      foreach( $playlist->tags()->getTagMaps() as $tagMap ) {
//        $tag = $tagMap->getTag();
//        if( !isset($tag->text) ) {
//          continue;
//        }
//        if( !empty($tagStr) ) {
//          $tagStr .= ', ';
//        }
//        $tagStr .= $tag->text;
//      }
//      $tag = array('tags' => $tagStr);
//      $artistInfo = array();
//      $artistInfo = $songArtistTable->getArtist($songId);
//
//      if( !empty($artistInfo) && isset($artistInfo) ) {
//        foreach( $artistInfo as $artist ) {
//          $artistTitleInfo[] = $artist['title'];
//        }
//        $this->view->artistInfo = $artistTitleInfo;
//      } else {
//        $params = $playlist->params;
//        if( !empty($params) ) {
//          $params = Zend_Json::decode($params);
//          $artistInfo = explode(',', $params['artist']);
//          $this->view->artistInfo = $artistInfo;
//        }
//      }

      $subForm->populate($pObj->toArray());

//      if( !empty($tag) ) {
//        $info = array_merge($pObj->toArray(), $tag);
//        $subForm->populate($info);
//      } else {
//        $subForm->populate($pObj->toArray());
//      }
      $form->addSubForm($subForm, $pObj->getGuid());
    }

//    if( empty($songId) ) {
//      $name = Engine_Db_Table::getDefaultAdapter();
//      $query1 = $name->select()
//        ->from('engine4_music_playlist_songs')
//        ->where('playlist_id = ?', $playlistId)
//      ;
//      foreach( $query1->query()->fetchAll() as $q ) {
//        $songId[] = $q['song_id'];
//        $playlist = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
//        $song_value = $playlist->params;
//        $song_info = Zend_Json::decode($song_value);
//      }
//    } elseif( $noOfSongId == 1 ) {
//      $playlist = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
//      $song_value = $playlist->params;
//      $song_info = Zend_Json::decode($song_value);
//      $songId[] = $songId;
//    }

    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    try {
      foreach( $paginator as $pObj ) {
        $artistId = $pObj['artist_id'];
        $subForm = $form->getSubForm($pObj->getGuid());
        $values = $subForm->getValues();
        $values = $values[$pObj->getGuid()];
        $artist = Engine_Api::_()->getItem('sitemusic_artist', $artistId);
        $artist->title = $values['title'];
        $artist->description = $values['description'];
        $artist->user_id = $viewer->getIdentity();
        $artist->save();
      }
    } catch( Exception $e ) {
      throw $e;
    }

    return $this->_helper->redirector->gotoRoute(array('controller' => 'manage', 'action' => 'album'));
  }

  public function deleteAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    // In smoothbox
    $artistId = $this->_getParam('id');
    $artistTable = Engine_Api::_()->getDbtable('artists', 'sitemusic');
    $artistRow = $artistTable->find($artistId)->current();

    if( !$artistRow ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_("Entry doesn't exist or not authorized to delete");
      return;
    }

    $artistId = $artistRow->getIdentity();

    $this->view->form = $form = new Sitemusic_Form_Admin_Categories_Delete();

    if( !$this->getRequest()->isPost() ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
      return;
    }
    // Process
    $db = $artistTable->getAdapter();
    $db->beginTransaction();

    try {

      $artistRow->delete();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->view->status = true;
    $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your entry has been deleted.');
    return $this->_forward('success', 'utility', 'core', array(
        'parentRefresh' => 10,
        'messages' => Array($this->view->message)
    ));
  }

  public function editAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    // In smoothbox
    $artistId = $this->_getParam('id');
    //  $this->view->artist_id = $this->view->category_id = $id;
    $artistTable = Engine_Api::_()->getDbtable('artists', 'sitemusic');
    $artistRow = $artistTable->find($artistId)->current();
    $artist = Engine_Api::_()->getItem('sitemusic_artist', $artistId);
    if( !$artistRow ) {
      return $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('')
      ));
    } else {
      $artistId = $artistRow->getIdentity();
    }

    $form = $this->view->form = new Sitemusic_Form_Admin_Artistform();
    $form->setTitle('Edit Artist');
    $form->setAction($this->getFrontController()->getRouter()->assemble(array()));
    $form->setField($artistRow);

    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Process
    $values = $form->getValues();
    $viewer = Engine_Api::_()->user()->getViewer();
    $db = $artistTable->getAdapter();
    $db->beginTransaction();

    try {
      $artistRow->owner_id = $viewer->getIdentity();
      $artistRow->title = $values['label'];
      $artistRow->description = $values['description'];
      if( !empty($values['profilephoto']) ) {
        $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($artistRow, $form->profilephoto);
        $artistRow->photo_id = $photo->photo_id;
      }
      if( !empty($values['coverphoto']) ) {
        $coverPhoto = $artistRow->setCoverPhoto($form->coverphoto);
        $artistRow->cover_photo_id = $coverPhoto->cover_photo_id;
      }
      $artistRow->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('')
    ));
  }

  protected function _forwardCustom($action, $controller = null, $module = null, array $params = null)
  {
    // Parent
    $request = $this->getRequest();

    if( null !== $params ) {
      $request->setParams($params);
    }

    if( null !== $controller ) {
      $request->setControllerName($controller);

      // Module should only be reset if controller has been specified
      if( null !== $module ) {
        $request->setModuleName($module);
      }
    }

    $request->setActionName($action);
    if( Engine_API::_()->seaocore()->isSiteMobileModeEnabled() ) {
      $sr_response = Engine_Api::_()->sitemobile()->setupRequest($request);
    }
    $request->setDispatched(false);
  }

}
