<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: SongController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_ManageController extends Core_Controller_Action_Standard
{

  public function init()
  {
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
  }

  public function albumAction()
  {
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {

      return;
    }

    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_album");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function playlistAction()
  {
    // Check auth
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_userpl', null, 'view')->isValid() ) {
      return;
    }

    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_playlist");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function songAction()
  {
    // Check auth
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return;
    }
    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_song");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function songLyricsAction()
  {

    if( !$this->_helper->requireUser()->isValid() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You must be logged in.');
      return;
    }

    $itemId = $this->_getParam('item_id');
    $playlistSong = Engine_Api::_()->getItem('sitemusic_playlist_song', $itemId);
    $this->view->song = $playlistSong;
  }

  public function likedAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }


    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_liked");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function followingAction()
  {

    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_following");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function albumownerFollowingAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    $this->view->navigation = Engine_Api::_()
      ->getApi('menus', 'core')
      ->getNavigation('sitemusic_user_following', array());

    $this->view->viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = Engine_Api::_()->user()->getViewer()->getIdentity();
    $this->view->resource_type = 'user';
    $userTable = Engine_Api::_()->getDbTable('users', 'user');
    $uName = $userTable->info('name');
    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
    $fName = $followTable->info('name');
    $select = $userTable->select()
      ->from($uName);
    $select->joinLeft($fName, "$uName.user_id = $fName.resource_id", '');
    $select->where('poster_id = ?', $viewerId)
      ->where('resource_type = ?', 'user');
    $this->view->paginator = $paginator = Zend_Paginator::factory($select);
  }

  public function artistFollowingAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $this->view->navigation = Engine_Api::_()
      ->getApi('menus', 'core')
      ->getNavigation('sitemusic_user_following', array());

    $this->view->viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = Engine_Api::_()->user()->getViewer()->getIdentity();
    $this->view->resource_type = 'sitemusic_artist';
    $artistTable = Engine_Api::_()->getDbTable('artists', 'sitemusic');
    $aName = $artistTable->info('name');
    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
    $fName = $followTable->info('name');
    $select = $artistTable->select()
      ->from($aName);
    $select->join($fName, "$aName.artist_id = $fName.resource_id", '');
    $select->where('poster_id = ?', $viewerId)
      ->where('resource_type = ?', 'sitemusic_artist');
    $this->view->paginator = $paginator = Zend_Paginator::factory($select);
  }

  public function favouriteAction()
  {
    $enableFavourite = Engine_Api::_()->sitemusic()->enableFavourite();
    if( empty($enableFavourite) ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_favourite");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function ratedAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_manage_rated");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function historyAction()
  {
    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $this->_helper->content
      ->setNoRender()
      ->setEnabled();
  }

  public function artistAction()
  {
    $enableArtist = Engine_Api::_()->sitemusic()->isArtistEnabled();
    if( empty($enableArtist) ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $this->_helper->content
      ->setNoRender()
      ->setEnabled();
  }

  protected function _forwardCustom($action, $controller = null, $module = null, array $params = null)
  {
    // Parent
    $request = $this->getRequest();

    if( null !== $params ) {
      $request->setParams($params);
    }

    if( null !== $controller ) {
      $request->setControllerName($controller);

      // Module should only be reset if controller has been specified
      if( null !== $module ) {
        $request->setModuleName($module);
      }
    }

    $request->setActionName($action);
    if( Engine_API::_()->seaocore()->isSiteMobileModeEnabled() ) {
      $sr_response = Engine_Api::_()->sitemobile()->setupRequest($request);
    }
    $request->setDispatched(false);
  }

}
