<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: SongController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_SongsController extends Core_Controller_Action_Standard
{

  public function init()
  {
// Get viewer info
    $this->view->viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
// Get subject
    if( !Engine_Api::_()->core()->hasSubject() && null !== ($songId = $this->_getParam('song_id')) &&
      null !== ($song = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId)) &&
      $song instanceof Sitemusic_Model_PlaylistSong ) {
      Engine_Api::_()->core()->setSubject($song);
    }
  }

  public function indexAction()
  {
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return;
    }
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_songs_index");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function deleteAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    // Check method
    if( !$this->getRequest()->isPost() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('Invalid request method');
      return;
    }

    // Check auth
    if( !Engine_Api::_()->authorization()->isAllowed('sitemusic_pl', null, 'edit') ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('Not allowed to edit this album');
      return;
    }

    $songId = $this->_getParam('song_id');
    $playlistId = $this->_getParam('playlist_id');
    $changeUrl = $this->_getParam('changeUrl');
    $pItem = Engine_Api::_()->getItem('sitemusic_pl', $playlistId);
    if( empty($pItem) ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('Not a valid album song');
    }
    $psItem = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);

    if( empty($psItem) ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('Not a valid song');
    }
    try {
      if( $psItem->file_id ) {
        $psItem->delete();
        $psItem->deleteUnused();
      }
      // delete song mapping from song-artist table
      Engine_Api::_()->getItemTable('sitemusic_songartist')->delete(array('song_id = ?' => $songId));

      $songCount = $pItem->song_count;
      if( $songCount ) {
        $pItem->song_count = --$songCount;
        $pItem->save();
      }
    } catch( Exception $e ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('Unknown database error');
      throw $e;
    }
    $this->view->success = true;
    if( $changeUrl ) {
      return $this->_forward('success', 'utility', 'core', array(
          'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'manage', 'action' => 'album'), 'sitemusic_general', true),
          'messages' => Array('Your song has been successfully deleted.')
      ));
    } else {
      return $this->_forward('success', 'utility', 'core', array(
          'parentRefresh' => 10,
          'messages' => array('Your song has been successfully deleted')
      ));
    }
  }

  public function uploadAction()
  {
// only members can upload sitemusic
    if( !$this->_helper->requireUser()->checkRequire() ) {
      $this->view->status = false;
      $this->view->error = $this->view->translate('You do not have permission to upload Music.');
      return;
    }

// Check method
    if( !$this->getRequest()->isPost() ) {
      $this->view->status = false;
      $this->view->error = $this->view->translate('Invalid request method');
      return;
    }

// Check file
    //CHECK FILE
    $values = $this->getRequest()->getPost();
    $response = Sitemusic_Service_FancyUpload::upload();
    if( !empty($response['error']) ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
      return;
    }

    if( empty($response['path']) || empty(file_exists($response['path'])) ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('No file');
      return;
    }

// Process
    $db = Engine_Api::_()->getDbtable('playlists', 'sitemusic')->getAdapter();
    $db->beginTransaction();

    try {
      $song = Engine_Api::_()->getApi('core', 'sitemusic')->createSong($response['path']);
      $this->view->status = true;
      $this->view->song = $song;
      $this->view->song_id = $song->getIdentity();
      $this->view->song_url = $song->getHref();
      $db->commit();
    } catch( Sitemusic_Model_Exception $e ) {
      $db->rollback();

      $this->view->status = false;
      $this->view->message = $this->view->translate($e->getMessage());
    } catch( Exception $e ) {
      return $this->exceptionWrapper($e, null, $db);
    }
    @unlink($response['path']);
  }

  public function viewAction()
  {
// Check permission
    $viewer = Engine_Api::_()->user()->getViewer();
    $song = Engine_Api::_()->getItem('sitemusic_playlist_song', $this->_getParam('item_id'));

    if( Engine_Api::_()->core()->hasSubject() ) {
      Engine_Api::_()->core()->clearSubject();
    }
    if( !empty($song) ) {
      Engine_Api::_()->core()->setSubject($song);
    }

    if( empty($song) ) {
      return $this->_helper->requireSubject->forward();
    }

    if( !$song->isDisplayable() ) {
      return $this->_helper->requireSubject->forward();
    }

    if( !$this->_helper->requireSubject()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', $viewer, 'view')->isValid() ) {
      return;
    }
    if( !$song || !$song->getIdentity() ) {
      return $this->_helper->requireSubject->forward();
    }

    if( $song->genre_id ) {
      $genreId = $song->genre_id;
      $songCategory = Engine_Api::_()->getItem('sitemusic_songcategory', $genreId);
      if( $songCategory ) {
        //CHECK AND SET META KEYWORDS
        Engine_Api::_()->sitemusic()->checkMetaKeywords($songCategory);
      }
    }

    $this->view->song = $song;
    $this->view->owner = $owner = $song->getOwner();
    $this->view->viewer = $viewer;
    $this->view->viewer_id = $viewer->getIdentity();
    $this->view->rating_count = Engine_Api::_()->sitemusic()->ratingCount($song->getIdentity(), $song->getType());
    $this->view->rated = Engine_Api::_()->sitemusic()->checkRated($song->getIdentity(), $viewer->getIdentity(), $song->getType());

// Get tags
    $this->view->songTags = $song->tags()->getTagMaps();
// Render
    $this->_helper->content
//->setNoRender()
      ->setEnabled()
    ;
  }

  public function editinfoAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $this->_helper->content
      // ->setNoRender()
      ->setEnabled()
    ;

    $viewer = Engine_Api::_()->user()->getViewer();

    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', $viewer, 'edit')->isValid() ) {
      return;
    }
    // check if viewer are superadmin,admin or moderator
    $isAdmin = false;
    if( in_array($viewer->level_id, array(1, 2, 3)) ) {
      $isAdmin = true;
    }
    $itemTilte = $this->_getParam('artist_id');
    $toObject = null;

    $this->view->playlist_id = $playlistId = $this->_getParam('item_id');
    $albumId = $this->_getParam('album_id');
    if( !empty($albumId) ) {
      $this->view->playlist_id = $playlistId = $albumId;
    }
    $this->view->playlist = $album = Engine_Api::_()->getItem('sitemusic_pl', $playlistId);

    $songId = $this->_getParam('song_id');

    if( is_string($songId) ) {
      $songId = explode(',', $songId);
    }

    if( Engine_Api::_()->core()->hasSubject() ) {
      Engine_Api::_()->core()->clearSubject();
    }

    if( !empty($album) ) {
      Engine_Api::_()->core()->setSubject($album);
    }

    if( !$this->_helper->requireAuth()->setAuthParams($album, null, 'view')->isValid() ) {
      return;
    }

    // for redirecting artist info page
    $artistIdParams = $this->_getParam('artist_ids');
    if( $artistIdParams ) {
      $this->view->artistIdParams = $artistIdParams;
      $this->view->isRedirectArtist = $isRedirectArtist = true;
    }
    $redirect = $this->_getParam('redirect');
    if( !empty($redirect) ) {
      $str = $this->_getParam('str');
      $route = '/admin/sitemusic/manage/manage-song' . $str;
    }

    $this->view->sitemusic = $sitemusic = Engine_Api::_()->core()->getSubject();
    $songArtistTable = Engine_Api::_()->getItemTable('sitemusic_songartist');
    $songTable = Engine_Api::_()->getItemTable('sitemusic_playlist_song');
    $this->view->paginator = $paginator = $songTable->getPaginator(array(
      'sitemusic_pl' => $sitemusic,
      'song_id' => $songId,
      'playlist_id' => $playlistId,
      'notCheckApprove' => 1,
      'is_admin' => $isAdmin ? $isAdmin : ''));

    $this->view->form = $form = new Sitemusic_Form_Info();


    $paginator->setItemCountPerPage(500);
    foreach( $paginator as $pObj ) {
      $songId = $pObj['song_id'];
      $subForm = new Sitemusic_Form_Editinfo(array('elementsBelongTo' => $pObj->getGuid(), 'song_id' => $songId));
      $playlist = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
      $loop = 0;
      $tagStr = '';
      foreach( $playlist->tags()->getTagMaps() as $tagMap ) {
        $tag = $tagMap->getTag();
        if( !isset($tag->text) ) {
          continue;
        }
        if( !empty($tagStr) ) {
          $tagStr .= ', ';
        }
        $tagStr .= $tag->text;
      }
      $tag = array('tags' => $tagStr);
      $artistInfo = array();
      $artistInfo = $songArtistTable->getArtist($songId);

      $artistTitleString = $playlist->getArtistNameString();
      if( !empty($artistTitleString) ) {

        $artistPopulate = array('item_title' => $artistTitleString);
        $populateInfo = array_merge($artistPopulate, $tag);
      }
      if( !empty($populateInfo) ) {
        $info = array_merge($pObj->toArray(), $populateInfo);

        $subForm->populate($info);
      } else {
        $subForm->populate($pObj->toArray());
      }
      $form->addSubForm($subForm, $pObj->getGuid());
    }

    if( empty($songId) ) {
      $name = Engine_Db_Table::getDefaultAdapter();
      $query1 = $name->select()
        ->from('engine4_sitemusic_playlist_songs')
        ->where('playlist_id = ?', $playlistId)
      ;
      foreach( $query1->query()->fetchAll() as $q ) {
        $songId[] = $q['song_id'];
        $playlist = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
        $song_value = $playlist->params;
        $song_info = Zend_Json::decode($song_value);
      }
    }

    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $i = 0;
    $newArtistIdsParam = array();
    try {
      foreach( $paginator as $pObj ) {
        $songId = $pObj['song_id'];
        $subForm = $form->getSubForm($pObj->getGuid());
        $values = $subForm->getValues();
        $values = $values[$pObj->getGuid()];
        $artistName = $values['item_title'];
        $artistName = trim($artistName, ", ");
        if( !empty($artistName) ) {
          $delimeterExist = strpos($artistName, ',');

          if( $delimeterExist ) {
            $artistNameArray = array();
            $artistNameArray = explode(',', $artistName);
          } else {
            $artistNameArray[] = $artistName;
          }
          $newArtistId = $songArtistTable->checkArtistMapping($artistNameArray, $songId, $playlistId);
          $newArtistIdsParam = array_merge($newArtistIdsParam, $newArtistId);
          unset($artistNameArray);
          $artistName = '';
        } else {
          $songArtistTable->delete(array('song_id = ?' => $songId));
        }

        // UNSET META inforamtion after getting inforamtion by user
        if( isset($values['genre_id']) && isset($song_info['genre']) && $values['genre_id'] != 0 ) {
          unset($song_info['genre']);
        }
        if( isset($values['artist']) && isset($song_info['artist']) ) {
          unset($song_info['artist']);
        }
        // end unset meta info

        $playlist = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);

        // check meta info exist or not
        if( isset($song_info['artist']) || isset($song_info['genre']) ) {
          $metaInfo = Zend_Json::encode($song_info);
          $playlist->params = $metaInfo;
        } else {
          $playlist->params = '';
        }

        $playlist->title = $values['title'];
        $playlist->genre_id = $values['genre_id'];
        $playlist->lyrics = $values['lyrics'];

// Add tags
        $tags = preg_split('/[,]+/', $values['tags']);
        $playlist->tags()->addTagMaps($viewer, $tags);
        $playlist->save();
        $i++;
      }
    } catch( Exception $e ) {
      throw $e;
    }
    if( !empty($redirect) && $redirect == 'admin' ) {
      $this->_helper->redirector->gotoUrl($route);
    } elseif( !empty($newArtistIdsParam) && isset($newArtistIdsParam) ) {
      //   $newArtistIdString = json_encode($newArtistIdsParam);
      $newArtistIdString = implode(' ', $newArtistIdsParam);
      return $this->_helper->redirector->gotoRoute(array('controller' => 'songs', 'action' => 'editinfo', 'item_id' => $playlistId, 'artist_ids' => $newArtistIdString), 'sitemusic_general', true);
    } elseif( $this->_getParam('song_id') ) {
      $this->_helper->redirector->gotoRoute(array('controller' => 'songs', 'action' => 'editinfo', 'song_id' => $songId, 'item_id' => $playlistId), 'sitemusic_general', true);
    } else {
      $this->_helper->redirector->gotoRoute(array('controller' => 'songs', 'action' => 'editinfo', 'item_id' => $playlistId), 'sitemusic_item_specific', true);
    }
  }

  public function rateAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $user_id = $viewer->getIdentity();
    $resourceType = 'sitemusic_playlist_song';
    $rating = $this->_getParam('rating');
    $item_id = $this->_getParam('item_id');
    $table = Engine_Api::_()->getDbtable('ratings', 'sitemusic');
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      Engine_Api::_()->sitemusic()->setRating($item_id, $user_id, $rating, $resourceType);

      $song = Engine_Api::_()->getItem('sitemusic_playlist_song', $item_id);
      $song->rating_count = $result = Engine_Api::_()->sitemusic()->getRating($song->getIdentity(), $resourceType);
      $song->save();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $total = Engine_Api::_()->sitemusic()->ratingCount($song->getIdentity(), $resourceType);

    $data = array();
    $data[] = array(
      'total' => $total,
      'rating' => $rating,
    );
    return $this->_helper->json($data);
  }

  public function homeAction()
  {
//    $song = array("ajaxTabs" => array('Trending', 'Latest', 'Most_Liked', 'Most_Popular'),
//    "showOptions" => array(
//        "artist_favourite" => "Artist Favourite",
//        "artist_rating" => "Artist Rating",
//        "song_count" => "Song Count",
//        "like_count" => "Like Count",
//        "label" => "label",
//      ));
//    $s = json_encode($song);
//    print_r($s);
//    die;
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_songs_home");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function getSongOfTheDayAction()
  {
    $data = array();
    $playlistSongTable = Engine_Api::_()->getDbtable('playlistSongs', 'sitemusic');
    $select = $playlistSongTable->select()
        ->where('title  LIKE ? ', '%' . $this->_getParam('text') . '%')
        ->where('approved = ?', 1)
        ->order('title ASC')->limit('10');
    $songs = $playlistSongTable->fetchAll($select);

    foreach( $songs as $song ) {
      $songPhoto = $this->view->itemPhoto($song, 'thumb.normal');
      $data[] = array(
        'id' => $song->song_id,
        'label' => $song->title,
        'photo' => $songPhoto
      );
    }
    return $this->_helper->json($data);
  }

  public function songInfoAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    if( !$this->_helper->requireUser()->isValid() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You must be logged in.');
      return;
    }

    $this->view->enableStatsCountOnZero = Engine_Api::_()->sitemusic()->enableStatsCountOnZero();
    $itemId = $this->_getParam('item_id');
    $playlistSong = Engine_Api::_()->getItem('sitemusic_playlist_song', $itemId);
    $this->view->song = $playlistSong;
    if( $playlistSong->genre_id ) {
      $songCategory = Engine_Api::_()->getItem('sitemusic_songcategory', $playlistSong->genre_id);
      if( $songCategory ) {
        $this->view->category_name = $songCategory->category_name;
      }
    }
  }

  public function composeSongAction()
  {
    // Check user
    if( !$this->_helper->requireUser()->isValid() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You must be logged in.');
      return;
    }
    // Check auth
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'create')->checkRequire() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You are not allowed to upload songs.');
      return;
    }
    // Prepare
    $viewer = Engine_Api::_()->user()->getViewer();
    $playlistTable = Engine_Api::_()->getDbTable('playlists', 'sitemusic');

    // Get special playlist
    if( 0 >= ($playlist_id = $this->_getParam('playlist_id')) &&
      false != ($type = $this->_getParam('type')) ) {
      $playlist = $playlistTable->getSpecialPlaylist($viewer, $type);
      Engine_Api::_()->core()->setSubject($playlist);
    }
    // Check subject
    if( !$this->_helper->requireSubject('sitemusic_pl')->checkRequire() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('Invalid playlist');
      return;
    }

    $response = Seaocore_Service_FancyUpload::upload();
    if( !empty($response['error']) ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
      return;
    }

    if( empty($response['path']) || empty(file_exists($response['path'])) ) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('No file');
      return;
    }

    // Process
    $db = Engine_Api::_()->getDbtable('playlists', 'sitemusic')->getAdapter();
    $db->beginTransaction();

    try {

      // Create song
      $file = Engine_Api::_()->getApi('core', 'sitemusic')->createSong($response['path']);
      if( !$file ) {
        throw new Music_Model_Exception('Song was not successfully attached');
      }

      $songApprove = 1;
      // Add song
      $song = $playlist->addSong($file, $songApprove);
      if( !$song ) {
        throw new Music_Model_Exception('Song was not successfully attached');
      }

      $this->view->songInfo = $songInfo = Engine_Api::_()->getApi('core', 'sitemusic')->songInfoForPlayer($song);
      $this->view->status = true;
      $this->view->song = $song;
      $this->view->song_title = $song->getTitle();
      $this->view->song_url = $songUrl;
      $this->view->song_id = $song->getIdentity();

      $db->commit();
    } catch( Sitemusic_Model_Exception $e ) {
      $db->rollback();
      echo $e->getMessage();
      die;
      $this->view->status = false;
      $this->view->message = $this->view->translate($e->getMessage());
      return;
    } catch( Exception $e ) {
      echo $e->getMessage();
      die;
      $this->exceptionWrapper($e, null, $db);
      $this->view->status = false;
    }
  }

  public function rejectAction()
  {

    if( !$this->_helper->requireUser()->isValid() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You must be logged in.');
      return;
    }
    $this->view->form = $form = new Sitemusic_Form_Reject();

    $songId = $this->_getParam('song_id');
    $playlistSong = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
    if( empty($playlistSong) ) {
      return;
    } else {
      $playlistSong->delete();
    }
    $this->_redirect('sitemusic/manage/song');
  }

  public function approvedAction()
  {
    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    $id = $this->_getParam('id');
    $approve = $this->_getParam('approve');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();
    try {
      $psItem = Engine_Api::_()->getItem('sitemusic_playlist_song', $id);
      $psItem->approved = $approve;
      $psItem->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    $this->_redirect('sitemusic/manage/song');
  }

  public function editLyricsAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    // only members can manage music
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    // Check auth
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'edit')->checkRequire() ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('You are not allowed to edit lyrics.');
      return;
    }

    $songId = $this->_getParam('item_id');
    if( empty($songId) ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate('please try again.');
      return;
    }

    $this->view->form = $form = new Sitemusic_Form_EditLyrics();
    $psItem = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
    $form->populate($psItem->toArray());
    // Check post
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    $values = $form->getValues();

    try {
      $psItem->lyrics = $values['lyrics'];
      $psItem->save();

      $this->view->success = true;
      $this->view->message = $this->view->translate('You are succesfully edit this lyrics.');
    } catch( Exception $e ) {
      throw $e;
    }
//    return $this->_forward('success', 'utility', 'core', array(
//        'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'songs', 'action' => 'view', 'item_id' => $songId), 'sitemusic_item_view', true),
//        'messages' => Array($this->view->message)
//    ));
    $this->_helper->redirector->gotoRoute(array('controller' => 'songs', 'action' => 'view', 'item_id' => $songId), 'sitemusic_item_view', true);
  }

  function increaseDownloadCountAction()
  {
    $songId = $this->_getParam('songId');
    if( empty($songId) ) {
      return;
    }
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();
    try {
      $psItem = Engine_Api::_()->getItem('sitemusic_playlist_song', $songId);
      if( $psItem ) {
        $psItem->download_count = ++$psItem->download_count;
        $psItem->save();
        $db->commit();
      }
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
  }

  protected function _forwardCustom($action, $controller = null, $module = null, array $params = null)
  {
    // Parent
    $request = $this->getRequest();

    if( null !== $params ) {
      $request->setParams($params);
    }

    if( null !== $controller ) {
      $request->setControllerName($controller);

      // Module should only be reset if controller has been specified
      if( null !== $module ) {
        $request->setModuleName($module);
      }
    }

    $request->setActionName($action);
    if( Engine_API::_()->seaocore()->isSiteMobileModeEnabled() ) {
      $sr_response = Engine_Api::_()->sitemobile()->setupRequest($request);
    }
    $request->setDispatched(false);
  }

}
