<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Level.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Form_Admin_Settings_Level_Level extends Authorization_Form_Admin_Level_Abstract {

    public function init() {
        parent::init();

        // My stuff
        $this
                ->setTitle('Member Level Settings')
                ->setDescription("These settings are applied on a per member level basis. Start by selecting the member level you want to modify, then adjust the settings for that level below.");

        // Element: view
        $this->addElement('Radio', 'view', array(
            'label' => 'Allow Viewing of News?',
            'description' => 'Do you want to let members view news? If set to no, some other settings on this page may not apply.',
            'multiOptions' => array(
                2 => 'Yes, allow viewing of all news, even private ones.',
                1 => 'Yes, allow viewing of News.',
                0 => 'No, do not allow news to be viewed.',
            ),
            'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
        if (!$this->isModerator()) {
            unset($this->view->options[2]);
        }

        if (!$this->isPublic()) {

            // Element: create
            $this->addElement('Radio', 'create', array(
                'label' => 'Allow Creation of News?',
                'description' => 'Do you want to let members create news? If set to no, some other settings on this page may not apply. This is useful if you want members to be able to view news, but only want certain levels to be able to create News.',
                'multiOptions' => array(
                    1 => 'Yes, allow creation of News.',
                    0 => 'No, do not allow news to be created.'
                ),
                'value' => 1,
            ));

            // Element: edit
            $this->addElement('Radio', 'edit', array(
                'label' => 'Allow Editing of News?',
                'description' => 'Do you want to let members edit their News? If set to no, some other settings on this page may not apply.',
                'multiOptions' => array(
                    2 => 'Yes, allow members to edit all News.',
                    1 => 'Yes, allow members to edit their own News.',
                    0 => 'No, do not allow members to edit their News.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if (!$this->isModerator()) {
                unset($this->edit->options[2]);
            }

            // Element: delete
            $this->addElement('Radio', 'delete', array(
                'label' => 'Allow Deletion of News?',
                'description' => 'Do you want to let members delete their news? If set to no, some other settings on this page may not apply.',
                'multiOptions' => array(
                    2 => 'Yes, allow members to delete all News.',
                    1 => 'Yes, allow members to delete their own News.',
                    0 => 'No, do not allow members to delete their News.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if (!$this->isModerator()) {
                unset($this->delete->options[2]);
            }

            // Element: comment
            $this->addElement('Radio', 'comment', array(
                'label' => 'Allow Commenting on News?',
                'description' => 'Do you want to let members of this level comment on news?',
                'multiOptions' => array(
                    2 => 'Yes, allow members to comment on all news, including private ones.',
                    1 => 'Yes, allow members to comment on News.',
                    0 => 'No, do not allow members to comment on News.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if (!$this->isModerator()) {
                unset($this->comment->options[2]);
            }

            // Element: auth_view
            $this->addElement('MultiCheckbox', 'auth_view', array(
                'label' => 'News View Options',
                'description' => 'Your members can choose from any of the options checked below when they decide who can see their news entries. These options appear on your members\' "Add News" and "Edit News" pages. If you do not check any options, settings will default to the last saved configuration. If you select only one option, members of this level will not have a choice.',
                'multiOptions' => array(
                    'everyone' => 'Everyone',
                    'registered' => 'All Registered Members',
                    'owner_network' => 'Friends and Networks',
                    'owner_member_member' => 'Friends of Friends',
                    'owner_member' => 'Friends Only',
                    'owner' => 'Just Me'
                ),
                'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
            ));

            // Element: auth_comment
            $this->addElement('MultiCheckbox', 'auth_comment', array(
                'label' => 'News Comment Options',
                'description' => 'Your members can choose from any of the options checked below when they decide who can post comments on their News. If you do not check any options, settings will default to the last saved configuration. If you select only one option, members of this level will not have a choice.',
                'multiOptions' => array(
                    'everyone' => 'Everyone',
                    'registered' => 'All Registered Members',
                    'owner_network' => 'Friends and Networks',
                    'owner_member_member' => 'Friends of Friends',
                    'owner_member' => 'Friends Only',
                    'owner' => 'Just Me'
                ),
                'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
            ));

            // Element: auth_html
            $this->addElement('Text', 'auth_html', array(
                'label' => 'HTML in News Entries?',
                'description' => 'If you want to allow specific HTML tags, you can enter them below (separated by commas). (Example: b, img, a, embed, font.)',
                'value' => 'strong, b, em, i, u, strike, sub, sup, p, div, pre, address, h1, h2, h3, h4, h5, h6, span, ol, li, ul, a, img, embed, br, hr'
            ));

            // Element: max
            $this->addElement('Text', 'max_allowed', array(
                'label' => 'Maximum Allowed News Entries?',
                'description' => 'Enter the maximum number of allowed news entries. The field must contain an integer between 1 and 999, or 0 for unlimited.',
                'validators' => array(
                    array('Int', true),
                    new Engine_Validate_AtLeast(0),
                ),
                'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.max.allowed.news', 0),
            ));

        }

        if(!$this->isModerator() && !$this->isPublic()) {

            $this->addElement('Radio', 'news_approval', array(
                'label' => 'Admin Approval for Adding News?',
                'description' => 'If you enable this feature, your members can not publish the news unless you approve them.',
                'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No',
                ),
                'value' => 0,
            ));
        }
    }

}
