<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Rss.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Form_Admin_Settings_Level_Rss extends Authorization_Form_Admin_Level_Abstract {

    public function init() {
        parent::init();

        // My stuff
        $this
                ->setTitle('Member Level Settings')
                ->setDescription("These settings are applied on a per member level basis. Start by selecting the member level you want to modify, then adjust the settings for that level below.");

        
        $rssEnabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 0);
        if(!$rssEnabled){
            $this->addError('Enable RSS from “Global Settings → RSS Settings” to modify RSS settings on a per member level basis.');
            $this->removeElement('level_id');
            $this->removeElement('submit');
            return;
        }
        // Element: view
        $this->addElement('Radio', 'view', array(
            'label' => 'Allow Viewing of RSS?',
            'description' => 'Do you want to let members view RSS? If set to no, some other settings on this page may not apply.',
            'multiOptions' => array(
                2 => 'Yes, allow members to view all RSS, even private ones.',
                1 => 'Yes, allow viewing of RSS.',
                0 => 'No, do not allow RSS to be viewed.'
            ),
            'value' => ( $this->isModerator() ? 2 : 1 ),
        ));

        if (!$this->isModerator()) {
            unset($this->view->options[2]);
        }

        if (!$this->isPublic()) {

            // Element: create
            $this->addElement('Radio', 'create', array(
                'label' => 'Allow Creation of RSS?',
                'description' => 'Do you want to let members create RSS? If set to no, some other settings on this page may not apply. This is useful if you want members to be able to view RSS, but only want certain levels to be able to create RSS.',
                'multiOptions' => array(
                    1 => 'Yes, allow creation of RSS.',
                    0 => 'No, do not allow RSS to be created.'
                ),
                'value' => 1,
            ));

            // Element: edit
            $this->addElement('Radio', 'edit', array(
                'label' => 'Allow Editing RSS Feeds?',
                'description' => 'Admin Approval for Adding RSS Feeds?',
                'multiOptions' => array(
                    1 => 'Yes, allow editing of RSS.',
                    0 => 'No, do not allow RSS to be edited.'
                ),
                'value' => 1,
            ));

            // Element: delete
            $this->addElement('Radio', 'delete', array(
                'label' => 'Allow Deletion of RSS?',
                'description' => 'Do you want to let members delete their RSS ?',
                'multiOptions' => array(
                    2 => 'Yes, allow members to delete all RSS.',
                    1 => 'Yes, allow members to delete their own RSS.',
                    0 => 'No, do not allow members to delete their RSS.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if (!$this->isModerator()) {
                unset($this->delete->options[2]);
            }

            // Element: max
            $this->addElement('Text', 'max_allowed', array(
                'label' => 'Maximum Allowed RSS Entries?',
                'description' => 'Enter the maximum number of allowed RSS entries. The field must contain an integer between 1 and 999, or 0 for unlimited.',
                'validators' => array(
                    array('Int', true),
                    new Engine_Validate_AtLeast(0),
                ),
                'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.max.allowed.rss', 0),
            ));

            $this->addElement('Radio', 'rss_approval', array(
                'label' => 'Do you want Admin approval for RSS creation?',
                'description' => 'If you enable this feature, your members can not publish their RSS unless you approve them.',
                'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No',
                ),
                'value' => 0,
            ));
        }
    }

}
