<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Rss.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Form_Rss extends Engine_Form {

    public $_error = array();

    public function init() {

        $this->setTitle('Add RSS')
                ->setDescription('Add a new RSS below by filling the below information, then click "Save".')
                ->setAttrib('name', 'sitenews_rss')
                ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()));
        $user = Engine_Api::_()->user()->getViewer();

        // init to
        $this->addElement('Text', 'rss_url', array(
            'label' => 'RSS URL',
            'allowEmpty' => 'false',
            'required' => 'true',
            'autocomplete' => 'off',
            'oninput' => 'validateUrl()',
            'filters' => array(
                'StripTags',
                new Engine_Filter_Censor(),
            ),
            'autofocus' => 'autofocus',
        ));

        $this->addElement('dummy', 'rss_url_msg', array('value' => 0));

        $this->addElement('Text', 'title', array(
            'label' => 'RSS Title',
            'maxlength' => '100',
            'onkeyup' => 'setHiddenRSSTitle();',
            'allowEmpty' => false,
            'required' => true,
            'filters' => array(
                new Engine_Filter_Censor(),
                'StripTags',
                new Engine_Filter_StringLength(array('max' => '100'))
            ),
        ));

        $this->addElement('Textarea', 'description', array(
            'label' => 'RSS Description',
            'onkeyup' => 'setHiddenRSSDescription();',
        ));


        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.category.enabled', 1)) {
            // prepare categories
            $categories = Engine_Api::_()->getDbtable('categories', 'sitenews')->getCategories(array('fetchColumns' => array('category_id', 'category_name'), 'sponsored' => 0, 'cat_depandancy' => 1, 'orderBy' => 'category_name'));
            if (count($categories) != 0) {
                $categories_prepared[""] = "";
                foreach ($categories as $category) {
                    $categories_prepared[$category->category_id] = $category->category_name;
                }
            }

            if (Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
                $onChangeEvent = "subcategories(this.value, '', '');";
                $categoryFiles = 'application/modules/Sitenews/views/scripts/_formNewsSubcategory.tpl';
            } else {
                $onChangeEvent = "showSMFields(this.value, 1);sm4.core.category.set(this.value, 'subcategory');";
                $categoryFiles = 'application/modules/Sitenews/views/sitemobile/scripts/_subCategory.tpl';
            }

            $this->addElement('Select', 'category_id', array(
                'label' => 'Category',
                'allowEmpty' => false,
                'required' => true,
                'multiOptions' => $categories_prepared,
                'onchange' => $onChangeEvent,
            ));

            $this->addElement('Select', 'subcategory_id', array(
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
                'decorators' => array(array('ViewScript', array('viewScript' => $categoryFiles, 'class' => 'form element')))
            ));

            $this->addElement('Select', 'subsubcategory_id', array(
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
            ));

            $this->addDisplayGroup(array(
                'subcategory_id',
                'subsubcategory_id',
                    ), 'Select', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => $categoryFiles,
                            'class' => 'form element')))
            ));
        }

        if (Engine_Api::_()->authorization()->isAllowed('album', $user, 'create')) {
            $upload_url = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'upload-photo'), 'sitenews_general', true);
        }

        // keyword(tags)
        // if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rsstags.enabled', 1)) {
        //     $this->addElement('Text', 'tags', array(
        //         'label' => 'Tags (Keywords)',
        //         'autocomplete' => 'off',
        //         'description' => 'Separate tags with commas.',
        //         'filters' => array(
        //             new Engine_Filter_Censor(),
        //         ),
        //     ));
        //     $this->tags->getDecorator("Description")->setOption("placement", "append");
        // }

        $this->addElement('File', 'photo', array(
            'label' => 'RSS Logo',
            'autocomplete' => 'on',
            'filters' => array(
                new Engine_Filter_Censor(),
            ),
        ));
        $this->photo->addValidator('Extension', false, 'jpg,png,gif,jpeg,JPG,PNG,GIF,JPEG');


        $this->addElement('Select', 'draft', array(
            'label' => 'Status',
            'multiOptions' => array("0" => "Published", "1" => "Saved As Draft"),
            'onChange' => 'checkStatus()',
            'description' => 'If this RSS is published, it cannot be switched back to draft mode.'
        ));
        $this->draft->getDecorator('Description')->setOption('placement', 'append');

        $date = new Engine_Form_Element_CalendarDateTime('publish_date');
        $date->setLabel("Publishing Date");
        $date->setDescription('If you are publishing the RSS just now, you do not need to enter date-time.');
        $date->setAllowEmpty(true);
        $this->addElement($date);
        $this->publish_date->getDecorator('Description')->setOption('placement', 'append');

        $availableLabels = array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
        );

        $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitenews_news', $user, 'auth_view');
        $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));

        if (!empty($viewOptions) && count($viewOptions) >= 1) {
            // Make a hidden field
            if (count($viewOptions) == 1) {
                $this->addElement('hidden', 'auth_view', array( 'order' => 600,'value' => key($viewOptions)));
                // Make select box
            } else {
                $this->addElement('Select', 'auth_view', array(
                    'label' => 'Privacy',
                    'description' => 'Who may see news of this RSS?',
                    'multiOptions' => $viewOptions,
                    'value' => key($viewOptions),
                ));
                $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
            }
        }

        // Element: auth_comment
        $commentOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitenews_news', $user, 'auth_comment');
        $commentOptions = array_intersect_key($availableLabels, array_flip($commentOptions));

        if (!empty($commentOptions) && count($commentOptions) >= 1) {
            // Make a hidden field
            if (count($commentOptions) == 1) {
                $this->addElement('hidden', 'auth_comment', array( 'order' => 601,'value' => key($commentOptions)));
                // Make select box
            } else {
                $this->addElement('Select', 'auth_comment', array(
                    'label' => 'Comment Privacy',
                    'description' => 'Who may post comments on news of this RSS?',
                    'multiOptions' => $commentOptions,
                    'value' => key($commentOptions),
                ));
                $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
            }
        }
        $this->addElement('Hash', 'token', array(
            'timeout' => 3600,
        ));

        $this->addElement('Hidden', 'rsstitle', array(
            'order' => 604,
        ));

        $this->addElement('Hidden', 'rssdescription', array(
            'order' => 605,
        ));

        // Element: submit
        $this->addElement('Button', 'submit', array(
            'label' => 'Save',
            'type' => 'submit',
        ));
    }

    public function saveValues() {
        $values = $this->getValues();
        $params = Array();
        if ((empty($values['owner_type'])) || (empty($values['owner_id']))) {
            $params['owner_id'] = Engine_Api::_()->user()->getViewer()->user_id;
            $params['owner_type'] = 'user';
        } else {
            $params['owner_id'] = $values['owner_id'];
            $params['owner_type'] = $values['owner_type'];
            throw new Zend_Exception("Non-user channel owners not yet implemented");
        }
        $owner = Engine_Api::_()->getItem('user', $params['owner_id']);
        $params['title'] = $values['title'];
        $params['description'] = $values['description'];
        $params['category_id'] = (int) @$values['category_id'];
        $params['subcategory_id'] = (int) @$values['subcategory_id'];
        $params['subsubcategory_id'] = (int) @$values['subsubcategory_id'];
        $params['publish_date'] = $values['publish_date'];
        $permission = Engine_Api::_()->getDbtable('permissions', 'authorization');
        $value = $permission->select()
                ->from($permission->info('name'), 'value')
                ->where('type = ?', 'sitenews_rss')
                ->where('name = ?', 'rss_approval')
                ->where('level_id = ?', $owner->level_id)
                ->query()
                ->fetchColumn();
        date_default_timezone_get($owner->timezone);
        if ($value == 1 || isset($params['publish_date']) && $params['publish_date'] > date('Y-m-d h-i a')) {
            $params['published'] = 0;
        }
        $params['rss_url'] = $values['rss_url'];
        $params['auth_view'] = $values['auth_view'];
        $params['auth_comment'] = $values['auth_comment'];
        $rss = Engine_Api::_()->getDbtable('rss', 'sitenews')->createRow();
        $rss->setFromArray($params);
        try {
            $rss->save();
        } catch (Exception $ex) {
            die(" exception " . $ex);
        }

        // CREATE AUTH STUFF HERE
        $auth = Engine_Api::_()->authorization()->context;
        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

        if (empty($values['auth_view'])) {
            $values['auth_view'] = 'everyone';
        }
        if (empty($values['auth_comment'])) {
            $values['auth_comment'] = 'owner_member';
        }
        $viewMax = array_search($values['auth_view'], $roles);
        $commentMax = array_search($values['auth_comment'], $roles);
        foreach ($roles as $i => $role) {
            $auth->setAllowed($rss, $role, 'view', ($i <= $viewMax));
            $auth->setAllowed($rss, $role, 'comment', ($i <= $commentMax));
        }
        return $rss;
    }

}
