<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Category.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Model_Category extends Core_Model_Item_Abstract {

    protected $_searchTriggers = false;

    public function getTitle() {
        return $this->category_name;
    }

    public function getUsedCount() {
        $sitenewsTable = Engine_Api::_()->getItemTable('sitenews_news');
        return $sitenewsTable->select()
                        ->from($sitenewsTable, new Zend_Db_Expr('COUNT(news_id)'))
                        ->where('category_id = ?', $this->category_id)
                        ->query()
                        ->fetchColumn();
    }

    public function getTable() {
        if (is_null($this->_table)) {
            $this->_table = Engine_Api::_()->getDbtable('categories', 'sitenews');
        }
        return $this->_table;
    }

    public function isOwner($owner) {
        if ($owner instanceof Core_Model_Item_Abstract) {
            return ( $this->getIdentity() == $owner->getIdentity() && $this->getType() == $owner->getType() );
        } else if (is_array($owner) && count($owner) === 2) {
            return ( $this->getIdentity() == $owner[1] && $this->getType() == $owner[0] );
        } else if (is_numeric($owner)) {
            return ( $owner == $this->getIdentity() );
        }

        return false;
    }

    public function getCategorySlug() {

        if (!empty($this->category_slug)) {
            $slug = $this->category_slug;
        } else {
            $slug = Engine_Api::_()->seaocore()->getSlug($this->category_name, 225);
        }

        return $slug;
    }

    public function getOwner($recurseType = null) {
        return $this;
    }

    public function setPhoto($news) {

        if ($news instanceof Zend_Form_Element_File) {
            $file = $news->getFileName();
        } else if (is_array($news) && !empty($news['tmp_name'])) {
            $file = $news['tmp_name'];
        } else if (is_string($news) && file_exists($news)) {
            $file = $news;
        } else {
            return;
        }

        if (empty($file))
            return;

        //GET NEWS DETAILS
        $name = basename($file);
        $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
        $mainName = $path . '/' . $name;

        //GET VIEWER ID
       
        $news_params = array(
            'parent_file_id' => $this->category_id,
            //'type' => 'thumb.icon',
            'parent_type' => "sitenews_category",
        );

        //RESIZE IMAGE WORK
        $image = Engine_Image::factory();
        $image->open($file);
        $image->open($file)
                ->resample(0, 0, $image->width, $image->height, $image->width, $image->height)
                ->write($mainName)
                ->destroy();

        try {
            $newsFile = Engine_Api::_()->storage()->create($mainName, $news_params);
        } catch (Exception $e) {
            if ($e->getCode() == Storage_Api_Storage::SPACE_LIMIT_REACHED_CODE) {
                echo $e->getMessage();
                exit();
            }
        }

        return $newsFile;
    }

    public function getHref($params = array()) {

        if ($this->subcat_dependency) {
            $type = 'subsubcategory';
            $params['subsubcategory_id'] = $this->category_id;
            $params['subsubcategoryname'] = $this->getCategorySlug();
            $cat = $this->getTable()->getCategory($this->cat_dependency);
            $params['subcategory_id'] = $cat->category_id;
            $params['subcategoryname'] = $cat->getCategorySlug();
            $cat = $this->getTable()->getCategory($cat->cat_dependency);
            $params['category_id'] = $cat->category_id;
            $params['categoryname'] = $cat->getCategorySlug();
        } else if ($this->cat_dependency) {
            $type = 'subcategory';
            $params['subcategory_id'] = $this->category_id;
            $params['subcategoryname'] = $this->getCategorySlug();
            $cat = $this->getTable()->getCategory($this->cat_dependency);
            $params['category_id'] = $cat->category_id;
            $params['categoryname'] = $cat->getCategorySlug();
        } else {
            $type = 'category';
            $params['category_id'] = $this->category_id;
            $params['categoryname'] = $this->getCategorySlug();
        }

        $route = "sitenews_news_general_" . $type;
        if ($type == 'category' && Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
            $route = Engine_Api::_()->sitenews()->getCategoryHomeRoute();
        } 

        $params = array_merge(array(
            'route' => $route,
            'reset' => true,
                ), $params);
        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        return Zend_Controller_Front::getInstance()->getRouter()
                        ->assemble($params, $route, $reset);

        $params = array_merge(array(
            'route' => "sitenews_news_general_" . $type,
            'reset' => true,
                ), $params);
        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        return Zend_Controller_Front::getInstance()->getRouter()
                        ->assemble($params, $route, $reset);
    }

}
