<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Categories.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Model_DbTable_Categories extends Engine_Db_Table {

    protected $_name = 'sitenews_categories';
    protected $_rowClass = 'Sitenews_Model_Category';
    protected $_categories = array();

    /**
     * Return categories
     *
     * @param array $category_ids
     * @return all categories
     */
    public function getCategories($params = array()) {

        //MAKE QUERY
        $select = $this->select();

        //GET CATEGORY TABLE NAME
        $categoryTableName = $this->info('name');

        if (isset($params['orderBy']) && $params['orderBy'] == 'category_name') {
            $select->order('category_name');
        } else {
            $select->order('cat_order');
        }

        if (isset($params['cat_depandancy']) && !empty($params['cat_depandancy'])) {
            $select->where('cat_dependency = ?', 0);
        }

        if (isset($params['sponsored']) && !empty($params['sponsored'])) {
            $select->where('sponsored = ?', 1);
        }

        if (isset($params['fetchColumns']) && !empty($params['fetchColumns'])) {
            $select->setIntegrityCheck(false)->from($categoryTableName, $params['fetchColumns']);
        } else {
            $select->setIntegrityCheck(false)->from($categoryTableName);
        }

        if (isset($params['havingNews']) && $params['havingNews']) {
            $tableNews = Engine_Api::_()->getDbTable('news', 'sitenews');
            $tableNewsName = $tableNews->info('name');
            $select->join($tableNewsName, "$tableNewsName.category_id = $categoryTableName.category_id", null);
            $select->group('category_id');
        }

        if (isset($params['category_id']) && !empty($params['category_id'])) {
            $select->where('category_id in (?)', $params['category_id']);
        }
        if (isset($params['limit']) && !empty($params['limit'])) {
            $select->limit($params['limit']);
        }

        //RETURN DATA
        return $this->fetchAll($select);
    }

    public function getCategoriesPaginator(array $params) {
        return Zend_Paginator::factory($this->getCategories($params));
    }

    /**
     * Return subcaregories
     *
     * @param int category_id
     * @return all sub categories
     */
    public function getSubCategories($params = array()) {

        $categoryTableName = $this->info('name');

        //RETURN IF CATEGORY ID IS EMPTY
        if (empty($params['category_id'])) {
            return;
        }

        //MAKE QUERY
        $select = $this->select()
                ->from($categoryTableName, $params['fetchColumns'])
                ->where('cat_dependency = ?', $params['category_id'])
                ->order('cat_order');

        if (isset($params['havingNews']) && $params['havingNews']) {
            $tableNews = Engine_Api::_()->getDbTable('news', 'sitenews');
            $tableNewsName = $tableNews->info('name');
            $select->join($tableNewsName, "$tableNewsName.subcategory_id = $categoryTableName.category_id", null)
                    ->where($tableNewsName . '.category_id = ?', $params['category_id'])
                    ->group($categoryTableName . '.category_id');
        }

        //RETURN RESULTS
        return $this->fetchAll($select);
    }

    public function getCategoryName($category_id) {

        //RETURN IF CATEGORY ID IS EMPTY
        if (empty($category_id)) {
            return;
        }

        //MAKE QUERY
        $categoryName = $this->select()
                ->from($this->info('name'), array('category_name'))
                ->where('category_id = ?', $category_id)
                ->query()
                ->fetchColumn();
        //RETURN RESULTS
        return $categoryName;
    }

    public function getCategoriesHavingNoChield($arrayLevels = array(), $showAllCategories = 0) {

        $categoryTableName = $this->info('name');
        $select = $this->select()
                ->from($categoryTableName, array('category_id', 'category_name', 'cat_dependency', 'subcat_dependency'))
                ->order('cat_order');

        if (!$showAllCategories) {
            $tableNews = Engine_Api::_()->getDbtable('news', 'sitenews');
            $tableNewsName = $tableNews->info('name');
            $select = $this->select()->setIntegrityCheck(false)->from($categoryTableName);
        }

        $addedNewsJoin = 0;
        if (!empty($arrayLevels) && Count($arrayLevels) < 3) {

            if (!in_array('category', $arrayLevels) && in_array('subcategory', $arrayLevels) && in_array('subusbcategory', $arrayLevels)) {

                if (!$showAllCategories) {
                    $select->join($tableNewsName, "$tableNewsName.subcategory_id=$categoryTableName.category_id OR $tableNewsName.subsubcategory_id=$categoryTableName.category_id", null);
                    $addedNewsJoin = 1;
                }

                $select->where("cat_dependency != 0 OR subcat_dependency != 0");
            } elseif (in_array('category', $arrayLevels) && !in_array('subcategory', $arrayLevels) && in_array('subusbcategory', $arrayLevels)) {

                if (!$showAllCategories) {
                    $select->join($tableNewsName, "$tableNewsName.category_id=$categoryTableName.category_id OR $tableNewsName.subsubcategory_id=$categoryTableName.category_id", null);
                    $addedNewsJoin = 1;
                }

                $select->where("(cat_dependency = 0 AND subcat_dependency = 0) OR (cat_dependency != 0 AND subcat_dependency != 0)");
            } elseif (in_array('category', $arrayLevels) && in_array('subcategory', $arrayLevels) && !in_array('subusbcategory', $arrayLevels)) {

                if (!$showAllCategories) {
                    $select->join($tableNewsName, "$tableNewsName.category_id=$categoryTableName.category_id OR $tableNewsName.subcategory_id=$categoryTableName.category_id", null);
                    $addedNewsJoin = 1;
                }

                $select->where("(cat_dependency = 0 AND subcat_dependency = 0) OR (cat_dependency != 0 AND subcat_dependency = 0)");
            } elseif (!in_array('category', $arrayLevels) && !in_array('subcategory', $arrayLevels) && in_array('subusbcategory', $arrayLevels)) {

                if (!$showAllCategories) {
                    $select->join($tableNewsName, "$tableNewsName.subsubcategory_id=$categoryTableName.category_id", null);
                    $addedNewsJoin = 1;
                }

                $select->where("cat_dependency != 0 AND subcat_dependency != 0");
            } elseif (in_array('category', $arrayLevels) && !in_array('subcategory', $arrayLevels) && !in_array('subusbcategory', $arrayLevels)) {

                if (!$showAllCategories) {
                    $select->join($tableNewsName, "$tableNewsName.category_id=$categoryTableName.category_id", null);
                    $addedNewsJoin = 1;
                }

                $select->where("cat_dependency = 0 AND subcat_dependency = 0");
            } elseif (!in_array('category', $arrayLevels) && in_array('subcategory', $arrayLevels) && !in_array('subusbcategory', $arrayLevels)) {

                if (!$showAllCategories) {
                    $select->join($tableNewsName, "$tableNewsName.subcategory_id=$categoryTableName.category_id", null);
                    $addedNewsJoin = 1;
                }

                $select->where("cat_dependency != 0 AND subcat_dependency = 0");
            }
        }

        if (!$addedNewsJoin && !$showAllCategories) {
            $select->join($tableNewsName, "$tableNewsName.category_id=$categoryTableName.category_id", null);
        }

        $select->order('cat_order');
        //RETURN DATA
        return $this->fetchAll($select);
    }

    /**
     * Get category object
     * @param int $category_id : category id
     * @return category object
     */
    public function getCategory($category_id) {
        if (empty($category_id))
            return;
        if (!array_key_exists($category_id, $this->_categories)) {
            $this->_categories[$category_id] = $this->find($category_id)->current();
        }
        return $this->_categories[$category_id];
    }

    /**
     * Return slug
     *
     * @param int $categoryname
     * @return categoryname
     */
    public function getCategorySlug($categoryname) {
        $slug = $categoryname;
        return Engine_Api::_()->seaocore()->getSlug($slug, 225);
    }

    public function getCatDependancyArray() {

        return $this->select()
                        ->from($this->info('name'), 'cat_dependency')
                        ->where('cat_dependency <>?', 0)
                        ->group('cat_dependency')
                        ->query()
                        ->fetchAll(Zend_Db::FETCH_COLUMN);
    }

    public function getSubCatDependancyArray() {

        return $this->select()->from($this->info('name'), 'subcat_dependency')->where('subcat_dependency <>?', 0)->group('subcat_dependency')->query()->fetchAll(Zend_Db::FETCH_COLUMN);
    }

    public function setDefaultImages($toPath, $fromPath, $columnName) {
        @mkdir(APPLICATION_PATH . $toPath, 0777);
        $dir = APPLICATION_PATH . $fromPath;
        $public_dir = APPLICATION_PATH . $toPath;
        $fieArr = array();
        if (is_dir($dir) && is_dir($public_dir)) {
            $files = scandir($dir);
            foreach ($files as $file) {
                if (strstr($file, '.png') || strstr($file, '.jpg') || strstr($file, '.gif')) {
                    $fieArr[] = $file;
                    @copy(APPLICATION_PATH . "$fromPath/$file", APPLICATION_PATH . "$toPath/$file");
                }
            }
            @chmod(APPLICATION_PATH . $toPath, 0777);
        }
        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), array('category_id', 'category_name', $columnName));
        $categories = $this->fetchAll($select);
        //UPLOAD DEFAULT ICONS
        foreach ($categories as $category) {
             
            Engine_Api::_()->sitenews()->categoriesPageCreate(array(0=>$category->category_id));
            
            $categoryName = Engine_Api::_()->seaocore()->getSlug($category->category_name, 225);
            $iconName = false;
            foreach ($fieArr as $f) {
                if (strstr($f, $categoryName)) {
                    $iconName = $f;
                    break;
                }
            }
            if ($iconName == false) {
                continue;
            }
            @chmod(APPLICATION_PATH . $toPath, 0777);
            $file = array();
            if ($columnName == 'photo_id' && !empty($category->photo_id)) {
                continue;
            } else if ($columnName == 'file_id' && !empty($category->file_id)) {
                continue;
            } else if ($columnName == 'banner_id' && !empty($category->banner_id)) {
                continue;
            }

            $file['tmp_name'] = APPLICATION_PATH . "$toPath/$iconName";
            $file['name'] = $iconName;
            if (file_exists($file['tmp_name'])) {
                $name = basename($file['tmp_name']);
                $path = dirname($file['tmp_name']);
                $mainName = $path . '/' . $file['name'];
                @chmod($mainName, 0777);
                $photo_params = array(
                    'parent_id' => $category->category_id,
                    'parent_type' => "sitenews_category",
                );

                //RESIZE IMAGE WORK
                $image = Engine_Image::factory();
                $image->open($file['tmp_name']);
                $image->open($file['tmp_name']);
                $image->resample(0, 0, $image->width, $image->height, $image->width, $image->height)
                        ->write($mainName)
                        ->destroy();

                $photoFile = Engine_Api::_()->storage()->create($mainName, $photo_params);
                //UPDATE FILE ID IN CATEGORY TABLE
                if (!empty($photoFile->file_id)) {
                    if ($columnName == 'photo_id') {
                        $category->photo_id = $photoFile->file_id;
                    } else if ($columnName == 'file_id') {
                        $category->file_id = $photoFile->file_id;
                    } else {
                        $category->banner_id = $photoFile->file_id;
                    }
                    $category->save();
                }
            }
        }

        //REMOVE THE CREATED PUBLIC DIRECTORY
        if (is_dir(APPLICATION_PATH . $toPath)) {
            $files = scandir(APPLICATION_PATH . $toPath);
            foreach ($files as $file) {
                $is_exist = file_exists(APPLICATION_PATH . "$toPath/$file");
                if ($is_exist) {
                    @unlink(APPLICATION_PATH . "$toPath/$file");
                }
            }
            @rmdir(APPLICATION_PATH . $toPath);
        }
    }

    public function uploadDefaultImages() {
        @ini_set('memory_limit', '-1');
        $iconImagesToPath = "/temporary/news_categorie_icons";
        $iconImagesfromPath = "/application/modules/Sitenews/externals/images/category_images/icons";

        $mainImagesToPath = "/temporary/news_categorie_main_images";
        $mainImagesfromPath = "/application/modules/Sitenews/externals/images/category_images/main_images";

        $bannerImagesToPath = "/temporary/news_categorie_banner_images";
        $bannerImagesfromPath = "/application/modules/Sitenews/externals/images/category_images/banner_images";

        $this->setDefaultImages($iconImagesToPath, $iconImagesfromPath, 'file_id');
        $this->setDefaultImages($mainImagesToPath, $mainImagesfromPath, 'photo_id');
        $this->setDefaultImages($bannerImagesToPath, $bannerImagesfromPath, 'banner_id');
        $this->setSposoredCategories();
    }

    public function setSposoredCategories() {
        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), array('category_id'))->where('category_id in(?)', array(2, 3, 5, 7, 11, 15));
        $categories = $this->fetchAll($select);
        //UPLOAD DEFAULT ICONS
        foreach ($categories as $category) {
            $categoryMain = Engine_Api::_()->getItem('sitenews_category', $category['category_id']);
            $categoryMain->sponsored = 1;
            $categoryMain->save();
        }
    }

    public function getCategoriesAssoc() {
        $stmt = $this->select()
                ->from($this, array('category_id', 'category_name'))
                ->order('category_name ASC')
                ->query();

        $data = array();
        foreach ($stmt->fetchAll() as $category) {
            $data[$category['category_id']] = $category['category_name'];
        }

        return $data;
    }

    public function getUserCategoriesAssoc($user) {
        if ($user instanceof User_Model_User) {
            $user = $user->getIdentity();
        } else if (!is_numeric($user)) {
            return array();
        }

        $stmt = $this->getAdapter()
                ->select()
                ->from('engine4_sitenews_categories', array('category_id', 'category_name'))
                ->joinLeft('engine4_sitenews_news', "engine4_sitenews_news.category_id = engine4_sitenews_categories.category_id")
                ->group("engine4_sitenews_categories.category_id")
                ->where('engine4_sitenews_news.owner_id = ?', $user)
                ->where('engine4_sitenews_news.draft = ?', "0")
                ->order('category_name ASC')
                ->query();

        $data = array();
        foreach ($stmt->fetchAll() as $category) {
            $data[$category['category_id']] = $category['category_name'];
        }

        return $data;
    }

    /**
     * Return categories
     *
     * @param array $category_ids
     * @return all categories
     */
    public function getNewsCategories($params = array()) {

        //MAKE QUERY
        $select = $this->select();

        //GET CATEGORY TABLE NAME
        $categoryTableName = $this->info('name');

        if (isset($params['orderBy']) && $params['orderBy'] == 'category_name') {
            $select->order('category_name');
        } else {
            $select->order('cat_order');
        }

        if (isset($params['cat_depandancy']) && strlen($params['cat_depandancy']) > 0) {
            $select->where('cat_dependency = ?', 0);
        }

        if (isset($params['sponsored']) && !empty($params['sponsored'])) {
            $select->where('sponsored = ?', 1);
        }

        if (isset($params['fetchColumns']) && !empty($params['fetchColumns'])) {
            $select->setIntegrityCheck(false)->from($categoryTableName, $params['fetchColumns']);
        } else {
            $select->setIntegrityCheck(false)->from($categoryTableName);
        }

        if (isset($params['havingNews']) && $params['havingNews']) {
            $tableNews = Engine_Api::_()->getDbTable('news', 'sitenews');
            $tableNewsName = $tableNews->info('name');
            $select->join($tableNewsName, "$tableNewsName.category_id = $categoryTableName.category_id", null);
            $select->group('category_id');
        }
        if (isset($params['category_id']) && !empty($params['category_id'])) {
            $select->where("$categoryTableName.category_id in (?)", $params['category_id']);
        }
        if (isset($params['limit']) && !empty($params['limit'])) {
            $select->limit($params['limit']);
        }
        //RETURN DATA

        return $this->fetchAll($select);
    }

}
