<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: News.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
//include_once APPLICATION_PATH . '/application/modules/Sitenews/Api/WebParser.php';

class Sitenews_Model_DbTable_News extends Engine_Db_Table {

    protected $_name = 'sitenews_news';
    protected $_rowClass = "Sitenews_Model_News";
    protected $_serializedColumns = array('networks_privacy');

    public function saveTemporaryImage($img_url, $store_dir = 'image', $store_dir_type = 'relative', $overwrite = false, $pref = false, $debug = false) {
        
        //first get the base name of the image
        $i_name = explode('.', basename($img_url));
        $type = strtolower(trim($i_name[1]));
        $i_name = $i_name[0];
     
        //now try to guess the image type from the given url
        //it should end with a valid extension...
        //good for security too
        // $type = exif_imagetype($img_url);

        if($type == 'png') {
            
            $img_type = 'png';
        }else if($type == 'jpg' || $type == 'jpeg') {
            
            $img_type = $type;
        }else if($type == 'gif') {
            
            $img_type = 'gif';
        }else {
            
            if(true == $debug && $type == false){
                echo 'Invalid image URL';
            }elseif(true == $debug && $type){
                echo 'Invalid image type';
            }
            return ''; //possible error on the image URL
        }
     
        $dir_name = (($store_dir_type == 'relative')? './' : '') . rtrim($store_dir, '/') . '/';
     
        //create the directory if not present
        if(!file_exists($dir_name))
            mkdir($dir_name, 0777, true);
     
        //calculate the destination image path
        $i_dest = $dir_name . $i_name . (($pref === false)? '' : '_' . $pref) . '.' . $img_type;
     
        //lets see if the path exists already
        if(file_exists($i_dest)) {
            $pref = (int) $pref;
     
            //modify the file name, do not overwrite
            if(false == $overwrite)
                return $this->saveTemporaryImage($img_url, $store_dir, $store_dir_type, $overwrite, ++$pref, $debug);
            //delete & overwrite
            else
                unlink ($i_dest);
        }
     
        //first check if the image is fetchable
        $img_info = @getimagesize($img_url);
     
        //is it a valid image?
        if(false == $img_info || !isset($img_info[2]) || !($img_info[2] == IMAGETYPE_JPEG || $img_info[2] == IMAGETYPE_PNG || $img_info[2] == IMAGETYPE_JPEG2000 || $img_info[2] == IMAGETYPE_GIF)) {
            if(true == $debug)
                echo 'The image doesn\'t seem to exist in the remote server';
            return ''; //return empty string
        }
     
        //now try to create the image
        if($img_type == 'jpg') {
            $m_img = @imagecreatefromjpeg($img_url);
        } else if($img_type == 'png') {
            $m_img = @imagecreatefrompng($img_url);
            @imagealphablending($m_img, false);
            @imagesavealpha($m_img, true);
        } else if($img_type == 'gif') {
            $m_img = @imagecreatefromgif($img_url);
        } else {
            $m_img = FALSE;
        }
     
        //was the attempt successful?
        if(FALSE === $m_img) {
            if(true == $debug)
                echo 'Can not create image from the URL';
            return '';
        }
     
        //now attempt to save the file on local server
        if($img_type == 'jpg') {
            if(imagejpeg($m_img, $i_dest, 100))
                return $i_dest;
            else
                return '';
        } else if($img_type == 'png') {
            if(imagepng($m_img, $i_dest, 0))
                return $i_dest;
            else
                return '';
        } else if($img_type == 'gif') {
            if(imagegif($m_img, $i_dest))
                return $i_dest;
            else
                return '';
        }
     
        return '';
    }

    /**
     * Gets a select object for the user's news
     *
     * @param Core_Model_Item_Abstract $user The user to get the messages for
     * @return Zend_Db_Table_Select
     */
    public function getNewsSelect($params = array()) {
        $table = Engine_Api::_()->getDbtable('news', 'sitenews');
        $rName = $table->info('name');
        $newsCategory = Engine_Api::_()->getDbtable('categories', 'sitenews');
        $newsCategoryName = $newsCategory->info('name');

        //Time interval
        $sqlTimeStr = '';
        $interval = '';
        if (isset($params['interval']) && !empty($params['interval'])) {
            $interval = $params['interval'];
            $current_time = date("Y-m-d H:i:s");
            if ($interval == 'week') {
                $time_duration = date('Y-m-d H:i:s', strtotime('-7 days'));
                $sqlTimeStr = ".publish_date BETWEEN " . "'" . $time_duration . "'" . " AND " . "'" . $current_time . "'";
            } elseif ($interval == 'month') {
                $time_duration = date('Y-m-d H:i:s', strtotime('-1 months'));
                $sqlTimeStr = ".publish_date BETWEEN " . "'" . $time_duration . "'" . " AND " . "'" . $current_time . "'" . "";
            }
        }


        $locationTable = Engine_Api::_()->getDbtable('locations', 'sitenews');
        $select = $this->select()->from($rName, '*');
        $locationTableName = $locationTable->info('name');

        $ownerTableName = $rName;
        $select->setIntegrityCheck(false);

        if (isset($params['news_city']) && !empty($params['news_city']) && strstr(',', $params['news_city'])) {
            $news_city = explode(',', $params['news_city']);
            $params['news_city'] = $news_city[0];
        }
        if (isset($params['news_street']) && !empty($params['news_street']) || isset($params['news_city']) && !empty($params['news_city']) || isset($params['news_state']) && !empty($params['news_state']) || isset($params['news_country']) && !empty($params['news_country'])) {
            $select->join($locationTableName, "$rName.news_id = $locationTableName.news_id   ", null);
        }
        if (isset($params['news_street']) && !empty($params['news_street'])) {
            $select->where($locationTableName . '.address   LIKE ? ', '%' . $params['news_street'] . '%');
        } if (isset($params['news_city']) && !empty($params['news_city'])) {
            $select->where($locationTableName . '.city = ?', $params['news_city']);
        } if (isset($params['news_state']) && !empty($params['news_state'])) {
            $select->where($locationTableName . '.state = ?', $params['news_state']);
        } if (isset($params['news_country']) && !empty($params['news_country'])) {
            $select->where($locationTableName . '.country = ?', $params['news_country']);
        }

        if (!isset($params['location']) && isset($params['locationSearch']) && !empty($params['locationSearch'])) {
            $params['location'] = $params['locationSearch'];

            if (isset($params['locationmilesSearch'])) {
                $params['locationmiles'] = $params['locationmilesSearch'];
            }
        }

        $addGroupBy = 1;
        if (!isset($params['location']) && (isset($params['detactLocation']) && $params['detactLocation'] && isset($params['latitude']) && $params['latitude'] && isset($params['longitude']) && $params['longitude'] && isset($params['defaultLocationDistance']) && $params['defaultLocationDistance'])) {
            $locationsTable = Engine_Api::_()->getDbtable('locations', 'sitenews');
            $locationTableName = $locationsTable->info('name');
            $radius = $params['defaultLocationDistance']; //in miles
            $latitude = $params['latitude'];
            $longitude = $params['longitude'];
            $flage = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.proximity.search.kilometer', 0);
            if (!empty($flage)) {
                $radius = $radius * (0.621371192);
            }
            //$latitudeRadians = deg2rad($latitude);
            $latitudeSin = "sin(radians($latitude))";
            $latitudeCos = "cos(radians($latitude))";

            $select->join($locationTableName, "$rName.news_id = $locationTableName.news_id", array("(degrees(acos($latitudeSin * sin(radians($locationTableName.latitude)) + $latitudeCos * cos(radians($locationTableName.latitude)) * cos(radians($longitude - $locationTableName.longitude)))) * 69.172) AS distance", $locationTableName . '.location AS locationName'));
            $sqlstring = "(degrees(acos($latitudeSin * sin(radians($locationTableName.latitude)) + $latitudeCos * cos(radians($locationTableName.latitude)) * cos(radians($longitude - $locationTableName.longitude)))) * 69.172 <= " . "'" . $radius . "'";
            $sqlstring .= ")";
            $select->where($sqlstring);

            if (isset($params['orderby']) && $params['orderby'] == "distance") {
                $select->order("distance");
            }

            $select->group("$rName.news_id");
            $addGroupBy = 0;
        }

        if ((isset($params['location']) && !empty($params['location'])) || (!empty($params['Latitude']) && !empty($params['Longitude']))) {

            $enable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.proximitysearch', 1);
            $longitude = 0;
            $latitude = 0;
            $detactLatLng = false;
            if (isset($params['location']) && $params['location']) {
                $cookieLocation = Engine_Api::_()->seaocore()->getMyLocationDetailsCookie();
                $detactLatLng = isset($cookieLocation['location']) && $cookieLocation['location'] != $params['location'];
            }
            if ((isset($params['locationmiles']) && (!empty($params['locationmiles']) && !empty($enable))) || $detactLatLng) {

                if ($params['location']) {
                    $selectLocQuery = $locationTable->select()->where('location = ?', $params['location']);
                    $locationValue = $locationTable->fetchRow($selectLocQuery);
                }

                //check for zip code in location search.
                if ((empty($params['Latitude']) && empty($params['Longitude'])) || $detactLatLng) {
                    if (empty($locationValue)) {

                        $locationResults = Engine_Api::_()->getApi('geoLocation', 'seaocore')->getLatLong(array('location' => $params['location'], 'module' => 'Sitenews'));
                        if (!empty($locationResults['latitude']) && !empty($locationResults['longitude'])) {
                            $latitude = $locationResults['latitude'];
                            $longitude = $locationResults['longitude'];
                        }
                    } else {
                        $latitude = (float) $locationValue->latitude;
                        $longitude = (float) $locationValue->longitude;
                    }
                } else {
                    $latitude = (float) $params['Latitude'];
                    $longitude = (float) $params['Longitude'];
                }
                if ($latitude && $latitude && isset($params['location']) && $params['location']) {
                    $seaocore_myLocationDetails['latitude'] = $latitude;
                    $seaocore_myLocationDetails['longitude'] = $longitude;
                    $seaocore_myLocationDetails['location'] = $params['location'];
                    $seaocore_myLocationDetails['locationmiles'] = $params['locationmiles'];

                    Engine_Api::_()->seaocore()->setMyLocationDetailsCookie($seaocore_myLocationDetails);
                }
            }

            if (isset($params['locationmiles']) && (!empty($params['locationmiles']) && !empty($enable)) && $latitude && $longitude) {
                $radius = $params['locationmiles'];

                $flage = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.proximity.search.kilometer', 0);
                if (!empty($flage)) {
                    $radius = $radius * (0.621371192);
                }

                //$latitudeRadians = deg2rad($latitude);
                $latitudeSin = "sin(radians($latitude))";
                $latitudeCos = "cos(radians($latitude))";

                $select->join($locationTableName, "$rName.news_id = $locationTableName.news_id", array("(degrees(acos($latitudeSin * sin(radians($locationTableName.latitude)) + $latitudeCos * cos(radians($locationTableName.latitude)) * cos(radians($longitude - $locationTableName.longitude)))) * 69.172) AS distance"));


                $sqlstring = "(degrees(acos($latitudeSin * sin(radians($locationTableName.latitude)) + $latitudeCos * cos(radians($locationTableName.latitude)) * cos(radians($longitude - $locationTableName.longitude)))) * 69.172 <= " . "'" . $radius . "'";
                $sqlstring .= ")";
                $select->where($sqlstring);

                if (isset($params['orderby']) && $params['orderby'] == "distance") {
                    $select->order("distance");
                }
            } else {
                $select->join($locationTableName, "$rName.news_id = $locationTableName.news_id", null);
                $select->where("`{$locationTableName}`.formatted_address LIKE ? or `{$locationTableName}`.location LIKE ? or `{$locationTableName}`.city LIKE ? or `{$locationTableName}`.state LIKE ?", "%" . $params['location'] . "%");
            }
        }

        //GET TAGMAP TABLE NAME
        $tagMapTableName = Engine_Api::_()->getDbtable('TagMaps', 'core')->info('name');
        $tagName = Engine_Api::_()->getDbtable('Tags', 'core')->info('name');
        $isTagIdSearch = false;
        if (isset($params['tag_id']) && !empty($params['tag_id'])) {
            $select
                    ->setIntegrityCheck(false)
                    ->joinLeft($tagMapTableName, "$tagMapTableName.resource_id = $rName.news_id", array('tagmap_id', 'resource_type', 'resource_id', $tagMapTableName . '.tag_id'))
                    ->where($tagMapTableName . '.resource_type = ?', 'sitenews_news')
                    ->where($tagMapTableName . '.tag_id = ?', $params['tag_id']);
            $isTagIdSearch = true;
        }
        if (isset($params['search']) && !empty($params['search'])) {

            if ($isTagIdSearch == false) {
                $select
                        ->setIntegrityCheck(false)
                        ->joinLeft($tagMapTableName, "$tagMapTableName.resource_id = $rName.news_id and " . $tagMapTableName . ".resource_type = 'sitenews_news'", array('tagmap_id', 'resource_type', 'resource_id', $tagMapTableName . '.tag_id'));
            }
            $select->joinLeft($tagName, "$tagName.tag_id = $tagMapTableName.tag_id", array());
            $select->where("lower($rName.title) LIKE ? OR lower($rName.description) LIKE ? OR lower($tagName.text) LIKE ? ", '%' . strtolower($params['search']) . '%');
            $select->group("$reName.news_id");
        }


        if (isset($params['rss']) && !empty($params['rss'])) {
            $select->where($rName . '.rss = ?', $params['rss']);
        }

        if (!isset($params['myNews'])) {
            $select->where($rName . '.published = ?', 1);
        }
        if (isset($params['breaking'])) {
            $select->where($rName . '.breaking_news = ?', 1);
        }

        if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
            $select->where($rName . '.owner_id = ?', $params['user_id']);
        }

        if (!empty($params['user']) && $params['user'] instanceof User_Model_User) {
            $select->where($rName . '.owner_id = ?', $params['user_id']->getIdentity());
        }

        if (!empty($params['users'])) {
            $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
            $select->where($rName . '.owner_id in (?)', new Zend_Db_Expr($str));
        }

        if (!empty($params['category'])) {
            $select->where($rName . '.category_id = ?');
        }
        if (!empty($params['category_id'])) {
            $select->where($rName . '.category_id = ?', $params['category_id']);
        }
        if (!empty($params['subcategory_id'])) {
            $select->where($rName . '.subcategory_id = ?', $params['subcategory_id']);
        }
        if (!empty($params['subsubcategory_id'])) {
            $select->where($rName . '.subsubcategory_id = ?', $params['subsubcategory_id']);
        }

        //multiple categories selected
        if (!empty($params['categoryids'])) {
            $categoryids = $params['categoryids'];
            $select->where($rName . '.category_id in (?)', $categoryids);
        }
        //multiple subcategories
        if (!empty($params['subcategoryids'])) {
            $categoryids = $params['subcategoryids'];
            $select->where($rName . '.subcategory_id in (?)', $categoryids);
        }
        //multiple subcategories
        if (!empty($params['subsubcategoryids'])) {
            $categoryids = $params['subsubcategoryids'];
            $select->where($rName . '.subsubcategory_id in (?)', $categoryids);
        }

        if (!empty($params['category'])) {
            $select->where($rName . '.category_id = ?');
        }
        if (!empty($params['category_id'])) {
            $select->where($rName . '.category_id = ?', $params['category_id']);
        }
        if (!empty($params['subcategory_id'])) {
            $select->where($rName . '.subcategory_id = ?', $params['subcategory_id']);
        }
        if (!empty($params['subsubcategory_id'])) {
            $select->where($rName . '.subsubcategory_id = ?', $params['subsubcategory_id']);
        }

        if (isset($params['draft'])) {
            $select->where($rName . '.draft = ?', $params['draft']);
        }

        // Could we use the search indexer for this?
        if (!empty($params['search'])) {
            $select->where($rName . ".title LIKE ? OR " . $rName . ".description LIKE ?", '%' . $params['search'] . '%');
        }

        if (!empty($params['start_date'])) {
            $select->where($rName . ".creation_date > ?", date('Y-m-d', $params['start_date']));
        }

        if (!empty($params['end_date'])) {
            $select->where($rName . ".creation_date < ?", date('Y-m-d', $params['end_date']));
        }

        if (!empty($params['visible'])) {
            $select->where($rName . ".search = ?", $params['visible']);
        }

        if (isset($params['newsType']) && !empty($params['newsType']) && $params['newsType'] != 'user' && $params['newsType'] != 'All') {
            $select->where("$rName.parent_type = ?", $params['newsType']);
        } else if (isset($params['newsType']) && $params['newsType'] == 'user' && $params['newsType'] != 'All') {
            $select->where("$rName.parent_type is NULL");
        }
        $yesterdayDate = date('Y-m-d 00:00:00', strtotime("-1 days"));
        if (isset($params['filter']) && !empty($params['filter'])) {
            switch ($params['filter']) {
                case 'video_feeds':
                    $select->where($rName . '.media_type = ?', 'video');
                    break;
                case 'image_feeds':
                    $select->where($rName . '.media_type = ?', 'image');
                    break;
                case "yesterday":
                    $select->where($rName . '.publish_date >= ?', $yesterdayDate)
                            ->where($rName . '.publish_date < ?', date('Y-m-d 00:00:00'));
                    break;
                case "comment_count":
                    $select->where($rName . '.comment_count>0');
                    break;
                case 'like_count':
                    $select->where($rName . '.like_count>0');
                    break;
                case 'favourite_count' :
                    $select->where($rName . '.favourite_count >0');
                    break;
                case 'featured' :
                    $select->where($rName . '.featured = 1');
                    break;
                case 'sponsored' :
                    $select->where($rName . '.sponsored = 1');
                    break;
            }
        }

        if (isset($params['orderBy']) && !empty($params['orderBy'])) {
            if (in_array('creationDate_desc', $params['orderBy'])) {
                $select->order($rName . '.publish_date DESC');
            }
            if (in_array('view_desc', $params['orderBy'])) {
                $select->order($rName . '.view_count DESC');
            }
            if (in_array('title', $params['orderBy'])) {
                $select->order($rName . '.title ASC');
            }
            if (in_array('featured_creationDate_desc', $params['orderBy'])) {
                $select->order($rName . '.featured DESC');
                $select->order($rName . '.publish_date DESC');
            }
            if (in_array('featured_view_desc', $params['orderBy'])) {
                $select->order($rName . '.featured DESC');
                $select->order($rName . '.view_count DESC');
            }
        }
        if (isset($params['popularType']) && !empty($params['popularType'])) {
             switch ($params['popularType']) {
                case "featured":
                    $select->where($rName . '.featured = 1');
                    break;
                case "sponsored":
                    $select->where($rName . '.sponsored = 1');
                    break;
                case "breaking_news":
                    $select->where($rName . '.breaking_news = 1');
                    break;
            }
        }
        if (isset($params['orderby']) && !empty($params['orderby'])) {
            switch ($params['orderby']) {
                case "creationDate":
                    $select->order($rName . '.publish_date DESC');
                    break;
                case "creationDateAsc":
                    $select->order($rName . '.publish_date ASC');
                    break;
                case "modifiedDate":
                    $select->order($rName . '.modified_date DESC');
                    break;
                case "viewCount":
                    $select->order($rName . '.view_count DESC');
                    break;
                case "commentCount":
                    $select->order($rName . '.comment_count DESC');
                    break;
                case 'likeCount':
                    $select->order($rName . '.like_count  DESC');
                    break;
                case 'favouriteCount':
                    $select->order($rName . '.favourite_count  DESC');
                    break;
                case 'title':
                    $select->order($rName . '.title ASC');
                    break;
                case 'title_reverse':
                    $select->order($rName . '.title DESC');
                    break;
                case 'featured':
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.publish_date DESC');
                    break;
                case 'featuredView':
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.view_count DESC');
                    break;
                case 'sponsored':
                    $select->order($rName . '.sponsored DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'sponsoredFeatured':
                    $select->order($reName . '.sponsored DESC');
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'featuredSponsored':
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.sponsored DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'breaking':
                    $select->order($rName . '.breaking DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'random' :
                    $select->order('RAND()');
                    break;
                default:
                    $select->order($rName . '.modified_date DESC');
                    break;
            }
        }

        //interval orderby
        if (isset($params['orderInterval']) && !empty($params['orderInterval'])) {
            switch ($params['orderInterval']) {

                case 'creation_date':
                    $select->order($rName . '.publish_date DESC');
                    if (($interval == 'week') || ($interval == 'month')) {
                        $select->where($rName . "$sqlTimeStr");
                    }
                    break;
                case 'modified_date':
                    $select->order($rName . '.modified_date DESC');
                    if (($interval == 'week') || ($interval == 'month')) {
                        $select->where($rName . "$sqlTimeStr");
                    }
                    break;
                case 'view_count':
                    $select->order($rName . '.view_count DESC');
                    break;
                case 'like_count':
                    if (($interval == 'week') || ($interval == 'month')) {
                        $popularityTable = Engine_Api::_()->getDbtable('likes', 'core');
                        $popularityTableName = $popularityTable->info('name');
                        $select = $select->joinLeft($popularityTableName, $popularityTableName . '.resource_id = ' . $rName . '.news_id', array("COUNT($rName.news_id) as total_count"))
                                ->where($popularityTableName . '.resource_type = ?', 'sitenews_news')
                                ->order("total_count DESC");
                        $select->where($popularityTableName . "$sqlTimeStr");
                    } else {
                        $select->order($rName . '.like_count DESC');
                    }
                    break;
                case 'comment_count':
                    if (($interval == 'week') || ($interval == 'month')) {
                        $popularityTable = Engine_Api::_()->getDbtable('comments', 'core');
                        $popularityTableName = $popularityTable->info('name');


                        $select = $select->joinLeft($popularityTableName, $popularityTableName . '.resource_id = ' . $rName . '.news_id', array("COUNT($rName.news_id) as total_count"))
                                ->where($popularityTableName . '.resource_type = ?', 'sitenews_news')
                                ->order("total_count DESC");
                        $select->where($popularityTableName . "$sqlTimeStr");
                    } else {
                        $select->order($rName . '.comment_count DESC');
                    }
                    break;
                case 'favourite_count' :
                    $select->order($rName . '.favourite_count DESC');
                    break;
                case 'random':
                    $select->order('Rand()');
                    break;
            }
        }

        if (isset($params['limit'])) {
            $select->limit($params['limit']);
        }

        return $select;
    }

    public function getNewsCategoryId($news_id) {
        $newsItem = Engine_Api::_()->getItem('sitenews_news', $news_id);
        return $newsItem->category_id;
    }

    public function getLikedNewsSelect(array $params) {

        $newsTableName = $this->info('name');
        $likesTable = Engine_Api::_()->getDbtable('likes', 'core');
        $likesTableName = $likesTable->info('name');
        $select = $this->select()->from($newsTableName, '*');
        $select->joinLeft($likesTableName, $likesTableName . ".resource_id=" . $newsTableName . ".news_id", null);
        $select->where('resource_type = ?', 'sitenews_news');
        if (!empty($params['owner_id']))
            $select->where('poster_id = ?', $params['owner_id']);
        if (isset($params['order']) && $params['order'] == 'random') {
            $select->order('RAND()');
        } else {
            $select->order("$newsTableName.creation_date DESC");
        }
        if (!isset($params['myNews'])) {
            $select->where($newsTableName . '.published = ?', 1);
        }
        if (isset($params['search']) && !empty($params['search'])) {
            $select->where("lower($newsTableName.title) like ? ", '%' . strtolower($params['search']) . '%');
        }
        return $select;
    }

    public function getLikedNewsPaginator(array $params) {
        return Zend_Paginator::factory($this->getLikedNewsSelect($params));
    }

    public function getSubscribedNewsSelect(array $params) {

        $newsTableName = $this->info('name');
        $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'sitenews');
        $subscriptionsTableName = $subscriptionsTable->info('name');
        $select = $this->select()->setIntegrityCheck(false);

        if (!isset($params['myNews'])) {
            $select->where($newsTableName . '.published = ?', 1);
        }
        if (isset($params['news_id']) && !empty($params['news_id'])) {
            $select->from($subscriptionsTableName, '*');
            $select->where("$subscriptionsTableName.news_id = ?", $params['news_id']);
        } else {
            $select->from($newsTableName, '*');
            $select->joinLeft($subscriptionsTableName, $subscriptionsTableName . ".news_id=" . $newsTableName . ".news_id", null);
        }

        if (!empty($params['owner_id']))
            $select->where("$subscriptionsTableName.owner_id = ?", $params['owner_id']);
        if (isset($params['order']) && $params['order'] == 'random') {
            $select->order('RAND()');
        } else {
            $select->order("$subscriptionsTableName.creation_date DESC");
        }
        if (isset($params['search']) && !empty($params['search'])) {
            $select->where("lower($rssTableName.title) like ? ", '%' . strtolower($params['search']) . '%');
        }
        return $select;
    }

    public function getSubscribedNewsPaginator(array $params) {
        return Zend_Paginator::factory($this->getSubscribedNewsSelect($params));
    }

    /**
     * Get total channels of particular category / subcategoty 
     *
     * @param array $params
     * @return int $totalNews;
     */
    public function getNewsCount($params = array()) {

        //MAKE QUERY
        $select = $this->select()
                ->from($this->info('name'), array('COUNT(*) AS count'));

        if (isset($params['foruser']) && !empty($params['foruser'])) {
            $select->where('search = ?', 1);
        }
        if (isset($params['synchronized'])) {
            $select->where('synchronized = ?', $params['synchronized']);
        }
        if (isset($params['type']) && !empty($params['type'])) {
            $select->where('type in (?)', $params['type']);
        }
        if (!empty($params['columnName']) && !empty($params['category_id'])) {
            $column_name = $params['columnName'];
            $select->where("$column_name = ?", $params['category_id']);
        }

        $totalNews = $select->query()->fetchColumn();

        //RETURN NEWS COUNT
        return $totalNews;
    }

    /**
     * Gets a paginator
     *
     * @param Core_Model_Item_Abstract $user The user to get the messages for
     * @return Zend_Paginator
     */
    public function getNewsPaginator($params = array()) {
        $paginator = Zend_Paginator::factory($this->getNewsSelect($params));
        if (!empty($params['page'])) {
            $paginator->setCurrentPageNumber($params['page']);
        }
        if (!empty($params['limit'])) {
            $paginator->setItemCountPerPage($params['limit']);
        }

        if (empty($params['limit'])) {
            $page = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.page', 10);
            $paginator->setItemCountPerPage($page);
        }
        return $paginator;
    }

    public function getFavouriteNewsSelect(array $params) {

        $newsTableName = $this->info('name');
        $favouritesTable = Engine_Api::_()->getDbtable('favourites', 'seaocore');
        $favouritesTableName = $favouritesTable->info('name');
        $select = $this->select()->from($newsTableName, '*');
        $select->joinLeft($favouritesTableName, $favouritesTableName . ".resource_id=" . $newsTableName . ".news_id", null);
        $select->where('resource_type = ?', 'sitenews_news');
        if (!empty($params['owner_id']))
            $select->where('poster_id = ?', $params['owner_id']);

        if (!isset($params['myNews'])) {
            $select->where($newsTabeName . '.published = ?', 1);
        }
        if (isset($params['order']) && $params['order'] == 'random') {
            $select->order('RAND()');
        } else {
            $select->order("$favouritesTableName.creation_date DESC");
        }
        if (isset($params['search']) && !empty($params['search'])) {
            $select->where("lower($newsTableName.title) like ? ", '%' . strtolower($params['search']) . '%');
        }
        return $select;
    }

    public function getFavouriteNewsPaginator(array $params) {
        return Zend_Paginator::factory($this->getFavouriteNewsSelect($params));
    }

    /**
     * Get paginator of News
     *
     * @param array $params
     * @return Zend_Paginator;
     */
    Public function NewsBySettings($params = array()) {
        $newsTableName = $this->info('name');
        $select = $this->select()
                ->setIntegrityCheck(false)
                ->from($newsTableName)
                ->where($newsTableName . '.search = ?', 1);


        //MAKE TIMING STRING
        $sqlTimeStr = '';
        $interval = '';
        if (isset($params['interval']) && !empty($params['interval'])) {
            $interval = $params['interval'];
            $current_time = date("Y-m-d H:i:s");
            if ($interval == 'week') {
                $time_duration = date('Y-m-d H:i:s', strtotime('-7 days'));
                $sqlTimeStr = ".creation_date BETWEEN " . "'" . $time_duration . "'" . " AND " . "'" . $current_time . "'";
            } elseif ($interval == 'month') {
                $time_duration = date('Y-m-d H:i:s', strtotime('-1 months'));
                $sqlTimeStr = ".creation_date BETWEEN " . "'" . $time_duration . "'" . " AND " . "'" . $current_time . "'" . "";
            }
        }
        if (isset($params['news_ids']) && !empty($params['news_ids'])) {
            $select->where($newsTableName . '.news_id IN(?)', $params['news_ids']);
        }
        if (!empty($params['category_id'])) {
            $select->where($newsTableName . '.category_id = ?', $params['category_id']);
        }
        if (!isset($params['myNews'])) {
            $select->where($newsTableName . '.published = ?', 1);
        }
        if (isset($params['rss']) && !empty($params['rss'])) {
            $select->where($newsTableName . '.rss = ?', $params['rss']);
        }
        if (isset($params['showNews']) && $params['showNews'] == "video_feeds") {
            $select->where($newsTableName . '.media_type = ?', 'video');
        }
        if (isset($params['showNews']) && $params['showNews'] == "image_feeds") {
            $select->where($newsTableName . '.media_type = ?', 'image');
        }

        if (!empty($params['subcategory_id'])) {
            $select->where($newsTableName . '.subcategory_id = ?', $params['subcategory_id']);
        }

        if (!empty($params['subsubcategory_id'])) {
            $select->where($newsTableName . '.subsubcategory_id = ?', $params['subsubcategory_id']);
        }

        if (!empty($params['users'])) {
            $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
            $select->where($newsTableName . '.owner_id in (?)', new Zend_Db_Expr($str));
        }

        if (empty($params['users']) && isset($params['view_view']) && $params['view_view'] == '1') {
            $select->where($newsTableName . '.owner_id = ?', '0');
        }

        if (isset($params['orderby']) && !empty($params['orderby'])) {
            switch ($params['orderby']) {

                case 'creation_date':
                    $select->order($newsTableName . '.creation_date DESC');
                    if (($interval == 'week') || ($interval == 'month')) {
                        $select->where($newsTableName . "$sqlTimeStr");
                    }
                    break;
                case 'modified_date':
                    $select->order($newsTableName . '.modified_date DESC');
                    if (($interval == 'week') || ($interval == 'month')) {
                        $select->where($newsTableName . "$sqlTimeStr");
                    }
                    break;
                case 'view_count':
                    $select->order($newsTableName . '.view_count DESC');
                    break;
                case 'like_count':
                    if (($interval == 'week') || ($interval == 'month')) {
                        $popularityTable = Engine_Api::_()->getDbtable('likes', 'core');
                        $popularityTableName = $popularityTable->info('name');
                        $select = $select->joinLeft($popularityTableName, $popularityTableName . '.resource_id = ' . $newsTableName . '.news_id', array("COUNT($newsTableName.news_id) as total_count"))
                                ->where($popularityTableName . '.resource_type = ?', 'sitenews_news')
                                ->order("total_count DESC");

                        $select->where($popularityTableName . "$sqlTimeStr");
                    } else {
                        $select->order($newsTableName . '.like_count DESC');
                    }
                    break;
                case 'comment_count':
                    if (($interval == 'week') || ($interval == 'month')) {
                        $popularityTable = Engine_Api::_()->getDbtable('comments', 'core');
                        $popularityTableName = $popularityTable->info('name');

                        $select = $select->joinLeft($popularityTableName, $popularityTableName . '.resource_id = ' . $newsTableName . '.news_id', array("COUNT($newsTableName.news_id) as total_count"))
                                ->where($popularityTableName . '.resource_type = ?', 'sitenews_news')
                                ->order("total_count DESC");
                        $select->where($popularityTableName . "$sqlTimeStr");
                    } else {
                        $select->order($newsTableName . '.comment_count DESC');
                    }
                    break;
                case 'subscribe_count' :
                    $select->order($newsTableName . '.subscribe_count DESC');
                    break;
                case 'favourite_count' :
                    $select->order($newsTableName . '.favourite_count DESC');
                    break;
                case 'random':
                    $select->order('Rand()');
                    break;
                case 'mostRecent':
                    $select->order('news_id DESC');
                    break;      
                case 'featured':
                    $select->order('featured DESC');
                    break;
                case 'sponsored':
                    $select->order('sponsored DESC');
                    break;  
                case 'breaking_news':
                    $select->order('breaking_news DESC');
                    break;  
            }
        }
        if (isset($params['orderby']) && !empty($params['orderby']) && $params['orderby'] != 'creation_date' && $params['orderby'] != 'modified_date' && $params['orderby'] != 'random') {
            $select->order($newsTableName . ".news_id DESC");
        }
        if (isset($params['showNewsType']) && !empty($params['showNewsType'])) {
            switch ($params['showNewsType']) {
                case 'featured' :
                    $select->where("$newsTableName.featured = ?", 1);
                    break;
                case 'sponsored' :
                    $select->where($newsTableName . '.sponsored = ?', '1');
                    break;
                case 'breaking' :
                    $select->where("$newsTableName.breaking_news = ?", 1);
                    break;
                case 'featuredSponsored' :
                    $select->where("$newsTableName.sponsored = 1 OR $newsTableName.featured = 1");
                    break;
                case 'breaking_news' :
                    $select->where("$newsTableName.breaking_news = ?", 1);
                    break;
                case 'featuredNsponsored' :
                    $select->where("$newsTableName.sponsored = 1 OR $newsTableName.featured = 1");
                    break;
            }
        }

        //Start Network work
        $select = $this->getNetworkBaseSql($select, array('not_groupBy' => 1));
        //End Network work

        $select->group("$newsTableName.news_id");

        if (isset($params['limit']) && !empty($params['limit'])) {
            $limit = $params['limit'];
        }
        if (isset($params['start_index']) && $params['start_index'] >= 0) {
            $select = $select->limit($limit, $params['start_index']);
            return $this->fetchAll($select);
        }
        return Zend_Paginator::factory($select);
    }

    /**
     * Get pages to add as item of the day
     * @param string $title : search text
     * @param int $limit : result limit
     */
    public function getDayItems($title, $limit = 10) {

        //MAKE QUERY
        $select = $this->select()
                ->from($this->info('name'), array('news_id', 'owner_id', 'title'))
                ->where('lower(title)  LIKE ? ', '%' . strtolower($title) . '%')
                ->where('search = ?', '1')
                ->order('title ASC')
                ->limit($limit);

        //RETURN RESULTS
        return $this->fetchAll($select);
    }

    public function getNetworkBaseSql($select, $params = array()) {
        $select = $this->addPrivacyNewsSQl($select, $this->info('name'));
        if (empty($select))
            return;

        $sitenews_tableName = $this->info('name');

        //START NETWORK WORK
        $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.network', 0);

        if (!empty($enableNetwork) || (isset($params['browse_network']) && !empty($params['browse_network']))) {

            $viewer = Engine_Api::_()->user()->getViewer();
            $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
            if (!Zend_Registry::isRegistered('viewerNetworksIdsRss')) {
                $viewerNetworkIds = $networkMembershipTable->getMembershipsOfIds($viewer);
                Zend_Registry::set('viewerNetworksIdsNews', $viewerNetworkIds);
            } else {
                $viewerNetworkIds = Zend_Registry::get('viewerNetworksIdsNews');
            }
            if (!Engine_Api::_()->sitenews()->rssBaseNetworkEnable()) {
                $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

                if (!empty($viewerNetwork)) {
                    if (isset($params['setIntegrity']) && !empty($params['setIntegrity'])) {
                        $select->setIntegrityCheck(false)
                                ->from($sitenews_tableName);
                    }
                    $networkMembershipName = $networkMembershipTable->info('name');
                    $select
                            ->join($networkMembershipName, "`{$sitenews_tableName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
                            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
                            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity());
                    if (!isset($params['not_groupBy']) || empty($params['not_groupBy'])) {
                        $select->group($sitenews_tableName . ".news_id");
                    }
                    if (isset($params['extension_group']) && !empty($params['extension_group'])) {
                        $select->group($params['extension_group']);
                    }
                }
            } else {
                $viewerNetwork = $networkMembershipTable->getMembershipsOfInfo($viewer);
                $str = array();
                $columnName = "`{$sitenews_tableName}`.networks_privacy";
                foreach ($viewerNetwork as $networkvalue) {
                    $network_id = $networkvalue->resource_id;
                    $str[] = "'" . $network_id . "'";
                    $str[] = "'" . $network_id . ",%'";
                    $str[] = "'%," . $network_id . ",%'";
                    $str[] = "'%," . $network_id . "'";
                }
                if (!empty($str)) {
                    $likeNetworkVale = (string) ( join(" or $columnName  LIKE ", $str) );
                    $select->where($columnName . ' LIKE ' . $likeNetworkVale . ' or ' . $columnName . " IS NULL");
                } else {
                    $select->where($columnName . " IS NULL");
                }
            }
            //END NETWORK WORK
        }

        return $select;
    }

    public function addPrivacyNewsSQl($select, $tableName = null) {

        $privacybase = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.privacybase', 0);

        if (empty($privacybase))
            return $select;

        $column = $tableName ? "$tableName.news_id" : "news_id";

        return $select->where("$column IN(?)", $this->getOnlyViewableNewsId());
    }

    public function getOnlyViewableNewsId() {

        $viewer = Engine_Api::_()->user()->getViewer();
        $news_ids = array();
        $cache = Zend_Registry::get('Zend_Cache');
        $cacheName = 'news_ids_user_id_' . $viewer->getIdentity();

        $data = APPLICATION_ENV == 'development' ? ( Zend_Registry::isRegistered($cacheName) ? Zend_Registry::get($cacheName) : null ) : $cache->load($cacheName);
        if ($data && is_array($data)) {
            $rss_ids = $data;
        } else {
            set_time_limit(0);
            $table = Engine_Api::_()->getItemTable('sitenews_news');
            $news_select = $table->select()
                    ->where('search = ?', true)
                    ->order('news_id DESC');

            // Create new array filtering out private channels
            $i = 0;
            foreach ($news_select->getTable()->fetchAll($news_select) as $news) {
                if ($news->isOwner($viewer) || Engine_Api::_()->authorization()->isAllowed($news, $viewer, 'view')) {
                    $news_ids[$i++] = $news->news_id;
                }
            }

            // Try to save to cache
            if (empty($news_ids))
                $news_ids = array(0);

            if (APPLICATION_ENV == 'development') {
                Zend_Registry::set($cacheName, $news_ids);
            } else {
                $cache->save($news_ids, $cacheName);
            }
        }

        return $news_ids;
    }

    public function checkNewsExistsAlready($new, $title) {

        $guid = $new->guid();
        $link = $new->link();

        $illegalGuid = strpos($guid,':');
        $illegalLink = strpos($link,':');

        $pubDate = $new->pubDate();

        $newsTable = Engine_Api::_()->getItemTable('sitenews_news');
        $select = $newsTable->select()
                ->from($newsTable->info('name'), 'news_id')
                ->where('title like ? ', $title);

        if (!empty($guid) && !$illegalGuid){
            
            $select->where('guid = ? ', $guid);
        }elseif(!empty($link) && !$illegalLink){
            
            $select->where('original_link = ? ', $link);
        }

        $select->limit(1);
        $debug = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.debug', 0);

        try{
                $row = $newsTable->fetchRow($select);
                if($debug){

                    $file = APPLICATION_PATH.'/temporary/log/newsDebug.log';
                    $writeContent = file_get_contents($file);
                    if(!empty($row)){

                        $writeContent.='Query: '.$select->__toString().PHP_EOL;
                        file_put_contents($file, $writeContent);
                    }
                }

        }catch(Exception $e){
            
            if($debug){
                
                $writeContent.='checkNewsExistsAlready(): Exception'.PHP_EOL;
                $writeContent.='exp: '.$e->getMessage().PHP_EOL;
                $writeContent.='Query:'.$select->__toString().PHP_EOL;
                file_put_contents($file, $writeContent);
            }

            return true;
        }
        return $row;
    }

    public function saveNews($rss, $default = false) {
        
        $debug = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.debug', 0);
        if($debug){
            
            $file = APPLICATION_PATH.'/temporary/log/newsDebug.log';
            if(!file_exists($file)){

                $fileObject = fopen($file, 'w');
                fwrite($fileObject, ' ### News / RSS Importer and Aggregator Plugin - Debug ### '.PHP_EOL);
                fclose($fileObject);
                chmod($file, 0777); 
            }

            $writeContent = file_get_contents($file);
            $writeContent.='Save News Begins..'.PHP_EOL;
            file_put_contents($file, $writeContent);
        }

        if(!$default) {
                $sitenews_fetch_rss = Zend_Registry::isRegistered('sitenews_fetch_rss') ? Zend_Registry::get('sitenews_fetch_rss') : null;
        if(empty($sitenews_fetch_rss))
            return false;
        }
        $newsItem = 0;
        $rss_id = $rss->rss_id;
        
        if($default) {
            $feedsLimit = 5;
        } else {
            $feedsLimit = Engine_Api::_()->getApi('settings', 'core')->getSetting('feeds.limit', 10);
        }
        if($debug){
            //for debug
            $feedsLimit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.debugfeedlimit', 2);
        }
        
        //SET NEWS THUMBNAIL
        if (!$rss->file_id) {
            $news = Zend_Feed_Reader::import($rss->rss_url);
            $rssImageArray = $news->getImage();
            $thumbUrl = trim($rssImageArray['uri']);

            if (!empty($thumbUrl)) {
                // $rssImageArray['tmp_name'] = $rssImageArray['uri'];
                try {
                        $path = APPLICATION_PATH . '/public/';
                        //                                 (url, dir, dir_type, overite, , debug)
                        $image = $this->saveTemporaryImage($thumbUrl, $path , NULL, false, true, false);                    
                        if(!empty($image)){
                            
                            chmod($image,'777');
                            $rss->setPhoto($image,array('setRssLogo'=>1));
                        }    

                } catch (Exception $ex) {

                    if($debug){
                        
                        $writeContent.='Exception In Rss Logo Fetch :-'.PHP_EOL;
                        $writeContent.=$ex->getMessage().PHP_EOL;
                        file_put_contents($file, $writeContent);
                    }
                }
            }
        }

        // auth stuff
        $auth = Engine_Api::_()->authorization()->context;
        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

        $viewMax = array_search($rss->auth_view, $roles);
        $commentMax = array_search($rss->auth_comment, $roles);

        $webParser = Engine_Api::_()->getApi('webParser', 'sitenews');
        $newsTable = Engine_Api::_()->getItemTable('sitenews_news');
        $news = Zend_Feed::import($rss->rss_url);
        if($debug){
            
            $writeContent.= 'Total News Fetched from RSS(ID:'.$rss->rss_id.')'.count($news).PHP_EOL;
            file_put_contents($file, $writeContent);
        }
        
        foreach ($news as $new) {
            if ($newsItem >= $feedsLimit) {
                if($debug){
                    
                    $writeContent.= 'Feed Limit Exhausted (Limit in debug: '.$feedsLimit.')'.PHP_EOL;
                    file_put_contents($file, $writeContent);                    
                }
                break;
            }
            $linkUrl = $new->link();
            $content = $webParser->getContent($linkUrl);
            if(empty($content) || empty($content['title'])){
                continue;
            }
            if($debug){
                $writeContent.= '[WebPage Parser Fetched] Title:'.$content['title'].PHP_EOL;
                file_put_contents($file, $writeContent);
            }
            $row = $this->checkNewsExistsAlready($new, $content['title']);
            if (!empty($row)) {
                
                if($debug){
                    
                    $writeContent.= '[WebPage Parser Fetched] This title already saved'.PHP_EOL;
                    file_put_contents($file, $writeContent);
                }
                continue;
            }

            $channel['rss'] = $rss_id;
            $channel['published'] = $rss->published;
            $channel['owner_id'] = $rss->owner_id;
            $channel['owner_type'] = $rss->owner_type;
            $channel['type'] = 'feed';
            $channel['category_id'] = $rss->category_id;
            $channel['subcategory_id'] = $rss->subcategory_id;
            $channel['subsubcategory_id'] = $rss->subsubcategory_id;
            $channel['category'] = $new->getCategory();
            $channel['guid'] = $new->guid();
            $channel['author'] = $new->author();
            $channel['title'] = $content['title'];
            if ($new->pubDate()) {
                $channel['publish_date'] = date('Y-m-d H:i:s', strtotime($new->pubDate()));
            } else {
                $channel['publish_date'] = date('Y-m-d H:i:s');
            }
            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.full.content', 1)) {
                $newsotherinfocontent = $content['content'];
            } else {
                $newsotherinfocontent = $content['excerpt'];
            }

            $channel['description'] = $content['excerpt'];
            $channel['creation_date'] = date('Y-m-d H:i:s');
            $channel['original_link'] = $linkUrl;
            $path = '';
            if (isset($content['lead_image_url'])) {
                $thumbUrl = $content['lead_image_url'];
                if ($thumbUrl) {
                    $content = file_get_contents($thumbUrl);
                    $path = APPLICATION_PATH . '/public/image.jpeg';
                    $fp = fopen($path, "w");
                    fwrite($fp, $content);
                    fclose($fp);
                    chmod($path, 0777);
                    $channel['media_type'] = 'image';
                }
            }
            
            $newsRow = $newsTable->createRow();
            $newsRow->setFromArray($channel);
            $newsRow->save();
            if($debug){

                $writeContent.= 'News Saved Successfully.'.PHP_EOL;
                file_put_contents($file, $writeContent);
            }
            
            if ($path) {
                try {
                    $newsRow->setPhoto($path);
                    $newsRow->save();

                    if($debug){

                        $writeContent.= 'News Photo Saved Successfully.'.PHP_EOL;
                        file_put_contents($file, $writeContent);
                    }
                } catch (Exception $ex) {
                    
                    if($debug){
                        
                        $writeContent .= '(News ID:'.$newsRow->news_id.')Exception In Saving news photo :-'.PHP_EOL;
                        $writeContent .= $ex->getMessage().PHP_EOL;
                        file_put_contents($file, $writeContent);        
                    }
                    $newsRow->delete();
                    continue;
                }
            }

            if($debug){

                $writeContent.='(News ID:'.$newsRow->news_id.') News Saved.'.PHP_EOL;
                file_put_contents($file, $writeContent);                        
            }


            // CREATE AUTH STUFF HERE
            foreach ($roles as $i => $role) {
                $auth->setAllowed($newsRow, $role, 'view', ($i <= $viewMax));
                $auth->setAllowed($newsRow, $role, 'comment', ($i <= $commentMax));
            }
            $newsItem++;

            $viewer = Engine_Api::_()->user()->getViewer();
            $viewer_id = $viewer->getIdentity();
            if(empty($viewer_id)){

                $subject = Engine_Api::_()->seaocore()->getSuperAdmin();
            }else{

                $subject = $viewer;
            }

            if ($newsRow->rss) {
                $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($subject, $rss, 'sitenews_news_new_in_rss', null, array('child_id' => $newsRow->getIdentity()));
            } else {
                $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $newsRow, 'sitenews_news_new');
            }

            // make sure action exists before attaching the news to the activity
            if ($action) {
                Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $newsRow);
            }

            $tableOtherinfo = Engine_Api::_()->getDbTable('newsotherinfo', 'sitenews');
            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            try {
                $row = $tableOtherinfo->getOtherinfo($newsRow->getIdentity());
                if (empty($row))
                    Engine_Api::_()->getDbTable('newsotherinfo', 'sitenews')->insert(array(
                        'news_id' => $newsRow->getIdentity(),
                        'content' => $newsotherinfocontent
                    )); //COMMIT
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
        }
        if($debug){
            
            $writeContent.='saveFeed ended'.PHP_EOL;
            $status = file_put_contents($file, $writeContent);        
        }

        if ($path) {
            imagedestroy($path);
        }
        $rss->feeds_count = $rss->feedsCount();
        $rss->save();
        return $newsItem;
    }

}
