<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Rss.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Model_DbTable_Rss extends Engine_Db_Table {

    protected $_name = 'sitenews_rss';
    protected $_rowClass = 'Sitenews_Model_Rss';
    protected $_serializedColumns = array('networks_privacy');

    public function getLikedRssSelect(array $params) {

        $rssTableName = $this->info('name');
        $likesTable = Engine_Api::_()->getDbtable('likes', 'core');
        $likesTableName = $likesTable->info('name');
        $select = $this->select()->from($rssTableName, '*');
        $select->joinLeft($likesTableName, $likesTableName . ".resource_id=" . $rssTableName . ".rss_id", null);
        $select->where('resource_type = ?', 'sitenews_rss');
        if (!empty($params['owner_id']))
            $select->where('poster_id = ?', $params['owner_id']);

        if (!isset($params['myNews'])) {
            $select->where($rssTableName . '.published = ?', 1);
        }
        if (isset($params['order']) && $params['order'] == 'random') {
            $select->order('RAND()');
        } else {
            $select->order("$likesTableName.creation_date DESC");
        }
        if (isset($params['search']) && !empty($params['search'])) {
            $select->where("lower($rssTableName.title) like ? ", '%' . strtolower($params['search']) . '%');
        }
        return $select;
    }

    public function getLikedRssPaginator(array $params) {
        return Zend_Paginator::factory($this->getLikedRssSelect($params));
    }

    public function getSubscribedRssSelect(array $params) {

        $rssTableName = $this->info('name');
        try {
            $subscriptionsTable = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');
            $subscriptionsTableName = $subscriptionsTable->info('name');
        } catch (Exception $e) {
            return false;
        }

        $select = $this->select()->setIntegrityCheck(false);
        if (isset($params['rss_id']) && !empty($params['rss_id'])) {
            $select->from($subscriptionsTableName, '*');
            $select->where("$subscriptionsTableName.rss_id = ?", $params['rss_id']);
        } else {
            $select->from($rssTableName, '*');
            $select->joinLeft($subscriptionsTableName, $subscriptionsTableName . ".rss_id=" . $rssTableName . ".rss_id", null);
        }

        if (!empty($params['owner_id']))
            $select->where("$subscriptionsTableName.subscriber_user_id = ?", $params['owner_id']);

        if (!isset($params['myNews'])) {
            $select->where($rssTableName . '.published = ?', 1);
        }
        if (isset($params['order']) && $params['order'] == 'random') {
            $select->order('RAND()');
        } else {
            $select->order("$subscriptionsTableName.creation_date DESC");
        }
        if (isset($params['search']) && !empty($params['search'])) {
            $select->where("lower($rssTableName.title) like ? ", '%' . strtolower($params['search']) . '%');
        }
        return $select;
    }

    public function getSubscribedRssPaginator(array $params) {
        return Zend_Paginator::factory($this->getSubscribedRssSelect($params));
    }

    public function getRssPaginator($params = array(), $customParams = array()) {
        return Zend_Paginator::factory($this->getRssSelect($params, $customParams));
    }

    public function getRss($params) {
        return $this->getRssSelect($params);
    }

    /**
     * Get channel select query
     *
     * @param array $params
     * @param array $customParams
     * @return string $select;
     */
    public function getRssSelect($params = array(), $customParams = null) {

        $table = Engine_Api::_()->getDbtable('rss', 'sitenews');
        $rName = $table->info('name');

        $tmTable = Engine_Api::_()->getDbtable('TagMaps', 'core');
        $tmName = $tmTable->info('name');

        $select = $table->select()
                ->order(!empty($params['orderby']) ? $params['orderby'] . ' DESC' : $rName . '.creation_date DESC' );

        if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
            $select->where($rName . '.owner_id = ?', $params['user_id']);
        }

        if (!empty($params['user']) && $params['user'] instanceof User_Model_User) {
            $select->where($rName . '.owner_id = ?', $params['user_id']->getIdentity());
        }

        if (!empty($params['users'])) {
            $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
            $select->where($rName . '.owner_id in (?)', new Zend_Db_Expr($str));
        }

        if (isset($params['rss_ids']) && !empty($params['rss_ids'])) {
            $select->where($rName . '.rss_id IN(?)', $params['rss_ids']);
        }

        if (!empty($params['tag'])) {
            $select
                    ->setIntegrityCheck(false)
                    ->from($rName)
                    ->joinLeft($tmName, "$tmName.resource_id = $rName.rss_id")
                    ->where($tmName . '.resource_type = ?', 'sitenews')
                    ->where($tmName . '.tag_id = ?', $params['tag']);
        }

        if (!isset($params['myNews'])) {
            $select->where($rName . '.published = ?', 1);
        }

        if (!empty($params['category'])) {
            $select->where($rName . '.category_id = ?', $params['category']);
        }

        if (isset($params['draft'])) {
            $select->where($rName . '.draft = ?', $params['draft']);
        }

        if (!empty($params['search'])) {
            $select->where($rName . ".title LIKE ? OR " . $rName . ".description LIKE ?", '%' . $params['search'] . '%');
        }

        if (!empty($params['start_date'])) {
            $select->where($rName . ".creation_date > ?", date('Y-m-d', $params['start_date']));
        }

        if (!empty($params['end_date'])) {
            $select->where($rName . ".creation_date < ?", date('Y-m-d', $params['end_date']));
        }

        if (!empty($params['visible'])) {
            $select->where($rName . ".search = ?", $params['visible']);
        }

        if (isset($params['filter']) && !empty($params['filter'])) {
            switch ($params['filter']) {
                case "subscribe_count":
                    $select->where($rName . '.subscribe_count>0');
                    break;
                case "comment_count":
                    $select->where($rName . '.comment_count>0');
                    break;
                case 'like_count':
                    $select->where($rName . '.like_count>0');
                    break;
                case 'favourite_count' :
                    $select->where($rName . '.favourite_count >0');
                    break;

                case 'featured' :
                    $select->where($rName . '.featured = 1');
                    break;
            }
        }

        if (!isset($params['orderby']) || empty($params['orderby'])) {
            $select->order($rName . '.creation_date DESC');
        }

        if (isset($params['orderby']) && !empty($params['orderby'])) {
            switch ($params['orderby']) {
                case "creation_date":
                    $select->order($rName . '.creation_date DESC');
                    break;
                case "creationDateAsc":
                    $select->order($rName . '.creation_date ASC');
                    break;
                case "modified_date":
                    $select->order($rName . '.modified_date DESC');
                    break;
                case "view_count":
                    $select->order($rName . '.view_count DESC');
                    break;
                case "comment_count":
                    $select->order($rName . '.comment_count DESC');
                    break;
                case 'like_count':
                    $select->order($rName . '.like_count  DESC');
                    break;
                case 'feeds_count':
                    $select->order($rName . '.feeds_count  DESC');
                    break;
                case 'favourite_count':
                    $select->order($rName . '.favourite_count  DESC');
                    break;
                case 'subscribe_count':
                    $select->order($rName . '.subscribe_count  DESC');
                    break;
                case 'title':
                    $select->order($rName . '.title ASC');
                    break;
                case 'title_reverse':
                    $select->order($rName . '.title DESC');
                    break;
                case 'featured':
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'sponsored':
                    $select->order($rName . '.sponsored DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'sponsoredFeatured':
                    $select->order($reName . '.sponsored DESC');
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'featuredSponsored':
                    $select->order($rName . '.featured DESC');
                    $select->order($rName . '.sponsored DESC');
                    $select->order($rName . '.creation_date ASC');
                    break;
                case 'random' :
                    $select->order('RAND()');
                    break;
                default:
                    $select->order($rName . '.modified_date DESC');
                    break;
            }
        }

        return $select;
    }

    public function getFavouriteRssSelect(array $params) {

        $rssTableName = $this->info('name');
        $favouritesTable = Engine_Api::_()->getDbtable('favourites', 'seaocore');
        $favouritesTableName = $favouritesTable->info('name');
        $select = $this->select()->from($rssTableName, '*');
        $select->joinLeft($favouritesTableName, $favouritesTableName . ".resource_id=" . $rssTableName . ".rss_id", null);
        $select->where('resource_type = ?', 'sitenews_rss');
        if (!empty($params['owner_id']))
            $select->where('poster_id = ?', $params['owner_id']);

        if (!isset($params['myNews'])) {
            $select->where($rssTableName . '.published = ?', 1);
        }
        if (isset($params['order']) && $params['order'] == 'random') {
            $select->order('RAND()');
        } else {
            $select->order("$favouritesTableName.creation_date DESC");
        }
        if (isset($params['search']) && !empty($params['search'])) {
            $select->where("lower($rssTableName.title) like ? ", '%' . strtolower($params['search']) . '%');
        }
        return $select;
    }

    public function getFavouriteRssPaginator(array $params) {
        return Zend_Paginator::factory($this->getFavouriteRssSelect($params));
    }

    /**
     * Get pages to add as item of the day
     * @param string $title : search text
     * @param int $limit : result limit
     */
    public function getDayItems($title, $limit = 10) {

        //MAKE QUERY
        $select = $this->select()
                ->from($this->info('name'), array('rss_id', 'owner_id', 'title', 'rss_url', 'file_id'))
                ->where('lower(title)  LIKE ? ', '%' . strtolower($title) . '%')
                ->where('search = ?', '1')
                ->order('title ASC')
                ->limit($limit);

        //RETURN RESULTS
        return $this->fetchAll($select);
    }

    public function addPrivacyRssSQl($select, $tableName = null) {

        $privacybase = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.privacybase', 0);

        if (empty($privacybase))
            return $select;

        $column = $tableName ? "$tableName.rss_id" : "rss_id";

        return $select->where("$column IN(?)", $this->getOnlyViewableRssId());
    }

    public function getOnlyViewableRssId() {

        $viewer = Engine_Api::_()->user()->getViewer();
        $rss_ids = array();
        $cache = Zend_Registry::get('Zend_Cache');
        $cacheName = 'rss_ids_user_id_' . $viewer->getIdentity();

        $data = APPLICATION_ENV == 'development' ? ( Zend_Registry::isRegistered($cacheName) ? Zend_Registry::get($cacheName) : null ) : $cache->load($cacheName);
        if ($data && is_array($data)) {
            $rss_ids = $data;
        } else {
            set_time_limit(0);
            $table = Engine_Api::_()->getItemTable('sitenews_rss');
            $rss_select = $table->select()
                    ->where('search = ?', true)
                    ->order('rss_id DESC');

            // Create new array filtering out private channels
            $i = 0;
            foreach ($rss_select->getTable()->fetchAll($rss_select) as $rss) {
                if ($rss->isOwner($viewer) || Engine_Api::_()->authorization()->isAllowed($rss, $viewer, 'view')) {
                    $rss_ids[$i++] = $rss->rss_id;
                }
            }

            // Try to save to cache
            if (empty($rss_ids))
                $rss_ids = array(0);

            if (APPLICATION_ENV == 'development') {
                Zend_Registry::set($cacheName, $rss_ids);
            } else {
                $cache->save($rss_ids, $cacheName);
            }
        }

        return $rss_ids;
    }

    public function getNetworkBaseSql($select, $params = array()) {
        $select = $this->addPrivacyRssSQl($select, $this->info('name'));
        if (empty($select))
            return;

        $sitenews_tableName = $this->info('name');

        //START NETWORK WORK
        $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.network', 0);

        if (!empty($enableNetwork) || (isset($params['browse_network']) && !empty($params['browse_network']))) {

            $viewer = Engine_Api::_()->user()->getViewer();
            $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
            if (!Zend_Registry::isRegistered('viewerNetworksIdsRss')) {
                $viewerNetworkIds = $networkMembershipTable->getMembershipsOfIds($viewer);
                Zend_Registry::set('viewerNetworksIdsRss', $viewerNetworkIds);
            } else {
                $viewerNetworkIds = Zend_Registry::get('viewerNetworksIdsRss');
            }
            if (!Engine_Api::_()->sitenews()->rssBaseNetworkEnable()) {
                $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

                if (!empty($viewerNetwork)) {
                    if (isset($params['setIntegrity']) && !empty($params['setIntegrity'])) {
                        $select->setIntegrityCheck(false)
                                ->from($sitenews_tableName);
                    }
                    $networkMembershipName = $networkMembershipTable->info('name');
                    $select
                            ->join($networkMembershipName, "`{$sitenews_tableName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
                            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
                            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity());
                    if (!isset($params['not_groupBy']) || empty($params['not_groupBy'])) {
                        $select->group($sitenews_tableName . ".rss_id");
                    }
                    if (isset($params['extension_group']) && !empty($params['extension_group'])) {
                        $select->group($params['extension_group']);
                    }
                }
            } else {
                $viewerNetwork = $networkMembershipTable->getMembershipsOfInfo($viewer);
                $str = array();
                $columnName = "`{$sitenews_tableName}`.networks_privacy";
                foreach ($viewerNetwork as $networkvalue) {
                    $network_id = $networkvalue->resource_id;
                    $str[] = "'" . $network_id . "'";
                    $str[] = "'" . $network_id . ",%'";
                    $str[] = "'%," . $network_id . ",%'";
                    $str[] = "'%," . $network_id . "'";
                }
                if (!empty($str)) {
                    $likeNetworkVale = (string) ( join(" or $columnName  LIKE ", $str) );
                    $select->where($columnName . ' LIKE ' . $likeNetworkVale . ' or ' . $columnName . " IS NULL");
                } else {
                    $select->where($columnName . " IS NULL");
                }
            }
            //END NETWORK WORK
        }

        return $select;
    }

    public function setDefaultImages($toPath, $fromPath) {

        @mkdir(APPLICATION_PATH . $toPath, 0777);
        $dir = APPLICATION_PATH . $fromPath;
        $public_dir = APPLICATION_PATH . $toPath;
        $fieArr = array();
        if (is_dir($dir) && is_dir($public_dir)) {
            $files = scandir($dir);
            foreach ($files as $file) {
                if (strstr($file, '.png') || strstr($file, '.jpg') || strstr($file, '.jpeg')) {
                    $fieArr[] = $file;
                    @copy(APPLICATION_PATH . "$fromPath/$file", APPLICATION_PATH . "$toPath/$file");
                }
            }
            @chmod(APPLICATION_PATH . $toPath, 0777);
        }
        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), '*');
        $rss = $this->fetchAll($select);
        //UPLOAD DEFAULT ICONS
        foreach ($rss as $r) {

            // CREATE AUTH STUFF HERE
            $auth = Engine_Api::_()->authorization()->context;
            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
            $values = array();
            $values['auth_view'] = 'everyone';
            $values['auth_comment'] = 'everyone';
            $values['auth_topic'] = 'everyone';
            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);
            $topicMax = array_search($values['auth_topic'], $roles);
            foreach ($roles as $i => $role) {
                $auth->setAllowed($r, $role, 'view', ($i <= $viewMax));
                $auth->setAllowed($r, $role, 'comment', ($i <= $commentMax));
                $auth->setAllowed($r, $role, 'topic', ($i <= $topicMax));
            }

            $rssUrl = $r->rss_url;
            $iconName = false;
            foreach ($fieArr as $f) {
                if (strstr($f, $rssUrl)) {
                    $iconName = $f;
                    break;
                }
            }
            if ($iconName == false) {
                continue;
            }
            @chmod(APPLICATION_PATH . $toPath, 0777);
            $file = array();

            $file['tmp_name'] = APPLICATION_PATH . "$toPath/$iconName";
            $r->setPhoto($file['tmp_name']);
            $r->save();
        }

        //REMOVE THE CREATED PUBLIC DIRECTORY
        if (is_dir(APPLICATION_PATH . $toPath)) {
            $files = scandir(APPLICATION_PATH . $toPath);
            foreach ($files as $file) {
                $is_exist = file_exists(APPLICATION_PATH . "$toPath/$file");
                if ($is_exist) {
                    @unlink(APPLICATION_PATH . "$toPath/$file");
                }
            }
            @rmdir(APPLICATION_PATH . $toPath);
        }
    }

    public function createDefaultRSS($rss_url, $category_id) {
        $feeds = Zend_Feed_Reader::import($rss_url);
        $params = array();
        $params['category_id'] = $category_id;
        $params['rss_url'] = $rss_url;
        $params['title'] = $feeds->getTitle();
        $params['description'] = $feeds->getDescription();
        $params['owner_id'] = Engine_Api::_()->user()->getViewer()->user_id;
        $params['owner_type'] = 'user';
        $params['auth_view'] = 'everyone';
        $params['auth_comment'] = 'everyone';
        $rss = Engine_Api::_()->getDbtable('rss', 'sitenews')->createRow();
        $rss->setFromArray($params);

        try {
            $rss->save();
            Engine_Api::_()->getItemTable('sitenews_news')->saveNews($rss, true);
        } catch (Exception $ex) {
            
        }
    }

}
