<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Rsssubscriptions.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Model_DbTable_Rsssubscriptions extends Engine_Db_Table {

    public function sendNotifications($news, Sitenews_Model_Rss $rss, $notificationType) {
        
        if (!empty($news) && (!empty($news->draft) || $news->owner_type != 'user')) {
            return $this;
        }

        // Get news owner
        if(!empty($news)) {
            
            $owner = $news->getOwner('user');
        }else{

            $owner = $rss->getOwner('user');
        }

        // Get notification table
        $notificationTable = Engine_Api::_()->getDbtable('notifications', 'activity');

        // Get all subscribers
        $select = $this->select()
                        ->where('rss_id = ?',$rss->getIdentity());
        $data = $this->fetchAll($select)->toArray();

        if(empty($data) || count($data)<=0){

            return;
        }

        $params = array('label' => $rss->title, 'news_title' => !empty($news)?$news->title:null);
        if(empty($params['news_title'])){

            unset($params['news_title']);
        }

        // Send notifications
        foreach ($data as $value) {
            $user = Engine_Api::_()->getItem('user', $value['subscriber_user_id']);
            $notification = json_decode($value['notification'], true);
            if (isset($notification['notification']) && !empty($notification['notification'])) {
                $row = $notificationTable->createRow();
                $row->user_id = $user->getIdentity();
                $row->subject_type = $owner->getType();
                $row->subject_id = $owner->getIdentity();
                $row->object_type = $rss->getType();
                $row->object_id = $rss->getIdentity();
                $row->type = $notificationType;
                $row->params = $params;
                $row->date = date('Y-m-d H:i:s');
                $row->save();
            }
        }

        return $this;
    }

    public function checkSubscription(User_Model_User $user, User_Model_User $subscriber) {
        return (bool) $this->select()
                        ->from($this, new Zend_Db_Expr('TRUE'))
                        ->where('user_id = ?', $user->getIdentity())
                        ->where('subscriber_user_id = ?', $subscriber->getIdentity())
                        ->query()
                        ->fetchColumn();
    }

    public function createSubscription(User_Model_User $user, User_Model_User $subscriber) {
        // Ignore if already subscribed
        if ($this->checkSubscription($user, $subscriber)) {
            return $this;
        }

        // Create
        $this->insert(array(
            'user_id' => $user->getIdentity(),
            'subscriber_user_id' => $subscriber->getIdentity(),
        ));

        return $this;
    }

    public function removeSubscription(User_Model_User $user, User_Model_User $subscriber) {
        // Ignore if already not subscribed
        if (!$this->checkSubscription($user, $subscriber)) {
            return $this;
        }

        // Delete
        $this->delete(array(
            'user_id = ?' => $user->getIdentity(),
            'subscriber_user_id = ?' => $subscriber->getIdentity(),
        ));

        return $this;
    }

    public function getSubscribedUser($rss_id, $user_id = null) {
        $select = $this->select()
                ->from($this->info('name'))
                ->where('rss_id = ?', $rss_id);
        if (!empty($user_id)) {
            $select->where('subscriber_user_id = ?', $user_id);
        }
        return $this->fetchAll($select);
    }

}
