<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: News.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Model_News extends Core_Model_Item_Abstract {

    protected $_parent_type = 'user';
    protected $_owner_type = 'user';
    protected $_searchTriggers = array('title', 'body', 'search');
    protected $_parent_is_owner = true;
    protected $_type = 'sitenews_news';
    protected $_keyWords = null;

    // General 
    public function getShortType($inflect = false) {
        if ($inflect) {
            return 'News';
        }
        return 'news';
    }

    public function getRss() {

        if (!$this->rss)
            return false;

        $rss = Engine_Api::_()->getItem('sitenews_rss', $this->rss);
        return $rss;
    }

    //Get the news tags
    public function getTags() {
        try {
            $tags = "";
            $tagMapTable = Engine_Api::_()->getDbtable('TagMaps', 'core');
            $tagMapTableName = $tagMapTable->info('name');
            $tagTable = Engine_Api::_()->getDbtable('Tags', 'core');
            $tagTableName = $tagTable->info('name');
            $select = $tagMapTable->select()
                    ->from($tagMapTableName, 'tag_id')
                    ->where('resource_id = ?', $this->news_id)
                    ->query()
                    ->fetchAll();

            if ($select) {
                $tags = $tagTable->select()
                        ->from($tagTableName, 'text')
                        ->where('tag_id in (?)', $select)
                        ->query()
                        ->fetchAll();
            }
            return $tags;
        } catch (Exception $e) {
            echo $e;
            die;
        }
    }

    /**
     * Gets an absolute URL to the page to view this item
     *
     * @return string
     */
    public function getHref($params = array()) {
        $slug = $this->getSlug();

        $params = array_merge(array(
            'route' => 'sitenews_entry_view',
            'reset' => true,
            'user_id' => $this->owner_id,
            'news_id' => $this->news_id,
            'slug' => $slug,
                ), $params);
        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        return Zend_Controller_Front::getInstance()->getRouter()
                        ->assemble($params, $route, $reset);
    }

    /**
     * Set news location
     *
     */
    public function setLocation() {

        $id = $this->news_id;

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.location', 0)) {
            $sitenews = $this;
            if (!empty($sitenews))
                $location = $sitenews->location;

            if (!empty($location)) {
                $locationTable = Engine_Api::_()->getDbtable('locations', 'sitenews');
                $locationRow = $locationTable->getLocation(array('id' => $id));

                if (isset($_POST['locationParams']) && $_POST['locationParams']) {
                    if (is_string($_POST['locationParams']))
                        $_POST['locationParams'] = Zend_Json_Decoder::decode($_POST['locationParams']);
                    if ($_POST['locationParams']['location'] === $location) {
                        try {
                            $loctionV = $_POST['locationParams'];
                            $loctionV['news_id'] = $id;
                            $loctionV['zoom'] = 16;
                            if (empty($locationRow))
                                $locationRow = $locationTable->createRow();

                            $locationRow->setFromArray($loctionV);
                            $locationRow->save();
                        } catch (Exception $e) {
                            throw $e;
                        }
                        return;
                    }
                }
                $selectLocQuery = $locationTable->select()->where('location = ?', $location);
                $locationValue = $locationTable->fetchRow($selectLocQuery);

                $enableSocialengineaddon = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('seaocore');

                if (empty($locationValue)) {
                    $getSEALocation = array();
                    if (!empty($enableSocialengineaddon)) {
                        $getSEALocation = Engine_Api::_()->getDbtable('locations', 'seaocore')->getLocation(array('location' => $location));
                    }
                    if (empty($getSEALocation)) {

                        $locationLocal = $location;
                        $urladdress = urlencode($locationLocal);
                        $delay = 0;

                        //ITERATE THROUGH THE ROWS, GEOCODING EACH ADDRESS
                        $geocode_pending = true;
                        while ($geocode_pending) {

                            $request_url = "https://maps.googleapis.com/maps/api/geocode/json?address=$urladdress&sensor=true";

                            $ch = curl_init();
                            $timeout = 5;
                            curl_setopt($ch, CURLOPT_URL, $request_url);
                            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
                            ob_start();
                            curl_exec($ch);
                            curl_close($ch);
                            $doGetContents = ob_get_contents();
                            $json_resopnse = !empty($doGetContents) ? Zend_Json::decode($doGetContents) : array() ;
                            ob_end_clean();
                            $status = $json_resopnse['status'];
                            if (strcmp($status, "OK") == 0) {
                                // Successful geocode
                                $geocode_pending = false;
                                $result = $json_resopnse['results'];

                                // Format: Longitude, Latitude, Altitude
                                $lat = $result[0]['geometry']['location']['lat'];
                                $lng = $result[0]['geometry']['location']['lng'];
                                $f_address = $result[0]['formatted_address'];
                                $len_add = count($result[0]['address_components']);

                                $address = '';
                                $country = '';
                                $state = '';
                                $zip_code = '';
                                $city = '';
                                for ($i = 0; $i < $len_add; $i++) {
                                    $types_location = $result[0]['address_components'][$i]['types'][0];

                                    if ($types_location == 'country') {
                                        $country = $result[0]['address_components'][$i]['long_name'];
                                    } else if ($types_location == 'administrative_area_level_1') {
                                        $state = $result[0]['address_components'][$i]['long_name'];
                                    } else if ($types_location == 'administrative_area_level_2') {
                                        $city = $result[0]['address_components'][$i]['long_name'];
                                    } else if ($types_location == 'postal_code' || $types_location == 'zip_code') {
                                        $zip_code = $result[0]['address_components'][$i]['long_name'];
                                    } else if ($types_location == 'street_address') {
                                        if ($address == '')
                                            $address = $result[0]['address_components'][$i]['long_name'];
                                        else
                                            $address = $address . ',' . $result[0]['address_components'][$i]['long_name'];
                                    }else if ($types_location == 'locality') {
                                        if ($address == '')
                                            $address = $result[0]['address_components'][$i]['long_name'];
                                        else
                                            $address = $address . ',' . $result[0]['address_components'][$i]['long_name'];
                                    }else if ($types_location == 'route') {
                                        if ($address == '')
                                            $address = $result[0]['address_components'][$i]['long_name'];
                                        else
                                            $address = $address . ',' . $result[0]['address_components'][$i]['long_name'];
                                    }else if ($types_location == 'sublocality') {
                                        if ($address == '')
                                            $address = $result[0]['address_components'][$i]['long_name'];
                                        else
                                            $address = $address . ',' . $result[0]['address_components'][$i]['long_name'];
                                    }
                                }

                                try {
                                    $loctionV = array();
                                    $loctionV['news_id'] = $id;
                                    $loctionV['latitude'] = $lat;
                                    $loctionV['location'] = $locationLocal;
                                    $loctionV['longitude'] = $lng;
                                    $loctionV['formatted_address'] = $f_address;
                                    $loctionV['country'] = $country;
                                    $loctionV['state'] = $state;
                                    $loctionV['zipcode'] = $zip_code;
                                    $loctionV['city'] = $city;
                                    $loctionV['address'] = $address;
                                    $loctionV['zoom'] = 16;
                                    if (empty($locationRow))
                                        $locationRow = $locationTable->createRow();

                                    $locationRow->setFromArray($loctionV);
                                    $locationRow->save();
                                    if (!empty($enableSocialengineaddon)) {
                                        $location = Engine_Api::_()->getDbtable('locations', 'seaocore')->setLocation($loctionV);
                                    }
                                } catch (Exception $e) {
                                    throw $e;
                                }
                            } else if (strcmp($status, "620") == 0) {
                                //SENT GEOCODE TO FAST
                                $delay += 100000;
                            } else {
                                // FAILURE TO GEOCODE
                                $geocode_pending = false;
                                echo "Address " . $locationLocal . " failed to geocoded. ";
                                echo "Received status " . $status . "\n";
                            }
                            usleep($delay);
                        }
                    } else {

                        try {
                            //CREATE NEWS LOCATION
                            $loctionV = array();
                            if (empty($locationRow))
                                $locationRow = $locationTable->createRow();
                            $value = $getSEALocation->toarray();
                            unset($value['location_id']);
                            $value['news_id'] = $id;
                            $locationRow->setFromArray($value);
                            $locationRow->save();
                        } catch (Exception $e) {
                            throw $e;
                        }
                    }
                } else {

                    try {
                        //CREATE NEWS LOCATION
                        $loctionV = array();
                        if (empty($locationRow))
                            $locationRow = $locationTable->createRow();
                        $value = $locationValue->toarray();
                        unset($value['location_id']);
                        $value['news_id'] = $id;
                        $locationRow->setFromArray($value);
                        $locationRow->save();
                    } catch (Exception $e) {
                        throw $e;
                    }
                }
            }
        }
    }

    public function getSubscriptionModel() {
        if (empty($this->news_id))
            return false;

        $owner_id = Engine_Api::_()->user()->getViewer()->user_id;
        $subscription = Engine_Api::_()->getDbtable('subscriptions', 'sitenews');
        $subscriptionModel = $subscription->fetchRow($subscription->select()
                        ->where('owner_id = ?', $owner_id)
                        ->where('news_id = ?', $this->news_id));
        if ($subscriptionModel)
            return $subscriptionModel;
        return false;
    }

    public function isSubscribed() {
        if (empty($this->news_id))
            return false;

        $owner_id = Engine_Api::_()->user()->getViewer()->user_id;
        $subscription = Engine_Api::_()->getDbtable('subscriptions', 'sitenews');
        $subscriptionModel = $subscription->fetchRow($subscription->select()
                        ->where('owner_id = ?', $owner_id)
                        ->where('news_id = ?', $this->news_id));
        if ($subscriptionModel)
            return true;
        return false;
    }

    /**
     * Return slug
     * */
    public function getSlug($str = null, $maxstrlen = 64) {

        if (null === $str) {
            $str = $this->title;
        }

        $maxstrlen = 225;

        return Engine_Api::_()->seaocore()->getSlug($str, $maxstrlen);
    }

    public function count() {
        $newsTable = Engine_Api::_()->getItemTable('sitenews_news');
        return $newsTable->select()
                        ->from($newsTable, new Zend_Db_Expr('COUNT(news_id)'))
                        ->where('news_id = ?', $this->news_id)
                        ->limit(1)
                        ->query()
                        ->fetchColumn();
    }

    public function isViewableByNetwork() {
        $regName = 'view_privacy_' . $this->getGuid();
        if (!Zend_Registry::isRegistered($regName)) {
            $flage = true;
            $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.network', 0);
            $viewPricavyEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.networkprofile.privacy', 0);
            $viewer = Engine_Api::_()->user()->getViewer();
            if ($enableNetwork && $viewPricavyEnable && !$this->isOwner($viewer)) {
                $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
                $viewerNetworkIds = $networkMembershipTable->getMembershipsOfIds($viewer);
                if (Engine_Api::_()->sitenews()->rssBaseNetworkEnable()) {
                    if ($this->networks_privacy) {
                        if (!empty($viewerNetworkIds)) {
                            $rssNetworkId = explode(",", $this->networks_privacy);
                            $commanIds = array_intersect($rssNetworkId, $viewerNetworkIds);
                            if (empty($commanIds))
                                $flage = false;
                        } else {
                            $flage = false;
                        }
                    }
                } else {
                    if (!empty($viewerNetworkIds)) {
                        $ownerNetworkIds = $networkMembershipTable->getMembershipsOfIds($this->getOwner('user'));
                        if ($ownerNetworkIds) {
                            $commanIds = array_intersect($ownerNetworkIds, $viewerNetworkIds);
                            if (empty($commanIds))
                                $flage = false;
                        }
                    }
                }
            }
            Zend_Registry::set($regName, $flage);
        } else {
            $flage = Zend_Registry::get($regName);
        }
        return $flage;
    }

    public function canView($user = null) {
        if (!($user instanceof User_Model_User))
            $user = Engine_Api::_()->user()->getViewer();
        $can_view = $this->isViewableByNetwork();

        if ($can_view) {
            $can_view = Engine_Api::_()->authorization()->isAllowed($this->getType(), $user, 'view');
        } else {
            // $can_view = Engine_Api::_()->authorization()->isAllowed($this->getType(), $user, 'edit');
        }
        return $can_view;
    }

    public function getDescription() {
        // @todo decide how we want to handle multibyte string functions
        $tmpBody = strip_tags($this->description);
        return ( Engine_String::strlen($tmpBody) > 255 ? Engine_String::substr($tmpBody, 0, 255) . '...' : $tmpBody );
    }

    public function getKeywords($separator = ' ') {
        if ($this->_keyWords === null) {
            $keywords = array();
            foreach ($this->tags()->getTagMaps() as $tagmap) {
                $tag = $tagmap->getTag();
                $keywords[] = $tag->getTitle();
            }
            $this->_keyWords = $keywords;
        }
        $keywords = $this->_keyWords;
        if (null === $separator) {
            return $keywords;
        }

        return join($separator, $keywords);
    }

    /**
     * Gets a proxy object for the comment handler
     *
     * @return Engine_ProxyObject
     * */
    public function comments() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
    }

    /**
     * Gets a proxy object for the favourite handler
     *
     * @return Engine_ProxyObject
     * */
    public function favourites() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('favourites', 'core'));
    }

    /**
     * Gets a proxy object for the like handler
     *
     * @return Engine_ProxyObject
     * */
    public function likes() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
    }

    /**
     * Gets a url to the current news representing this item. Return null if none
     * set
     *
     * @param string The news type (null -> main, thumb, icon, etc);
     * @return string The photo url
     */
    public function getPhotoUrl($type = null) {
        $photo_id = $this->file_id;
        if (!$photo_id) {
            return null;
        }

        $file = Engine_Api::_()->getItemTable('storage_file')->getFile($photo_id, $type);
        if (!$file) {
            return null;
        }

        return $file->map();
    }

    /**
     * Gets a proxy object for the tags handler
     *
     * @return Engine_ProxyObject
     * */
    public function tags() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('tags', 'core'));
    }

    public function setPhoto($photo, $param = array()) {
        if ($photo instanceof Zend_Form_Element_File) {
            $file = $photo->getFileName();
            $fileName = $file;
        } else if ($photo instanceof Storage_Model_File) {
            $file = $photo->temporary();
            $fileName = $photo->name;
        } else if ($photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id)) {
            $tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
            $file = $tmpRow->temporary();
            $fileName = $tmpRow->name;
        } else if (is_array($photo) && !empty($photo['tmp_name'])) {
            $file = $photo['tmp_name'];
            $fileName = $photo['name'];
        } else if (is_string($photo) && file_exists($photo)) {
            $file = $photo;
            $fileName = $photo;
        } else {
            throw new Zend_Exception("invalid argument passed to setPhoto");
        }
        if (!$fileName) {
            $fileName = basename($file);
        }

        $extension = ltrim(strrchr(basename($fileName), '.'), '.');
        $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
        $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

        $params = array(
            'parent_type' => 'sitenews_news',
            'parent_id' => $this->getIdentity(),
            'user_id' => $this->owner_id,
            'name' => $fileName,
        );

        // Save
        $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
        //Fetching the width and height of thumbmail
        $normalHeight = Engine_Api::_()->getApi('settings', 'core')->getSetting('normal.news.height', 375);
        $normalWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('normal.news.width', 375);
        $largeHeight = Engine_Api::_()->getApi('settings', 'core')->getSetting('normallarge.news.height', 720);
        $largeWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('normallarge.news.width', 720);
        $mainHeight = Engine_Api::_()->getApi('settings', 'core')->getSetting('main.news.height', 1600);
        $mainWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('main.news.height', 1600);


        // Resize image (main)
        $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize($mainWidth, $mainHeight)
                ->write($mainPath)
                ->destroy();

        // Resize image (large)
        $profilePath = $path . DIRECTORY_SEPARATOR . $base . '_l.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize($largeWidth, $largeHeight)
                ->write($profilePath)
                ->destroy();

        // Resize image (normal)
        $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize($normalWidth, $normalHeight)
                ->write($normalPath)
                ->destroy();

        // Resize image (icon)
        $squarePath = $path . DIRECTORY_SEPARATOR . $base . '_is.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file);

        $size = min($image->height, $image->width);
        $x = ($image->width - $size) / 2;
        $y = ($image->height - $size) / 2;

        $image->resample($x, $y, $size, $size, 48, 48)
                ->write($squarePath)
                ->destroy();

        // Store
        $iMain = $filesTable->createFile($mainPath, $params);
        $iProfile = $filesTable->createFile($profilePath, $params);
        $iIconNormal = $filesTable->createFile($normalPath, $params);
        $iSquare = $filesTable->createFile($squarePath, $params);

        $iMain->bridge($iProfile, 'thumb.profile');
        $iMain->bridge($iIconNormal, 'thumb.normal');
        $iMain->bridge($iSquare, 'thumb.icon');
        $iMain->bridge($iMain, 'thumb.main');

        // Remove temp files
        @unlink($mainPath);
        @unlink($profilePath);
        @unlink($normalPath);
        @unlink($squarePath);

        if (!isset($param['setChannelMainPhoto'])) {
            // Update row
            $this->modified_date = date('Y-m-d H:i:s');
            $this->file_id = $iMain->getIdentity();
        }

        if (isset($this->news_cover) && !$this->news_cover) {
            $this->news_cover = $iden;
            $this->save();
        }
        if (isset($param['return']) && $param['return'] == 'photo') {
            return $photoItem;
        }
        return $this;
    }

    public function getNewsCount($params = array()) {

        //MAKE QUERY
        $select = $this->select()
                ->from($this->info('name'), array('COUNT(*) AS count'));


        if (isset($params['category_id'])) {
            $select->where("category_id =?", $params['category_id']);
        }


        $totalNews = $select->query()->fetchColumn();

        //RETURN NEWS COUNT
        return $totalNews;
    }

    public function getParent($recurseType = null) {

        if (isset($this->rss) && $this->rss) {
            return Engine_Api::_()->getItem('sitenews_rss', $this->rss);
        }

        parent::getParent();
    }

    public function getRichContent($view = false, $params = array()) {
        $session = new Zend_Session_Namespace('mobile');
        $mobile = $session->mobile;

        // $view == false means that this rich content is requested from the activity feed
        if ($view == false) {
            // prepare the thumbnail
            if ($this->file_id) {
                $thumb = Zend_Registry::get('Zend_View')->itemPhoto($this, null, null);
                $addOverlay = '<span class="news_overlay"></span>';
            } else {
                $thumb = '<img alt="" src="' . Zend_Registry::get('StaticBaseUrl') . 'application/modules/Sitenews/externals/images/news_default.png">';
                $addOverlay = '';
            }

            if (!$mobile) {
                $thumb = '<a class="Sitenews_thumb" id="news_thumb_' . $this->news_id . '" style="" href="' . $this->getHref() . '">
                  <div class="sitenews_thumb_wrapper sitenews_thumb_viewer">' . $addOverlay . $thumb . '</div>
                  </a>';
            } else {
                $thumb = '<a class="Sitenews_thumb" id="news_thumb_' . $this->news_id . '" class="news_thumb" href="' . $this->getHref() . '">
                  <div class="sitenews_thumb_wrapper sitenews_thumb_viewer">' . $addOverlay . $thumb . '</div>
                  </a>';
            }

            // prepare title and description
            $title = "<div class='feed_item_link_title'><a class='sea_add_tooltip_link feed_news_title' rel= \"" . $this->getType() . ' ' . $this->getIdentity() . "\" href='" . $this->getHref($params) . "' >$this->title</a></div>";
            $tmpBody = strip_tags($this->description);
            $description = "<div class='sitenews_desc'>" . (Engine_String::strlen($tmpBody) > 255 ? Engine_String::substr($tmpBody, 0, 255) . '...' : $tmpBody) . "</div>";

            $newsEmbedded = $thumb . '<div class="news_info">' . $title . $description . '</div>';
        }

        return $newsEmbedded;
    }

}
