<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Rss.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Model_Rss extends Core_Model_Item_Abstract {

    protected $_parent_type = 'user';
    protected $_owner_type = 'user';
    protected $_parent_is_owner = true;
    protected $_type = 'sitenews_rss';

    public function getShortType($inflect = false) {
        if ($inflect) {
            return 'RSS';
        }
        return 'rss';
    }

    public function getTitle() {
        return $this->title;
    }

    public function getSubscriptionModel() {
        if (empty($this->rss_id))
            return false;

        $owner_id = Engine_Api::_()->user()->getViewer()->user_id;
        $subscription = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');
        $subscriptionModel = $subscription->fetchRow($subscription->select()
                        ->where('subscriber_user_id = ?', $owner_id)
                        ->where('rss_id = ?', $this->rss_id));
        if ($subscriptionModel)
            return $subscriptionModel;
        return false;
    }

    public function isSubscribed() {
        if (empty($this->rss_id))
            return false;

        $subscription = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');

        $select = $subscription->select()
                ->where('rss_id = ?', $this->rss_id);

        if (Engine_Api::_()->user()->getViewer()) {
            $select = $select->where('subscriber_user_id = ?', Engine_Api::_()->user()->getViewer()->getIdentity());
        }

        $subscriptionModel = $subscription->fetchRow($select);

        if ($subscriptionModel)
            return true;
        return false;
    }

    public function getType($inflect = false) {
        if ($inflect) {
            return str_replace(' ', '', ucwords(str_replace('_', ' ', $this->_type)));
        }

        return $this->_type;
    }

    public function getOwner($recurseType = null) {
        $owner = Engine_Api::_()->getItem('user', $this->owner_id);
        return $owner;
    }

    /**
     * Gets an absolute URL to the store to view this item
     *
     * @return string
     */
    public function getHref($params = array()) {
        $slug = $this->getSlug();
        $params = array_merge(array(
            'route' => 'sitenews_rss_view',
            'reset' => true,
            'rss_id' => $this->rss_id,
                ), $params);
        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        $urlO = Zend_Controller_Front::getInstance()->getRouter()->assemble($params, $route, $reset);
        return $urlO;
    }

    /**
     * Return slug
     * */
    public function getSlug($str = null, $maxstrlen = 64) {

        if (null === $str) {
            $str = $this->title;
        }

        $maxstrlen = 225;

        return Engine_Api::_()->seaocore()->getSlug($str, $maxstrlen);
    }

    /**
     * Gets a url to the current rss representing this item. Return null if none
     * set
     *
     * @param string The rss type (null -> main, thumb, icon, etc);
     * @return string The rss url
     */
    public function getPhotoUrl($type = null) {
        $photo_id = $this->file_id;
        if (!$photo_id) {
            return null;
        }

        $file = Engine_Api::_()->getItemTable('storage_file')->getFile($photo_id, $type);
        if (!$file) {
            return null;
        }

        return $file->map();
    }

    public function getFirstNews() {
        $rssTable = Engine_Api::_()->getItemTable('sitenews_rss');
        $select = $rssTable->select()
                ->where('rss_id = ?', $this->rss_id)
                ->order('order ASC')
                ->limit(1);
        return $rssTable->fetchRow($select);
    }

    public function getLastNews() {
        $rssTable = Engine_Api::_()->getItemTable('sitenews_rss');
        $select = $rssTable->select()
                ->where('rss_id = ?', $this->rss_id)
                ->order('order DESC')
                ->limit(1);
        return $rssTable->fetchRow($select);
    }

    public function feedsCount() {
        $rss_id = $this->rss_id;
        $newsTable = Engine_Api::_()->getItemTable('sitenews_news');
        return $newsTable->select()
                        ->from($newsTable->info('name'), new Zend_Db_Expr('COUNT(news_id)'))
                        ->where('rss = ?', $rss_id)
                        ->limit(1)
                        ->query()
                        ->fetchColumn();
    }

    public function count() {
        $newsTable = Engine_Api::_()->getItemTable('sitenews_news');
        return $rssTable->select()
                        ->from($rssTable, new Zend_Db_Expr('COUNT(news_id)'))
                        ->where('news_id = ?', $this->news_id)
                        ->limit(1)
                        ->query()
                        ->fetchColumn();
    }

    /**
     * Gets a proxy object for the comment handler
     *
     * @return Engine_ProxyObject
     * */
    public function comments() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
    }

    /**
     * Gets a proxy object for the like handler
     *
     * @return Engine_ProxyObject
     * */
    public function likes() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
    }

    /**
     * Gets a proxy object for the tags handler
     *
     * @return Engine_ProxyObject
     * */
    public function tags() {

        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('tags', 'core'));
    }

    public function isViewableByNetwork() {
        $regName = 'view_privacy_' . $this->getGuid();
        if (!Zend_Registry::isRegistered($regName)) {
            $flage = true;
            $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.network', 0);
            $viewPricavyEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.networkprofile.privacy', 0);
            $viewer = Engine_Api::_()->user()->getViewer();
            if ($enableNetwork && $viewPricavyEnable && !$this->isOwner($viewer)) {
                $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
                $viewerNetworkIds = $networkMembershipTable->getMembershipsOfIds($viewer);
                if (Engine_Api::_()->sitenews()->rssBaseNetworkEnable()) {
                    if ($this->networks_privacy) {
                        if (!empty($viewerNetworkIds)) {
                            $rssNetworkId = explode(",", $this->networks_privacy);
                            $commanIds = array_intersect($rssNetworkId, $viewerNetworkIds);
                            if (empty($commanIds))
                                $flage = false;
                        } else {
                            $flage = false;
                        }
                    }
                } else {
                    if (!empty($viewerNetworkIds)) {
                        $ownerNetworkIds = $networkMembershipTable->getMembershipsOfIds($this->getOwner('user'));
                        if ($ownerNetworkIds) {
                            $commanIds = array_intersect($ownerNetworkIds, $viewerNetworkIds);
                            if (empty($commanIds))
                                $flage = false;
                        }
                    }
                }
            }
            Zend_Registry::set($regName, $flage);
        } else {
            $flage = Zend_Registry::get($regName);
        }
        return $flage;
    }

    public function getSingletonAlbum() {
        $table = Engine_Api::_()->getItemTable('sitenews_album');
        $select = $table->select()
                ->where('rss_id = ?', $this->getIdentity())
                ->order('album_id ASC')
                ->limit(1);

        $album = $table->fetchRow($select);

        if (null == $album) {
            $album = $table->createRow();
            $album->setFromArray(array(
                'title' => $this->getTitle(),
                'rss_id' => $this->getIdentity()
            ));
            $album->save();
        }

        return $album;
    }

    public function setPhoto($photo, $param = array()) {
        if ($photo instanceof Zend_Form_Element_File) {
            $file = $photo->getFileName();
            $fileName = $file;
        } else if ($photo instanceof Storage_Model_File) {
            $file = $photo->temporary();
            $fileName = $photo->name;
        } else if ($photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id)) {
            $tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
            $file = $tmpRow->temporary();
            $fileName = $tmpRow->name;
        } else if (is_array($photo) && !empty($photo['tmp_name'])) {
            $file = $photo['tmp_name'];
            $fileName = $photo['name'];
        } else if (is_string($photo) && file_exists($photo)) {
            $file = $photo;
            $fileName = $photo;
        } else {
            throw new Zend_Exception("invalid argument passed to setPhoto");
        }
        if (!$fileName) {
            $fileName = basename($file);
        }

        $extension = ltrim(strrchr(basename($fileName), '.'), '.');
        $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
        $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

        $params = array(
            'parent_type' => 'sitenews_rss',
            'parent_id' => $this->getIdentity(),
            'user_id' => $this->owner_id,
            'name' => $fileName,
        );

        // Save
        $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
        //Fetching the width and height of thumbmail
        $normalHeight = Engine_Api::_()->getApi('settings', 'core')->getSetting('normal.news.height', 375);
        $normalWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('normal.news.width', 375);
        $largeHeight = Engine_Api::_()->getApi('settings', 'core')->getSetting('normallarge.news.height', 720);
        $largeWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('normallarge.news.width', 720);
        $mainHeight = Engine_Api::_()->getApi('settings', 'core')->getSetting('main.news.height', 1600);
        $mainWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('main.news.height', 1600);

        // Resize image (main)
        $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize($mainWidth, $mainHeight)
                ->write($mainPath)
                ->destroy();

        // Resize image (large)
        $profilePath = $path . DIRECTORY_SEPARATOR . $base . '_l.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize($largeWidth, $largeHeight)
                ->write($profilePath)
                ->destroy();

        // Resize image (normal)
        $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize($normalWidth, $normalHeight)
                ->write($normalPath)
                ->destroy();

        // Resize image (icon)
        $squarePath = $path . DIRECTORY_SEPARATOR . $base . '_is.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file);

        $size = min($image->height, $image->width);
        $x = ($image->width - $size) / 2;
        $y = ($image->height - $size) / 2;

        $image->resample($x, $y, $size, $size, 48, 48)
                ->write($squarePath)
                ->destroy();

        // Store
        $iMain = $filesTable->createFile($mainPath, $params);
        $iProfile = $filesTable->createFile($profilePath, $params);
        $iIconNormal = $filesTable->createFile($normalPath, $params);
        $iSquare = $filesTable->createFile($squarePath, $params);

        $iMain->bridge($iProfile, 'thumb.profile');
        $iMain->bridge($iIconNormal, 'thumb.normal');
        $iMain->bridge($iSquare, 'thumb.icon');
        $iMain->bridge($iMain, 'thumb.main');

        // Remove temp files
        @unlink($mainPath);
        @unlink($profilePath);
        @unlink($normalPath);
        @unlink($squarePath);

        //ADD TO ALBUM
        $viewer = Engine_Api::_()->user()->getViewer();

        $photoTable = Engine_Api::_()->getItemTable('sitenews_photo');
        $rows = $photoTable->fetchRow($photoTable->select()->from($photoTable->info('name'), 'order')->order('order DESC')->limit(1));
        $order = 0;
        if (!empty($rows)) {
            $order = $rows->order + 1;
        }
        $sitephotoAlbum = $this->getSingletonAlbum();
        $photoItem = $photoTable->createRow();
        $photoItem->setFromArray(array(
            'rss_id' => $this->getIdentity(),
            'album_id' => $sitephotoAlbum->getIdentity(),
            'user_id' => $viewer->getIdentity(),
            'file_id' => $iMain->getIdentity(),
            'collection_id' => $sitephotoAlbum->getIdentity(),
            'order' => $order
        ));
        $iden = $photoItem->save();
        if (!empty($param['setRssLogo'])) {
            // Update row
            $this->modified_date = date('Y-m-d H:i:s');
            $this->file_id = $iMain->getIdentity();
            $this->save();
        }

        if (isset($this->rss_cover) && !$this->rss_cover) {
            $this->rss_cover = $iden;
            $this->save();
        }
        if (isset($param['return']) && $param['return'] == 'photo') {
            return $photoItem;
        }
        return $this;
    }

    public function canView($user = null) {
        if (!($user instanceof User_Model_User))
            $user = Engine_Api::_()->user()->getViewer();
        $can_view = $this->isViewableByNetwork();

        if ($can_view) {
            $can_view = Engine_Api::_()->authorization()->isAllowed($this->getType(), $user, 'view');
        } else {
            // $can_view = Engine_Api::_()->authorization()->isAllowed($this->getType(), $user, 'edit');
        }
        return $can_view;
    }

}
