<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminLevelController.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_AdminLevelController extends Core_Controller_Action_Admin {

    public function indexAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_level_news) || empty($level_news)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_level');

        $this->view->navigation_rss = $navigation_rss = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_main_level', array(), 'sitenews_admin_main_level_news');

        // Get level id
        if (null !== ($id = $this->_getParam('id'))) {
            $level = Engine_Api::_()->getItem('authorization_level', $id);
        } else {
            $level = Engine_Api::_()->getItemTable('authorization_level')->getDefaultLevel();
        }

        if (!$level instanceof Authorization_Model_Level) {
            throw new Engine_Exception('missing level');
        }

        $id = $level->level_id;

        // Make form
        $this->view->form = $form = new Sitenews_Form_Admin_Settings_Level_Level(array(
            'public' => ( in_array($level->type, array('public')) ),
            'moderator' => ( in_array($level->type, array('admin', 'moderator')) ),
        ));
        $form->level_id->setValue($id);

        // Populate values
        $permissionsTable = Engine_Api::_()->getDbtable('permissions', 'authorization');
        $form->populate($permissionsTable->getAllowed('sitenews_news', $id, array_keys($form->getValues())));

        // Check post
        if (!$this->getRequest()->isPost()) {
            return;
        }

        // Check validitiy
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        // Process

        $values = $form->getValues();

        $db = $permissionsTable->getAdapter();
        $db->beginTransaction();

        try {
            // Set permissions
            $permissionsTable->setAllowed('sitenews_news', $id, $values);

            // Commit
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $form->addNotice('Your changes have been saved.');
    }

    public function rssAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_level_rss) || empty($level_rss)){
            
            $this->_helper->content->setNoRender();
            return;
        }        
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_level');

        $this->view->navigation_rss = $navigation_rss = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_main_level', array(), 'sitenews_admin_main_level_rss');

        // Get level id
        if (null !== ($id = $this->_getParam('id'))) {
            $level = Engine_Api::_()->getItem('authorization_level', $id);
        } else {
            $level = Engine_Api::_()->getItemTable('authorization_level')->getDefaultLevel();
        }

        if (!$level instanceof Authorization_Model_Level) {
            throw new Engine_Exception('missing level');
        }

        $id = $level->level_id;
        // Make form
        $this->view->form = $form = new Sitenews_Form_Admin_Settings_Level_Rss(array(
            'public' => ( in_array($level->type, array('public')) ),
            'moderator' => ( in_array($level->type, array('admin', 'moderator')) ),
        ));
        $rssEnabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 0);
        if(!$rssEnabled){
            return;
        }
        $form->level_id->setValue($id);

        // Populate values
        $permissionsTable = Engine_Api::_()->getDbtable('permissions', 'authorization');
        $form->populate($permissionsTable->getAllowed('sitenews_rss', $id, array_keys($form->getValues())));

        // Check post
        if (!$this->getRequest()->isPost()) {
            return;
        }

        // Check validitiy
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        // Process

        $values = $form->getValues();

        $db = $permissionsTable->getAdapter();
        $db->beginTransaction();

        try {
            // Set permissions
            $permissionsTable->setAllowed('sitenews_rss', $id, $values);

            // Commit
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $form->addNotice('Your changes have been saved.');
    }

}
