<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminManageController.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_AdminManageController extends Core_Controller_Action_Admin {

    //multi Delete BlackList Url
    public function multiDeleteBlacklistAction() {
        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            try {
                $db = Zend_Db_Table_Abstract::getDefaultAdapter();
                $table = Engine_Api::_()->getDbtable('blacklisturls', 'sitenews');
                $db->beginTransaction();
                foreach ($values as $key => $value) {
                    if ($key == 'delete_' . $value) {
                        $table->delete(array('blacklisturls_id = ?' => $value));
                    }
                }
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                echo $e;
            }
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'manage-blacklist-urls'));
    }

    // Delete single Blacklist Url    
    public function deleteBlacklisturlsAction() {

        // In smoothbox
        $this->_helper->layout->setLayout('admin-simple');
        $this->view->blacklisturls_id = $this->_getParam('id');

        // Check post
        if ($this->getRequest()->isPost()) {

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();

            try {
                $blackListUrl = Engine_Api::_()->getItem('sitenews_blacklisturl', $this->view->blacklisturls_id);
                $blackListUrl->delete();
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array('Blacklist Url has been deleted Successfully.')
            ));
        }

        // Output
        $this->renderScript('admin-manage/delete-blacklisturl.tpl');
    }

    public function enableBlacklistAction() {

        $blackListTable = Engine_Api::_()->getDbtable('blacklisturls', 'sitenews');
        $where = array('blacklisturls_id=?' => $this->getParam('blacklisturls_id'));
        if ($this->getParam('enabled') == 1) {
            $blackListTable->update(array('enabled' => 1), $where);
        } else {
            $blackListTable->update(array('enabled' => 0), $where);
        }
        $this->_redirect('admin/sitenews/manage/manage-blacklist-urls');
    }

    // create a blacklisted url
    public function addBlacklisturlsAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_blacklist_add) || empty($blacklist_add)){
            
            $this->_helper->content->setNoRender();
            return;
        }        
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_blacklisturls');
        $this->view->form = $form = new Sitenews_Form_Admin_Manage_AddBlacklisturl();
        if ($this->getRequest()->isPost() && $form->isValid($this->_getAllParams())) {
            $table = Engine_Api::_()->getDbtable('blacklisturls', 'sitenews');
            $blacklisturl = $table->createRow();
            $blacklisturl->setFromArray($form->getValues());
            $blacklisturl->save();
            $this->_redirect('admin/sitenews/manage/manage-blacklist-urls');
        }
    }

    // Admin: Manage BlackList Urls 
    public function manageBlacklistUrlsAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_manage_blacklist) || empty($manage_blacklist)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_blacklisturls');
        //MAKE FORM
        $this->view->formFilter = $formFilter = new Sitenews_Form_Admin_Manage_Blacklisturl();

        if ($formFilter->isValid($this->_getAllParams())) {
            $values = $formFilter->getValues();
        }
        
        foreach ($values as $key => $value) {
            if (null === $value) {
                unset($values[$key]);
            }
        }

        $blackListTable = Engine_Api::_()->getDbtable('blacklisturls', 'sitenews');
        $blackListTableName = $blackListTable->info('name');

        //MAKE QUERY
        $select = $blackListTable->select()
                ->setIntegrityCheck(false)
                ->from($blackListTableName);

        $this->view->blacklisturls_url = "";
        $this->view->enabled = "";

        if (!empty($_POST['blacklisturls_url'])) {
            $select->where('blacklisturls_url LIKE ? ', '%' . $_POST['blacklisturls_url'] . '%');
            $this->view->blacklisturls_url = $_POST['blacklisturls_url'];
        }

        if (!empty($_POST['blacklisturls_name'])) {
            $select->where('name LIKE ? ', '%' . $_POST['blacklisturls_name'] . '%');
            $this->view->blacklisturls_name = $_POST['blacklisturls_name'];
        }        

        if (isset($_POST['enabled']) && ($_POST['enabled'] != "")) {
            $select->where('enabled = ? ', $_POST['enabled']);
            $this->view->enabled = $_POST['enabled'];
        }

        $values = array_merge(array('order' => 'blacklisturls_id', 'order_direction' => 'DESC'), $values);

        $select->order((!empty($values['order']) ? $values['order'] : 'blacklisturls_id' ) . ' ' . (!empty($values['order_direction']) ? $values['order_direction'] : 'DESC' ));
        $this->view->order = (!empty($values['order']) ? $values['order'] : 'blacklisturls_id' );
        $this->view->order_direction =(!empty($values['order_direction']) ? $values['order_direction'] : 'DESC' );

        $this->view->assign($values);

        $valuesCopy = array_filter($values);

        // MAKE PAGINATOR
        $this->view->paginator = $paginator = Zend_Paginator::factory($select);
        $this->view->paginator = $paginator->setItemCountPerPage(20);
        $this->view->paginator = $paginator->setCurrentPageNumber($this->_getParam('page', 1));
        $this->view->formValues = $valuesCopy;
    }

    public function indexAction() {
        
        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_manage_news) || empty($manage_news)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_manage');

        $this->view->navigation_rss = $navigation_rss = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_admin_main_manage', array(), 'sitenews_admin_main_manage_news');

        //MAKE FORM
        $this->view->formFilter = $formFilter = new Sitenews_Form_Admin_Manage_Filter();

        if ($formFilter->isValid($this->_getAllParams())) {
            $values = $formFilter->getValues();
        }

        foreach ($values as $key => $value) {
            if (null === $value) {
                unset($values[$key]);
            }
        }

        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $newsTableName = $newsTable->info('name');

        //GET USER TABLE NAME
        $tableUserName = Engine_Api::_()->getItemTable('user')->info('name');

        //GET CATEGORY TABLE
        $tableCategoryName = Engine_Api::_()->getDbtable('categories', 'sitenews')->info('name');

        $select = $newsTable->select();
        //MAKE QUERY
        $select = $newsTable->select()
                ->setIntegrityCheck(false)
                ->from($newsTableName)
                ->joinLeft($tableUserName, "$newsTableName.owner_id = $tableUserName.user_id", 'username')
                ->joinLeft($tableCategoryName, "$newsTableName.category_id = $tableCategoryName.category_id", 'category_name')
                ->group("$newsTableName.news_id");

        // searching
        $this->view->owner = '';
        $this->view->title = '';
        $this->view->newsbrowse = '';
        $this->view->category_id = '';
        $this->view->subcategory_id = '';
        $this->view->subsubcategory_id = '';
        //GET CATEGORY TABLE
        $this->view->tableCategory = $tableCategory = Engine_Api::_()->getDbtable('categories', 'sitenews');
        if (!empty($_POST['title'])) {
            $this->view->title = $_POST['title'];
            $select->where($newsTableName . '.title  LIKE ?', '%' . $_POST['title'] . '%');
        }

        if (!empty($_POST['owner'])) {
            $owner = $this->view->owner = $_POST['owner'];
            $select->where("$tableUserName.username  LIKE '%$owner%' OR $tableUserName.displayname  LIKE '%$owner%'");
        }

        $rss_id = $this->_getParam('rss_id');
        if (!empty($_POST['rss_id']) || !empty($rss_id)) {
            if ($_POST['rss_id']) {
                $rss_id = $this->view->rss_id = $_POST['rss_id'];
            } elseif ($this->_getParam('rss_id')) {
                $rss_id = $this->view->rss_id = $this->_getParam('rss_id');
            }
            $select->where("$newsTableName.rss  = ? ", $rss_id);
        }
        $popularity = $this->_getParam('popularity');
        if (!empty($_POST['popularity']) || !empty($popularity)) {
            if ($_POST['popularity']) {
                $popularity = $this->view->popularity = $_POST['popularity'];
            } elseif ($this->_getParam('rss_id')) {
                $popularity = $this->view->popularity = $this->_getParam('popularity');
            }

            $select->where("$newsTableName." . $popularity . "  = 1");
        }

        if (!empty($_POST['category_id']) && empty($_POST['subcategory_id']) && empty($_POST['subsubcategory_id'])) {
            $this->view->category_id = $_POST['category_id'];
            $select->where($newsTableName . '.category_id = ? ', $_POST['category_id']);
        } elseif (!empty($_POST['category_id']) && !empty($_POST['subcategory_id']) && empty($_POST['subsubcategory_id'])) {
            $this->view->category_id = $_POST['category_id'];
            $this->view->subcategory_id = $_POST['subcategory_id'];
            $this->view->subcategory_name = $tableCategory->getCategory($this->view->subcategory_id)->category_name;

            $select->where($newsTableName . '.category_id = ? ', $_POST['category_id'])
                    ->where($newsTableName . '.subcategory_id = ? ', $_POST['subcategory_id']);
        } elseif (!empty($_POST['category_id']) && !empty($_POST['subcategory_id']) && !empty($_POST['subsubcategory_id'])) {
            $this->view->category_id = $_POST['category_id'];
            $this->view->subcategory_id = $_POST['subcategory_id'];
            $this->view->subsubcategory_id = $_POST['subsubcategory_id'];
            $this->view->subcategory_name = $tableCategory->getCategory($this->view->subcategory_id)->category_name;
            $this->view->subsubcategory_name = $tableCategory->getCategory($this->view->subsubcategory_id)->category_name;

            $select->where($newsTableName . '.category_id = ? ', $_POST['category_id'])
                    ->where($newsTableName . '.subcategory_id = ? ', $_POST['subcategory_id'])
                    ->where($newsTableName . '.subsubcategory_id = ? ', $_POST['subsubcategory_id']);
        }

        if (!empty($_POST['newsbrowse'])) {
            $this->view->newsbrowse = $_POST['newsbrowse'];
            if ($_POST['newsbrowse'] == 1) {
                $select->order($newsTableName . '.news_id DESC');
            } elseif ($_POST['newsbrowse'] == 2) {
                $select->order($newsTableName . '.subscribe_count DESC');
            } elseif ($_POST['newsbrowse'] == 3) {
                $select->order($newsTableName . '.like_count DESC');
            } elseif ($_POST['newsbrowse'] == 4) {
                $select->order($newsTableName . '.comment_count DESC');
            }
        }

        $values = array_merge(array('order' => 'news_id', 'order_direction' => 'DESC'), $values);

        $select->order((!empty($values['order']) ? $values['order'] : 'news_id' ) . ' ' . (!empty($values['order_direction']) ? $values['order_direction'] : 'DESC' ));

        $this->view->assign($values);

        $values = array_filter($values);

        // MAKE PAGINATOR
        $this->view->paginator = $paginator = Zend_Paginator::factory($select);
        $this->view->paginator = $paginator->setItemCountPerPage(20);
        $this->view->paginator = $paginator->setCurrentPageNumber($this->_getParam('page', 1));
        $this->view->formValues = $values;
    }

    public function approveNewsAction() {
        $news = Engine_Api::_()->getItem('sitenews_news', $this->getParam('news_id'));
        if ($this->getParam('approve') == 1) {
            $news->published = 1;
            $news->save();
        } else {
            $news->published = 0;
            $news->save();
        }
        $this->_redirect('admin/sitenews/manage');
    }

    public function approveRssAction() {
        $rss = Engine_Api::_()->getItem('sitenews_rss', $this->getParam('rss_id'));
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $where = array('rss=?' => $this->getParam('rss_id'));
        if ($this->getParam('approve') == 1) {
            $rss->published = 1;
            $rss->save();
            $newsTable->update(array('published' => 1), $where);
        } else {
            $rss->published = 0;
            $rss->save();
            $newsTable->update(array('published' => 0), $where);
        }
        $this->_redirect('admin/sitenews/manage/rss');
    }

    //Edit Rss: Cron (Enable/Disable)
    public function cronRssAction() {
        $rss = Engine_Api::_()->getItem('sitenews_rss', $this->getParam('rss_id'));
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $where = array('rss=?' => $this->getParam('rss_id'));
        if ($this->getParam('approve') == 1) {
            $rss->cron_update = 1;
            $rss->save();
        } else {
            $rss->cron_update = 0;
            $rss->save();
        }
        $this->_redirect('admin/sitenews/manage/rss');
    }

    public function rssAction() {
        
        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_manage_rss) || empty($manage_rss)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_manage');

        $this->view->navigation_rss = $navigation_rss = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_admin_main_manage', array(), 'sitenews_admin_main_manage_rss');

        //MAKE FORM
        $this->view->rssEnabled = $rssEnabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 0);
        if (!$rssEnabled) {
            $this->view->rssErrorMessage = 'Enable RSS from “Global Settings → RSS Settings” to manage RSS.';
            return;
        }
        $this->view->formFilter = $formFilter = new Sitenews_Form_Admin_Manage_Filter();

        if ($formFilter->isValid($this->_getAllParams())) {
            $values = $formFilter->getValues();
        }

        foreach ($values as $key => $value) {
            if (null === $value) {
                unset($values[$key]);
            }
        }

        $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
        $rssTableName = $rssTable->info('name');

        //GET USER TABLE NAME
        $tableUserName = Engine_Api::_()->getItemTable('user')->info('name');

        //GET CATEGORY TABLE
        $tableCategoryName = Engine_Api::_()->getDbtable('categories', 'sitenews')->info('name');

        $select = $rssTable->select();
        //MAKE QUERY
        $select = $rssTable->select()
                ->setIntegrityCheck(false)
                ->from($rssTableName)
                ->joinLeft($tableUserName, "$rssTableName.owner_id = $tableUserName.user_id", 'username')
                ->joinLeft($tableCategoryName, "$rssTableName.category_id = $tableCategoryName.category_id", 'category_name')
                ->group("$rssTableName.rss_id");

        // searching
        $this->view->owner = '';
        $this->view->title = '';
        $this->view->rssbrowse = '';
        $this->view->category_id = '';
        $this->view->subcategory_id = '';
        $this->view->subsubcategory_id = '';
        //GET CATEGORY TABLE
        $this->view->tableCategory = $tableCategory = Engine_Api::_()->getDbtable('categories', 'sitenews');
        if (!empty($_POST['title'])) {
            $this->view->title = $_POST['title'];
            $select->where($rssTableName . '.title  LIKE ?', '%' . $_POST['title'] . '%');
        }

        if (!empty($_POST['owner'])) {
            $owner = $this->view->owner = $_POST['owner'];
            $select->where("$tableUserName.username  LIKE '%$owner%' OR $tableUserName.displayname  LIKE '%$owner%'");
        }

        if (!empty($_POST['category_id']) && empty($_POST['subcategory_id']) && empty($_POST['subsubcategory_id'])) {
            $this->view->category_id = $_POST['category_id'];
            $select->where($rssTableName . '.category_id = ? ', $_POST['category_id']);
        } elseif (!empty($_POST['category_id']) && !empty($_POST['subcategory_id']) && empty($_POST['subsubcategory_id'])) {
            $this->view->category_id = $_POST['category_id'];
            $this->view->subcategory_id = $_POST['subcategory_id'];
            $this->view->subcategory_name = $tableCategory->getCategory($this->view->subcategory_id)->category_name;

            $select->where($rssTableName . '.category_id = ? ', $_POST['category_id'])
                    ->where($rssTableName . '.subcategory_id = ? ', $_POST['subcategory_id']);
        } elseif (!empty($_POST['category_id']) && !empty($_POST['subcategory_id']) && !empty($_POST['subsubcategory_id'])) {
            $this->view->category_id = $_POST['category_id'];
            $this->view->subcategory_id = $_POST['subcategory_id'];
            $this->view->subsubcategory_id = $_POST['subsubcategory_id'];
            $this->view->subcategory_name = $tableCategory->getCategory($this->view->subcategory_id)->category_name;
            $this->view->subsubcategory_name = $tableCategory->getCategory($this->view->subsubcategory_id)->category_name;

            $select->where($rssTableName . '.category_id = ? ', $_POST['category_id'])
                    ->where($rssTableName . '.subcategory_id = ? ', $_POST['subcategory_id'])
                    ->where($rssTableName . '.subsubcategory_id = ? ', $_POST['subsubcategory_id']);
        }

        if (!empty($_POST['rssbrowse'])) {
            $this->view->rssbrowse = $_POST['rssbrowse'];
            if ($_POST['rssbrowse'] == 1) {
                $select->order($rssTableName . '.rss_id DESC');
            } elseif ($_POST['rssbrowse'] == 2) {
                $select->order($rssTableName . '.subscribe_count DESC');
            } elseif ($_POST['rssbrowse'] == 3) {
                $select->order($rssTableName . '.like_count DESC');
            } elseif ($_POST['rssbrowse'] == 4) {
                $select->order($rssTableName . '.comment_count DESC');
            }
        }

        $values = array_merge(array('order' => 'rss_id', 'order_direction' => 'DESC'), $values);

        $select->order((!empty($values['order']) ? $values['order'] : 'rss_id' ) . ' ' . (!empty($values['order_direction']) ? $values['order_direction'] : 'DESC' ));

        $this->view->assign($values);

        $valuesCopy = array_filter($values);

        // MAKE PAGINATOR
        $this->view->paginator = $paginator = Zend_Paginator::factory($select);
        $this->view->paginator = $paginator->setItemCountPerPage(20);
        $this->view->paginator = $paginator->setCurrentPageNumber($this->_getParam('page', 1));
        $this->view->formValues = $valuesCopy;
    }

    public function deleteAction() {
        // In smoothbox
        $this->_helper->layout->setLayout('admin-simple');
        $id = $this->_getParam('id');
        $this->view->news_id = $id;

        // Check post
        if ($this->getRequest()->isPost()) {

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();

            try {
                $sitenews = Engine_Api::_()->getItem('sitenews_news', $id);
                if ($sitenews->rss != 0) {
                    $rss = Engine_Api::_()->getItem('sitenews_rss', $sitenews->rss);
                    $old_count = $rss->feeds_count;
                }
                // delete the news entry into the database
                $sitenews->delete();
                $rss->feeds_count = $old_count - 1;
                $rss->save();
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array('')
            ));
        }

        // Output
        $this->renderScript('admin-manage/delete.tpl');
    }

    public function multiDeleteAction() {
        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            try {
                $db = Zend_Db_Table_Abstract::getDefaultAdapter();
                $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
                $rssItems = $rssTable->fetchAll();
                $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
                $db->beginTransaction();
                foreach ($values as $key => $value) {
                    if ($key == 'delete_' . $value) {
                        $newsTable->delete(array('news_id = ?' => $value));
                    }
                }
                foreach ($rssItems as $item) {
                    $rssItem = Engine_Api::_()->getItem('sitenews_rss', $item['rss_id']);
                    $rssItem->feeds_count = $rssItem->feedsCount();
                    $rssItem->save();
                }
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                echo $e;
            }
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }

    public function multiDeleteRssAction() {
        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            try {
                $db = Zend_Db_Table_Abstract::getDefaultAdapter();
                $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
                $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
                $db->beginTransaction();
                foreach ($values as $key => $value) {
                    if ($key == 'delete_' . $value) {
                        $newsTable->delete(array('rss = ?' => $value));
                        $rssTable->delete(array('rss_id = ?' => $value));
                    }
                }
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                echo $e;
            }
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'rss'));
    }

    public function deleteRssAction() {
        // In smoothbox
        $this->_helper->layout->setLayout('admin-simple');
        $id = $this->_getParam('id');
        $this->view->feed_id = $id;

        // Check post
        if ($this->getRequest()->isPost()) {

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();

            try {
                $sitenewsRss = Engine_Api::_()->getItem('sitenews_rss', $id);
                $news = Engine_Api::_()->getDbtable('news', 'sitenews');
                $select = $news->select()
                        ->from($news->info('name'))
                        ->where('rss = ?', $sitenewsRss->rss_id);
                $newsItems = $news->fetchAll($select);
                foreach ($newsItems as $newsItem) {
                    $newsItem->delete();
                }

                // delete the news entry into the database
                $sitenewsRss->delete();
                $db->commit();
                $message = Zend_Registry::get('Zend_Translate')->_('RSS has been deleted Successfully.');
                return $this->_forward('success', 'utility', 'core', array(
                            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitenews_general', true),
                            'messages' => Array($message)
                ));

            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array('')
            ));
        }

        // Output
        $this->renderScript('admin-manage/delete-rss.tpl');
    }

    public function sponsoredAction() {

        $news_id = $this->_getParam('news_id');
        if ($news_id) {
            $news = Engine_Api::_()->getItem('sitenews_news', $news_id);
            $news->sponsored = !$news->sponsored;
            $news->save();
        }
        $this->_redirect('admin/sitenews/manage');
    }

    public function sponsoredRssAction() {

        $rss_id = $this->_getParam('rss_id');
        if ($rss_id) {
            $rss = Engine_Api::_()->getItem('sitenews_rss', $rss_id);
            $rss->sponsored = !$rss->sponsored;
            $rss->save();
        }
        $this->_redirect('admin/sitenews/manage/rss');
    }

    public function breakingNewsAction() {
        $news_id = $this->_getParam('id');
        if ($news_id) {
            $news = Engine_Api::_()->getItem('sitenews_news', $news_id);
            $news->breaking_news = !$news->breaking_news;
            $news->save();
        }
        $this->_redirect('admin/sitenews/manage');
    }

    public function featuredNewsAction() {
        $news_id = $this->_getParam('id');
        if ($news_id) {
            $news = Engine_Api::_()->getItem('sitenews_news', $news_id);
            $news->featured = !$news->featured;
            $news->save();
        }
        $this->_redirect('admin/sitenews/manage');
    }

}
