<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminNewsController.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_AdminNewsController extends Core_Controller_Action_Admin {

    public function indexAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_manage');
        $this->view->subNavigation = $subNavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_submain', array(), 'sitenews_admin_submain_news_tab');
    }

    //ACTION FOR NEWS SUGGESTION DROP-DOWN
    public function getNewsAction() {
        $title = $this->_getParam('text', null);
        $limit = $this->_getParam('limit', 40);
        $featured = $this->_getParam('featured', 0);
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $newsName = $newsTable->info('name');
        $allowTable = Engine_Api::_()->getDbtable('allow', 'authorization');
        $allowName = $allowTable->info('name');
        $data = array();
        $select = $newsTable->select()
                ->setIntegrityCheck(false)
                ->from($newsName);

        $select->join($allowName, $newsName . '.news_id = ' . $allowName . '.resource_id', array('resource_type', 'role'))
                ->where($allowName . '.resource_type = ?', 'sitenews_news')
                ->where($allowName . '.role = ?', 'registered')
                ->where($allowName . '.action = ?', 'view');
        $select->where("$newsName.search = ?", true)
                ->where("lower($newsName.title)  LIKE ? ", '%' . strtolower($title) . '%')
                ->limit($limit)
                ->order($newsName . '.title')
                ->order($newsName . '.creation_date');

        if (!empty($featured))
            $select->where($newsName . ".featured = ?", 0);

        $news = $newsTable->fetchAll($select);

        foreach ($news as $new) {
            $content_news = $this->view->itemPhoto($new, 'thumb.normal');
            $data[] = array(
                'id' => $new->news_id,
                'label' => $new->title,
                'news' => $content_news
            );
        }
        return $this->_helper->json($data);
    }

    public function featuredAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitenews_admin_main', array(), 'sitenews_admin_main_featured');
        $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
        $rssName = $rssTable->info('name');
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $newsName = $newsTable->info('name');
        $data = array();
        $select = $newsTable->select()
                ->setIntegrityCheck(false)
                ->from($newsName);

        $select->where($newsName . ".featured = ?", 1)
                ->order($newsName . '.creation_date DESC');
        $this->view->paginator = $paginator = Zend_Paginator::factory($select);
        // Set item count per page and current page number
        $paginator->setItemCountPerPage(50);
        $paginator->setCurrentPageNumber($this->_getParam('page', 1));
//        include APPLICATION_PATH . '/application/modules/Sitenews/controllers/license/license2.php';

        $select = $newsTable->select()
                ->from($newsName)
                ->where('featured = ?', 1);
        $this->view->isNews = $isNews = $newsTable->fetchAll($select);
    }

    //ACTION FOR UPDATE ORDER  OF NEWS WIDGTS TAB
    public function updateOrderAction() {
        //CHECK POST
        if ($this->getRequest()->isPost()) {
            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            $values = $_POST;
            try {
                foreach ($values['order'] as $key => $value) {
                    $tab = Engine_Api::_()->getItem('seaocore_tab', (int) $value);
                    if (!empty($tab)) {
                        $tab->order = $key + 1;
                        $tab->save();
                    }
                }
                $db->commit();
                $this->_helper->redirector->gotoRoute(array('action' => 'index'));
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
        }
    }

    //ACTION FOR MAKE TAB ENABLE/DISABLE
    public function enabledAction() {
        $id = $this->_getParam('tab_id');
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        $tab = Engine_Api::_()->getItem('seaocore_tab', $id);
        try {
            $tab->enabled = !$tab->enabled;
            $tab->save();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }

    public function categoriesAction() {

        $element_value = $this->_getParam('element_value', 1);
        $element_type = $this->_getParam('element_type', 'category_id');

        $categoriesTable = Engine_Api::_()->getDbTable('categories', 'sitenews');
        $select = $categoriesTable->select()
                ->from($categoriesTable->info('name'), array('category_id', 'category_name'))
                ->where("$element_type = ?", $element_value);

        if ($element_type == 'category_id') {
            $select->where('cat_dependency = ?', 0)->where('subcat_dependency = ?', 0);
        } elseif ($element_type == 'cat_dependency') {
            $select->where('subcat_dependency = ?', 0);
        } elseif ($element_type == 'subcat_dependency') {
            $select->where('cat_dependency = ?', $element_value);
        }

        $categoriesData = $categoriesTable->fetchAll($select);

        $categories = array();
        if (Count($categoriesData) > 0) {
            foreach ($categoriesData as $category) {
                $data = array();
                $data['category_name'] = $category->category_name;
                $data['category_id'] = $category->category_id;
                $categories[] = $data;
            }
        }

        $this->view->categories = $categories;
    }

}
