<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: SubscriptionController.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_SubscriptionController extends Seaocore_Controller_Action_Standard {

    public function init() {
        //SET THE SUBJECT
        if (0 !== ($rss_id = (int) $this->_getParam('rss_id')) &&
                null !== ($rss = Engine_Api::_()->getItem('sitenews_rss', $rss_id)) && !Engine_Api::_()->core()->hasSubject()) {
            Engine_Api::_()->core()->setSubject($rss);
        }
    }

    /*
     * This action used to subscribe the rss
     */

    public function subscribeRssAction() {

        //Checking for "Subscription" is enabled for this site
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.subscriptions.enabled', 1))
            return $this->_forwardCustom('requireauth', 'error', 'core');

        $message = Zend_Registry::get('Zend_Translate')->_("Subscribed successfully.");
        $subscriptionCount = 0;
        //FIND THE RSS MODEL
        $rss = Engine_Api::_()->core()->getSubject();
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $table = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');
        $db = $table->getAdapter();
        $db->beginTransaction();
        try {
            $subscriptionModel = $table->fetchRow($table->select()
                            ->from($table->info('name'), array('subscription_id'))
                            ->where('rss_id = ?', $rss->rss_id)
                            ->where('owner_type = ?', 'user')
                            ->where('owner_id = ?', $rss->owner_id)
                            ->where('subscriber_user_id = ?', $viewer_id)
            );
            if (!$subscriptionModel) {
                $form = new Sitenews_Form_NotificationSettings();
                $values = $form->getValues();
                $subscriptionModel = $table->createRow();
                $subscriptionModel->rss_id = $rss->rss_id;
                $subscriptionModel->owner_type = 'user';
                $subscriptionModel->owner_id = $rss->owner_id;
                $subscriptionModel->subscriber_user_id = $viewer_id;
                $rss->subscribe_count = new Zend_Db_Expr('subscribe_count + 1');
                $notificationArr['email'] = empty($values['email']) ? 0 : 1;
                $notificationArr['notification'] = empty($values['notification']) ? 0 : 1;

                if (empty($notificationArr['email']))
                    $values['action_email'] = null;

                if (empty($notificationArr['notification']))
                    $values['action_notification'] = null;
                $notificationArr['action_notification'] = empty($values['action_notification']) ? array() : $values['action_notification'];
                $notificationArr['action_email'] = empty($values['action_email']) ? array() : $values['action_email'];
                $notification = Zend_Json_Encoder::encode($notificationArr);
                $subscriptionModel->notification = $notification;
                $subscriptionModel->save();
                $rss->save();
                $ownerObj = $rss->getOwner();
                $notificationTable = Engine_Api::_()->getDbtable('notifications', 'activity');
                $notificationTable->addNotification($ownerObj, $viewer, $rss, "sitenews_rss_subscribe", array("label" => "rss", 'user_name' => $viewer->getTitle(), 'rss_title' => $rss->getTitle()));
                $subscriptionCount = $rss->subscribe_count;
            } else
                $message = Zend_Registry::get('Zend_Translate')->_("This RSS is already subscribed.");
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $data = array();
        $data[] = array(
            'message' => $message,
            'subscription_count' => $subscriptionCount
        );
        return $this->_helper->json($data);
    }

    /*
     * This action used to unsubscribe the rss
     */

    public function unsubscribeRssAction() {

        //Checking for "Subscription" is enabled for this site
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.subscriptions.enabled', 1))
            return $this->_forwardCustom('requireauth', 'error', 'core');

        $message = Zend_Registry::get('Zend_Translate')->_("Unsubscribed successfully.");

        $subscriptionCount = 0;

        //FIND THE RSS MODEL
        $rss = Engine_Api::_()->core()->getSubject();
        $viewer_id = Engine_Api::_()->user()->getViewer()->user_id;
        $table = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');
        $db = $table->getAdapter();
        $db->beginTransaction();
        try {
            $subscriptionModel = $table->fetchRow($table->select()
                            ->from($table->info('name'), array('subscription_id'))
                            ->where('rss_id = ?', $rss->rss_id)
                            ->where('owner_type = ?', 'user')
                            ->where('subscriber_user_id = ?', $viewer_id)
            );
            if ($subscriptionModel) {
                $subscriptionModel->delete();
                $rss->subscribe_count = new Zend_Db_Expr('subscribe_count - 1');
                $rss->save();
                $subscriptionCount = $rss->subscribe_count;
            } else
                $message = Zend_Registry::get('Zend_Translate')->_("RSS is already unsubscribed.");
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $data = array();
        $data[] = array(
            'message' => $message,
            'subscription_count' => $subscriptionCount
        );
        return $this->_helper->json($data);
    }

    /*
     * This action used to unsubscribe the rss
     */

    public function unsubscribeAction() {

        //Checking for "Subscription" is enabled for this site
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.subscriptions.enabled', 1))
            return $this->_forwardCustom('requireauth', 'error', 'core');

        if (!Engine_Api::_()->core()->hasSubject('sitenews_rss')) {
            return $this->setNoRender();
        }
        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');
        $this->view->form = $form = new Sitenews_Form_Unsubscribe();
        //CHECKING REQUEST FOR POST
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $message = Zend_Registry::get('Zend_Translate')->_("This RSS is unsubscribed successfully.");
        //FIND THE RSS MODEL
        $rss = Engine_Api::_()->core()->getSubject();
        $viewer_id = Engine_Api::_()->user()->getViewer()->user_id;
        $table = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');
        $db = $table->getAdapter();
        $db->beginTransaction();
        try {
            $subscriptionModel = $table->fetchRow($table->select()
                            ->from($table->info('name'), array('subscription_id'))
                            ->where('rss_id = ?', $rss->rss_id)
                            ->where('owner_type = ?', 'user')
                            ->where('owner_id = ?', $viewer_id)
            );
            if ($subscriptionModel) {
                $subscriptionModel->delete();
                $rss->subscribe_count = new Zend_Db_Expr('subscribe_count - 1');
                $rss->save();
            } else
                $message = Zend_Registry::get('Zend_Translate')->_("This RSS is already unsubscribed.");
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $this->view->status = true;
        $this->view->message = $message;
        return $this->_forward('success', 'utility', 'core', array(
                    'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitenews_subscription_general', true),
                    'messages' => Array($this->view->message)
        ));
    }

    public function notificationSettingsAction() {

        //Checking for "Subscription" is enabled for this site
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.subscriptions.enabled', 1))
            return $this->_forwardCustom('requireauth', 'error', 'core');

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');
        $rss_id = $this->_getParam('rss_id');
        //FIND THE Rss MODEL
        $rssModel = Engine_Api::_()->getItem('sitenews_rss', $rss_id);
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Invalid action.');
        $subscriptionModel = $rssModel->getSubscriptionModel();
        if ($subscriptionModel) {
            //INITIATE FORM OBJECT
            $this->view->form = $form = new Sitenews_Form_NotificationSettings();
            $data = Zend_Json_Decoder::decode($subscriptionModel->notification);
            $form->populate($data);
            //CHECKING REQUEST FOR POST
            if (!$this->getRequest()->isPost()) {
                return;
            }
            if (!$form->isValid($this->getRequest()->getPost())) {
                return;
            }
            $values = $form->getValues();
            $notificationArr['email'] = empty($values['email']) ? 0 : 1;
            $notificationArr['notification'] = empty($values['notification']) ? 0 : 1;
            $notification = Zend_Json_Encoder::encode($notificationArr);
            $subscriptionModel->notification = $notification;
            $subscriptionModel->save();
            $this->view->message = Zend_Registry::get('Zend_Translate')->_('Notifications has been updated.');
        }
        $this->view->status = true;
        return $this->_forward('success', 'utility', 'core', array(
                    'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitenews_general', true),
                    'messages' => Array($this->view->message)
        ));
    }

    public function manageAction() {
        //Checking for "Subscription" is enabled for this site
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.subscriptions.enabled', 1))
            return $this->_forwardCustom('requireauth', 'error', 'core');

        if (!$this->_helper->requireUser()->isValid()) {
            return;
        }
        $this->_helper->content->setNoRender()->setEnabled();
    }

}
