<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenewsletter
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenewsletter_Form_Admin_Campaigns_Create extends Engine_Form 
{
  public function init() {

    $this
        ->setTitle('Create Campaign')
        ->setDescription('');

    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;

    // TEMPLATE NAME
    $this->addElement('Text', 'subject', array(
      'label' => 'Campaign Subject',
      'description' => '',
      'required' => true
    ));

    $categoryTable = Engine_Api::_()->getDbtable('categories', 'sitenewsletter');
    // Get all enabled categories to display at user end
    $availableLabels = $categoryTable->getAllEnabledCategories();

    $this->addElement('MultiCheckbox', 'category_id', array(
      'label' => 'Newsletter Type',
      'description' => 'Select the newsletter types for which you want to send the newsletter.',
      'required' => true,
      'multiOptions' => $availableLabels,
      'onchange' => 'oncategoryChange(this.value);'
    ));

    $templateTable = Engine_Api::_()->getDbtable('templates', 'sitenewsletter');
    $templates = $templateTable->select()->query()->fetchAll();
    foreach ($templates as $id => $template) {
      if($template['name'] != 'header' && $template['name'] != 'footer') {
        $id = $template['template_id'];
        $availableTemplates[$id] = $template['displayname'];
      }
    }

    $this->addElement('Select', 'template_id', array(
      'label' => 'Template',
      'description' => 'Select the template which you want to use for the newsletter.',
      'multiOptions' => $availableTemplates,
    ));

    $uploadUrl = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'upload-photo'));

    $editorOptions = array(
      'uploadUrl' => $uploadUrl,
      'html' => true,
    );

    $this->addElement('TinyMce', 'body', array(
      'label' => 'Add Campaign Body',
      'description' => "Enter the text for the campaign body that you want to show to your users in the newsletter.",
      'editorOptions' => $editorOptions,
    ));

    // CHECK BACKGROUND CHOICE FROM IMAGE AND COLOR
    $this->addElement('Select', 'target_user', array(
      'label' => 'Targeted Users',
      'description' => 'The members belonging to selected criteria will be the receivers of this campaign newsletters.',
      'multiOptions' => array(
        'all' => 'All subscribed users for selected newsletter types.',
        'manually' => 'Add users by manually adding their emails in the field provided below.',
        'member_level' => 'Select the required Member levels from subscribers list below.',
        'network_level' => 'Select the required Networks from the subscribers list below.',
        'profile_type' => 'Select the required Profile Types from the subscribers list below.',
        'guest_users' => 'I want guest users of my site to receive this newsletter.'
      ),
      'value' => 'all',
      'onchange' => 'chooseTargetedUsers(this.value);'
    ));

    $this->addElement('Text', 'emails', array(
            'label' => 'Emails',
            'description' => 'Start typing the email.',
            'autocomplete' => 'off'));
    Engine_Form::addDefaultDecorators($this->emails);
    $this->emails->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Hidden', 'subscriber_ids', array(
      'order' => 9,
      'filters' => array(
        'HtmlEntities'
      ),
    ));
    Engine_Form::addDefaultDecorators($this->subscriber_ids);

    //Element: Get Member Level 
    $level_id = Engine_Api::_()->sitenewsletter()->getSubscribedLevelid();
    // Prepare user levels
    $levelOptions = array();
    foreach( Engine_Api::_()->getDbtable('levels', 'authorization')->fetchAll() as $level ) {
      if (in_array($level->level_id, $level_id)) {
        $levelOptions[$level->level_id] = $level->getTitle();
      }
    }
    if (!empty($levelOptions)) {
      $this->addElement('Select', 'level_id', array(
        'label' => 'Subscribed Member Level',
        'description' => 'Select out of the subscribed member levels, the members of the selected member levels will receive this newsletter.',
        'multiOptions' => $levelOptions,
      ));
    } else {
      $description = "<div class='tip'><span>" . Zend_Registry::get('Zend_Translate')->_("There are currently no member level that could be subscribed for newsletter.") . "</span></div>";
      $this->addElement('Dummy', 'level', array(
        'description' => $description,
      ));
      $this->level->addDecorator('Description', array('placement' =>
        Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));
    }

    
    //ELEMENT : Get network level
    $network = Engine_Api::_()->sitenewsletter()->getSubscribedNetwork();
    if (!empty($network)) {
      $this->addElement('Select', 'network_id', array(
        'label' => 'Subscribed Network Level',
        'description' => 'Select the network level for sending the newsletter who\'s are subscribed.',
        'multiOptions' => $network,
      ));
    } else {
      $description = "<div class='tip'><span>" . Zend_Registry::get('Zend_Translate')->_("There is currently no network the members of which can be subscribed to newsletters from your site.") . "</span></div>";
      $this->addElement('Dummy', 'network', array(
        'description' => $description,
      ));
      $this->network->addDecorator('Description', array('placement' =>
        Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));
    }

    //ELEMENT : Get profile type
    $profile = Engine_Api::_()->sitenewsletter()->getSubscribedProfileTypes();
    if (!empty($profile)) {
      $this->addElement('Select', 'profile_type', array(
        'label' => 'Subscribed Profile Type',
        'description' => 'Select out of the subscribed Profile Types, the members of the selected profile type will receive this newsletter.',
        'multiOptions' => $profile,
      ));
    } else {
      $description = "<div class='tip'><span>" . Zend_Registry::get('Zend_Translate')->_("There are currently no profile type that could be subscribed for newsletter.") . "</span></div>";
      $this->addElement('Dummy', 'profile', array(
        'description' => $description,
      ));
      $this->profile->addDecorator('Description', array('placement' =>
        Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));
    }

    $this->addElement('Button', 'submit', array(
      'label' => 'Create Campaign',
      'type' => 'submit',
      'ignore' => true
    ));
  }
}
