<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteemailverification
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenewsletter_Form_Admin_Layout extends Engine_Form {

    public function init() {

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $this
                ->setTitle('Header & Footer Settings')
                ->setAttrib('enctype', 'multipart/form-data')
                ->setAttribs(array(
                  'id' => 'layout_form',
                  'class' => 'global_form_box',
                ))
                ->setDescription('You can create and design the Header and Footer for newsletters from here. You can set the text, colors, logos and background images for header and footer of newsletters.');

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        
        $this->addElement('Text', 'sitenewsletter_template_width', array(
          'label' => 'Email Template Width',
          'description' => "Set the width of template. [Note: Email template width is set in pixel and default width is 700px.]",
          'value' => 700,
          'validators' => array(
            array('Int', true),
          ),
        ));

        // HEADING FOR HEADER SETTINGS
        $this->addElement('Dummy', 'headersettings', array(
          'decorators' => array(array('ViewScript', array(
            'viewScript' => '_formElementsHeading.tpl',
            'heading' => 'Header Settings',
             'class' => 'form element'
          ))),
        ));

        // HEADER COLOR
        $this->addElement('Text', 'sitenewsletter_header_color', array(
          'decorators' => array(array('ViewScript', array(
                'viewScript' => '_headerColorPicker.tpl',
                'class' => 'form element',
                'name' => 'sitenewsletter_header_color',
                'value' => $coreSettings->getSetting('sitenewsletter_header_color', '#000000'),
                'label' => 'Select Header Font Color',
                'description' => 'Please choose font color for text shown in the header.',
                'order' => 1
              ))),
        ));

        $this->addElement('Radio', 'sitenewsletter_header_site', array(
          'label' => 'Header Logo / Name',
          'description' => 'Select one of these to display name or logo of site.',
          'multiOptions' => array(
            1 => 'Logo',
            0 => 'Title'
          ),
          'value' => $coreSettings->getSetting('sitenewsletter_header_site', 0),
          'onchange' => 'chooseheadersite(this.value);'
        ));        

        //SITE LOGO
        $this->addElement('File', 'sitenewsletter_site_header_logo', array(
          'label' => 'Site Logo',
          'description' => 'Upload the logo image which you want to display in header of newsletters. [Size recommended is width:auto; height:68px;]'
        ));
        
        $this->sitenewsletter_site_header_logo->addValidator('Extension', false, 'jpg,jpeg,png,JPG,JPEG,PNG');


        // SITE NAME
        $this->addElement('Text', 'sitenewsletter_sitename', array(
            'label' => 'Site Title',
            'description' => 'Enter the title of your website which you want to show in the newsletters from your site.',
            'value' => $coreSettings->getSetting('sitenewsletter_sitename', $coreSettings->getSetting('core_general_site_title')),
        ));

        // CHECK BACKGROUND CHOICE FROM IMAGE AND COLOR
        $this->addElement('Radio', 'sitenewsletter_header_background', array(
          'label' => 'Background Color / Background Image',
          'description' => 'Select one of these for background settings.',
          'multiOptions' => array(
            1 => 'Background Color',
            0 => 'Background Image'
          ),
          'value' => $coreSettings->getSetting('sitenewsletter_header_background', 1),
          'onchange' => 'choosebackground(this.value);'
        ));

        //BACKGROUND COLOR
        $this->addElement('Text', 'sitenewsletter_header_bgcolor', array(
          'label' => 'Header Background Color',
          'description' => 'Select the header background color.',
          'decorators' => array(array('ViewScript', array(
                'viewScript' => '_headerColorPicker.tpl',
                'class' => 'form element',
                'name' => 'sitenewsletter_header_bgcolor',
                'value' => $coreSettings->getSetting('sitenewsletter_header_bgcolor', '#cccccc'),
                'label' => 'Header Background Color',
                'description' => 'Select the header background color.',
                'order' => 99
              ))),
        ));

        // BACKGROUND IMAGE
        $this->addElement('File', 'sitenewsletter_header_bgimage', array(
          'label' => 'Header Background Image',
          'description' => 'Upload the header background image. [Size recommended is width:700px; height:120px]'
        ));

        $this->addElement('Radio', 'sitenewsletter_header_enable', array(
          'label' => 'Enable Header Menu',
          'description' => 'Do you want to enable the header menu to display?',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => $coreSettings->getSetting('sitenewsletter_header_enable', 1)
        ));

        $description = "<div class='tip'><span>" . Zend_Registry::get('Zend_Translate')->_("Please <a href='admin/menus?name=newsletter_header' target='_blank'>click here</a> to update newsletter header menu.") . "</span></div>";
        $this->addElement('Dummy', 'sitenewsletter_header_menu', array(
          'label' => 'Update Header Menu',
          'description' => $description,
        ));
        $this->sitenewsletter_header_menu->addDecorator('Description', array('placement' =>
          Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));


        $this->sitenewsletter_header_bgimage->addValidator('Extension', false, 'jpg,jpeg,png,gif,JPG,JPEG,PNG,GIF');

        // HEADING FOR FOOTER SETTINGS
        $this->addElement('Dummy', 'footersettings', array(
          'decorators' => array(array('ViewScript', array(
            'viewScript' => '_formElementsHeading.tpl',
            'heading' => 'Footer Settings',
             'class' => 'form element'
          ))),
        ));

        // FOOTER COLOR
        $this->addElement('Text', 'sitenewsletter_footer_color', array(
          'decorators' => array(array('ViewScript', array(
                'viewScript' => '_headerColorPicker.tpl',
                'class' => 'form element',
                'name' => 'sitenewsletter_footer_color',
                'value' => $coreSettings->getSetting('sitenewsletter_footer_color', '#000000'),
                'label' => 'Select Footer Font Color',
                'description' => 'Please choose font color for text shown in the footer.',
                'order' => 99
              ))),
        ));

        $this->addElement('Radio', 'sitenewsletter_footer_icon', array(
          'label' => 'Footer Icon',
          'description' => 'Do you want to add footer logo?',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => $coreSettings->getSetting('sitenewsletter_footer_icon', 0),
          'onchange' => 'chooseFooterIcon(this.value);'
        ));

        //SITE SMALL LOGO ICON
        $this->addElement('File', 'sitenewsletter_site_logo_icon', array(
          'label' => 'Footer Logo',
          'description' => 'Upload the logo icon image for footer of the template. [Size recommended is width:auto; height:55px;]',
        ));
        
        $this->sitenewsletter_site_header_logo->addValidator('Extension', false, 'jpg,jpeg,png,JPG,JPEG,PNG');


        //BACKGROUND COLOR
        $this->addElement('Text', 'sitenewsletter_footer_bgcolor', array(
          'label' => 'Footer Background Color',
          'description' => 'Select the footer background color.',
          'decorators' => array(array('ViewScript', array(
                'viewScript' => '_headerColorPicker.tpl',
                'class' => 'form element',
                'name' => 'sitenewsletter_footer_bgcolor',
                'value' => $coreSettings->getSetting('sitenewsletter_footer_bgcolor', '#ada5a5'),
                'label' => 'Footer Background Color',
                'description' => 'Select the footer background color.',
                'order' => 99
              ))),
        ));

        $this->addElement('Radio', 'sitenewsletter_footer_enable', array(
          'label' => 'Enable Footer Menu',
          'description' => 'Do you want to enable the footer menu links to display?',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => $coreSettings->getSetting('sitenewsletter_footer_enable', 1)
        ));

        $description = "<div class='tip'><span>" . Zend_Registry::get('Zend_Translate')->_("Please <a href='admin/menus?name=newsletter_footer' target = '_blank'>click here</a> to update newsletter footer menu.") . "</span></div>";
        $this->addElement('Dummy', 'sitenewsletter_footer_menu', array(
          'label' => 'Update Footer Menu',
          'description' => $description,
        ));
        $this->sitenewsletter_footer_menu->addDecorator('Description', array('placement' =>
          Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));

        $this->addElement('Radio', 'sitenewsletter_sociallinks_enable', array(
          'label' => 'Enable Social Links',
          'description' => 'Do you want social links to show up in the newsletter?',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => $coreSettings->getSetting('sitenewsletter_sociallinks_enable', 0)
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}

?>
