<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenewsletter
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Categories.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenewsletter_Model_DbTable_Categories extends Engine_Db_Table
{
  protected $_rowClass = 'Sitenewsletter_Model_Category';
  
  // Get the category in Ascending order
  public function getCategoriesAssoc()
  {
    $stmt = $this->select()
        ->from($this, array('category_id', 'category_name'))
        ->order('category_name ASC')
        ->query();
    
    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['category_id']] = $category['category_name'];
    }
    
    return $data;
  }

  // Get all enabled categories
  public function getEnabledCategories()
  {
    $stmt = $this->select()
        ->from($this, array('category_id', 'category_name'))
        ->where('enabled = ?',1)
        ->where('visibility = ?', 0)
        ->order('category_name ASC')
        ->query();
    
    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['category_id']] = $category['category_name'];
    }
    return $data;
  }

  // Get all enabled categories
  public function getAllEnabledCategories()
  {
    $stmt = $this->select()
        ->from($this, array('category_id', 'category_name'))
        ->where('enabled = ?',1)
        ->order('category_name ASC')
        ->query();
    
    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['category_id']] = $category['category_name'];
    }
    return $data;
  }

  public function getHideEnabledCategories() {
    $stmt = $this->select()
        ->from($this, array('category_id', 'category_name'))
        ->where('enabled = ?',1)
        ->where('visibility = ?', 1)
        ->order('category_name ASC')
        ->query();
    
    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['category_id']] = $category['category_name'];
    }
    return $data;
  }

  // Get all auto subscribed categories for guest or existing users
  public function fetchAutoSubscribedCategories()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    $stmt = $this->select()
        ->from($this, array('category_id'))
        ->where('enabled = ?', 1)
        ->where('visibility = ?', 0);
    if (empty($viewer_id))
      $stmt->where('subscribe_gusers = ?', 1);
    else
      $stmt->where('subscribe_eusers = ?', 1);

    $data = array();
    foreach ($stmt->query()->fetchAll() as $category) {
      $data[] = $category['category_id'];
    }
    return $data;
  }

  public function getCategoryName($category_id) {

    //RETURN IF CATEGORY ID IS EMPTY
    if (empty($category_id)) {
      return;
    }

    //MAKE QUERY
    $categoryName = $this->select()
            ->from($this->info('name'), array('category_name'))
            ->where('category_id = ?', $category_id)
            ->query()
            ->fetchColumn();
    //RETURN RESULTS
    return $categoryName;
  }
  
  /**
   * Return categories
   *
   * @param array $category_ids
   * @return all categories
   */
  public function getCategories($params = array()) {

    //MAKE QUERY
    $select = $this->select();

    //GET CATEGORY TABLE NAME
    $categoryTableName = $this->info('name');

    if (isset($params['orderBy']) && $params['orderBy'] == 'category_name') {
      $select->order('category_name');
    } else {
      $select->order('category_order');
    }

    if (isset($params['enabled']) && !empty($params['enabled'])) {
      $select->where('enabled = ?', 1);
    }

    if (isset($params['fetchColumns']) && !empty($params['fetchColumns'])) {
      $select->setIntegrityCheck(false)->from($categoryTableName, $params['fetchColumns']);
    } else {
      $select->setIntegrityCheck(false)->from($categoryTableName);
    }

    //RETURN DATA
    return $this->fetchAll($select);
  } 
}
