<?php
/**
 * SocialEngine
 *
 * @category   Application_Core
 * @package    Core
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: Pages.php 9994 2013-03-25 23:18:04Z john $
 * @author     John
 */

/**
 * @category   Application_Core
 * @package    Core
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 */
class Sitenewsletter_Model_DbTable_Templates extends Engine_Db_Table implements Engine_Content_Storage_Interface
{
  protected $_rowClass = 'Sitenewsletter_Model_Template';

  public function loadMetaData(Engine_Content $contentAdapter, $name)
  {
    $select = $this->select()->where('name = ?', $name)->orWhere('page_id = ?', $name);
    $page = $this->fetchRow($select);

    if( !is_object($page) ) {
      // throw?
      return null;
    }

    return $page->toArray();
  }

  public function loadContent(Engine_Content $contentAdapter, $name)
  {
    if( is_array($name) ) {
      $name = join('_', $name);
    }
    if( !is_string($name) && !is_numeric($name) ) {
      throw new Exception('not string');
    }

    $select = $this->select()->where('name = ?', $name)->orWhere('template_id = ?', $name);
    $page = $this->fetchRow($select);

    if( !is_object($page) ) {
      // throw?
      return null;
    }

    // Get all content
    $contentTable = Engine_Api::_()->getDbtable('content', 'sitenewsletter');
    $select = $contentTable->select()
      ->where('template_id = ?', $page->template_id)
      ->order('order ASC')
      ;
    $content = $contentTable->fetchAll($select);

    // Create structure
    $structure = $this->prepareContentArea($content);

    // Get the body settings 
    $templateslayoutTable = Engine_Api::_()->getDbtable('templateslayouts', 'sitenewsletter');

    // Create element (with structure)
    if ($page->name != 'footer' && $page->name != 'header') {
      $settingRow = $templateslayoutTable->fetchRow($templateslayoutTable->select()->from($templateslayoutTable->info('name'), array('body_fontsize', 'body_fontcolor', 'body_bgcolor'))->where('template_id = ?', $page->template_id));
      if (empty($settingRow->body_bgcolor) || empty($settingRow->body_fontcolor) || empty($settingRow->body_fontsize)) {
        $bgcolor = '#ffffff';
        $font = 16;
        $color = '#000000';
      } else {
        $bgcolor = $settingRow->body_bgcolor;
        $font = $settingRow->body_fontsize;
        $color = $settingRow->body_fontcolor;
      }

      $element = new Engine_Content_Element_Container(array(
        'class' => 'layout_page_' . $page->name,
        'style' => 'display:block; padding:0 10px 10px 10px;background-color:'.$bgcolor.';color:'.$color.';font-size:'.$font.'px; float:left; width:100%; box-sizing:border-box; -webkit-box-sizing:border-box;',
        'elements' => $structure
      ));
    } else {
      $element = new Engine_Content_Element_Container(array(
        'class' => 'layout_page_' . $page->name,
        'elements' => $structure
      ));
    }

    return $element;
  }

  public function prepareContentArea($content, $current = null)
  {
    // Get parent content id
    $parent_content_id = null;
    if( null !== $current ) {
      $parent_content_id = $current->content_id;
    }
    
    // Get children
    $children = $content->getRowsMatching('parent_content_id', $parent_content_id);
    if( empty($children) && null === $parent_content_id ) {
      $children = $content->getRowsMatching('parent_content_id', 0);
    }

    // Get struct
    $struct = array();
    foreach( $children as $child ) {
      $elStruct = $this->createElementParams($child);
      if( $elStruct ) {
        $elStruct['elements'] = $this->prepareContentArea($content, $child);
        $struct[] = $elStruct;
      }
    }

    return $struct;
  }

  public function createElementParams($row)
  {
    $data = array(
      'identity' => $row->content_id,
      'type' => $row->type,
      'name' => $row->name,
      'order' => $row->order,
    );
    $params = (array) $row->params;
    if( isset($params['title']) ) {
      $data['title'] = $params['title'];
    }
    $data['params'] = $params;
    
    // Check mobile here?
    if( !empty($params['nomobile']) && 
        Engine_Api::_()->hasModuleBootstrap('mobi') &&
        !empty($_SESSION['mobile']) &&
        !empty($_SESSION['mobile']['mobile']) ) {
      return false;
    }
    // Get the body settings 
    $templateslayoutTable = Engine_Api::_()->getDbtable('templateslayouts', 'sitenewsletter');
    $settingRow = $templateslayoutTable->fetchRow($templateslayoutTable->select()->from($templateslayoutTable->info('name'), array('body_bgcolor'))->where('template_id = ?', $row->template_id));
    if (empty($settingRow->body_bgcolor) ) 
      $bgcolor = '#ffffff';
    else 
      $bgcolor = $settingRow->body_bgcolor;

    $data['style'] = $this->getCSS($row->name, $bgcolor);
    return $data;
  }


  public function getCSS($name, $bgcolor = null) {
    $this->_css = array(
      'main' => 'width:100%; margin:auto;',
      'left' => 'float:left; width:25%; background:#eee; margin-right:10px; margin-bottom:15px; padding:0 10px;',
      'right' => 'float:right; width:25%; background:#eee; padding:0 10px; margin-left:10px;',
      'middle' => 'overflow:hidden; background:#f5f5f5;',
      'top' => 'width:100%; margin:auto;',
      'bottom' => 'width:100%; margin:10px auto 0; clear:both;',
      'widget' => 'display:inline-block;',
      'sitenewsletter.list-popular-items' => 'border-width: 10px 0 0 0; border-style: solid; border-color:'.$bgcolor.'; margin:0 -10px; padding:15px 20px; margin:0 -10px',
      'sitenewsletter.track-link' => 'border-width: 10px 0 0 0;margin:0 -10px; border-style: solid; border-color:'.$bgcolor.'; padding:10px; text-align:center;',
      'core.html-block' => 'border-width: 10px 0 0 0; border-style: solid; border-color:'.$bgcolor.'; margin:0 -10px; padding:5px 20px;',
      'core.rich-text-block' => 'border-width: 10px 0 0 0; border-style: solid; border-color:'.$bgcolor.'; margin:0 -10px; padding:0 20px;',
      'core.content' => 'border-width: 10px 0 0 0; border-style: solid; border-color:'.$bgcolor.'; margin:0 -10px; padding:0 20px;',
      'sitenewsletter.template-header' => '',
      'sitenewsletter.template-footer' => '',
    );
    return $this->_css[$name];
  }
  public function deleteTemplate(Sitenewsletter_Model_Template $template)
  {
    $contentTable = Engine_Api::_()->getDbtable('content', 'sitenewsletter');
    $contentTable->delete(array(
      'template_id = ?' => $template->template_id,
    ));
    
    $template->delete();

    return $this;
  }
}