<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenewsletter
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: ScheduledCampaigns.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenewsletter_Plugin_Task_Scheduled extends Core_Plugin_Task_Abstract
{
  public function execute()
  {
    $campaginTable = Engine_Api::_()->getDbtable('campaigns', 'sitenewsletter');
    $campaignName = $campaginTable->info('name');

    // GET SCHEDULED CAMPAIGNS
    $campagin_result = $campaginTable->select()
      ->from($campaignName, array('campaign_id', 'scheduled_date', 'timezone'))
      ->where('scheduled_date NOT IN ( "0000-00-00 00:00:00" )')->query()->fetchAll();
      
    foreach ($campagin_result as $campaginData) {

      $tz = new DateTimeZone($campaginData['timezone']);
      $now = new DateTime('now', $tz);
      $scheduled_date1 = new DateTime($campaginData['scheduled_date'], $tz);

      $scheduled_date2 = new DateTime($campaginData['scheduled_date'], $tz);

      $timestamp = $scheduled_date2->format('U')+600;
      $scheduled_date2->setTimestamp($timestamp);

      if (($now->format('Y-m-d H:i:s') >= $scheduled_date1->format('Y-m-d H:i:s')) && ($now->format('Y-m-d H:i:s') <= $scheduled_date2->format('Y-m-d H:i:s'))) {
       
        $campaign = Engine_Api::_()->getItem('sitenewsletter_campaign', $campaginData['campaign_id']);

        $category = Zend_Json::decode($campaign->category_id);
        $target_user = $campaign->target_user;
        switch($target_user) {
          case 'all':
            $emails = Engine_Api::_()->sitenewsletter()->getSubscribeEmails($category);
            break;

          case 'manually':
            $emails = Engine_Api::_()->sitenewsletter()->getMunualEmails(explode(",", $campaign->subscriber_ids));
            break;

          case 'member_level':
            $emails = Engine_Api::_()->sitenewsletter()->getMemberEmails($campaign->level_id, $category);
            break;

          case 'network_level':
            $emails = Engine_Api::_()->sitenewsletter()->getNetworkEmails($campaign->network_id, $category);
            break;

          case 'profile_type':
            $emails = Engine_Api::_()->sitenewsletter()->getProfiletypeEmails($campaign->profile_type, $category);
            break;

          case 'guest_users':
            $emails = Engine_Api::_()->sitenewsletter()->getGuestuserEmails($category);
            break;
        }

        $emailCount = count($emails);
        $maxWidth = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenewsletter.template.width', 700);
        $content = Engine_Content::getInstance();
        $content->getView()->baseUrl();

        $old_storage = $content->getStorage();
        Zend_Controller_Front::getInstance()->getResponse()->setBody($campaign->body);

        $contentTable = Engine_Api::_()->getDbtable('templates', 'sitenewsletter');
        
        $template_name = Engine_Api::_()->getItem('sitenewsletter_template', $campaign->template_id);
        $content->setStorage($contentTable);
       
        $header = $content->render('header');
        $contentBody = $content->render($campaign->template_id);
        $footer = $content->render('footer');
        $content->setStorage($old_storage);

        $email = Engine_Api::_()->getApi('settings', 'core')->core_mail_from;
        $view = Zend_Registry::get('Zend_View');
        $subject = $campaign->subject;

        $sentEmailCount = 0;
        foreach ($emails as $reciever_email) {
          $tracker = $view->absoluteUrl($view->baseUrl('tracker_mail.php?id='.$campaginData['campaign_id'].'&log=true&email='.$reciever_email));
          $message = '';
          $message .= '<div style="max-width:'.$maxWidth.'px; margin:auto; border:1px solid #ddd;">';
          $message .= '<img alt="" src="'.$tracker.'" width="1" height="1" border="0" />';
          $message .= $header. $contentBody.$footer;
          $message .= '</div>';
          $dom = new DomDocument();
          @$dom->loadHTML($message);
          $urls = $dom->getElementsByTagName('a');
          foreach ($urls as $url)
          {
            $href = $url->getAttribute('href');
            if (substr_count($href, $content->getView()->baseUrl('admin/sitenewsletter/statistics/refer-count'))) {
              $newhref = $href.'&id='.$campaginData['campaign_id'].'&mail='.$reciever_email;
              $url->setAttribute('href', $newhref);
            } elseif (substr_count($href, $content->getView()->baseUrl())) {
              $newhref = $view->absoluteUrl($href);
              $url->setAttribute('href', $newhref);
            } else
              continue;
          }
          $message = $dom->saveHTML();

          $link = $view->absoluteUrl(Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
                        'module' => 'sitenewsletter',
                        'controller' => 'subscribe',
                        'action' => 'unsubscribe',
                        'token' => base64_encode(time() . ":" . $reciever_email)
                            ), 'unsubscribe', true));
          $button = "<div style='max-width:700px; margin:auto; text-align:center;'><a href=$link style='color:blue;'>Unsubscribe from this newsletter</a></div>";
          $sentEmails = Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciever_email, 'NEWSLETTER_SEND_NOTIFICATION', array(
              'subject' => $subject,
              'message' => $message,
              'unsubscribe_link' => $button,
              'email' => $email,
              'queue' => false
            )
          );
          if ($sentEmails) {
            $sentEmailCount = ++$sentEmailCount;
          }
          if($sentEmailCount == $emailCount) {
            $campaign->status = 'completed';
            $campaign->email_count = $sentEmailCount;
            $campaign->total_email = $emailCount;
            $campaign->save();
          } else {
            $campaign->status = 'failed';
            $campaign->save();
          }
        }
      }
    }
  }
}