<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepagewishlist
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitepagewishlist_IndexController extends Core_Controller_Action_Standard {

	//COMMON FUNCTION WHICH CALL AUTOMATICALLY BEFORE EVERY ACTION OF THIS CONTROLLER
	public function init() {

		//VIEW PARIVACY CHECK
    if (!$this->_helper->requireAuth()->setAuthParams('sitepagewishlist_wishlist', null, 'view')->isValid()) {
      return;
    }
	}

	//ACTION FOR SHOW ALL WISHLISTS
	public function browseAction() {

		//GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('sitepage_main');

		//FORM GENERATION
    $this->view->form = $form = new Sitepagewishlist_Form_Search();

		//GET VALUES 
    if( $form->isValid($this->_getAllParams()) ) {
      $this->view->formValues = $values = $form->getValues();
    } else {
      $this->view->formValues = $values = array();
    }

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();

		//GE WISHLIST PAGE TABLE
    $wishlistPageTable = Engine_Api::_()->getDbtable('pages', 'sitepagewishlist');
    $wishlistPageTableName = $wishlistPageTable->info('name');

		//GET WISHLIST TABLE
    $wishlistTable = Engine_Api::_()->getDbtable('wishlists', 'sitepagewishlist');
    $wishlistTableName = $wishlistTable->info('name');

		//MAKE QUERY
    $select = $wishlistTable->select()
                    ->setIntegrityCheck(false)
                    ->from($wishlistTableName)
                    ->joinLeft($wishlistPageTableName, "$wishlistPageTableName.wishlist_id = $wishlistTableName.wishlist_id", array("COUNT($wishlistPageTableName.wishlist_id) AS total_item"));

		if(!empty($values['text'])) {
			$tableUserName = Engine_Api::_()->getItemTable('user')->info('name');
			$select->joinLeft($tableUserName, "$tableUserName.user_id = $wishlistTableName.owner_id", array("user_id"))
						 ->where($tableUserName . ".username LIKE ?", '%' . $values['text'] . '%');
		}

		if(!empty($values['orderby']) && $values['orderby'] == 'total_item') {
			$select->order('total_item DESC');
		}

    $select->order($wishlistTableName.'.wishlist_id DESC')->group($wishlistTableName . '.wishlist_id');

		//GET PAGINATOR
    $this->view->paginator = $paginator = Zend_Paginator::factory($select);
    $paginator->setItemCountPerPage(10);
    $paginator->setCurrentPageNumber($this->_getParam('page'));
	}	

	//ACTION FOR ADDING THE ITEM IN WISHLIST
  public function addAction() {

		//GET PAGE ID AND CHECK PAGE ID VALIDATION
    $page_id = $this->_getParam('page_id');
    if (empty($page_id)) {
      return $this->_forward('notfound', 'error', 'core');
    }

		//GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('sitepage_main');

    //GET VIEWER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

    //FORM GENERATION
    $this->view->form = $form = new Sitepagewishlist_Form_Add();

		//FORM VALIDATION
    if (!$this->getRequest()->isPost() || !$form->isValid($this->getRequest()->getPost())) {
      return;
    }

		//GET FORM VALUES
    $values = $form->getValues();

		//CHECK FOR NEW ADDED WISHLIST TITLE
    $is_error = 0;
    if (isset($values['wishlist_new']) && $values['wishlist_new'] == 1 && empty($values['wishlist_new_title'])) {
      $is_error = 1;
    }

    if ($is_error == 1) {
      $error = $this->view->translate('Please fill the new wish lists title also.');
      $this->view->status = false;
      $error = Zend_Registry::get('Zend_Translate')->_($error);

      $form->getDecorator('errors')->setOption('escape', false);
      $form->addError($error);
      return;
    }

		//GET WISHLIST PAGE TABLE
    $wishlistPageTable = Engine_Api::_()->getDbtable('pages', 'sitepagewishlist');

		//GET WISHLIST TABLE
    $wishlistTable = Engine_Api::_()->getDbtable('wishlists', 'sitepagewishlist');

		//MAKE QUERY
    $select = $wishlistTable->select()->where('owner_id = ?', $viewer_id);
    $wishlistDatas = $wishlistTable->fetchAll($select);

		//WORK ON PREVIOUSLY CREATED WISHLIST
    if (!empty($wishlistDatas)) {

      foreach ($wishlistDatas as $wishlistData) {
        $key_name = 'wishlist_' . $wishlistData->wishlist_id;
        if (isset($values[$key_name]) && !empty($values[$key_name])) {

          $wishlistPageTable->insert(array(
              'wishlist_id' => $wishlistData->wishlist_id,
              'page_id' => $page_id,
          ));
        }

        $in_key_name = 'inWishlist_' . $wishlistData->wishlist_id;
        if (isset($values[$in_key_name]) && empty($values[$in_key_name])) {
          $wishlistPageTable->delete(array('wishlist_id = ?' => $wishlistData->wishlist_id));
        }
      }
    }

    if (!empty($values['wishlist_new']) && $values['wishlist_new_title']) {
      $wishlistTable = Engine_Api::_()->getDbtable('wishlists', 'sitepagewishlist');
      $db = $wishlistPageTable->getAdapter();
      $db->beginTransaction();

      try {

        //CREATE WISHLIST
        $wishlist = $wishlistTable->createRow();
        $wishlist->title = $values['wishlist_new_title'];
        $wishlist->owner_id = $viewer_id;
        $wishlist->save();

        $db->commit();
      } catch (Exception $e) {
        $db->rollback();
        throw $e;
      }

      $wishlistPageTable->insert(array(
          'wishlist_id' => $wishlist->wishlist_id,
          'page_id' => $page_id,
      ));
	
			//WISHLIST EDIT URL
			$url = $this->_helper->url->url(array('action' => 'edit', 'wishlist_id' => $wishlist->getIdentity()), 'sitepagewishlist_general');

//CODE FOR OPEN EDIT FORM IN LIGHTBOX
 $script = <<<EOF
            
<script type="text/javascript"> 
 Smoothbox.open('$url');     
</script>
EOF;

echo $script;

    } 
		else {
			$this->_redirect("wishlists/manage");
		}
  }

  //ACTION FOR REMOVE ITEM FROM THIS WISHLIST
  public function removeAction() {

		//SET LAYOUT
    $this->_helper->layout->setLayout('default-simple');

		//GET WISHLIST AND PAGE ID 
    $this->view->wishlist_id = $wishlist_id = $this->_getParam('wishlist_id');
    $page_id = $this->_getParam('page_id');

    if ($this->getRequest()->isPost()) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      try {

				//DELETE FROM DATABASE
        Engine_Api::_()->getDbtable('pages', 'sitepagewishlist')->delete(array('wishlist_id = ?' => $wishlist_id, 'page_id = ?' => $page_id));

        $db->commit();
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
      $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('This item is removed successfully from this wish list !')
      ));
    }
    $this->renderScript('index/remove.tpl');
  }

	//ACTION FOR TELL TO THE FRIEND FOR THIS WISHLIST
  public function tellAFriendAction() {
		
		//DEFAULT LAYOUT
    $this->_helper->layout->setLayout('default-simple');

		//GET VIEWER DETAIL
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewr_id = $viewer->getIdentity();

		//GET WISHLIST ID AND WISHLIST OBJECT
    $wishlist_id = $this->_getParam('wishlist_id', $this->_getParam('wishlist_id', null));
    $wishlist = Engine_Api::_()->getItem('sitepagewishlist_wishlist', $wishlist_id);

    //FORM GENERATION
    $this->view->form = $form = new Sitepagewishlist_Form_TellAFriend();

    if (!empty($viewr_id)) {
      $value['wishlist_sender_email'] = $viewer->email;
      $value['wishlist_sender_name'] = $viewer->displayname;
      $form->populate($value);
    }

    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

			//GET FORM VALUES
      $values = $form->getValues();

			//EMAIL IDS
      $reciver_ids = explode(',', $values['wishlist_reciver_emails']);

      if (!empty($values['wishlist_send_me'])) {
        $reciver_ids[] = $values['wishlist_sender_email'];
      }

			$reciver_ids = array_unique($reciver_ids);

      $sender_email = $values['wishlist_sender_email'];

			//CHECK VALID EMAIL ID FORMITE
      $validator = new Zend_Validate_EmailAddress();
      $validator->getHostnameValidator()->setValidateTld(false);

      if (!$validator->isValid($sender_email)) {
        $form->addError(Zend_Registry::get('Zend_Translate')->_('Invalid sender email address value'));
        return;
      }
      foreach ($reciver_ids as $reciver_id) {
        $reciver_id = trim($reciver_id, ' ');
        if (!$validator->isValid($reciver_id)) {
          $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter correct email address of the receiver(s).'));
          return;
        }
      }

			//GET EMAIL DETAILS
      $sender = $values['wishlist_sender_name'];
      $message = $values['wishlist_message'];
			$params['wishlist_id'] = $wishlist_id;
			$params['slug'] = $wishlist->getSlug();
      $heading = ucfirst($wishlist->getTitle());

      Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciver_ids, 'SITEPAGEWISHLIST_TELLAFRIEND_EMAIL', array(
          'host' => $_SERVER['HTTP_HOST'],
          'sender_name' => $sender,
          'wishlist_title' => $heading,
          'message' => '<div>' . $message . '</div>',
          'object_link' => $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble($params, 'sitepagewishlist_view', true),
          'sender_email' => $sender_email,
          'queue' => true
      ));

      $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => true,
          'parentRefresh' => false,
          'format' => 'smoothbox',
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your message to your friend has been sent successfully.'))
      ));
    }
  }

	//ACTION FOR MAIN VIEW WISHLIST PAGE
  public function viewAction() {

		//GET WISHLIST ID AND SET WISHLIST SUBJECT
    $wishlist = null;
    if (null !== ($wishlist_id = $this->_getParam('wishlist_id'))) {
      $wishlist = Engine_Api::_()->getItem('sitepagewishlist_wishlist', $wishlist_id);
      if (null !== $wishlist) {
        Engine_Api::_()->core()->setSubject($wishlist);
      }
    }

		//SUBJECT VALIDATION
    if (!$this->_helper->requireSubject('sitepagewishlist_wishlist')->isValid()) {
      return;
    }

		//PAGE OFFER IS INSTALLED OR NOT
		$this->view->sitepageOfferEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepageoffer');

		//GET WISHLIST SUBJECT
    $this->view->wishlist = $wishlist = Engine_Api::_()->core()->getSubject('sitepagewishlist_wishlist');

		//GET WISHLIST OWNER
    $this->view->owner = $wishlist->getOwner();

		//GET VIEWER ID
		$this->view->viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

		//GET WISHLIST PAGE DATA
    $wishlistPageData = Engine_Api::_()->getDbTable('pages', 'sitepagewishlist')->wishlistPages($wishlist_id);
    $this->view->wishlistPageData = array();
    if (!empty($wishlistPageData)) {
      $this->view->wishlistPageData = $wishlistPageData->toArray();
    }
    $this->view->total_item = Count($wishlistPageData);
  }

	//ACTION FOR CREATING THE WISHLIST
  public function createAction() {

    //GET VIEWER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

    //FORM GENERATION
    $this->view->form = $form = new Sitepagewishlist_Form_Create();

    if (!$this->getRequest()->isPost() || !$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    //GET WISHLIST TABLE
    $wishlistTable = Engine_Api::_()->getItemTable('sitepagewishlist_wishlist');
    $db = $wishlistTable->getAdapter();
    $db->beginTransaction();

    try {

			//GET FORM VALUES
      $values = $form->getValues();
      $values['owner_id'] = $viewer->getIdentity();

      //CREATE WISHLIST
      $wishlist = $wishlistTable->createRow();
      $wishlist->setFromArray($values);
      $wishlist->save();

			//PRIVACY WORK
      $auth = Engine_Api::_()->authorization()->context;
      $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

      if (empty($values['auth_view'])) {
        $values['auth_view'] = array('everyone');
      }

      $viewMax = array_search($values['auth_view'], $roles);
      foreach ($roles as $i => $role) {
        $auth->setAllowed($wishlist, $role, 'view', ($i <= $viewMax));
      }

      $db->commit();
    } catch (Exception $e) {
      $db->rollback();
      throw $e;
    }

		$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('Wish List is created Successfully !'))
		));
  }

	//ACTION FOR EDIT WISHLIST
  public function editAction() {

		//GET WISHLIST ID AND CHECK VALIDATION
    $wishlist_id = $this->_getParam('wishlist_id');
    if (empty($wishlist_id)) {
      return $this->_forward('notfound', 'error', 'core');
    }

		//FORM GENERATION
    $this->view->form = $form = new Sitepagewishlist_Form_Edit();
	
		//GET WISHLIST OBJECT
    $wishlist = Engine_Api::_()->getItem('sitepagewishlist_wishlist', $wishlist_id);

    if (!$this->getRequest()->isPost()) {

      //PRIVACY WORK
      $auth = Engine_Api::_()->authorization()->context;
      $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
      $perms = array();
      foreach ($roles as $roleString) {
        $role = $roleString;
        if ($auth->isAllowed($wishlist, $role, 'view')) {
          $perms['auth_view'] = $roleString;
        }
      }

      $form->populate($wishlist->toArray());
      $form->populate($perms);
      return;
    }

		//FORM VALIDATION
    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $db = Engine_Api::_()->getItemTable('sitepagewishlist_wishlist')->getAdapter();
    $db->beginTransaction();

    try {

			//GET FORM VALUES
      $values = $form->getValues();

			//SAVE DATA
      $wishlist->setFromArray($values);
      $wishlist->save();

			//PRIVACTY WORK
      $auth = Engine_Api::_()->authorization()->context;
      $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

      if (empty($values['auth_view'])) {
        $values['auth_view'] = array('everyone');
      }

      $viewMax = array_search($values['auth_view'], $roles);
      foreach ($roles as $i => $role) {
        $auth->setAllowed($wishlist, $role, 'view', ($i <= $viewMax));
      }

      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

		//GET URL
		$url = $this->_helper->url->url(array('action' => 'manage'), 'sitepagewishlist_general');

		$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => true,
				'smoothboxClose' => 10,
				'parentRedirect' => $url,
				'parentRedirectTime' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('Wish List is edited Successfully !'))
		));
  }

	//ACTION FOR MANAGE WISHLISTS
  public function manageAction() {

    //GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('sitepage_main');

		//GET VIEWER DETAIL
    $viewer = Engine_Api::_()->user()->getViewer();

		//GET PAGINATOR
    $this->view->paginator = Engine_Api::_()->getDbtable('wishlists', 'sitepagewishlist')->userWishlists($viewer->getIdentity(), 1, 0);
    $this->view->paginator->setItemCountPerPage(10);
    $this->view->paginator->setCurrentPageNumber($this->_getParam('page'));
  }

  //ACTION FOR PRINT WISHLIST
  public function printAction() {

		//GET WISHLIST ID AND SET WISHLIST SUBJECT
    $wishlist = null;
    if (null !== ($wishlist_id = $this->_getParam('wishlist_id'))) {
      $wishlist = Engine_Api::_()->getItem('sitepagewishlist_wishlist', $wishlist_id);
      if (null !== $wishlist) {
        Engine_Api::_()->core()->setSubject($wishlist);
      }
    }

		//SUBJECT VALIDATION
    if (!$this->_helper->requireSubject('sitepagewishlist_wishlist')->isValid()) {
      return;
    }

		//PAGE OFFER IS INSTALLED OR NOT
		$this->view->sitepageOfferEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepageoffer');

		//GET WISHLIST
    $this->view->wishlist = $wishlist = Engine_Api::_()->core()->getSubject('sitepagewishlist_wishlist');

		//GET OWNER
    $this->view->owner = $wishlist->getOwner();

		//GET WISHLIST PAGE DATA
    $wishlistPageData = Engine_Api::_()->getDbTable('pages', 'sitepagewishlist')->wishlistPages($wishlist_id);
    $this->view->wishlistPageData = array();
    if (!empty($wishlistPageData)) {
      $this->view->wishlistPageData = $wishlistPageData->toArray();
    }
    $this->view->total_item = Count($wishlistPageData);
  }

  //ACTION FOR DELETE WISHLIST
  public function deleteAction() {

		//DEFAULT LAYOUT
    $this->_helper->layout->setLayout('default-simple');

		//GET WISHLIST ID
    $this->view->wishlist_id = $wishlist_id = $this->_getParam('wishlist_id');

    if ($this->getRequest()->isPost()) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      try {

				//DELETE WISHLIST CONTENT
				Engine_Api::_()->sitepagewishlist()->deleteContent($wishlist_id);

        $db->commit();
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
      $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => true,
          'parentRedirect' => $this->_helper->url->url(array('action' => 'manage'), 'sitepagewishlist_general'),
          'messages' => array('Wish List has been deleted successfully!')
      ));
    } else {
      $this->renderScript('index/delete.tpl');
    }
  }

	//ACTION FOR SHOWING THE WISHLIST ON PAGE DASHBOARD
  public function dashboardWishlistAction() {

    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitepage_main');

    //GET PAGE ID
    $page_id = $this->_getParam('page_id');

    //GET SITEPAGE ITEM
    $this->view->sitepage = $sitepage = Engine_Api::_()->getItem('sitepage_page', $page_id);

    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitepage()->isManageAdmin($sitepage, 'edit');
    if (empty($isManageAdmin)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //GET SELECTED TAB
    $this->view->sitepages_view_menu = 35;

    //GET REQUEST IS AJAX OR NOT
    $this->view->is_ajax = $this->_getParam('is_ajax', '');

    $this->view->paginator = Engine_Api::_()->getDbtable('wishlists', 'sitepagewishlist')->dashboardWishlists($page_id);
    $this->view->paginator->setItemCountPerPage(10);
    $this->view->paginator->setCurrentPageNumber($this->_getParam('page'));
  }

}
?>