<?php

class Sitepoll_Form_Admin_Settings_Level extends Authorization_Form_Admin_Level_Abstract{
    public function init(){
        parent::init();

        // My stuff
        $this
            ->setTitle('Member Level Settings')
            ->setDescription("These settings are applied on a per member level basis. Start by selecting the member level you want to modify, then adjust the settings for that level below.");

        // Element: view
        $this->addElement('Radio', 'view', array(
            'label' => 'Allow Viewing of Polls?',
            'description' => 'Do you want to let members view polls? If set to no, some other settings on this page may not apply.',
            'multiOptions' => array(
                2 => 'Yes, allow viewing of all polls, even private ones.',
                1 => 'Yes, allow viewing of polls.',
                0 => 'No, do not allow polls to be viewed.',
            ),
            'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
        if( !$this->isModerator() ) {
            unset($this->view->options[2]);
        }

        if( !$this->isPublic() ) {

            // Element: create
            $this->addElement('Radio', 'create', array(
                'label' => 'Allow Creation of Polls?',
                'description' => 'Do you want to let members create polls? If set to no, some other settings on this page may not apply. This is useful if you want members to be able to view polls, but only want certain levels to be able to create polls.',
                'multiOptions' => array(
                    1 => 'Yes, allow creation of polls.',
                    0 => 'No, do not allow polls to be created.'
                ),
                'value' => 1,
            ));

            // Element: edit
            $this->addElement('Radio', 'edit', array(
                'label' => 'Allow Editing of Polls?',
                'description' => 'Do you want to let members edit polls? If set to no, some other settings on this page may not apply.',
                'multiOptions' => array(
                    2 => 'Yes, allow members to edit all polls.',
                    1 => 'Yes, allow members to edit their own polls.',
                    0 => 'No, do not allow members to edit their polls.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if( !$this->isModerator() ) {
                unset($this->edit->options[2]);
            }

            // Element: delete
            $this->addElement('Radio', 'delete', array(
                'label' => 'Allow Deletion of Polls?',
                'description' => 'Do you want to let members delete polls? If set to no, some other settings on this page may not apply.',
                'multiOptions' => array(
                    2 => 'Yes, allow members to delete all polls.',
                    1 => 'Yes, allow members to delete their own polls.',
                    0 => 'No, do not allow members to delete their polls.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
            if( !$this->isModerator() ) {
                unset($this->delete->options[2]);
            }

            // Element: vote 
            $this->addElement('Radio', 'vote', array(
                'label' => 'Allow Voting on Polls?',
                'description' => 'Do you want to let members vote on polls?',
                'multiOptions' => array(
                    
                    1 => 'Yes, allow members to vote on polls.',
                    0 => 'No, do not allow members to vote on polls.',
                ),
                'value' =>1,
            ));

            // Element: comment
            $this->addElement('Radio', 'comment', array(
                'label' => 'Allow Commenting on Polls?',
                'description' => 'Do you want to let members of this level comment on polls?',
                'multiOptions' => array(
                    2 => 'Yes, allow members to comment on all polls, including private ones.',
                    1 => 'Yes, allow members to comment on polls.',
                    0 => 'No, do not allow members to comment on polls.',
                ),
                'value' => ( $this->isModerator() ? 2 : 1 ),
            ));
             if( !$this->isModerator() ) {
                unset($this->comment->options[2]);
            }

            // Element: auto approve
            $this->addElement('Radio', 'autoapprove', array(
                'label' => 'Allow Poll to auto approve ?',
                'description' => 'Do you want a new Poll to be automatically approved?',
                'multiOptions' => array(
                    
                    1 => 'Yes, automatically approve Poll.',
                    0 => 'No, site admin approval will be required for all Polls.',
                ),
                'value' =>1,
            ));

            // Element: featured
            $this->addElement('Radio', 'featured', array(
                'label' => 'Allow Poll to automatically mark as featured',
                'description' => 'Do you want a new Poll to be automatically made featured?',
                'multiOptions' => array(
                    
                    1 => 'Yes, automatically make Poll featured.',
                    0 => 'No, the site admin will be making the Poll featuredstrucure.',
                ),
                'value' =>1,
            ));            

            // Element: sponsered
            $this->addElement('Radio', 'sponsored', array(
                'label' => 'Allow Poll to automatically mark as sponsored',
                'description' => 'Do you want a new Poll to be automatically made sponsored?',
                'multiOptions' => array(
                    
                    1 => 'Yes, automatically make Poll sponsored.',
                    0 => 'No, the site admin will be making the Poll sponsored.',
                ),
                'value' =>1,
            ));   

            // Element: type
            $this->addElement('MultiCheckbox', 'auth_type', array(
                'label' => 'Poll Type Options',
                'description' => 'Your members can choose any of the options checked below that which type of media poll they want to post. If you select only one option, members of this level will not have a choice.',
                'multiOptions' => array(
                    '0'       => 'Text',
                    '2'       => 'Photo',
                    '3'       => 'Text with Photo',
                ),
                'required' => true,
                'value' => array(0,2,3),
            ));

            // Element: auth_view
            $this->addElement('MultiCheckbox', 'auth_view', array(
                'label' => 'Poll View Privacy',
                'description' => 'Your members can choose from any of the options checked below when they decide who can see their poll entries. These options appear on your members. If you do not check any options, settings will default to the last saved configuration. If you select only one option, members of this level will not have a choice.',
                'multiOptions' => array(
                    'everyone'            => 'Everyone',
                    'registered'          => 'All Registered Members',
                    'owner_network'       => 'Friends and Networks',
                    'owner_member_member' => 'Friends of Friends',
                    'owner_member'        => 'Friends Only',
                    'owner'               => 'Just Me'
                ),
                'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
            ));

            // Element: auth_comment
            $this->addElement('MultiCheckbox', 'auth_comment', array(
                'label' => 'Poll Comment Options',
                'description' => 'Your members can choose from any of the options checked below when they decide who can post comments on their entries. If you do not check any options, settings will default to the last saved configuration. If you select only one option, members of this level will not have a choice.',
                'multiOptions' => array(
                    'everyone'            => 'Everyone',
                    'registered'          => 'All Registered Members',
                    'owner_network'       => 'Friends and Networks',
                    'owner_member_member' => 'Friends of Friends',
                    'owner_member'        => 'Friends Only',
                    'owner'               => 'Just Me'
                ),
                'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
            ));

            // Element: Bar Style
            $this->addElement('MultiCheckbox', 'auth_style', array(
                'label' => 'Poll Bar Styles',
                'description' => 'Select which poll styles do you want to be enabled for this member level. 
                     Pie, Doughnut, Bar.',
                'multiOptions' => array(
                    'pie chart'            => 'Pie Chart',
                    'doughnut'             => 'Doughnut',
                    'progress chart'       => 'Progress Bar Chart'
                ),
                'required' => true,
                'value' => array('pie chart','doughnut','progress chart'),
            ));

            // Element: max
            $this->addElement('Text', 'max', array(
                'label' => 'Maximum Allowed Poll Entries?',
                'description' => 'Enter the maximum number of allowed poll entries. The field must contain an integer between 1 and 999, or 0 for unlimited.',
                'validators' => array(
                    array('Int', true),
                    new Engine_Validate_AtLeast(0),
                ),
                'required' => true,
                'value'=>0,
            ));

            // Element: FLOOD
            $this->addElement('FloodControl', 'flood', array(
                'label' => 'Maximum Allowed Poll Entries per Duration',
                'description' => 'Enter the maximum number of poll entries allowed for the selected duration (per minute / per hour / per day) for members of this level. The field must contain an integer between 1 and 9999, or 0 for unlimited.',
                'required' => true,
                'allowEmpty' => false,
                'value' => array(0, 'minute'),
            ));
            
        }
    }
}
