<?php

class Sitepoll_Model_DbTable_Polls extends Core_Model_Item_DbTable_Abstract
{ 
    protected $_rowClass = 'Sitepoll_Model_Poll';

    public function getPollsPaginator($params = array()) {
        $paginator = Zend_Paginator::factory($this->getPollsSelect($params));
        if( !empty($params['page']) ){
            $paginator->setCurrentPageNumber($params['page']);
        }
        if( !empty($params['limit']) ){
            $paginator->setItemCountPerPage($params['limit']);
        }

        if( empty($params['limit']) ){
            $page = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.page', 10);
            $paginator->setItemCountPerPage($page);
        }

        return $paginator;
    }

    public function getPollsSelect($params = array()) {
        $viewer = Engine_Api::_()->user()->getViewer();

        $table = Engine_Api::_()->getDbTable('polls','sitepoll');
        $tableName = $table->info('name');

        $reportTable = Engine_Api::_()->getDbtable('reports','sitepoll');
        $reportName = $reportTable->info('name');

        $tmTable = Engine_Api::_()->getDbtable('TagMaps', 'core');
        $tmName = $tmTable->info('name');

        $select = $table->select();
        $report = $reportTable->select();
        $select = $this
        ->select()
        ->from($this);

        $report
            ->from($reportName, array('poll_id'))
            ->where($reportName.'.user_id'."=".$viewer->getIdentity());
     
        if( !empty($params['tag']) ){
            $select
                ->setIntegrityCheck(false)
                ->joinInner($tmName, "$tmName.resource_id = $tableName.poll_id")
                ->where($tmName.'.resource_type = ?', 'sitepoll_poll')
                ->where($tmName.'.tag_id = ?', $params['tag']);
        }

        // my poll search
        if( !empty($params['user_id'])){
            $select = $select->where($tableName. '.user_id = ?', $params['user_id'] )
                              ->where($tableName . ".search = ?", 1)
            ->order($tableName.'.creation_date DESC');
        }
        
        if( !empty($params['user_id']) && is_numeric($params['user_id']) ){
            $owner = Engine_Api::_()->getItem('user', $params['user_id']);
            $select = $this->getProfileItemsSelect($owner, $select);
        } elseif( !empty($params['user']) && $params['user'] instanceof User_Model_User ) {
            $owner = $params['user'];
            $select = $this->getProfileItemsSelect($owner, $select);
        } elseif( isset($params['users']) ) {
            $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
            $select->where($rName.'.owner_id in (?)', new Zend_Db_Expr($str));
            if( !in_array($viewer->level_id, $this->_excludedLevels) ) {
                $select->where("view_privacy != ? ", 'owner');
            }
        } else {
            $param = array();
            $select = $this->getItemsSelect($param, $select);
        }

        // search bar
        if( !empty($params['search']) ){
            $select->where($tableName.".title LIKE ? OR ".$tableName.".title LIKE ?", '%'.$params['search'].'%');
        }

        if( !empty($params['closed']) ){
            if ($params['closed']==1){
                $select->where($tableName.'.is_closed = ?', 0);
            } else if($params['closed']==2){
                $select->where($tableName.'.is_closed = ?', 1);
            }
        }

        if (isset($params['category']) && !empty($params['category'])){
                $select->where($tableName. '.category_id = ?', $params['category']);     
        }

        if (isset($params['orderby']) && !empty($params['orderby'])){
            if ($params['orderby']=='featured')
                $select->where($tableName.'.featured = ?', '1');

            if ($params['orderby']=='sponsored')
                $select = $select->where($tableName. '.sponsored = ?', '1');

            if ($params['orderby']=='view_count')
                $select = $select->where($tableName. '.view_count <> ?', '0')->order($tableName. '.view_count DESC');

            if ($params['orderby']=='like_count')
                $select = $select->where($tableName. '.like_count <> ?', '0')->order($tableName. '.like_count DESC');

            if ($params['orderby']=='comment_count')
                $select = $select->where($tableName. '.comment_count <> ?', '0')->order($tableName. '.comment_count DESC');

            if ($params['orderby']=='vote_count')
                $select = $select->where($tableName. '.vote_count <> ?', '0')->order($tableName. '.vote_count DESC');

            if ($params['orderby']=='most_voted')
                $select = $select->where($tableName. '.vote_count <> ?', '0')->order($tableName. '.vote_count DESC');

            if ($params['orderby']=='creation_date')
                $select->order($tableName. '.start_datetime DESC');

            if ($params['orderby']=='title')
                $select->order($tableName. '.title ASC');

            if ($params['orderby']=='popular')
                $select
            ->where($tableName. '.vote_count <> ?', '0')->order($tableName. '.vote_count DESC')
            ->where($tableName. '.view_count <> ?', '0')->order($tableName. '.view_count DESC');
        }

        if (isset($params['auth_type']) && !empty($params['auth_type'])) {
            if ($params['auth_type']==1)
                $select = $select->where($tableName. '.auth_type = ?', '0');

            if ($params['auth_type']==2)
                $select = $select->where($tableName. '.auth_type = ?', '2');

            if ($params['auth_type']==3)
                $select = $select->where($tableName. '.auth_type = ?', '3');
        }

        // browse poll search
        if( !empty($params['approved'])){
            $select = $select
                             ->where($tableName. '.approved = ?', '1')
                             ->where($tableName . ".search = ?", 1)
                             ->where($tableName. '.declined = ?', '0');
        }

        if (isset($params['ordering']) && !empty($params['ordering'])) {
            if(!empty($params['ordering']==1)){
                $select = $select->order($tableName.'.start_datetime ASC');
            } 

            if(!empty($params['ordering']==0)){
                $select=$select->order($tableName.'.view_count DESC');
            }

            if(!empty($params['ordering']==2)){
                $select=$select->order($tableName.'.title ASC');
            }

            if(!empty($params['ordering']==3)){ 
                $select=$select
                ->order($tableName.'.sponsored DESC' )
                ->order($tableName.'.start_datetime ASC');
            }

            if(!empty($params['ordering']==4)){
                $select=$select 
                ->order($tableName.'.featured DESC' )
                ->order($tableName.'.start_datetime ASC');
            }

            if(!empty($params['ordering']==5)){
                $select=$select 
                ->order($tableName.'.sponsored DESC' )
                ->order($tableName.'.featured DESC' )
                ->order($tableName.'.start_datetime ASC');
            }

            if(!empty($params['ordering']==6)){
                $select=$select 
                ->order($tableName.'.featured DESC' )
                ->order($tableName.'.sponsored DESC' )
                ->order($tableName.'.start_datetime ASC');
            }
        }
        if( !empty($params['sort'])) {

            if( $params['sort'] == 'featured' ) {
                $select->where($tableName . '.featured = ?', 1);
            }

            if( $params['sort'] == 'sponsored' ) {
                $select->where($tableName . '.sponsored = ?', 1);
            }
        }

        return $select;
    }

    public function getItemsSelect($params, $select = null){
        if( $select == null ) {
            $select = $this->select();
        }
        if( isset($params['search']) ) {
            $select->where("search = ?", $params['search']);
        }
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('poll.allow.unauthorized', 0)){
            return $select;
        }
        $table = $this->info('name');
        $registeredPrivacy = array('everyone', 'registered');
        $viewer = Engine_Api::_()->user()->getViewer();
        if( $viewer->getIdentity() && !in_array($viewer->level_id, $this->_excludedLevels) ) {
            $viewerId = $viewer->getIdentity();
            $netMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
            $viewerNetwork = $netMembershipTable->getMembershipsOfIds($viewer);
            if( !empty($viewerNetwork) ) {
                array_push($registeredPrivacy,'owner_network');
            }
            $friendsIds = $viewer->membership()->getMembersIds();
            $friendsOfFriendsIds = $friendsIds;
            foreach( $friendsIds as $friendId ) {
                $friend = Engine_Api::_()->getItem('user', $friendId);
                $friendMembersIds = $friend->membership()->getMembersIds();
                $friendsOfFriendsIds = array_merge($friendsOfFriendsIds, $friendMembersIds);
            }
        }
        if( !$viewer->getIdentity() ) {
            $select->where("view_privacy = ?", 'everyone');
        } elseif( !in_array($viewer->level_id, $this->_excludedLevels) ) {
            $select->Where("$table.user_id = ?", $viewerId)
            ->orwhere("view_privacy IN (?)", $registeredPrivacy);
            if( !empty($friendsIds) ) {
                $select->orWhere("view_privacy = 'owner_member' AND $table.user_id IN (?)", $friendsIds);
            }
            if( !empty($friendsOfFriendsIds) ) {
                $select->orWhere("view_privacy = 'owner_member_member' AND $table.user_id IN (?)", $friendsOfFriendsIds);
            }
            if( empty($viewerNetwork) && !empty($friendsOfFriendsIds) ) {
                $select->orWhere("view_privacy = 'owner_network' AND $table.user_id IN (?)", $friendsOfFriendsIds);
            }
            $subquery = $select->getPart(Zend_Db_Select::WHERE);
            $select ->reset(Zend_Db_Select::WHERE);
            $select ->where(implode(' ',$subquery));
        }

        return $select;
    }

    public function getProfileItemsSelect($owner, $select = null){
        if( $select == null ) {
            $select = $this->select();
        }
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('poll.allow.unauthorized', 0)){
            return $select;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewerId = $viewer->getIdentity();
        if( !empty($owner) ) {
            $ownerId = $owner->getIdentity();
        }
        $isOwnerOrAdmin = false;
        if( !empty($viewerId) && ($ownerId == $viewerId || in_array($viewer->level_id, $this->_excludedLevels)) ) {
            $isOwnerOrAdmin = true;
        }
        if( !empty($owner) && $owner instanceof Core_Model_Item_Abstract ) {
            $select
            ->where('user_id = ?', $ownerId);

            if( $isOwnerOrAdmin ) {
                return $select;
            }
            $isOwnerViewerLinked = true;
            if( $viewer->getIdentity() ) {
                $restrictedPrivacy = array('owner');
                $ownerFriendsIds = $owner->membership()->getMembersIds();
                if( !in_array($viewerId, $ownerFriendsIds) ) {
                    array_push($restrictedPrivacy, 'owner_member');
                    $friendsOfFriendsIds = array();
                    foreach( $ownerFriendsIds as $friendId ) {
                        $friend = Engine_Api::_()->getItem('user', $friendId);
                        $friendMembersIds = $friend->membership()->getMembersIds();
                        $friendsOfFriendsIds = array_merge($friendsOfFriendsIds, $friendMembersIds);
                    }
                    if( !in_array($viewerId, $friendsOfFriendsIds) ) {
                        array_push($restrictedPrivacy, 'owner_member_member');
                        $netMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
                        $viewerNetwork = $netMembershipTable->getMembershipsOfIds($viewer);
                        $ownerNetwork = $netMembershipTable->getMembershipsOfIds($owner);
                        $checkViewer = array_intersect($viewerNetwork, $ownerNetwork);
                        if( empty($checkViewer) ) {
                            $isOwnerViewerLinked = false;
                        }
                    }
                }
                if( $isOwnerViewerLinked ) {
                    $select->where("view_privacy NOT IN (?)", $restrictedPrivacy);
                    return $select;
                }
            }
            $select->where("view_privacy = ?", 'everyone');
        }
        return $select;
    }

    public function updatePollState(){
        $pollTableName = $this->info('name');
        $select = $this->select()->from($pollTableName, '*')
        ->where('is_closed=?', 0)
        ->where('start_datetime!=?', 0000-00-00 );
        $polls = $this->fetchAll($select);
        $expire_time = new DateTime(date('Y-m-d H:i:s'), new DateTimeZone('UTC'));
        $expire_time = $expire_time->format('Y-m-d H:i:s');

        foreach ($polls as $poll) {
            if(!$poll || $poll->end_datetime <=$expire_time){
                $poll->is_closed = 1;
                $poll->status= 'Expired';
                $poll->save();
            }
        }
    }

    public function updatePollRequest(){
        $pollTableName = $this->info('name');
        $max_no=Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.maxreminder', 4);
        $select = $this->select()->from($pollTableName, '*')
                       ->where('request=?', 1)
                       ->where('request_no<?' ,$max_no);
        $polls = $this->fetchAll($select);
        $expire_time = new DateTime(date('Y-m-d H:i:s'), new DateTimeZone('UTC'));
        $expire_time = $expire_time->format('Y-m-d H:i:s');

        foreach ($polls as $poll) {
            if(!$poll || $poll->request_datetime <=$expire_time){
                $poll->request = 0;
                // $poll->status= 'Expired';
                $poll->save();
            }
        }
    }

    public function getTagCloud($limit = 100, $count_only = 0,$params=array()) {
        $tableTagmaps = 'engine4_core_tagmaps';
        $tableTags = 'engine4_core_tags';

        $tableSitepolls = $this->info('name');
        $select = $this->select()
                        ->setIntegrityCheck(false)
                        ->from($tableSitepolls, array(''))
                        ->joinInner($tableTagmaps, "$tableSitepolls.poll_id = $tableTagmaps.resource_id", array('COUNT(engine4_core_tagmaps.resource_id) AS Frequency'))
                        ->joinInner($tableTags, "$tableTags.tag_id = $tableTagmaps.tag_id", array('text', 'tag_id'))
                        ->where($tableSitepolls . ".search = ?", 1)
                        ->where($tableSitepolls . '.is_closed = ?', "0")
                        ->where($tableSitepolls . '.approved = ?', "1");
        $select = $select
                        ->where($tableTagmaps . '.resource_type = ?', 'sitepoll_poll')
                        ->group("$tableTags.text");

        if (isset($params['orderingType']) && !empty($params['orderingType']))
            $select->order("$tableTags.text");
        else
            $select->order("Frequency DESC");
                        
        if (!empty($count_only)) {
            $total_results = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
            return Count($total_results);
        }

        $select = $select->limit($limit);
        return $select->query()->fetchAll();
    }

    public function getNetworkBaseSql($select, $params = array()) {
        if (empty($select))
          return;
        $sitepoll_tableName = $this->info('name');
        //START NETWORK WORK
        $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.network', 0);
        if (!empty($enableNetwork) || (isset($params['browse_network']) && !empty($params['browse_network']))) {
          $viewer = Engine_Api::_()->user()->getViewer();
          $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
          if (!Engine_Api::_()->getApi('subCore', 'sitepage')->pageBaseNetworkEnable()) {
            $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

            if (!empty($viewerNetwork)) {
              if (isset($params['setIntegrity']) && !empty($params['setIntegrity'])) {
                $select->setIntegrityCheck(false)
                ->from($sitepage_tableName);
            }
            $networkMembershipName = $networkMembershipTable->info('name');
            $select
            ->join($networkMembershipName, "`{$sitepage_tableName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity());
            if (!isset($params['not_groupBy']) || empty($params['not_groupBy'])) {
                $select->group($sitepage_tableName . ".page_id");
            }
            if (isset($params['extension_group']) && !empty($params['extension_group'])) {
                $select->group($params['extension_group']);
            }
          }
        } else {
            $viewerNetwork = $networkMembershipTable->getMembershipsOfInfo($viewer);
            $str = array();
            $columnName = "`{$sitepage_tableName}`.networks_privacy";
            foreach ($viewerNetwork as $networkvalue) {
              $network_id = $networkvalue->resource_id;
              $str[] = "'" . $network_id . "'";
              $str[] = "'" . $network_id . ",%'";
              $str[] = "'%," . $network_id . ",%'";
              $str[] = "'%," . $network_id . "'";
          }
          if (!empty($str)) {
              $likeNetworkVale = (string) ( join(" or $columnName  LIKE ", $str) );
              $select->where($columnName . ' LIKE ' . $likeNetworkVale . ' or ' . $columnName . " IS NULL");
          } else {
              $select->where($columnName . " IS NULL");
          }
        }
              //END NETWORK WORK
        } else {
          $select = $this->addPrivacyPagesSQl($select, $this->info('name'));
        }

        return $select;
    }


}
