<?php

class Sitepoll_Model_Poll extends Core_Model_Item_Abstract{
    public function setPhoto($photo){
        if( $photo instanceof Zend_Form_Element_File ) {
            $file = $photo->getFileName();
        } elseif( is_array($photo) && !empty($photo['tmp_name']) ) {
            $file = $photo['tmp_name'];
        } elseif( is_string($photo) && file_exists($photo) ) {
            $file = $photo;
        } else {
            throw new Sitepoll_Model_Exception('Invalid argument passed to setPhoto: ' . print_r($photo, 1));
        }

        $name = basename($file);
        $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
        $params = array(
            'parent_type' => 'sitepoll',
            'parent_id' => $this->getIdentity()
        );

        // Save
        $storage = Engine_Api::_()->storage();

        // Resize image (main)
        $image = Engine_Image::factory();
        $image->open($file)
            ->resize(720, 720)
            ->write($path . '/m_' . $name)
            ->destroy();

        // Resize image (profile)
        $image = Engine_Image::factory();
        $image->open($file)
            ->resize(200, 400)
            ->write($path . '/p_' . $name)
            ->destroy();

        // Resize image (normal)
        $image = Engine_Image::factory();
        $image->open($file)
            ->resize(140, 160)
            ->write($path . '/in_' . $name)
            ->destroy();

        // Resize image (icon)
        $image = Engine_Image::factory();
        $image->open($file);

        $size = min($image->height, $image->width);
        $x = ($image->width - $size) / 2;
        $y = ($image->height - $size) / 2;

        $image->resample($x, $y, $size, $size, 48, 48)
            ->write($path . '/is_' . $name)
            ->destroy();

        // Store
        $iMain = $storage->create($path . '/m_' . $name, $params);
        $iProfile = $storage->create($path . '/p_' . $name, $params);
        $iIconNormal = $storage->create($path . '/in_' . $name, $params);
        $iSquare = $storage->create($path . '/is_' . $name, $params);

        $iMain->bridge($iProfile, 'thumb.profile');
        $iMain->bridge($iIconNormal, 'thumb.normal');
        $iMain->bridge($iSquare, 'thumb.icon');

        // Remove temp files
        @unlink($path . '/p_' . $name);
        @unlink($path . '/m_' . $name);
        @unlink($path . '/in_' . $name);
        @unlink($path . '/is_' . $name);

        // Update row
        $this->modified_date = date('Y-m-d H:i:s');
        $this->photo_id = $iMain->getIdentity();
        $this->save();

        return $this;
    }

    public function getParentItem(){
        if(!$this->parent_type || !$this->parent_id || $this->parent_type == "user")
          return false;
        return Engine_Api::_()->getItem($this->parent_type,$this->parent_id) ?? false;
    }

    public function getCategoryItem(){
        if(!$this->category_id)
          return false;
        return Engine_Api::_()->getItem('sitepoll_category',$this->category_id);
    }

    public function getPhotoUrl($type = null){
        if( $this->photo_id ) {
            return parent::getPhotoUrl($type);
        }
        return $this->getOwner()->getPhotoUrl($type);
    }

    public function getKeywords($separator = ' ')
    {
        $keywords = array();
        foreach( $this->tags()->getTagMaps() as $tagmap ) {
            $tag = $tagmap->getTag();
            if ($tag === null) {
                continue;
            }
            $keywords[] = $tag->getTitle();
        }

        if( null === $separator ) {
            return $keywords;
        }

        return join($separator, $keywords);
    }
    
    // Interfaces

    /**
     * Gets a proxy object for the comment handler
     *
     * @return Engine_ProxyObject
     **/
    public function comments(){
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
    }

    /**
     * Gets a proxy object for the like handler
     *
     * @return Engine_ProxyObject
     **/
    public function likes()
    {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
    }

    /**
     * Gets a proxy object for the tags handler
     *
     * @return Engine_ProxyObject
     **/
    public function tags()
    {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('tags', 'core'));
    }

    public function viewerVoted()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        return $this->getVote($viewer);
    }

    public function hasVoted(User_Model_User $user)
    {
        $table = Engine_Api::_()->getDbtable('votes', 'sitepoll');
        return (bool) $table
            ->select()
            ->from($table, 'COUNT(*)')
            ->where('poll_id = ?', $this->getIdentity())
            ->where('user_id = ?', $user->getIdentity())
            ->query()
            ->fetchColumn(0)
            ;
    }

    public function getVote(User_Model_User $user)
    {
        $table = Engine_Api::_()->getDbtable('votes', 'sitepoll');
        $tableName=$table->info('name');
        $select = $table->select();
        return $select
            ->from($tableName, 'option_id')
            ->where('poll_id = ?', $this->getIdentity())
            ->where('user_id = ?', $user->getIdentity())
            ->query()
            ->fetchColumn(0)
            ;
    }
 
    public function getHref($params = array()) 
    {
        $params = array_merge(array(
            'route' => 'sitepoll_view',
            'reset' => true,
            'user_id' => $this->user_id,
            'poll_id' => $this->poll_id,
        ), $params);
        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        return Zend_Controller_Front::getInstance()->getRouter()
            ->assemble($params, $route, $reset);
    }
    
    public function getTitle() {

        return $this->title;
    }

    public function getOptions(){
        return Engine_Api::_()->getDbtable('options', 'sitepoll')->fetchAll(array(
            'poll_id = ?' => $this->getIdentity(),
        ));
    }

    public function isPOllSucceeded($startdatetime,$enddatetime) {
        $pollExpr = strtotime(date('Y-m-d H:i:s', strtotime($enddatetime)));
        $pollStart = strtotime(date('Y-m-d H:i:s', strtotime($startdatetime)));
        if ($pollStart <= strtotime(date('Y-m-d H:i:s')) && strtotime(date('Y-m-d H:i:s')) <= $pollExpr) {
            return true;
        } else {
            return false;
        }
    }

    public function getStatus(){
        if ($this->isPollSucceeded($this->start_datetime,$this->end_datetime)) {
            $poll_status = 'Active';
        }else{
            $poll_status = 'Ended';
        }
        $pollExpr = strtotime(date('Y-m-d H:i:s', strtotime($this->end_datetime)));
        $pollStart = strtotime(date('Y-m-d H:i:s', strtotime($this->start_datetime)));
        if ($pollStart >= strtotime(date('Y-m-d H:i:s')) && strtotime(date('Y-m-d H:i:s')) <= $pollExpr) {
            $poll_status = 'Pending';
        }
        return $poll_status;
    }

    public function getSlug($str = null, $maxstrlen = 255) {
        if( null === $str ) {
          $str = $this->getTitle();
        }

        return Engine_Api::_()->seaocore()->getSlug($str, 225);
    }

    public function _delete(){
        $optionsTable = Engine_Api::_()->getItemTable('sitepoll_option');
        $optionsTable->delete(array('poll_id=?' => $this->poll_id));
        $reportsTable = Engine_Api::_()->getItemTable('sitepoll_report');
        $reportsTable->delete(array('poll_id=?' => $this->poll_id));
        $votesTable = Engine_Api::_()->getItemTable('sitepoll_vote');
        $votesTable->delete(array('poll_id=?' => $this->poll_id));
        parent::_delete();
    }

    public function postdelete(){
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->poll_id);
        $viewer = Engine_Api::_()->user()->getViewer();
        $user=Engine_Api::_()->getItem('user', $poll->user_id);
        $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
        $activityApi->removeActivities($user, $poll, 'sitepoll_new');
    }

    public function vote(User_Model_User $user, $option){
        $votesTable = Engine_Api::_()->getDbTable('votes', 'sitepoll');
        $optionsTable = Engine_Api::_()->getDbtable('options', 'sitepoll');

        // Get poll option
        if( is_numeric($option) ) {
            $option = $optionsTable->find((int) $option)->current();
        }
        if( !($option instanceof Zend_Db_Table_Row_Abstract) ) {
            throw new Engine_Exception('Missing or invalid poll option');
        }

        // Check for existing vote
        $vote = $votesTable->fetchRow(array(
            'poll_id = ?' => $this->getIdentity(),
            'user_id = ?' => $user->getIdentity(),
        ));

        // New vote is the same as old vote, ignore
        if( $vote &&
            $option->option_id == $vote->option_id ) {
            return $this;
        }

        if( !$vote ) {
            // Vote did not exist

            // Create vote
            $vote = $votesTable->createRow();
            $vote->setFromArray(array(
                'poll_id' => $this->getIdentity(),
                'user_id' => $user->getIdentity(),
                'option_id' => $option->option_id,
                'creation_date' => date("Y-m-d H:i:s"),
                'modified_date' => date("Y-m-d H:i:s"),
            ));
            $vote->save();

            // Increment new option count
            $optionsTable->update(array(
                'votes' => new Zend_Db_Expr('votes + 1'),
            ), array(
                'poll_id = ?' => $this->getIdentity(),
                'option_id = ?' => $vote->option_id,
            ));

            // Update internal vote count
            $this->vote_count = new Zend_Db_Expr('vote_count + 1');
            $this->save();
        } else {
            // Vote did exist

            // Decrement old option count
            $optionsTable->update(array(
                'votes' => new Zend_Db_Expr('votes - 1'),
            ), array(
                'poll_id = ?' => $this->getIdentity(),
                'option_id = ?' => $vote->option_id,
            ));

            // Change vote
            $vote->option_id = $option->option_id;
            $vote->modified_date  = date("Y-m-d H:i:s");
            $vote->save();

            // Increment new option count
            $optionsTable->update(array(
                'votes' => new Zend_Db_Expr('votes + 1'),
            ), array(
                'poll_id = ?' => $this->getIdentity(),
                'option_id = ?' => $vote->option_id,
            ));
        }
        return $this;
    }

    public function getRichContent(){
        $view = Zend_Registry::get('Zend_View');
        $view = clone $view;
        $view->clearVars();
        $view->addScriptPath('application/modules/Sitepoll/views/scripts/sitepoll');

        $content = '';
        $content .= '
      <div>
        
      ';

        $viewer = Engine_Api::_()->user()->getViewer();
        $options = $this->getOptions();
        $img_path=array();
        $text_option=array();
        $votes=array();
        $options_id=array();

        // Populate form 
        foreach($options as $option){
            $text=$option['poll_option'];
            $text_option[]=$text;
            $votes[]=$option['votes'];
            $options_id[]=$option['option_id'];
            if($option['photo_option']!=0){
                $photo_id=$option['photo_option'];
                $storage_file = Engine_Api::_()->getItem('storage_file', $photo_id);
                $src=$storage_file->map();
                $img_path[]=$src;
            }
        }

        $max=max($votes);
        $sum=array_sum($votes);
        $optionArray=array();
        $optionSrc=array();
        foreach($votes as $key=>$vote){
          if($vote==$max){
            $optionArray[]=$text_option[$key];
            if(!empty($img_path)){
              $optionSrc[]=$img_path[$key];
            }
          }
        }
        $view->optionArray=$optionArray;
        $view->optionSrc=$optionSrc;
        $view->max=$max;
        $view->sum=$sum;
        $view->text_option=$text_option;
        $view->img_path=$img_path;
        $view->options_id=$options_id;
        $view->votes=$votes;
        $view->vote_0=$votes[0];
        $view->vote_1=$votes[1];
        $view->vote_2=$votes[2];
        $view->vote_3=$votes[3];
        $view->vote_4=$votes[4];
        $view->vote_5=$votes[5];
        try{
            $cal=$votes[0]+$votes[1]+$votes[2]+$votes[3]+$votes[4]+$votes[5];
            if($cal!=0){
                $view->cal=$cal;
                $view->voteCount_0=round(($votes[0]/$cal)*100);
                $view->voteCount_1=round(($votes[1]/$cal)*100);
                $view->voteCount_2=round(($votes[2]/$cal)*100);
                $view->voteCount_3=round(($votes[3]/$cal)*100);
                $view->voteCount_4=round(($votes[4]/$cal)*100);
                $view->voteCount_5=round(($votes[5]/$cal)*100);
                $votes_array=array();
                foreach($votes as $vote){
                    $votes_array[]=round(($vote/$cal)*100);
                }
                $view->votes_array=$votes_array;
            }
        }catch( Exception $e ) {
            $db->rollback();
            throw $e;
        }
        $votesTable = Engine_Api::_()->getDbTable('votes', 'sitepoll');
        $flag=1;
        $viewer = Engine_Api::_()->user()->getViewer();
        $view->pre_vote_1=0;
        $view->key=0;
        if($this->hasVoted($viewer)){
            // Check for existing vote
            $vote = $votesTable->fetchRow(array(
                'poll_id = ?' => $this->getIdentity(),
                'user_id = ?' => $viewer->getIdentity(),
            ));
            $v=$vote->option_id;
            $view->pre_vote_1=$this->getIdentity();
            $view->key=$v;
            $key = array_search($v, $options_id);       
        }
        // Render the thing
        $view->poll = $this;
        $view->owner = $owner = $this->getOwner();
        $view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
        $view->pollOptions = $this->getOptions();
        $view->hasVoted = $this->viewerVoted();
        $view->canVote = $this->authorization()->isAllowed(null, 'vote');
        $view->canChangeVote = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.canchangevote', false);
        $view->hideLinks = true;
        $view->title=1;
        $content .= $view->render('view.tpl');

        $content .= '
      </div>
      ';
        return $content;
    }   
}
