<?php
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitepoll
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
class Sitepoll_AdminReportController extends Core_Controller_Action_Admin {

	public function indexAction() {

    	// NAVIGATION
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
		->getNavigation('sitepoll_admin_main', array(), 'sitepoll_admin_main_report');

   	 	// Make form
		$this->view->formFilter = $formFilter = new Sitepoll_Form_Admin_Filter();

    	// Process form
		if ($formFilter->isValid($this->_getAllParams())) {
			$filterValues = $formFilter->getValues();
		} else {
			$filterValues = array();
		}
		if (empty($filterValues['order'])) {
			$filterValues['order'] = 'report_id';
		}
		if (empty($filterValues['direction'])) {
			$filterValues['direction'] = 'DESC';
		}
		$this->view->filterValues = $filterValues;

    	// Get paginator
		$table = Engine_Api::_()->getItemTable('sitepoll_report');
		$select = $table->select()
		->order($filterValues['order'] . ' ' . $filterValues['direction']);
		$this->view->paginator = $paginator = Zend_Paginator::factory($select);
		$paginator->setCurrentPageNumber($this->_getParam('page'));
		$paginator->setItemCountPerPage(10);
	}

  	//DELETE THE REPORT.
	public function deleteAction() {

		$report = Engine_Api::_()->getItem('sitepoll_report', $this->_getParam('id', null));
		$id=$this->_getParam('id');

    	// Save values
		if ($this->getRequest()->isPost()) {
			$report->delete();
			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have successfully delete this abuse report.'))
			));
			$poll = Engine_Api::_()->getItem('sitepoll_poll', $id);
			$viewer = Engine_Api::_()->user()->getViewer();
			$owner = Engine_Api::_()->getItem("user" , $poll->user_id);
			Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $poll, 'sitepoll_poll_delete');
		}
	}

    //MULTI DELETE THE REPORT.
	public function deleteselectedAction() {
		if ($this->getRequest()->isPost()) {
			$values = $this->getRequest()->getPost();
			foreach ($values as $key => $value) {
				if ($key == 'delete_' . $value) {
					$row = Engine_Api::_()->getItem('sitepoll_report', (int) $value);
					if (!empty($row)) {
						$row->delete();
					}
				}
			}
		}
		$this->_helper->redirector->gotoRoute(array('action' => 'index'));
	}

    //FUNCTION FOR TAKE ACTION ON THE REPORT SEND BY USER.
	public function actionAction() {

    // Check report ID and report
		$report_id = $this->_getParam('report_id');
		$poll_id = $this->_getParam('poll_id');
		if (!$report_id) {
			$this->view->closeSmoothbox = true;
			return;
		}
		$report = Engine_Api::_()->getItem('sitepoll_report', $report_id);
		if (!$report) {
			$this->view->closeSmoothbox = true;
			return;
		}

    	// Get subject
		try {
			$this->view->subject = $subject = $report->getSubject();
		} catch (Exception $e) {
			$this->view->subject = $subject = null;
		}

    	// Get subject owner
		if ($subject instanceof Core_Model_Item_Abstract) {
			try {
				$this->view->subjectOwner = $subjectOwner = $subject->getOwner('user');
			} catch (Exception $e) {
        // Silence
				$this->view->subjectOwner = $subjectOwner = null;
			}
		} else {
			$this->view->subjectOwner = $subjectOwner = null;
		}

    	// Get member
		if ($subject instanceof User_Model_User) {
			$user = $subject;
		} else if ($subjectOwner instanceof User_Model_User) {
			$user = $subjectOwner;
		} else {
			$user = null;
		}

    	// Get member level
		if ($user) {
			$level = Engine_Api::_()->getItem('authorization_level', $user->level_id);
			if ($level->type == 'admin') {
        $user = null; // Can't delete admins
    	}
	}

	    // Make form
		$this->view->form = $form = new Sitepoll_Form_Admin_Report_Action();
		
			//HERE SUBJECT TYPE IS EMPTY THEN BOTH OPTION IS NOT SHOWN IN THE TAKE ACTION FORM.
		if (empty($subject)) {
			$form->removeElement('action');
			$form->removeElement('action_content');
		}

		if( !$subject ) {
			$form->removeElement('action');
			$form->removeElement('poster_action');
			$form->removeElement('ban');
		} else if( $subject instanceof User_Model_User ) {
			$form->removeElement('action');
			$form->getElement('action_poster')->setLabel('Action');
			$form->getElement('ban')->setLabel('Ban IP Address?');
		} else if( !$subjectOwner || !$user ) {
			$form->removeElement('ban');
			$form->removeElement('action_poster');
		}

		if (!$this->getRequest()->isPost()) {
			return;
		}
		if (!$form->isValid($this->getRequest()->getPost())) {
			return;
		}

		    // PROCESS
		$values = $form->getValues();

		    //DELETE ACTIVITY FEED.
		if (!empty($values['action'])) {
			if ($values['action'] == 1 && $subject instanceof Core_Model_Item_Abstract) {
				$subject->delete();
			}
		}
		    // DELETE CONTENT.
		if (!empty($values['action_content'])) {
			$contentObject = $subject->getObject();
			if ($values['action_content'] == 1 && $contentObject instanceof Core_Model_Item_Abstract) {
				$contentObject->delete();
			}
		}

		    // DELETE REPORT.
		if (!empty($values['dismiss'])) {
			$report->delete();
			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have successfully delete this abuse report.'))
			));
		}

		// GET DATA FROM ALL TABLE
		$poll = Engine_Api::_()->getItem('sitepoll_poll', $poll_id);
		$option = Engine_Api::_()->getDbtable('polls', 'sitepoll');
		$report = Engine_Api::_()->getDbtable('reports', 'sitepoll');    

		if(!empty($values['report']==0)){
			// Get Viewer
			$viewer = Engine_Api::_()->user()->getViewer();
			// Get Owner
			$owner = Engine_Api::_()->getItem("user" , $poll->user_id);
			
			$options=Engine_Api::_()->getDbtable('options','sitepoll')->getpollOption($poll_id);
			$reports=Engine_Api::_()->getDbtable('reports','sitepoll')->getpollReport($poll_id);

		        // In smoothbox
			$this->_helper->layout->setLayout('default-simple');

			$this->view->form = $form = new Sitepoll_Form_Delete();

			if( !$poll ) {
				$this->view->status = false;
				$this->view->error = Zend_Registry::get('Zend_Translate')->_("Poll doesn't exist or not authorized to delete");
				return;
			}

			if( !$this->getRequest()->isPost() ) {
				$this->view->status = false;
				$this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
				return;
			}
			$db = $poll->getTable()->getAdapter();
			$db->beginTransaction();

			try {
				$defaultParams = array(
						'ssl' => ( _ENGINE_SSL ? 'https://' : 'http://' ),
	                    'host' => $_SERVER['HTTP_HOST'],
	                    'email' => $owner->email,
	                     'title'=>$poll['title'],
	                     'object_link'=>Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action'=>'view','poll_id'=>$poll->poll_id), 'sitepoll_view', true)
	                 );
					$defaultParams['email']=$owner->email;
	                Engine_Api::_()->getApi('mail', 'core')->sendSystem($viewer, 'notify_sitepoll_poll_delete',$defaultParams);
				$poll->delete();
				$db->commit();

				$viewer = Engine_Api::_()->user()->getViewer();
				Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $viewer, 'sitepoll_poll_delete');
				} catch( Exception $e ) {
					$db->rollBack();
					throw $e;
			}

			$this->view->status = true;
			$this->view->message = Zend_Registry::get('Zend_Translate')->_('Your poll has been deleted.');
			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have successfully delete this abuse report.'))
			));
		} 

		if(!empty($values['report']==1))
		{
			try{
			$poll['approved'] = 0; 
			// DELETE THE FEED IF THE POLL IS DISAPPROVED
	        $poll->postdelete();
			$poll->save(); 
			$report->delete(array(
				'poll_id = ?' => $poll_id,
			));
			$viewer = Engine_Api::_()->user()->getViewer();
	        $owner = Engine_Api::_()->getItem("user" , $poll->user_id);

	        $defaultParams = array(
	        	'ssl' => ( _ENGINE_SSL ? 'https://' : 'http://' ),
	            'host' => $_SERVER['HTTP_HOST'],
	            'email' => $owner->email,
	            'title'=>$poll['title'],
	            'status'=>"dis-Approved",
	            'object_link'=>Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action'=>'view','poll_id'=>$poll->poll_id), 'sitepoll_view', true)
	                 
	        );
	            Engine_Api::_()->getApi('mail', 'core')->sendSystem($viewer, 'notify_sitepoll_poll_request',$defaultParams);
			Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $poll, 'sitepoll_poll_disapproved'); 
			}catch( Exception $e ) {
					$db->rollBack();
					throw $e;
			}

			$this->view->status = true;
			$this->view->message = Zend_Registry::get('Zend_Translate')->_('Your poll has been disapproved.');
			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your poll has been disapproved.'))
			));
		}

		    // Done
		$this->view->closeSmoothbox = true;
		}

}
