<?php 
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitepoll
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
class Sitepoll_AdminSettingsController extends Core_Controller_Action_Admin {
	public function indexAction() {
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
		->getNavigation('sitepoll_admin_main', array(), 'sitepoll_admin_main_settings');

		$this->view->form  = $form = new Sitepoll_Form_Admin_Settings_Global();

		if( $this->getRequest()->isPost() && $form->isValid($this->_getAllParams()) ) {
			$values = $form->getValues();
			foreach ($values as $key => $value){
				Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
			}
			$form->addNotice('Your changes have been saved.');
		}
	}

  //ACTION FOR CATEGORIES
	public function categoriesAction() {

    // GET NAVIGATION
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
		->getNavigation('sitepoll_admin_main', array(), 'sitepoll_admin_main_categories');

		$isAjax = $this->_getParam('is_ajax',false);
		if($isAjax) {		
			$divId=$this->_getParam('divId');
			$sitepollOrder=$this->_getParam('sitepollorder',null);
			$tableCategory = Engine_Api::_()->getDbTable('categories', 'sitepoll');
			$tableCategoryName = $tableCategory->info('name');

			if(empty($sitepollOrder)) {
				$this->view->success = false;
				return;
			}

			foreach($sitepollOrder as $order => $name) {
				$name = str_replace('cat_','',$name);
				$tableCategory->update(array('cat_order' => $order), array('category_name = ?' => $name));
			}

			$this->view->success = true;
			return;
		}
		$this->view->categories = Engine_Api::_()->getDbtable('categories', 'sitepoll')->fetchAll(NULL,'cat_order');
	}

    //ACTION TO ADD CATEGORY
	public function addCategoryAction() {
    	// In smoothbox
		$this->_helper->layout->setLayout('admin-simple');

    	// Generate and assign form
		$form = $this->view->form = new Sitepoll_Form_Admin_Settings_Category();
		$form->setAction($this->view->url(array()));

    	// Check post
		if( !$this->getRequest()->isPost() ) {
			$this->renderScript('admin-settings/form.tpl');
			return;
		}
		if( !$form->isValid($this->getRequest()->getPost()) ) {
			$this->renderScript('admin-settings/form.tpl');
			return;
		}

    	// Process
		$values = $form->getValues();
		$categoryTable = Engine_Api::_()->getItemTable('sitepoll_category');
		if($categoryTable->categoryPresent($values['label'])) {
			$form->addError("Category already Exists.");
			$this->renderScript('admin-settings/form.tpl');
			return;
		}

		$db = $categoryTable->getAdapter();
		$db->beginTransaction();

		$viewer = Engine_Api::_()->user()->getViewer();

		$insertname=$values['label'];
		$count=Engine_Api::_()->getItemTable('sitepoll_category')->CheckAllReadyExist($insertname);
		$categories_count = Engine_Api::_()->getDbtable('categories', 'sitepoll')->fetchAll();
		try {
			$categoryTable->insert(array(
				'user_id' => $viewer->getIdentity(),
				'category_name' => $values['label'],
				'cat_order' => count($categories_count)+1,
			));

			$db->commit();
		} catch( Exception $e ) {
			$db->rollBack();
			throw $e;
		}

		return $this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 10,
			'parentRefresh'=> 10,
			'messages' => array('')
		));
	}

    //ACTION FOR DELETING CATEGORY
	public function deleteCategoryAction() {
      	// In smoothbox
		$this->_helper->layout->setLayout('admin-simple');
		$category_id = $this->_getParam('id');
		$this->view->sitepoll_id = $this->view->category_id = $category_id;
		$categoriesTable = Engine_Api::_()->getItemTable('sitepoll_category');
		$category = $categoriesTable->find($category_id)->current();

		if( !$category ) {
			return $this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh'=> 10,
				'messages' => array('')
			));
		} else {
			$category_id = $category->getIdentity();
		}

        // get the categoreis apart from current category
		$this->view->categories = $remainingCategory = $categoriesTable->getRemainingCategory($category_id);
		if(count($remainingCategory) == 0){
			$this->renderScript('admin-settings/delete.tpl');
			return;
		}

        //check post request
		if( !$this->getRequest()->isPost() ) {
          // Output
			$this->renderScript('admin-settings/delete.tpl');
			return;
		}

        //post data
		$formValues = $this->getRequest()->getPost();
        // Process
		$db = $categoriesTable->getAdapter();
		$db->beginTransaction();

		try {
          //update the polls category with the form category
			Engine_Api::_()->getItemTable('sitepoll_poll')->update(array('category_id' => $formValues['category']),
				array(
					'category_id = ?'=> $category_id,
				)
			);
          // delete category
			$category->delete();
			$sitepollTable = Engine_Api::_()->getItemTable('sitepoll_category');
			$sitepollTable->update(array(
				'category_id' => 0,
			), array(
				'category_id = ?' => $category_id,
			));
			$db->commit();
		} catch( Exception $e ) {
			$db->rollBack();
			throw $e;
		}

		return $this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 10,
			'parentRefresh'=> 10,
			'messages' => array('')
		));
	}

  	//ACTION FOR FAQ
	public function faqAction() {
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitepoll_admin_main', array(), 'sitepoll_admin_main_faq');
	}

  	//ACTION FOR EDITING POLL NAME
	public function editCategoryAction() {
    	// In smoothbox
		$this->_helper->layout->setLayout('admin-simple');
		$category_id = $this->_getParam('id');

		$this->view->poll_id = $this->view->category_id = $category_id;

		// DATA FROM CATEGORIES TABLE
		$categoriesTable = Engine_Api::_()->getDbtable('categories', 'sitepoll');
		$category = $categoriesTable->find($category_id)->current();

		if( !$category ) {
			return $this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh'=> 10,
				'messages' => array('')
			));
		} 

		$form = $this->view->form = new Sitepoll_Form_Admin_Settings_Category();
		$form->setAction($this->getFrontController()->getRouter()->assemble(array()));
		$form->setField($category);

		if( !$this->getRequest()->isPost() ) {
      		// Output
			$this->renderScript('admin-settings/form.tpl');
			return;
		}

		if( !$form->isValid($this->getRequest()->getPost()) ) {
      		// Output
			$this->renderScript('admin-settings/form.tpl');
			return;
		}

    	// Process
		$values = $form->getValues();
		$categoryTable = Engine_Api::_()->getItemTable('sitepoll_category');
		if($categoryTable->categoryPresent($values['label'])) {
			$form->addError("Category already Exists.");
			$this->renderScript('admin-settings/form.tpl');
			return;
		}
		$db = $categoriesTable->getAdapter();
		$db->beginTransaction();

		try {
			$category->category_name = $values['label'];
			$category->save();

			$db->commit();
		} catch( Exception $e ) {
			$db->rollBack();
			throw $e;
		}

		return $this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 10,
			'parentRefresh'=> 10,
			'messages' => array('')
		));
	}

  	//ACTION FOR SHOWING THE POLL STATISTICS
	public function statisticAction() {

    	//GET NAVIGATION
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
		->getNavigation('sitepoll_admin_main', array(), 'sitepoll_admin_main_statistic');


    	//GET PAGE TABLE
		$tablePoll = Engine_Api::_()->getDbtable('polls', 'sitepoll');

    	//GET TOTAL POLLS    
		$this->view->totalSitepoll = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totalpoll'))->totalpoll;


    	//GET APPROVED POLLS
		$this->view->totalapproved = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totalapproved')->where('approved =?', 1))->totalapproved;

    	//GET DISAPPROVED POLLS
		$this->view->totaldisapproved = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totaldisapproved')->where('approved =?', 0)->where('approve_date IS NOT NULL'))->totaldisapproved;

    	//GET FEATURED POLLS
		$this->view->totalfeatured = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totalfeatured')->where('featured =?', 1))->totalfeatured;

    	//GET SPONSORED POLLS 
		$this->view->totalsponsored = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totalsponsored')->where('sponsored =?', 1))->totalsponsored;

  		//GET TEXT POLLS 
		$this->view->totaltextpoll = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totaltext')->where('auth_type =?', 0))->totaltext;

  		//GET PHOTO POLLS
		$this->view->totalphotopoll = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totalphoto')->where('auth_type =?', 2))->totalphoto;

  		//GET TEXT WITH PHOTO POLLS
		$this->view->totalphototextpoll = $tablePoll->fetchRow($tablePoll->select()->from($tablePoll->info('name'), 'count(*) AS totalphototext')->where('auth_type =?', 3))->totalphototext; 
	}
}
