<?php
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitepoll
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
class Sitepoll_IndexController extends Core_Controller_Action_Standard {
    public function indexAction() {
        
    }


    public function browseAction() {
        // Prepare
        $viewer = Engine_Api::_()->user()->getViewer();

        // Render
        $this->_helper->content
                //->setNoRender()
        ->setEnabled()
        ;
    }

    public function manageAction() {
        //Check auth
        if( !$this->_helper->requireUser()->isValid() ) {
            return;
        }
        if( !$this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'create')->isValid() ) {
            return;
        }

            // Render
        $this->_helper->content
                //->setNoRender()
        ->setEnabled()
        ;

        // Check create
        $this->view->canCreate = Engine_Api::_()->authorization()->isAllowed('poll', null, 'create');
    }

    public function tagAction() {

        // Validate request methods
        $this->validateRequestMethod();

        if (!($owner_id = $this->getRequestParam('owner_id'))) {
            $this->respondWithValidationError('parameter_missing', 'owner_id');
        }

        $owner = Engine_Api::_()->getItem('user', $owner_id);
        if (empty($owner)) {
            $this->respondWithError('no_record');
        } else {
            $getTagByTagger = Engine_Api::_()->getDbtable('tags', 'core')->getTagsByTagger('sitepoll_poll', $owner);
            $getTagByTaggerArray = $getTagByTagger->toArray();
            $this->respondWithSuccess($getTagByTaggerArray, true);
        }
    }

    public function tagscloudAction(){
        //Render
        $this->_helper->content
             ->setEnabled()
        ;
        //GET navigation
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitepoll_main', array(), '');
        
        //CONSTRUCTING TAG CLOUD
        $tag_array = array();
        $tag_cloud_array = Engine_Api::_()->getDbtable('polls', 'sitepoll')->getTagCloud('', $category_id, 0);
        $tag_id_array = array();
        foreach( $tag_cloud_array as $vales ) {
          $tag_array[$vales['text']] = $vales['Frequency'];
          $tag_id_array[$vales['text']] = $vales['tag_id'];
        }

        if (!empty($tag_array)) {
          $max_font_size = 18;
          $min_font_size = 12;
          $max_frequency = max(array_values($tag_array));
          $min_frequency = min(array_values($tag_array));
          $spread = $max_frequency - $min_frequency;
          if ($spread == 0) {
            $spread = 1;
          }
          $step = ($max_font_size - $min_font_size) / ($spread);

          $tag_data = array('min_font_size' => $min_font_size, 'max_font_size' => $max_font_size, 'max_frequency' => $max_frequency, 'min_frequency' => $min_frequency, 'step' => $step);
          $this->view->tag_data = $tag_data;
          $this->view->tag_id_array = $tag_id_array;
        }
        $this->view->tag_array = $tag_array;
    }

    // Create Action
    public function createAction(){
    
        if( !$this->_helper->requireUser()->isValid() ) {
          return;
        }
        if( !$this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'create')->isValid() ) {
              return;
        }

        // Render
        $this->_helper->content
                //->setNoRender()
            ->setEnabled()
            ;

          $this->view->options = array();

          // set up data needed to check quota
          $viewer = Engine_Api::_()->user()->getViewer();
          $values['user_id'] = $viewer->getIdentity();
          $paginator = Engine_Api::_()->getItemTable('sitepoll_poll')->getPollsPaginator($values);
          $this->view->quota = $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitepoll_poll', 'max');
          $current=$this->view->current_count =$current_count=$paginator->getTotalItemCount();
          $parent_type = $this->_getParam('parent_type');
          $parent_id = $this->_getParam('parent_id', $this->_getParam('subject_id'));
          if( $parent_type == 'group' && Engine_Api::_()->hasItemType('group') ) {
            $this->view->group = $group = Engine_Api::_()->getItem('group', $parent_id);
            if( !Engine_Api::_()->authorization()->isAllowed('group', $viewer, 'poll') ) {
                return;
            }
          } else {
                $parent_type = 'user';
                $parent_id = $viewer->getIdentity();
            }
            $this->view->parent_type = $parent_type;

            $this->view->form = $form = new Sitepoll_Form_Create(array(
                'parent_type' => $parent_type,
                'parent_id' => $parent_id
            ));

            if( !$this->getRequest()->isPost() ) {
              return;
            }
            if( !$form->isValid($this->getRequest()->getPost()) ) {
              return;
            }

            // Process
            $pollTable = Engine_Api::_()->getItemTable('sitepoll_poll');
            $pollOptionsTable = Engine_Api::_()->getDbtable('options', 'sitepoll');
            $db = $pollTable->getAdapter();
            $db->beginTransaction();
            $data=$this->getRequest()->getPost();

            $values = $form->getValues();
            if (($current_count >= $quota) && !empty($quota)){
                return;
            }

            // FLOOD CONTROL
            $itemFlood = Engine_Api::_()->getDbtable('permissions', 'authorization')->getAllowed('sitepoll_poll', $this->view->viewer()->level_id, 'flood');
            if(!empty($itemFlood[0])){
                        //get last activity
                $tableFlood = Engine_Api::_()->getDbTable("polls",'sitepoll');
                $select = $tableFlood->select()->where("user_id = ?",$this->view->viewer()->getIdentity())->order("creation_date DESC");
                if($itemFlood[1] == "minute"){
                    $select->where("creation_date >= DATE_SUB(NOW(),INTERVAL 1 MINUTE)");
                }else if($itemFlood[1] == "day"){
                    $select->where("creation_date >= DATE_SUB(NOW(),INTERVAL 1 DAY)");
                }else{
                    $select->where("creation_date >= DATE_SUB(NOW(),INTERVAL 1 HOUR)");
                }
                $floodItem = $tableFlood->fetchAll($select);
                if(count($floodItem) && $itemFlood[0] <= count($floodItem)){
                    $message = Engine_Api::_()->core()->floodCheckMessage($itemFlood,$this->view);
                    $form->addError($message);
                    return;
                }
            }
            /**
             * text -> p_name,image->image
             * textIdArray(0->p_name,1->p_name...);
             * imageIdArray(0->image,1->image);
             * cnt = x
             * idx = 0;
             * while(x--){
             *  create row otpion table;
             *  textIdArray code write;
             *  imageIdArray code_write;         
             *  ++idx;                              
             * }
             * 
             */
             $oldphotoIdArray = array();
             foreach($_FILES as $key=>$value) {
                if("image"==substr($key,0,5)) {
                 $oldphotoIdArray[] = $key;
                }
             }

             $photoIdArray=array();
             foreach($oldphotoIdArray as $photoArray) {
                if(!empty($_FILES[$photoArray]['name'])){
                    $photoIdArray[]=$photoArray;
                }
             }
             $oldtextIdArray = array();
             foreach($data as $key=>$value) { 
                if("p_name"==substr($key,0,6)) {
                 $oldtextIdArray[] = $key;
                }
             }
             $textIdArray=array();
             foreach($oldtextIdArray as $textArray) {
                if(!empty($data[$textArray])){
                    $textIdArray[]=$textArray;
                }
             }
             for($i=0;$i<count($textIdArray);$i++){
                for($j=$i+1;$j<count($textIdArray);$j++){
                    if(!empty($data[$textIdArray[$i]]))
                        $first = $data[$textIdArray[$i]];
                    if(!empty($data[$textIdArray[$j]]))
                        $second = $data[$textIdArray[$j]];
                    $first = $this->stringConversion($first);
                    $second = $this->stringConversion($second);
                    if(!$first || !$second){ 
                        $error=$this->view->translate("You must provide at least two possible answers.");
                        $form->getDecorator('errors')->setOption('escape', false);
                        $form->addError($error);

                        return;
                    }

                if($first == $second){
                    $error=$this->view->translate("Two options cannot be same.");
                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    $viewData = array();
                    foreach($textIdArray as $key){
                        $viewData[] = $data[$key];
                    }
                    $this->view->optionsArr =$viewData;
                    return;
                }
            }
        }

        for($i=0;$i<count($photoIdArray);$i++){
            for($j=$i+1;$j<count($photoIdArray);$j++){

                $first = $_FILES[$photoIdArray[$i]]['name'];
                $second = $_FILES[$photoIdArray[$j]]['name'];
                $first = $this->stringConversion($first);
                $second = $this->stringConversion($second);
                if(!$first || !$second){
                    $error=$this->view->translate("You must provide at least two possible answers.");
                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);

                    return;
                }

                if($first == $second){
                    $error=$this->view->translate("Two photo options cannot be same.");
                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    $viewData = array();
                    foreach($photoIdArray as $key){
                        $viewphotoData[] = $_FILES[$key];
                    }
                    $this->view->optionsphotoArr =$viewphotoData;
                    return;
                }
            }
        }


        if(!count($photoIdArray) && !count($textIdArray)) {
            $error=$this->view->translate("please choose at least one field");
            $form->getDecorator('errors')->setOption('escape', false);
            $form->addError($error);
            return;
        }

        if($values['auth_type']==3)
        {
            if(count($photoIdArray)!=count($textIdArray))
            {
                $error=$this->view->translate("Please add both text and photo");
                $form->getDecorator('errors')->setOption('escape', false);
                $form->addError($error);
                return;
            }
        }

        $counter = (count($photoIdArray))?count($photoIdArray):count($textIdArray);
        $check=$counter;
        $inc = 0;
        $filled=0;
        while($check--){
            if(!empty($data[$textIdArray[$inc]]) || !empty($_FILES[$photoIdArray[$inc]]['name'])){
                if($values['type']==3){
                    if(!empty($data[$textIdArray[$inc]]) && !empty($_FILES[$photoIdArray[$inc]]['name'])){
                        $filled++;
                    }
                }else{
                    $filled++;
                }
            }
            ++$inc;
        }


        if ($filled<2) {
            $error = $this->view->translate(" You must provide at least two possible answers.");
            $form->getDecorator('errors')->setOption('escape', false);
            $form->addError($error);
            return;
        }
        $this->view->maxOptions = $max_options = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll_poll.maxoptions', 6);
        if($values['category_id']<=0 ) {
            $error = $this->view->translate("category is required");
            $form->getDecorator('errors')->setOption('escape', false);
            $form->addError($error);
            return;
        }

        try {
            $values = $form->getValues();
            $values['user_id'] = $viewer->getIdentity();

            if ($values['auth_type']==0) {
                $values['auth_type_name']='Text';
            }else if ($values['auth_type']==2) {
                $values['auth_type_name']='Photo';
            }else if ($values['auth_type']==3) {
                $values['auth_type_name']='Photo with text';
            }

            // DATA SETTING AUTO APPROVE 
            if( $this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'autoapprove')->isValid() ) {
                $values['approved']=1;
                $values['status']='Active';
                $values['approve_date']=date('Y-m-d H:i:s');
                $values['start_datetime']=date('Y-m-d H:i:s');
                if ($values['draft']==0)
                {
                    $values['end_datetime']=date('Y-m-d H:i:s', strtotime("+1 day"));
                }else if ($values['draft']==1)
                {
                    $values['end_datetime']=date('Y-m-d H:i:s', strtotime("+3 day"));
                }else if($values['draft']==2)
                {
                    $values['end_datetime']=date('Y-m-d H:i:s', strtotime("+7 day"));
                }else if($values['draft']==3)
                {
                    $values['end_datetime']=date('Y-m-d H:i:s', strtotime("+14 day"));
                }
            }else{
                $values['approved']=0;
                $values['status']='Pending';
            }

            // DATA SETTING FOR FEATURE
            if( $this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'featured')->isValid() ) {
                $values['featured']=1;
            }else{
                $values['featured']=0;
            }

            // DATA SETTING FOR SPONSERED
            if( $this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'sponsored')->isValid() ) {
                $values['sponsored']=1;
            }else{
                $values['sponsored']=0;
            }

            // NETWORKS
            if (isset($values['networks'])) {
                $network_privacy = 'network_'. implode(',network_', $values['networks']);
                $values['networks'] = implode(',', $values['networks']);
            }

            if( empty($values['auth_view']) ) {
                $values['auth_view'] = 'everyone';
            }
            if( empty($values['auth_comment']) ) {
                $values['auth_comment'] = 'everyone';
            }

            $values['view_privacy'] = $values['auth_view'];

            $values['parent_type'] = $parent_type;
            $values['parent_id'] =  $parent_id;

                    // Create poll
            $poll = $pollTable->createRow();
            $poll->setFromArray($values);
            $poll->save();

            if( !empty($values['photo']) ) {
                $poll->setPhoto($form->photo);

            }

            $poll_id = $poll->getIdentity();

            //data enter in ad products/ option table
            $temp=0;
            while($counter--){

                if(!empty($data[$textIdArray[$temp]]) || !empty($_FILES[$photoIdArray[$temp]]['name'])){
                    $polloption = $pollOptionsTable->createRow();
                }
                            // text entry --
                if(!empty($data[$textIdArray[$temp]])) {
                    $polloption->setFromArray(array(
                        'poll_id' => $poll->getIdentity(),
                        'poll_option' => $data[$textIdArray[$temp]],
                    ));
                    $polloption->save();
                }
                            // photo entry
                if(!empty($_FILES[$photoIdArray[$temp]]))
                {   
                    $qpoll = $poll->getIdentity();
                    if(!empty($_FILES[$photoIdArray[$temp]]['name'])) {
                        $polloption->setPhoto($_FILES[$photoIdArray[$temp]],'photo_option',$qpoll);
                    }
                } 
                ++$temp; 
            }

            // Add tags
            $tags = preg_split('/[,]+/', $values['tags']);
            $poll->tags()->addTagMaps($viewer, $tags);

            // Auth
            $auth = Engine_Api::_()->authorization()->context;

            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');


            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);

            foreach( $roles as $i => $role ) {
                $auth->setAllowed($poll, $role, 'view', ($i <= $viewMax));
                $auth->setAllowed($poll, $role, 'comment', ($i <= $commentMax));
            }

            $db->commit();
            
            if( $this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'autoapprove')->isValid() ) {

                $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $poll, 'sitepoll_new','',array('privacy' => isset($values['auth_view'])? $values['auth_view'] : 'everyone'));
                if( $action ) {
                  Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $poll);
              }

              }
              if( !$this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'autoapprove')->isValid() ) {

                    //Send Notification To SUPERADMIN
                  $users = Engine_Api::_()->user()->getSuperAdmins();
                  foreach ($users as $user) {
                    $superadmin_id[] = $user->user_id;
                    if(!in_array($viewer->getIdentity(), $superadmin_id)){
                        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $poll, 'sitepoll_create_poll');
                }
            }
        }

        } catch( Exception $e ) {
            $db->rollback();
            throw $e;
        }

        //Redirect
        
        return $this->_redirect('poll-item/view/'.$poll_id);
    }

    // TO CHECK REPETATION
    private function stringConversion($param){
        $bar = ucwords(strtolower($param));
        $data = preg_replace('/\s+/', '', $bar);
        $y=strtolower($data);
        return $y;
    }
}
