<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Apns.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_Form_Admin_Apns extends Engine_Form {

    public function init() {
        // Set time zone
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        date_default_timezone_set($timezone);

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $URL = $view->baseUrl() . "/admin/files";
        $click = '<a href="' . $URL . '" target="_blank">file manager</a>';
        $customBlocks = sprintf("The below chosen Apple APN certificate will be used to send push notifications from your server. The SocialEngineAddOns Support Team will upload the appropriate certificate from %s at the time of app building, and will choose it from below. [Note: Please keep the extracting password of p12 file blank or it will give error in sending notifications.]", $click);

        // Get available p12 Certificate files
        $p12Certs = array('' => 'No certificate choosen');
        $p12Extension = array('p12',);
        $it = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
        foreach ($it as $file) {
            if ($file->isDot() || !$file->isFile())
                continue;
            $basename = basename($file->getFilename());
            if (!($pos = strrpos($basename, '.')))
                continue;
            $ext = strtolower(ltrim(substr($basename, $pos), '.'));
            if (!in_array($ext, $p12Extension))
                continue;
            $p12Certs['public/admin/' . $basename] = $basename;
        }

        // Get available pem Certificate files
        $pemCerts = array('' => 'No certificate choosen');
        $pemExtension = array('pem',);
        $it = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
        foreach ($it as $file) {
            if ($file->isDot() || !$file->isFile())
                continue;
            $basename = basename($file->getFilename());
            if (!($pos = strrpos($basename, '.')))
                continue;
            $ext = strtolower(ltrim(substr($basename, $pos), '.'));
            if (!in_array($ext, $pemExtension))
                continue;
            $pemCerts['public/admin/' . $basename] = $basename;
        }

        $this
                ->setTitle('APNS Configuration')
                ->setDescription('Below, you can configure APNS settings to start sending browser push notifications, in case you are using “Safari Browser”. To do so, please create a project <a href="https://console.developers.google.com/" target="_blank">Google Developer </a> page, and fill the below fields.');

        $this->loadDefaultDecorators();
        $this->getDecorator('Description')->setOption('escape', false);

        // pem certificate 
        $this->addElement('Select', 'sitepushnotification_apnscertpem', array(
            'label' => 'Apple APN Server Certificate (.pem)',
            'description' => $customBlocks,
            'multiOptions' => $pemCerts,
            'order' => 3,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.apnscertpem', ''),
        ));
        $this->sitepushnotification_apnscertpem->getDecorator('Description')->setOptions(array('placement' =>
            'PREPEND', 'escape' => false));

        // .p12 certificate 
        $this->addElement('Select', 'sitepushnotification_apnscertp12', array(
            'label' => 'Apple APN Server Certificate (.p12)',
            'description' => $customBlocks,
            'multiOptions' => $p12Certs,
            'order' => 4,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.apnscertp12', ''),
        ));
        $this->sitepushnotification_apnscertp12->getDecorator('Description')->setOptions(array('placement' =>
            'PREPEND', 'escape' => false));


        $logoId = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.pushimage', '');

        if ($logoId == null || $logoId == '0') {
            $logoValue = "";
        } else {
            $url = explode("/", Engine_Api::_()->storage()->get($logoId, '')->getPhotoUrl());
            $logo_name = explode("?c=", $url[count($url) - 1]);
            $logoValue = "[ Uploaded file " . $logo_name[0] . " ]";
        }

        $this->addElement('File', 'sitepushnotification_pushimage', array(
            'label' => 'Select Image for push notifications',
            'description' => ' Choose a logo to be displayed in the push notification, with the title and description. <br>' . $logoValue,
            'order' => 2,
            'value' => 0
        ));
        $this->sitepushnotification_pushimage->addValidator('Extension', false, 'png');
        $this->sitepushnotification_pushimage->getDecorator('Description')->setOption('escape', false);

        $this->addElement('Text', 'sitepushnotification_webpushid', array(
            'label' => 'Web Push Id',
            'order' => 1,
            'description' => 'Enter the Web Push Id you have entered while APNS configuration',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.webpushid', ''),
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'order' => 5,
            'type' => 'submit',
            'ignore' => true
        ));
    }

}
