<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminCreateController.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_AdminCreateController extends Core_Controller_Action_Admin {

    public function init() {
        parent::init();

        // Set time zone
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        date_default_timezone_set($timezone);
    }

    public function indexAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main', array(), 'spn_admin_main_createnotification');

        $users = Engine_Api::_()->getItemTable('sitepushnotification_user')->getUserIds();

        $this->view->form = $form = new Sitepushnotification_Form_Admin_Create;

        if (!$this->getRequest()->isPost()) {

            return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $params = $form->getValues();

        if ($params['url'] != '') {
            $params['url'] = str_replace("https://", "", $params['url']);
            $params['url'] = str_replace("http://", "", $params['url']);
            $params['url'] = $params['urlprtocol'] . $params['url'];
        }
        unset($params['urlprtocol']);

        if ($params['send_to'] == 'specific_user') {
            $params['users_data'] = json_encode($params['toValues']);
        }
        if ($params['send_to'] == 'member_level') {
            $params['users_data'] = json_encode($params['member_level']);
        }
        if ($params['send_to'] == 'registered') {
            $params['users_data'] = 1;
        }
        if ($params['send_to'] == 'network') {
            $params['users_data'] = json_encode($params['network']);
        }
        if ($params['send_to'] == 'non_loggedin') {
            $params['users_data'] = 0;
        }
        if ($params['logo'] != 0 || isset($params['logo'])) {
            $logo_id = Engine_Api::_()->getApi('core', 'sitepushnotification')->setPhoto($form->logo);
            $params['logo'] = $logo_id;
        } else
            $params['logo'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.defaultlogo', 0);

        $notificationsTable = Engine_Api::_()->getDbtable('schedulednotifications', 'sitepushnotification');
        $db = $notificationsTable->getAdapter();
        $db->beginTransaction();

        try {
            $notification = $notificationsTable->createRow();
            $notification->setFromArray($params);
            $notification->save();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        $message_id = $notification->message_id;

        if ($params['send_at'] == '1') {
            $status = Engine_Api::_()->getApi('core', 'sitepushnotification')->sendNow($params);
            // Setting delivery status of sent notification in scheduled notification table
            switch ($status) {
                case 1:
                    $status = '11';
                    break;

                case 0:
                    $status = '01';
                    break;

                default:
                    $status = '00';
                    break;
            }

            // var_dump($)
            Engine_Api::_()->getDbtable('schedulednotifications', 'sitepushnotification')->setStatus($status, $message_id);
        }

        $form->reset();
        $form->getElement('send_at')->setValue(1);
        $form->getElement('scheduled_time')->setValue(date("Y-m-d H:i:s"));
        $form->getElement('send_to')->setValue('registered');
        if ($params['send_at'] == '1')
            $form->addNotice('Your message has been successfully sent.');
        else
            $form->addNotice('Your message has been scheduled and will be sent at the given time.');
    }

    public function suggestAction() {
        $data = array();
        $text = $this->_getParam('search', $this->_getParam('value'));
        $limit = (int) $this->_getParam('limit', 10);

        $allFcmUsers = Engine_Api::_()->getDbtable('users', 'sitepushnotification')->getUsers($text, $limit);
        foreach ($allFcmUsers as $fcmUser) {
            $data[] = array(
                'type' => 'user',
                'id' => $fcmUser->getIdentity(),
                'guid' => $fcmUser->getGuid(),
                'label' => $fcmUser->getTitle(),
                'photo' => $this->view->itemPhoto($fcmUser, 'thumb.icon'),
                'url' => $fcmUser->getHref(),
            );
        }

        if ($this->_getParam('sendNow', true)) {
            return $this->_helper->json($data);
        } else {
            $this->_helper->viewRenderer->setNoRender(true);
            $data = Zend_Json::encode($data);
            $this->getResponse()->setBody($data);
        }
    }

    public function suggestSubscribersAction() {
        $data = array();
        $text = $this->_getParam('search', $this->_getParam('value'));
        $limit = (int) $this->_getParam('limit', 10);
        $allFcmUsers = Engine_Api::_()->getDbtable('notifications', 'sitepushnotification')->getUsers($text, $limit);
        foreach ($allFcmUsers as $fcmUser) {
            $data[] = array(
                'type' => 'user',
                'id' => $fcmUser->getIdentity(),
                'guid' => $fcmUser->getGuid(),
                'label' => $fcmUser->getTitle(),
                'photo' => $this->view->itemPhoto($fcmUser, 'thumb.icon'),
                'url' => $fcmUser->getHref(),
            );
        }

        if ($this->_getParam('sendNow', true)) {
            return $this->_helper->json($data);
        } else {
            $this->_helper->viewRenderer->setNoRender(true);
            $data = Zend_Json::encode($data);
            $this->getResponse()->setBody($data);
        }
    }

}
