<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminSettingsController.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_AdminSettingsController extends Core_Controller_Action_Admin {

    public function init() {
        parent::init();

        // Set time zone
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        date_default_timezone_set($timezone);
    }

    public function indexAction() {

        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
          ->getNavigation('spn_admin_main', array(), 'spn_admin_main_settings');

        $this->view->subNavigation = $subNavigation = Engine_Api::_()->getApi('menus', 'core')
          ->getNavigation('spn_admin_main_settings', array(), 'spn_admin_main_settings_general');

        $this->view->form = $form = new Sitepushnotification_Form_Admin_General;

        if (!$this->getRequest()->isPost()) {
          return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
          return;
        }

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
          $values = $form->getValues();
          $previous_logo = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification_defaultlogo','0');

          if ( isset($values['sitepushnotification_defaultlogo']) && $values['sitepushnotification_defaultlogo'] != null ) {
            $logo_id = Engine_Api::_()->getApi('core', 'sitepushnotification')->setPhoto($form->sitepushnotification_defaultlogo);
            $values['sitepushnotification_defaultlogo'] = $logo_id;
          } else if ($previous_logo != '0')
            $values['sitepushnotification_defaultlogo'] = $previous_logo;
          else
            $values['sitepushnotification_defaultlogo'] = 0;

          if ($values['sitepushnotification_subdomain'] != '') {
            $values['sitepushnotification_subdomain'] = "https://" . $values['sitepushnotification_subdomain'] . ".pushtor.com";
          }

          $settingsTable = Engine_Api::_()->getDbtable('settings', 'core');
          foreach ($values as $key => $value) {
            $settingsTable->setSetting($key, $value);
          }

          $form->addNotice('Your settings have been saved.');

          return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
        }
    }

    public function fcmSettingsAction() {      
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main', array(), 'spn_admin_main_settings');

        $this->view->subNavigation = $subNavigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main_settings', array(), 'spn_admin_main_settings_fcm');

        $this->view->form = $form = new Sitepushnotification_Form_Admin_Fcm;

        if (!$this->getRequest()->isPost()) {
            return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $values = $form->getValues();

        $settingsTable = Engine_Api::_()->getDbtable('settings', 'core');
        foreach ($values as $key => $value) {
            $settingsTable->setSetting($key, $value);
        }

        $result = $this->setConfig($values['sitepushnotification_fcmauth']);
        if( $result['return'] == 0 ) {
          $form->addNotice($result['message']);
        } else {
          $form->addNotice('Your settings have been saved.');
        }
        $this->getResponse()->setHeader('X-XSS-Protection', 0);
    }

    public function welcomeNotificationAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main', array(), 'spn_admin_main_settings');

        $this->view->subNavigation = $subNavigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main_settings', array(), 'spn_admin_main_settings_welcome');

        $this->view->form = $form = new Sitepushnotification_Form_Admin_Welcome;

        if (!$this->getRequest()->isPost()) {
            return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $values = $form->getValues();

        if (!empty($values['urlprotocol']) && !empty($values['sitepushnotification_welcome_url'])) {
            $values['sitepushnotification_welcome_url'] = $values['urlprotocol'] . trim($values['sitepushnotification_welcome_url']);
        }
        unset($values['urlprotocol']);

        if (!empty($values['sitepushnotification_welcome_logo'])) {
          // Remove old logo image before uploading new
          $old_logo = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.logo', '');
          if (!empty($old_logo)) {
              $tmpRow = Engine_Api::_()->getItem('storage_file', $old_logo)->remove();
          }
          $values['sitepushnotification_welcome_logo'] = Engine_Api::_()->getApi('core', 'sitepushnotification')->setPhoto($form->sitepushnotification_welcome_logo);
        } else
          $values['sitepushnotification_welcome_logo'] =Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.logo', '');

        foreach ($values as $key => $value) {
            $status = Engine_Api::_()->getApi('settings', 'core')->setSetting($key,$value);
        }

        $this->view->form = $form = new Sitepushnotification_Form_Admin_Welcome;
        $form->addNotice('Your settings have been saved.');
    }

    public function apnsSettingsAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main', array(), 'spn_admin_main_settings');

        $this->view->subNavigation = $subNavigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main_settings', array(), 'spn_admin_main_settings_apns');

        $this->view->form = $form = new Sitepushnotification_Form_Admin_Apns;

        if (!$this->getRequest()->isPost()) {
            return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $values = $form->getValues();

        // Creating iconset for push packages
        if ($values['sitepushnotification_pushimage'] != NULL) {
            $logo_id = Engine_Api::_()->getApi('core', 'sitepushnotification')->setPhoto($form->sitepushnotification_pushimage);
            $values['sitepushnotification_pushimage'] = $logo_id;
            $setPushImage = array();
            $setPushImage = Engine_Api::_()->getApi('core', 'sitepushnotification')->setPushImage($values['sitepushnotification_pushimage']);

            foreach ($setPushImage as $key => $value) {
                $values['sitepushnotification_' . $key] = $value;
            }
        } else {
            $values['sitepushnotification_pushimage'] = '0';
            $values['sitepushnotification_icon16'] = '0';
            $values['sitepushnotification_icon16x'] = '0';
            $values['sitepushnotification_icon32'] = '0';
            $values['sitepushnotification_icon32x'] = '0';
            $values['sitepushnotification_icon128'] = '0';
            $values['sitepushnotification_icon128x'] = '0';
        }

        $settingsTable = Engine_Api::_()->getDbtable('settings', 'core');
        foreach ($values as $keys => $val) {
            $settingsTable->setSetting($keys, $val);
        }
    }

    public function faqAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main', array(), 'spn_admin_main_faq');
    }

    public function httpsBenefitsAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('spn_admin_main', array(), 'spn_admin_main_httpsbenefits');
    }

    function setConfig($firebaseScript) {
        $result = array('return' => 1, 'message' => 'Configured successfully');
        //Get Config detail
        $doc = new DOMDocument();
        $doc->loadHTML("<html><head>$firebaseScript</head><body></body></html>");
        $items = $doc->getElementsByTagName('script');
        $config = '';
        foreach ($items as $item) {
            $data = $this->get_string_between($item->nodeValue, '{', '};');
            if (count($data) > 0) {
                $config = $data[0];
                break;
            }
        }
        if (empty($config)) {
            $result = array('return' => 0, 'message' => 'Enter the valid Firebase snippet code.');
            return $result;
        }
        $templatefilePath = APPLICATION_PATH . '/application/modules/Sitepushnotification/views/scripts/config_template.tpl';
        $outputFilePath = APPLICATION_PATH . '/application/modules/Sitepushnotification/views/scripts/config.tpl';
        $sw_templatefilePath = APPLICATION_PATH . '/application/modules/Sitepushnotification/externals/scripts/firebase-messaging-sw-template.js';
        $sw_outputFilePath = APPLICATION_PATH . '/firebase-messaging-sw.js';

        //Replace the Configurations details
        $target_data = str_replace("{{configDetails}}", $config, file_get_contents($templatefilePath));
        $sw_target_data = str_replace("{{configDetails}}", $config, file_get_contents($sw_templatefilePath));
        file_put_contents($outputFilePath, $target_data);
        file_put_contents($sw_outputFilePath, $sw_target_data);
        return $result;
    }

    function get_string_between($string, $start, $end) {
        $last_end = 0;
        $matches = array();
        while (($ini = strpos($string, $start, $last_end)) !== false) {

            $ini += strlen($start);
            $len = strpos($string, $end, $ini);
            if ($len === false)
                break;
            $len = $len - $ini;
            $matches[] = substr($string, $ini, $len);
            $last_end = $ini + $len + strlen($end);
        }
        return $matches;
    }

}
