<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_IndexController extends Core_Controller_Action_Standard {

    public function init() {
        parent::init();

        // Set time zone
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        date_default_timezone_set($timezone);
    }

    public function isTokenRegisteredAction() {
        $data = array('return' => 0, 'message' => 'Invalid action Performed');
        if (!$this->getRequest()->isPost()) {
            return $this->_helper->json($data);
        }
        $deviceId = $this->_getParam('device_id');
        $isExist = Engine_Api::_()->getDbtable('users', 'sitepushnotification')->getUserSubscription($deviceId);
        $data = array('return' => 1, 'message' => 'Given device token does not exist');
        if ($isExist) {
            $isValid = Engine_Api::_()->getApi('core','sitepushnotification')->isTokenValid($deviceId);
            $data = $isValid ? array('return' => 2, 'message' => 'Given device token exist') : array('return' => 1, 'message' => 'Given device token is not valid');
        }
        return $this->_helper->json($data);
    }

    public function updateSubscriptionAction() {
        if (is_null($this->getRequest())) {
            return;
        }
        if (!$this->getRequest()->isPost()) {
            return;
        }

        $request = 1;
        $responseResult = '';
        $params['uid'] = '0';
        $params['device_id'] = $this->_getParam('device_id');
        $params['browser'] = $this->_getParam('browser');

        // Check if request is from loggedin user
        if ($this->_getParam('loggedin'))
            $params['uid'] = $this->_getParam('uid');

        // Check if the user has enabled push-notifications
        $getUserPushSetting = Engine_Api::_()->getApi('core', 'sitepushnotification')->getUserPushSetting($params['uid']);
        $welcomeNotificationEnabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.enabled', '1');

        // Check if there is change in user permissions
        if ($getUserPushSetting == 1) {
            $request = Engine_Api::_()->getDbtable('users', 'sitepushnotification')->updateSubscription($params);
        }

        if ($request == 0 && $welcomeNotificationEnabled == '1')
          Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendWelcomeNotification($params);

        exit(1);
    }

    public function safariSubscriptionAction() {

        $url = $_SERVER['REQUEST_URI'];
        $array1 = explode("/", $url);

        $cert_p12_path = APPLICATION_PATH . '/' . Engine_Api::_()->getDbtable('settings', 'core')->find('sitepushnotification.apnscertp12')->current()->value;
        $webPushId = Engine_Api::_()->getDbtable('settings', 'core')->find('sitepushnotification.webpushid')->current()->value;
        $apnsPassword = '';
        $siteTitle = Engine_Api::_()->getDbtable('settings', 'core')->find('sitepushnotification.sitetitle')->current()->value;
        $host = $_SERVER['SERVER_NAME'];

        if ($cert_p12_path == '0' && $webPushId == '0') {
            echo "Cannot send notification.No certificates found.";
            return;
        }
        
        if ($array1[6] == "pushPackages" || $array1[5] == "pushPackages") {

//     Get path of uploaded push package icons from database
            $uid = "authenticationToken_0";
            $iconSet = array();
            $iconSet = Engine_Api::_()->getApi('core', 'sitepushnotification')->getIconSet();

            $var = new Zend_WebPush_Apns();
            $certificate = $var->Certificate($cert_p12_path, $apnsPassword);
            $packageGenerator = $var->PackageGenerator($certificate, $host, $iconSet, $siteTitle, $webPushId);

            $package = $packageGenerator->createPushPackageForUser($uid);
            header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
            header("Expires: Sat, 26 Jul 1997 05:00:00 GMT"); // Date in the past
            header("Content-type: application/zip");
            // send zip file to the browser
            echo file_get_contents($package->getZipPath());
            exit(1);
        } elseif ($array1[6] == "log" || $array1[5] == "log") {

            echo "<br> error request recieved";
            $errorlog = APPLICATION_PATH . "/application/libraries/WebPushAPNS/errorlog.txt";
            $log = fopen($errorlog, "a");
            $datajson = file_get_contents('php://input');
            fwrite($log, date("d-m-Y H:i:s") . " eror code $datajson \n");
            fclose($log);
            exit(1);
        } elseif (($array1[6] == "devices" && $array1[8] == "registrations" ) || ($array1[5] == "devices" && $array1[7] == "registrations" )) {
           
            if ($_SERVER['REQUEST_METHOD'] == "POST") {
                $errorlog = APPLICATION_PATH . "/application/libraries/WebPushAPNS/errorlog.txt";
                $log = fopen($errorlog, "a");
                fwrite($log, date("d-m-Y H:i:s") . " post request \n");
                fclose($log);

                $params = array();
                $params['uid'] = 0;
                $params['browser'] = 'safari';
                $params['device_id'] = $array1[7];

                $request = Engine_Api::_()->getDbtable('users', 'sitepushnotification')->setSubscription($params);
            } else if ($_SERVER['REQUEST_METHOD'] == "DELETE") {
                $errorlog = APPLICATION_PATH . "/application/libraries/WebPushAPNS/errorlog.txt";
                $log = fopen($errorlog, "a");
                fwrite($log, date("d-m-Y H:i:s") . " delete request \n");
                fclose($log);

                Engine_Api::_()->getDbtable('users', 'sitepushnotification')->deleteSubscription($array1[7]);
            }

            fclose($log);
            exit(1);
        }
    }

    function unsubscribeDeviceAction() {
        $data = array('return' => 0, 'message' => 'Invalid action Performed');
        if (!$this->getRequest()->isPost()) {
            return $this->_helper->json($data);
        }

        $device_id = $this->_getParam('device_id');
        
        $isExist = Engine_Api::_()->getDbtable('users', 'sitepushnotification')->getUserSubscription($device_id);
        
        if (!$isExist) {
            $data = array('return' => 1, 'message' => 'Given device token does not exist');
            return $this->_helper->json($data);
        }

        Engine_Api::_()->getDbtable('users', 'sitepushnotification')->deleteSubscription($device_id);
        $data = array('return' => 1, 'message' => 'Device unsubscribed from server.');

        return $this->_helper->json($data);
    }

}