<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteapi
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    FormValidators.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitequicksignup_Api_Siteapi_FormValidators extends Siteapi_Api_Validators {

    private $_profileTypeId = false;

    /**
     * Validation: user signup form
     * 
     * @return array
     */
    public function getSignupFormValidators($values) {
        $accountValidations = $fieldValidations = array();
    
            // Get signup account form validation.
        if (isset($values['account_validation']) && !empty($values['account_validation'])) {
                $accountValidations = $this->_getSignupAccountFormValidations();
        }
        
        // Get fields account form validation.
        if (isset($values['fields_validation']) && !empty($values['fields_validation'])) {
            if (isset($values['profile_type']) && !empty($values['profile_type']))
                $this->_profileTypeId = $values['profile_type'];

            if (!empty($this->_profileTypeId))
                $fieldValidations = $this->_getSignupFieldsFormValidations();
        }

        return array_merge($accountValidations, $fieldValidations);
    }

    /**
     * Validation: user signup account form
     * 
     * @return array
     */
    private function _getSignupAccountFormValidations($formValidators = array()) {  
        $enableOtp = Engine_Api::_()->getApi('Siteapi_Core', 'user')->hasEnableOtp();
        $settings = Engine_Api::_()->getApi('settings', 'core');
        if($enableOtp)  {
        // $options = array('Db_NoRecordExists', true, array(Engine_Db_Table::getTablePrefix() . 'users', 'email'));

        
            $showBothPhoneAndEmail = $settings->getSetting('siteotpverifier.singupShowBothPhoneAndEmail', 1);
            $reqphoneno = !empty($showBothPhoneAndEmail) && $settings->getSetting('siteotpverifier.singupRequirePhone', 1);

            if (!empty($showBothPhoneAndEmail)) {
                $formValidators['email'] = $this->getEmailValidator($options);
                if($reqphoneno || !empty($_REQUEST['phoneno']))
                    $formValidators['phoneno'] = $this->getMobileValidator();
            } else {
                if (!strstr($_REQUEST['emailaddress'], '@')) {
                    $formValidators['emailaddress'] = $this->getMobileValidator();
                    $formValidators['email'] = $this->getEmailValidator($options);
                } else {
                    $formValidators['emailaddress'] = $this->getEmailValidator($options);
                }
            }

        }
        else {
            $formValidators['email'] = array('required' => true,
                                    'allowEmpty' => false
                                );
        }
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitequicksignup.confirm.email', 0)) {

            $formValidators['emailconf'] = array('required' => true,
                                    'allowEmpty' => false
                                );
        }
    
       
        $settings = Engine_Api::_()->getApi('settings', 'core');
        $random = ($settings->getSetting('user.signup.random', 0) == 1);

        if ($settings->getSetting('user.signup.inviteonly') > 0) {
            $formValidators['code'] = array(
                'required' => true,
                'allowEmpty' => false
        
            );
        }
        if(empty($_REQUEST['facebook_uid']) && empty($_REQUEST['twitter_uid']) && empty($_REQUEST['google_id']) && empty($_REQUEST['apple_id']) && ($settings->getSetting('sitequicksignup.signup.random', 0) == 0))
            $formValidators['password'] = $this->getPasswordValidator();

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitequicksignup.confirm.password', 1) && (empty($_REQUEST['facebook_uid']) && empty($_REQUEST['twitter_uid']) && empty($_REQUEST['google_id']) && empty($_REQUEST['apple_id']))) {
            $formValidators['passconf'] = $this->getPassConfValidator();
        }

        if ($settings->getSetting('user.signup.username', 1) > 0) {
            $formValidators['username'] = array(
                'validators' => array(
                    array('NotEmpty', true),
                    array('Alnum', true),
                    array('StringLength', true, array(4, 64)),
                    array('Regex', true, array('/^[a-z][a-z0-9]*$/i')),
                    array('Db_NoRecordExists', true, array(Engine_Db_Table::getTablePrefix() . 'users', 'username'))
                ),
                'required' => true,
                'allowEmpty' => false
    
            );
        }

        $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('user');
        if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
            $profileTypeField = $topStructure[0]->getChild();
            $options = $profileTypeField->getOptions();
            if (COUNT($options) > 1) {
                $formValidators['profile_type'] = array(
                    'required' => true,
                    'allowEmpty' => false,
                    
                );
            }
        }
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitequicksignup.timezone', 0)) {

            $formValidators['timezone'] = array(
                'required' => true,
                'allowEmpty' => false
            );
        }

        $translate = Zend_Registry::get('Zend_Translate');
        $languageList = $translate->getList();
        if (COUNT($languageList) > 1) {
            $formValidators['language'] = array(
                'required' => true,
                'allowEmpty' => false
                
            );
        }
        return $formValidators;
    }

    /**
     * Validation: user signup field form
     * 
     * @return array
     */
    private function _getSignupFieldsFormValidations() {
        $option_id = $this->_profileTypeId;
        $mapData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMaps('user');
        $getRowsMatching = $mapData->getRowsMatching('option_id', $option_id);
        $fieldArray = array();
        $getFieldInfo = Engine_Api::_()->fields()->getFieldInfo();
        foreach ($getRowsMatching as $map) {
            $meta = $map->getChild();
            $type = $meta->type;

            if (!empty($type) && ($type == 'heading'))
                continue;

            if (!isset($meta->show) || empty($meta->show))
                continue;

            if (!isset($meta->display) || empty($meta->display))
                continue;


            $fieldForm = $getMultiOptions = array();
            $key = $map->getKey();

            if (!empty($meta->alias))
                $key = $key . '_' . ( $meta->alias ? 'alias_' . $meta->alias : sprintf('field_%d', $meta->alias->field_id) );
            else
                $key = $key . '_alias_';

            if (isset($meta->required) && !empty($meta->required)) {
                $fieldArray[$key] = array(
                    'required' => true,
                    'allowEmpty' => false
                );


                if (isset($meta->label) && !empty($meta->label))
                    $fieldArray[$key]['label'] = $meta->label;
            }

            //for validation of age limit on profile field
            if ($meta->type == 'birthdate') {
                if (isset($meta->config['min_age'])) {
                    if (isset($meta->required) && !empty($meta->required))
                        $fieldArray[$key] = array(
                            'required' => true,
                            'allowEmpty' => false,
                            'min' => $meta->config['min_age'],
                            'label' => $meta->label
                        );
                    else {
                        $fieldArray[$key] = array(
                            'min' => $meta->config['min_age'],
                            'label' => $meta->label
                        );
                    }
                }
            }

            if (isset($mets->validators) && !empty($mets->validators)) {
                $fieldArray[$option_id."_profile_type_".$key]['validators'] = $mets->validators;
            }
        }
        return $fieldArray;
    }

     public function getMobileValidator($options = array()) {
        $phoneValidator = array();
        $settings = Engine_Api::_()->getApi('settings', 'core');
        $showBothPhoneAndEmail = $settings->getSetting('siteotpverifier.singupShowBothPhoneAndEmail', 1);
        $reqphoneno = !empty($showBothPhoneAndEmail) && $settings->getSetting('siteotpverifier.singupRequirePhone', 1);
        if (empty($showBothPhoneAndEmail)) {
            $reqphoneno = 1;
        }
        $phoneValidator = array('required' => $reqphoneno,
            'allowEmpty' => false,
            'validators' => array(
                array('NotEmpty', empty($reqphoneno) ? false : true),
                array('Regex', true, array('/^[1-9][0-9]{7,10}$/')),
                array('Db_NoRecordExists', true, array(Engine_Db_Table::getTablePrefix() . 'siteotpverifier_users', 'phoneno'))
            ),
        );


        return $phoneValidator;
    }

    //return the email validators and filters
    public function getEmailValidator($options = array()) {
        $emailValidator = array();
        $emailValidator = array('required' => 1,
            'allowEmpty' => false,
            'validators' => array(array('NotEmpty', 1), array('EmailAddress', 1), array('Db_NoRecordExists', '1', array('engine4_users', 'email'))),
            'filters' => array('StringTrim')
        );

        if (isset($options['required']) && !$options['required'])
            unset($emailValidator['required']);
        if (isset($options['Db_NoRecordExists']) && !$options['Db_NoRecordExists'])
            unset($emailValidator['validators'][2]);

        return $emailValidator;
    }


}