<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siterecaptcha
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2016-05-18 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siterecaptcha_Form_Admin_Global extends Engine_Form {

    // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
    public $_SHOWELEMENTSBEFOREACTIVATE = array(
        "submit_lsetting", "environment_mode"
    );
    protected $_captcha_options = array(
        1 => 'Yes, make members complete the CAPTCHA form.',
        0 => 'No, do not show a CAPTCHA form.',
    );

    public function init() {

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $this
                ->setTitle('Global Settings')
                ->setDescription('These settings affect all members in your community.');

        $this->addElement('Text', 'siterecaptcha_lsettings', array(
            'label' => 'Enter License key',
            'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
            'value' => $coreSettings->getSetting('siterecaptcha.lsettings'),
        ));

        if (APPLICATION_ENV == 'production') {
            $this->addElement('Checkbox', 'environment_mode', array(
                'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few stores of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
                'description' => 'System Mode',
                'value' => 1,
            ));
        } else {
            $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
        }

        // Add submit button
        $this->addElement('Button', 'submit_lsetting', array(
            'label' => 'Activate Your Plugin Now',
            'type' => 'submit',
            'onclick' => 'showlightbox();',
            'ignore' => true
        ));

        $translator = $this->getTranslator();
        if ($translator) {
            $description_spam = sprintf($translator->translate('%1$s'), $this->getView()->htmlLink('admin/core/settings/spam#signup-wrapper', 'here', array('target' => '_blank')));
        } else {
            $description_spam = null;
        }

        // recaptcha
        if ($translator) {
            $description = sprintf($translator->translate('Please enter your Google No CAPTCHA reCAPTCHA Site Key. <br />[<b>Note:</b> You can generate Google No CAPTCHA reCAPTCHA Site Key for your website by following this URL: %1$s.]'), $this->getView()->htmlLink('https://www.google.com/recaptcha/admin#list', 'https://www.google.com/recaptcha/admin#list', array('target' => '_blank')));
        } else {
            $description = null;
        }

        $this->addElement('Text', 'siterecaptcha_site_key', array(
            'label' => 'reCAPTCHA Site Key',
            'description' => $description,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting("siterecaptcha.site.key"),
            'filters' => array(
                'StringTrim',
            ),
        ));
        $this->getElement('siterecaptcha_site_key')
                ->getDecorator('Description')
                ->setOption('escape', false);

        // recaptcha
        if ($translator) {
            $description = sprintf($translator->translate('Please enter your Google No CAPTCHA reCAPTCHA Secret Key. <br />[<b>Note:</b> You can generate Google No CAPTCHA reCAPTCHA Secret Key for your website by following this URL: %1$s.]'), $this->getView()->htmlLink('https://www.google.com/recaptcha/admin#list', 'https://www.google.com/recaptcha/admin#list', array('target' => '_blank')));
        } else {
            $description = null;
        }

        $this->addElement('Text', 'siterecaptcha_secret_key', array(
            'label' => 'reCAPTCHA Secret Key',
            'description' => $description,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting("siterecaptcha.secret.key"),
            'filters' => array(
                'StringTrim',
            ),
        ));
        $this->getElement('siterecaptcha_secret_key')
                ->getDecorator('Description')
                ->setOption('escape', false);


        $this->addElement('Radio', 'signup', array(
            'label' => 'Activate reCAPTCHA in sign up form?',
            'multiOptions' => array(
                1 => 'Yes, activate No CAPTCHA reCAPTCHA in sign up form.',
                0 => 'No, do not activate No CAPTCHA reCAPTCHA in sign up form.',
            ),
            'value' => 0,
        ));


        $this->addElement('Radio', 'login', array(
            'label' => 'Activate reCAPTCHA in sign in form?',
            'multiOptions' => array(
                1 => 'Yes, activate No CAPTCHA reCAPTCHA in sign in form.',
                0 => 'No, do not activate No CAPTCHA reCAPTCHA in sign in form.',
            ),
            'value' => 0,
        ));


        $this->addElement('Radio', 'invite', array(
            'label' => 'Activate reCAPTCHA in invite form?',
            'multiOptions' => array(
                1 => 'Yes, activate No CAPTCHA reCAPTCHA in invite form.',
                0 => 'No, do not activate No CAPTCHA reCAPTCHA in invite form.',
            ),
            'value' => 0,
        ));

        $this->addElement('Radio', 'contact', array(
            'label' => 'Activate reCAPTCHA in contact form?',
            'multiOptions' => array(
                2 => 'Yes, activate No CAPTCHA reCAPTCHA in contact form.',
                1 => 'Yes, activate No CAPTCHA reCAPTCHA in contact form, but members are exempt.',
                0 => 'No, do not activate No CAPTCHA reCAPTCHA to anyone.',
            ),
            'value' => 0,
        ));

        // init profile
        $this->addElement('Radio', 'comment', array(
            'label' => 'Activate reCAPTCHA in comments?',
            'multiOptions' => array(
                1 => 'Yes, activate No CAPTCHA reCAPTCHA in comments.',
                0 => 'No, do not activate  No CAPTCHA reCAPTCHA in comments.',
            ),
            'value' => 0,
        ));

        $pages = array(
            'userAccount' => 'SE Core User Sign Up',
            'userLogin' => 'SE Core User Sign In',
            'coreComment' => 'SE Core Comment',
            'coreContact' => 'SE Core Contact Page',
            'inviteInvite' => 'SE Core Invite Page',
        );

        if ($translator) {
            $faq = sprintf($translator->translate('%1$s'), $this->getView()->htmlLink('admin/siterecaptcha/settings/faq/faq/faq_5', 'here', array('target' => '_blank')));
        } else {
            $faq = null;
        }

        $fileCode = Engine_Api::_()->siterecaptcha()->isRecaptchaFileRelatedChanges();

        if (empty($fileCode)) {
            $this->addElement('MultiCheckbox', 'siterecaptcha_replace_files', array(
                'label' => 'File replacement for reCAPTCHA',
                'description' => "Do you want to automatically replace the files of below pages to implement the Google reCAPTCHA? <br />[<b>Note:</b> To manually configure the files (like 'application/modules/User/Form/Signup/Account.php', 'application/modules/User/Form/Login.php' etc.) of different pages, you need to follow the process mentioned $faq.]",
                'multiOptions' => $pages,
                'escape' => false,
                    //'value' => $coreSettings->getSetting('siterecaptcha.replace.files'),
            ));
            $this->getElement('siterecaptcha_replace_files')
                    ->getDecorator('Description')
                    ->setOption('escape', false);
        }

        // Add submit button
        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}
