<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitereviewpaidlisting
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2014-05-19 5:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitereviewpaidlisting_Api_Core extends Core_Api_Abstract {

  /**
   * Send emails for perticuler listing
   * @params $type : which mail send
   * $params $listingId : Id of listing
   * */
  public function sendMail($type, $listingId) {

    if (empty($type) || empty($listingId)) {
      return;
    }
    $listing = Engine_Api::_()->getItem('sitereview_listing', $listingId);
    $listing_type = Engine_Api::_()->getDbtable('listingtypes', 'sitereview')->getListingTypeColumn($listing->listingtype_id, 'title_singular');
    $listing_type = strtolower($listing_type);
    
    $mail_template = null;
    if (!empty($listing)) {

      $owner = Engine_Api::_()->user()->getUser($listing->owner_id);
      switch ($type) {
        case "APPROVAL_PENDING":
          $mail_template = 'sitereview_'.$listing_type.'_approval_pending';
          break;
        case "EXPIRED":
          if ($listing->getPackage()->isFree())
            $mail_template = 'sitereview_'.$listing_type.'_expired';
          else
            $mail_template = 'sitereview_'.$listing_type.'_renew';
          break;
        case "OVERDUE":
          $mail_template = 'sitereview_'.$listing_type.'_overdue';
          break;
        case "CANCELLED":
          $mail_template = 'sitereview_'.$listing_type.'_cancelled';
          break;
        case "ACTIVE":
          $mail_template = 'sitereview_'.$listing_type.'_active';
          break;
        case "PENDING":
          $mail_template = 'sitereview_'.$listing_type.'_pending';
          break;
        case "REFUNDED":
          $mail_template = 'sitereview_'.$listing_type.'_refunded';
          break;
        case "APPROVED":
          $mail_template = 'sitereview_'.$listing_type.'_approved';
          break;
        case "DISAPPROVED":
          $mail_template = 'sitereview_'.$listing_type.'_disapproved';
          break;
        case "DECLINED":
          $mail_template = 'sitereview_'.$listing_type.'_declined';
          break;
        case "RECURRENCE":
          $mail_template = 'sitereview_'.$listing_type.'_recurrence';
          break;
      }

      $httpVar = _ENGINE_SSL ? 'https://' : 'http://';
      $list_baseurl = $httpVar . $_SERVER['HTTP_HOST'] .
              Zend_Controller_Front::getInstance()->getRouter()->assemble(array('listing_id' => $listing->listing_id, 'slug' => $listing->getSlug()), "sitereview_entry_view_listtype_$listing->listingtype_id", true);

      //MAKING LISTING TITLE LINK
      $list_title_link = '<a href="' . $list_baseurl . '"  >' . $listing->title . ' </a>';

      Engine_Api::_()->getApi('mail', 'core')->sendSystem($owner, $mail_template, array(
          'site_title' => Engine_Api::_()->getApi('settings', 'core')->getSetting('core.general.site.title', 1),
          'list_title' => $listing->title,
          'list_description' => ucfirst($listing->body),
          'list_title_with_link' => $list_title_link,
          'object_link' => $list_baseurl,
          'queue' => false,
      ));
    }
  }

  /**
   * Allow contect for perticuler package
   * @params $type : which check
   * $params $package_id : Id of listing
   * $params $params : array some extra
   * */
  public function allowPackageContent($package_id, $type = null, $listingTypeId = null) {

    if (!$this->hasPackageEnable($listingTypeId))
      return;

    $flage = false;
    $package = Engine_Api::_()->getItem('sitereviewpaidlisting_package', $package_id);

    if (empty($package))
      return $flage;

    if (isset($package->$type) && !empty($package->$type))
      $flage = true;

    return $flage;
  }

  /**
   * Get Listing Profile Fileds If package set some fields
   * @return array : profile fields
   * */
  public function getProfileFields() {

    $packageId = Zend_Controller_Front::getInstance()->getRequest()->getParam('id');
    $packageProfileFields = Engine_Api::_()->getItem('sitereviewpaidlisting_package', $packageId)->profilefields;
    return unserialize($packageProfileFields);
  }

  /**
   * Check here that show renew link or not
   * $params $listing_id : Id of listing
   * @return bool $showLink
   * */
  public function canShowRenewLink($listing_id) {
    if (!$this->hasPackageEnable())
      return;
    $showLink = false;
    $listing = Engine_Api::_()->getItem('sitereview_listing', $listing_id);

    if (!empty($listing)) {
      $package = $listing->getPackage();

      if (!$package->isOneTime() || $package->isFree() || (!empty($package->level_id) && !in_array($listing->getOwner()->level_id, explode(",", $package->level_id)))) {
        return (bool) false;
      }
      if ($package->renew) {
        if (!empty($listing->expiration_date) && $listing->status != "initial" && $listing->status != "overdue") {
          $diff_days = round((strtotime($listing->expiration_date) - strtotime(date('Y-m-d H:i:s'))) / 86400);
          if ($diff_days <= $package->renew_before || $listing->expiration_date <= date('Y-m-d H:i:s')) {
            return (bool) true;
          }
        }
      }
    }
    return (bool) $showLink;
  }
  
  public function canAdminShowRenewLink($listing_id) {
    if (!$this->hasPackageEnable())
        return false;

    $showLink = false;
    $listing = Engine_Api::_()->getItem('sitereview_listing', $listing_id);
    if (!empty($listing)) {
        if (!empty($listing->approved) && $listing->expiration_date !== "2250-01-01 00:00:00")
            $showLink = true;
    }
    return (bool) $showLink;
  }

  /**
   * Check here that show payment link or not
   * $params $listingId : Id of listing
   * @return bool $showLink
   * */
  public function canShowPaymentLink($listing_id) {

    if (!Engine_Api::_()->sitereviewpaidlisting()->hasPackageEnable())
      return;

    $showLink = true;
    $listing = Engine_Api::_()->getItem('sitereview_listing', $listing_id);

    if (!empty($listing)) {
      $package = $listing->getPackage();
      if ($package->isFree()) {
        return (bool) false;
      }

      if (empty($listing->expiration_date) || $listing->expiration_date === "0000-00-00 00:00:00") {
        return (bool) true;
      }

      if ($listing->status != "initial" && $listing->status != "overdue") {
        return (bool) false;
      }

      if (($package->isOneTime()) && !$package->hasDuration() && !empty($listing->approved)) {
        return false;
      }
    } else {
      $showLink = false;
    }
    return (bool) $showLink;
  }

  /**
   * Check package is enable or not for site
   * @return bool
   */
  public function hasPackageEnable($listingTypeId = 0) {

    if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereviewpaidlisting'))
      return (bool) 0;

    if (empty($listingTypeId))
      $listingtype_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('listingtype_id');
    else
      $listingtype_id = $listingTypeId;

    if (!empty($listingtype_id)) {
      $listingTypeTable = Engine_Api::_()->getDbTable('listingtypes', 'sitereview');
      $package = $listingTypeTable->select()
              ->from($listingTypeTable->info('name'), array('package'))
              ->where('listingtype_id = ?', $listingtype_id)
              ->query()
              ->fetchColumn();
    }
    else
      $package = 1;

    if (!empty($package))
      return (bool) 1;
    else
      return (bool) 0;
  }

  /**
   * DISAPROVED AFTER EXPIRY LISTING THIS IS USE ONLY FOR ENABLE PACKAGE MENAGEMENT
   * */
  public function updateExpiredListings($listingTypeId = 0) {

    if (empty($listingTypeId)) {
      $listingtypes = Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypes();
      foreach ($listingtypes as $listingtype) {
        $listingTypeId = $listingtype->listingtype_id;
        if (!$this->hasPackageEnable($listingTypeId))
          continue;
        $this->updateListingTables($listingTypeId);
      }
    }
    else {
      if (!$this->hasPackageEnable($listingTypeId))
        return;
      $this->updateListingTables($listingTypeId);
    }
  }

  public function updateListingTables($listingTypeId = 0) {

    $listingTable = Engine_Api::_()->getDbtable('listings', 'sitereview');
    $listingTableName = $listingTable->info('name');
    //LIST FOR LISTINGS WHICH ARE EXPIRIED NOW AND SEND MAIL
    $select = $listingTable->select()
            ->from($listingTableName, array('listing_id'))
            ->where('listingtype_id = ?', $listingTypeId)
            ->where('status <>  ?', 'expired')
            ->where('approved = ?', '1')
            ->where('expiration_date <= ?', date('Y-m-d H:i:s'));

    foreach ($listingTable->fetchAll($select) as $listing) {
      $this->sendMail("EXPIRED", $listing->listing_id);
    }

    //UPDATE THE STATUS
    $listingTable->update(array(
        'approved' => 0,
        'status' => 'expired'
            ), array(
        'listingtype_id =?' => $listingTypeId,
        'status <>?' => 'expired',
        'expiration_date <=?' => date('Y-m-d H:i:s'),
    ));
    Engine_Api::_()->getApi('settings', 'core')->setSetting('sitereviewpaidlisting.task.updateexpiredlistings', time());

    $listingTable->update(array(
        'search' => 0
            ), array(
        'listingtype_id =?' => $listingTypeId,
        'status =?' => 'expired',
    ));
  }

    /**
   * Check here that show cancel link or not
   * @return bool $showLink
   * */
  public function canShowCancelLink($listing_id) {

    if (!Engine_Api::_()->sitereviewpaidlisting()->hasPackageEnable())
      return;

    $showLink = false;
    $listing = Engine_Api::_()->getItem('sitereview_listing', $listing_id);

    if (!empty($listing)) {
      $package = $listing->getPackage();

      if (!$package->isFree() && $listing->status == "active" && !$package->isOneTime() && $package->hasDuration() && !empty($listing->approved)) {
        return (bool) true;
      }
    }
    
    return (bool) $showLink;
  }

  //Function to return Currency Conversion rate
  public function getPriceWithCurrency($price) { 

    return Engine_Api::_()->sitereview()->getPriceWithCurrency($price);
  }  
  
}