<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteshortcut
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminManageController.php 2017-02-24 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteshortcut_AdminManageController extends Core_Controller_Action_Admin
{
  public function indexAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteshortcut_admin_main', array(), 'siteshortcut_admin_main_manage');
    $shortcutType = Engine_Api::_()->getDbTable('shortcuttypes', 'siteshortcut');
    $modules = Engine_Api::_()->getDbtable('modules', 'core')->getEnabledModuleNames();
    $select = $shortcutType->select()
      ->where('module_name  IN(?) ', $modules)
      ->order("order ASC");
    $this->view->shortcuttypes = $shortcutType->fetchAll($select);
  }

  public function addShortcuttypeAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteshortcut_admin_main', array(), 'siteshortcut_admin_main_manage');
    $this->view->form = $form = new Siteshortcut_Form_Admin_Manage_Shortcuttype();
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $shortcutType = Engine_Api::_()->getDbTable('shortcuttypes', 'siteshortcut');
    $values = $form->getValues();
    $db = Engine_Db_Table::getDefaultAdapter();
    if( in_array($values['module_name'], array('sitereview', 'sitereviewlistingtype')) ) {
      $params = array(
        'membership' => 0,
        'admin' => 0,
        'owner' => 'owner_id'
      );
    } else {
      $itemType = $values['type'];
      $tablePrefix = $shortcutType->getTablePrefix();
      $membershipTablename = $tablePrefix . $values['module_name'] . "_membership";

      $listTableName = $tablePrefix . $values['module_name'] . '_lists';
      $listItemTableName = $tablePrefix . $values['module_name'] . '_listitems';
      $tableExist = $db->query('SHOW TABLES LIKE "' . $membershipTablename . '"')->fetch();
      $listTableExist = $db->query('SHOW TABLES LIKE "' . $listTableName . '"')->fetch();
      $listItemTableExist = $db->query('SHOW TABLES LIKE "' . $listItemTableName . '"')->fetch();
      $tableCols = Engine_Api::_()->getItemTable($itemType)->info('cols');
      $ownerColumnName = in_array('owner_id', $tableCols) ? 'owner_id' : 'user_id';
      $params = array(
        'membership' => $tableExist ? 1 : 0,
        'owner' => $ownerColumnName,
        'admin' => ($listTableExist && $listItemTableExist) ? 1 : 0,
      );
    }
    $values['params'] = $params;
    if( $values['shortcut_allow'] === 'member' && $params['membership'] == 0 ) {
      $values['shortcut_allow'] = 'admin';
    }
    if( $values['shortcut_allow'] == 'admin' && $params['admin'] == 0 ) {
      $values['shortcut_allow'] = 'owner';
    }
    if( $values['notification_allow'] === 'member' && $params['membership'] == 0 ) {
      $values['notification_allow'] = 'admin';
    }
    if( $values['notification_allow'] == 'admin' && $params['admin'] == 0 ) {
      $values['notification_allow'] = 'owner';
    }

    $row = $shortcutType->createRow();
    $row->setFromArray($values);
    $row->save();
    $this->_helper->redirector->gotoRoute(array('module' => 'siteshortcut', 'controller' => 'manage'), 'admin_default', true);
  }

  public function editShortcuttypeAction()
  {
    $shortcuttype_id = $this->_getParam('shortcuttype_id');
    $module_name = $this->_getParam('module_name');
    $shortcutType = Engine_Api::_()->getDbtable('shortcuttypes', 'siteshortcut')->find($shortcuttype_id)->current();

    if( empty($shortcuttype_id) || !$shortcutType ) {
      $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }
    $params = $shortcutType->params;
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteshortcut_admin_main', array(), 'siteshortcut_admin_main_manage');
    $this->view->form = $form = new Siteshortcut_Form_Admin_Manage_ShortcuttypeEdit();
    if( in_array($module_name, array('user', 'message', 'activity', 'core')) ) {
      foreach( array('module_name', 'type', 'shortcut_allow') as $element ) {
        $form->removeElement($element);
      }
    } else {
      $shortcutAllowOptions = $form->getElement('shortcut_allow')->getMultiOptions();
      if( in_array($module_name, array('sitepage', 'sitegroup', 'sitestore', 'sitebusiness')) ) {
        $params['membership'] = (int) Engine_Api::_()->getDbtable('modules', 'core')
            ->isModuleEnabled($module_name . 'member');
      }
      if( $params['membership'] == 0 ) {
        $values['shortcut_allow'] = 'admin';
        unset($shortcutAllowOptions['member']);
      }
      if( $params['admin'] == 0 ) {
        unset($shortcutAllowOptions['admin']);
      }
      $shortcutAllowOptions = $form->getElement('shortcut_allow')->setMultiOptions($shortcutAllowOptions);
    }

    $form->populate($shortcutType->toArray());
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $values = $form->getValues();
    if( $values['shortcut_allow'] === 'member' && $params['membership'] == 0 ) {
      $values['shortcut_allow'] = 'admin';
    }
    if( $values['shortcut_allow'] == 'admin' && $params['admin'] == 0 ) {
      $values['shortcut_allow'] = 'owner';
    }
    if( $values['notification_allow'] === 'member' && $params['membership'] == 0 ) {
      $values['notification_allow'] = 'admin';
    }
    if( $values['notification_allow'] == 'admin' && $params['admin'] == 0 ) {
      $values['notification_allow'] = 'owner';
    }
    $shortcutType->setFromArray($values);
    $shortcutType->save();
    $this->_helper->redirector->gotoRoute(array('module' => 'siteshortcut', 'controller' => 'manage'), 'admin_default', true);
  }

  public function enableShortcuttypeAction()
  {
    $shortcuttype_id = $this->_getParam('shortcuttype_id');
    if( empty($shortcuttype_id) ) {
      $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }
    $shortcutType = Engine_Api::_()->getDbtable('shortcuttypes', 'siteshortcut')->find($shortcuttype_id)->current();
    if( empty($shortcutType) ) {
      $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }
    $shortcutType->enabled = !$shortcutType->enabled;
    $shortcutType->save();
    $this->_helper->redirector->gotoRoute(array('action' => 'index'));
  }

  public function deleteShortcuttypeAction()
  {
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->shortcuttype_id = $shortcuttype_id = $this->_getParam('shortcuttype_id');


    if( $this->getRequest()->isPost() ) {
      if( empty($shortcuttype_id) ) {
        return;
      }

      $shortcutType = Engine_Api::_()->getDbtable('shortcuttypes', 'siteshortcut')->find($shortcuttype_id)->current();
      $shortcutType->delete();
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
      ));
    }
  }

  //ACTION FOR UPDATE ORDER 
  public function updateOrderAction()
  {
    //CHECK POST
    if( $this->getRequest()->isPost() ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      $values = $_POST;
      try {
        foreach( $values['order'] as $key => $value ) {
          $content = Engine_Api::_()->getDbtable('shortcuttypes', 'siteshortcut')->find((int) $value)->current();
          if( !empty($content) ) {
            $content->order = $key + 1;
            $content->save();
          }
        }
        $db->commit();
        $this->_helper->redirector->gotoRoute(array('action' => 'index'));
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
    }
  }

}
