<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestore
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Core.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestore_Api_Siteapi_Core extends Core_Api_Abstract {

	public $_profileFieldsArray;

	public function getStorePaginator($values = array()) {
		return Engine_Api::_()->sitestore()->getSitestoresPaginator($values);
	}

	public function getOwner() {
		return $this->_owner;
	}

	public function setOwner($owner) {
		$this->_owner = $owner;
		return $this;
	}

	public function getPackageId() {
		return $this->_packageId;
	}

	public function setPackageId($package_id) {
		$this->_packageId = $package_id;
		return $this;
	}

	/*
		     * Get browse/manage page search api
		     *
		     * @return array
	*/

	public function getSearchForm() {
		$searchForm = array();
		$storesearchsettings = Engine_Api::_()->getDbTable('searchformsetting', 'seaocore');
		$coreSettings = Engine_Api::_()->getApi('settings', 'core');
		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

		// Set "Category" form element in the search form.
		$categories = Engine_Api::_()->getDbTable('categories', 'sitestore')->getCategories();
		$subcategoryArray = array();
		if (count($categories) != 0) {
			$categories_prepared[0] = '';
			foreach ($categories as $category) {
				$categories_prepared[$category->category_id] = $this->translate($category->category_name);
				$subcategoryArray[$category->category_id]['form'] = array(
					'name' => 'subcategory_id',
					'type' => 'Select',
					'label' => $this->translate('Subcategory'),
					'multiOptions' => array(0 => ''),
				);
			}
		}

		$subcategories = Engine_Api::_()->getDbtable('categories', 'sitestore')->getCategoriesByLevel('subcategory');

		if (!empty($subcategories)) {
			foreach ($subcategories as $row => $value) {
				$subcategoryArray[$value->cat_dependency]['form']['multiOptions'][$value->category_id] = $this->translate($value->category_name);
				$subcategoryArray[$value->cat_dependency]['subsubcategories'][$value->category_id] = array(
					'name' => 'subsubcategory_id',
					'type' => 'Select',
					'label' => $this->translate('3rd Level category'),
					'multiOptions' => array(0 => ''),
				);

				$subsubcategories = Engine_Api::_()->getDbtable('categories', 'sitestore')->getCategoriesByLevel('subsubcategory');

				if (!empty($subsubcategories)) {
					foreach ($subsubcategories as $row => $subvalue) {
						if ($subvalue->cat_dependency == $value->category_id) {
							$subcategoryArray[$value->cat_dependency]['subsubcategories'][$subvalue->cat_dependency]['multiOptions'][$subvalue->category_id] = $this->translate($subvalue->category_name);
						}

					}

					foreach ($subcategoryArray[$value->cat_dependency]['subsubcategories'] as $catkey => $catvalue) {
						if (count($catvalue['multiOptions']) == 1) {
							unset($subcategoryArray[$value->cat_dependency]['subsubcategories']);
						}

					}
				}
			}
			foreach ($subcategoryArray as $key => $value) {
				if (count($value['form']['multiOptions']) == 1) {
					unset($subcategoryArray[$key]);
				}

			}
		}

		$searchForm[] = array(
			'label' => $this->translate('Category'),
			'type' => 'Select',
			'name' => 'category_id',
			'multiOptions' => $categories_prepared,
		);

		// Set "Show" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'show');
		if (!empty($row) && !empty($row->display)) {
			if (isset($multiOptionsArray)) {
				unset($multiOptionsArray);
			}

			$multiOptionsArray = array();
			$multiOptionsArray['1'] = $this->translate('Everyone\'s Stores');
			$multiOptionsArray['2'] = $this->translate('Only My Friends\' Stores');
			$multiOptionsArray['4'] = $this->translate('Stores I Like');
			$multiOptionsArray['5'] = $this->translate('Featured Stores');

			$value_deault = 1;
			$enableNetwork = $coreSettings->getSetting('sitestore.network', 0);
			if (empty($enableNetwork)) {
				$networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
				$viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer_id));

				if (!empty($viewerNetwork) || Engine_Api::_()->getApi('subCore', 'sitestore')->storeBaseNetworkEnable()) {
					$show_multiOptions["3"] = $this->translate('Only My Networks');
					$browseDefaulNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.default.show', 0);

					if (!isset($_GET['show']) && !empty($browseDefaulNetwork)) {
						$value_deault = 3;
					} elseif (isset($_REQUEST['show'])) {
						$value_deault = $_REQUEST['show'];
					}
				}
			}

			$searchForm[] = array(
				'type' => 'Select',
				'name' => 'show',
				'label' => $this->translate('Show'),
				'multiOptions' => $multiOptionsArray,
				'value' => $value_deault,
			);
		}

		// Set "Browse By" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'orderby');
		$sitestorereviewEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorereview');
		$multiOptionsArray = array();
		$multiOptionsArray[''] = '';
		$multiOptionsArray['creation_date'] = $this->translate('Most Recent');
		$multiOptionsArray['view_count'] = $this->translate('Most Viewed');
		$multiOptionsArray['like_count'] = $this->translate('Most Liked');
		$multiOptionsArray['title'] = $this->translate('Alphabetical');
		if (!empty($row) && !empty($row->display) && !empty($sitestorereviewEnabled)) {
			if (Engine_Api::_()->sitestore()->isCommentsAllow("sitestore_store")) {
				$multiOptionsArray['review_count'] = $this->translate('Most Reviewed');
				$multiOptionsArray['rating'] = $this->translate('Highest Rated');
			}
		}
		$searchForm[] = array(
			'type' => 'Select',
			'name' => 'orderby',
			'label' => $this->translate('Browse By'),
			'multiOptions' => $multiOptionsArray,
		);

		// Set "Search" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'search');
		if (!empty($row) && !empty($row->display)) {
			$searchForm[] = array(
				'type' => 'Text',
				'name' => 'search',
				'label' => $this->translate('Search Stores'),
			);
		}

		// Set "Price" form element in the search form.
		$pricefieldoptions = $storesearchsettings->getFieldsOptions('sitestore', 'price');
		if (!empty($pricefieldoptions)) {
			$enablePrice = $coreSettings->getSetting('sitestore.price.field', 0);
			if (!empty($enablePrice)) {
				$searchForm[] = array(
					'type' => 'Text',
					'name' => 'price',
					'label' => $this->translate('Price'),
				);
			}
		}

		// Set "Within Kilometers / Within Miles", "Street", "City", "State" and "Country" form element in the search form.
		$rowLocation = $storesearchsettings->getFieldsOptions('sitestore', 'location');
		if (!empty($rowLocation) && !empty($rowLocation->display)) {
			$enableLocation = $coreSettings->getSetting('sitestore.locationfield', 1);
			if (!empty($enableLocation)) {
				$row = $storesearchsettings->getFieldsOptions('sitestore', 'locationmiles');
				if (!empty($row) && !empty($row->display)) {
					$enableProximitysearch = $coreSettings->getSetting('sitestore.proximitysearch', 1);
					if (!empty($enableProximitysearch)) {
						$flage = $coreSettings->getSetting('sitestore.proximity.search.kilometer', 0);
						if ($flage) {
							$locationLable = $this->translate("Within Kilometers");
							$locationOption = array(
								'0' => '',
								'1' => $this->translate('1 Kilometer'),
								'2' => $this->translate('2 Kilometers'),
								'5' => $this->translate('5 Kilometers'),
								'10' => $this->translate('10 Kilometers'),
								'20' => $this->translate('20 Kilometers'),
								'50' => $this->translate('50 Kilometers'),
								'100' => $this->translate('100 Kilometers'),
								'250' => $this->translate('250 Kilometers'),
								'500' => $this->translate('500 Kilometers'),
								'750' => $this->translate('750 Kilometers'),
								'1000' => $this->translate('1000 Kilometers'),
							);
						} else {
							$locationLable = $this->translate("Within Miles");
							$locationOption = array(
								'0' => '',
								'1' => $this->translate('1 Mile'),
								'2' => $this->translate('2 Miles'),
								'5' => $this->translate('5 Miles'),
								'10' => $this->translate('10 Miles'),
								'20' => $this->translate('20 Miles'),
								'50' => $this->translate('50 Miles'),
								'100' => $this->translate('100 Miles'),
								'250' => $this->translate('250 Miles'),
								'500' => $this->translate('500 Miles'),
								'750' => $this->translate('750 Miles'),
								'1000' => $this->translate('1000 Miles'),
							);
						}

						// Set "Within Kilometers / Within Miles" form element in the search form.
						$searchForm[] = array(
							'type' => 'Select',
							'name' => 'locationmiles',
							'label' => $locationLable,
							'multiOptions' => $locationOption,
						);
					}

					$searchForm[] = array(
						'type' => 'Text',
						'name' => 'sitestore_location',
						'label' => $this->translate("Location"),
					);
				}

				// Set "Street" form element in the search form.
				$row = $storesearchsettings->getFieldsOptions('sitestore', 'street');
				if (!empty($row) && !empty($row->display)) {
					$searchForm[] = array(
						'type' => 'Text',
						'name' => 'sitestore_street',
						'label' => $this->translate('Street'),
					);
				}

				// Set "City" form element in the search form.
				$row = $storesearchsettings->getFieldsOptions('sitestore', 'city');
				if (!empty($row) && !empty($row->display)) {
					$searchForm[] = array(
						'type' => 'Text',
						'name' => 'sitestore_city',
						'label' => $this->translate('City'),
					);
				}

				// Set "State" form element in the search form.
				$row = $storesearchsettings->getFieldsOptions('sitestore', 'state');
				if (!empty($row) && !empty($row->display)) {
					$searchForm[] = array(
						'type' => 'Text',
						'name' => 'sitestore_state',
						'label' => $this->translate('State'),
					);
				}

				// Set "Country" form element in the search form.
				$row = $storesearchsettings->getFieldsOptions('sitestore', 'country');
				if (!empty($row) && !empty($row->display)) {
					$searchForm[] = array(
						'type' => 'Text',
						'name' => 'sitestore_country',
						'label' => $this->translate('Country'),
					);
				}
			}
		}

		// Set "Badge" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'badge_id');
		if (!empty($row) && !empty($row->display)) {
			if ((int) Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorebadge') && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorebadge.seaching.bybadge', 1)) {
				$badgeData = Engine_Api::_()->getDbTable('badges', 'sitestorebadge')->getBadgesData(array('search_code' => 1));
				if (!empty($badgeData)) {
					$badgeData = $badgeData->toArray();
					$badgeCount = Count($badgeData);
					if (!empty($badgeCount)) {
						$badge_options = array();
						$badge_options[0] = '';
						foreach ($badgeData as $key => $name) {
							$badge_options[$name['badge_id']] = $name['title'];
						}

						$searchForm[] = array(
							'type' => 'Select',
							'name' => 'badge_id',
							'label' => $this->translate('Badge'),
							'multiOptions' => $badge_options,
						);
					}
				}
			}
		}

		// Set "Store Profile Type" form element in the search form.
		$searchFormSettings = $storesearchsettings->getFieldsOptions('sitestore', 'profile_type');
		if (!empty($searchFormSettings)) {
			$multiOptions = array();
			$multiOptions[''] = '';
			$profileTypeFields = Engine_Api::_()->fields()->getFieldsObjectsByAlias("sitestore_store", 'profile_type');
			if (count($profileTypeFields) == 1) {
				$profileTypeField = $profileTypeFields['profile_type'];
				$options = $profileTypeField->getOptions();
				if (!empty($options) && COUNT($options) >= 2) {
					foreach ($options as $option) {
						$multiOptions[$option->option_id] = $option->label;
					}

					asort($multiOptions);
					$searchForm[] = array(
						'type' => 'Select',
						'name' => 'profile_type',
						'label' => $this->translate('Store Profile Type'),
						'multiOptions' => $multiOptions,
					);
				}
			}
		}

		// Set "Stores With Offers" form element in the search form.
		$sitestoreofferEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreoffer');
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'offer_type');
		if (!empty($row) && !empty($row->display) && !empty($sitestoreofferEnabled)) {
			$multiOptionsArray = array();
			$multiOptionsArray[''] = '';
			$multiOptionsArray['all'] = $this->translate('All Offers');
			$multiOptionsArray['hot'] = $this->translate('Hot Offers');
			$multiOptionsArray['featured'] = $this->translate('Featured Offers');

			$searchForm[] = array(
				'type' => 'Select',
				'name' => 'offer_type',
				'label' => $this->translate('Stores With Offers'),
				'multiOptions' => $multiOptionsArray,
			);
		}

		// Set "Status" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'closed');
		if (!empty($row) && !empty($row->display)) {
			$enableStatus = $coreSettings->getSetting('sitestore.status.show', 0);
			if ($enableStatus) {
				$multiOptionsArray = array();
				$multiOptionsArray[''] = $this->translate('All Stores');
				$multiOptionsArray['0'] = $this->translate('Only Open Stores');
				$multiOptionsArray['1'] = $this->translate('Only Closed Stores');

				$searchForm[] = array(
					'type' => 'Select',
					'name' => 'closed',
					'label' => $this->translate('Status'),
					'multiOptions' => $multiOptionsArray,
				);
			}
		}

		// Set "Only Stores With Reviews" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'has_review');
		if (!empty($row) && !empty($row->display) && (int) Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorereview')) {
			$searchForm[] = array(
				'type' => 'Checkbox',
				'name' => 'has_review',
				'label' => $this->translate('Only Stores With Reviews'),
			);
		}

		// Set "Only Stores With Photos" form element in the search form.
		$row = $storesearchsettings->getFieldsOptions('sitestore', 'has_photo');
		if (!empty($row) && !empty($row->display)) {
			$searchForm[] = array(
				'type' => 'Checkbox',
				'name' => 'has_photo',
				'label' => $this->translate('Only Stores With Photos'),
			);
		}

		// Set "Search" form button in the search form.
		$searchForm[] = array(
			'type' => 'Submit',
			'name' => 'done',
			'label' => $this->translate('Search'),
		);

		$response['form'] = $searchForm;
		$response['categoriesForm'] = $subcategoryArray;

		return $response;
	}

	/*
		     * Browse Order Search Form
	*/

	public function getManageSearchForm() {
		$form = array();

		$form[] = array(
			'name' => 'search',
			'label' => $this->translate("Search"),
			'required' => true,
			'value' => 1,
		);

		$form[] = array(
			'name' => 'order_id',
			'type' => 'Text',
			'label' => $this->translate("Order Id (#)"),
		);

		$form[] = array(
			'name' => 'creation_date',
			'type' => 'Text',
			'label' => $this->translate("Order Date : ex (2000-12-25)"),
		);

		$form[] = array(
			'name' => 'billing_name',
			'type' => 'Text',
			'label' => $this->translate("Billing Name"),
		);

		$form[] = array(
			'name' => 'shipping_name',
			'type' => 'Text',
			'label' => $this->translate("Shipping Name"),
		);

		$form[] = array(
			'name' => 'order_min_amount',
			'type' => 'Text',
			'label' => $this->translate("Order Total Min."),
		);

		$form[] = array(
			'name' => 'order_max_amount',
			'type' => 'Text',
			'label' => $this->translate("Order Total Max."),
		);

		$form[] = array(
			'name' => 'delivery_time',
			'type' => 'Text',
			'label' => $this->translate("Delivery Time (In Days)"),
		);
		$form[] = array(
			'name' => 'order_status',
			'type' => 'Select',
			'label' => $this->translate("Order Status"),
			'multiOptions' => array(
				'0' => '',
				'1' => $this->translate("Approval Pending"),
				'2' => $this->translate("Payment Pending"),
				'3' => $this->translate("Processing"),
				'4' => $this->translate("On Hold"),
				'5' => $this->translate("Fraud"),
				'6' => $this->translate("Completed"),
				'7' => $this->translate("Canceled"),
			),
		);

		if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.downpayment', 0)) {
			$form[] = array(
				'name' => 'downpayment',
				'type' => 'Select',
				'label' => $this->translate("Downpayment"),
			);
		}

		$form[] = array(
			'name' => 'Submit',
			'label' => $this->translate("Search"),
		);

		return $form;
	}

	/**
	 * Gets default profile ids
	 *
	 * @param sitepage object
	 * return array
	 */
	public function getDefaultProfileTypeId($subject) {
		$getFieldId = null;
		$fieldsByAlias = Engine_Api::_()->fields()->getFieldsObjectsByAlias($subject);
		if (!empty($fieldsByAlias['profile_type'])) {
			$optionId = $fieldsByAlias['profile_type']->getValue($subject);
			if (!empty($optionId))
				$getFieldId = $optionId->value;
		}
		if (empty($getFieldId)) {
			return;
		}

		return $getFieldId;
	}

	/**
	 *  Gets the profile fields for the directory page based on category
	 *
	 *  @param array fieldsform
	 *  @return array
	 */
	private function _getProfileFields($fieldsForm = array()) {
		$fieldsForm = array();
		foreach ($this->_profileFieldsArray as $option_id => $prfileFieldTitle) {

			if (!empty($option_id)) {
				$mapData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMaps('sitestore_store');
				$getRowsMatching = $mapData->getRowsMatching('option_id', $option_id);

				$fieldArray = array();
				$getFieldInfo = Engine_Api::_()->fields()->getFieldInfo();
				$getHeadingName = '';
				foreach ($getRowsMatching as $map) {
					$meta = $map->getChild();
					$type = $meta->type;

					if (!empty($type) && ($type == 'heading')) {
						$getHeadingName = $meta->label;
						continue;
					}

					if (!empty($this->_validateSearchProfileFields) && (!isset($meta->search) || empty($meta->search))) {
						continue;
					}

					$fieldForm = $getMultiOptions = array();
					$key = $map->getKey();

					// Findout respective form element field array.
					if (isset($getFieldInfo['fields'][$type]) && !empty($getFieldInfo['fields'][$type])) {
						$getFormFieldTypeArray = $getFieldInfo['fields'][$type];

						// In case of Generic profile fields.
						if (isset($getFormFieldTypeArray['category']) && ($getFormFieldTypeArray['category'] == 'generic')) {
							// If multiOption enabled then perpare the multiOption array.

							if (($type == 'select') || ($type == 'radio') || (isset($getFormFieldTypeArray['multi']) && !empty($getFormFieldTypeArray['multi']))) {
								$getOptions = $meta->getOptions();
								if (!empty($getOptions)) {
									foreach ($getOptions as $option) {
										$getMultiOptions[$option->option_id] = $option->label;
									}
								}
							}

							// Prepare Generic form.
							$fieldForm['type'] = ucfirst($type);
							$fieldForm['name'] = $key . '_field_' . $meta->field_id;
							$fieldForm['label'] = (isset($meta->label) && !empty($meta->label)) ? Engine_Api::_()->getApi('Core', 'siteapi')->translate($meta->label) : '';
							$fieldForm['description'] = (isset($meta->description) && !empty($meta->description)) ? Engine_Api::_()->getApi('Core', 'siteapi')->translate($meta->description) : '';

							// Add multiOption, If available.
							if (!empty($getMultiOptions)) {
								$fieldForm['multiOptions'] = $getMultiOptions;
							}
							// Add validator, If available.
							if (isset($meta->required) && !empty($meta->required)) {
								$fieldForm['hasValidator'] = true;
							}

							$fieldForm['heading'] = $getHeadingName;

							if (COUNT($this->_profileFieldsArray) > 1) {

								if (isset($this->_create) && !empty($this->_create) && $this->_create == 1) {
									$optionCategoryName = $this->getProfileTypeLabel($option_id);
									$fieldsForm[$option_id][] = $fieldForm;
								} else {
									$fieldsForm[$option_id][] = $fieldForm;
								}
							} else {
								$fieldsForm[] = $fieldForm;
							}

						} else if (isset($getFormFieldTypeArray['category']) && ($getFormFieldTypeArray['category'] == 'specific') && !empty($getFormFieldTypeArray['base'])) {
							// In case of Specific profile fields.
							// Prepare Specific form.
							$fieldForm['type'] = ucfirst($getFormFieldTypeArray['base']);
							$fieldForm['name'] = $key . '_field_' . $meta->field_id;
							$fieldForm['label'] = (isset($meta->label) && !empty($meta->label)) ? Engine_Api::_()->getApi('Core', 'siteapi')->translate($meta->label) : '';
							$fieldForm['description'] = (isset($meta->description) && !empty($meta->description)) ? $meta->description : '';

							// Add multiOption, If available.
							if ($getFormFieldTypeArray['base'] == 'select') {
								$getOptions = $meta->getOptions();
								foreach ($getOptions as $option) {
									$getMultiOptions[$option->option_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($option->label);
								}
								$fieldForm['multiOptions'] = $getMultiOptions;
							}

							// Add validator, If available.
							if (isset($meta->required) && !empty($meta->required)) {
								$fieldForm['hasValidator'] = true;
							}

							if (COUNT($this->_profileFieldsArray) > 1) {
								if (isset($this->_create) && !empty($this->_create) && $this->_create == 1) {
									$optionCategoryName = $this->getProfileTypeLabel($option_id);
									$fieldsForm[$optionCategoryName][] = $fieldForm;
								} else {
									$fieldsForm[$option_id][] = $fieldForm;
								}
							} else {
								$fieldsForm[] = $fieldForm;
							}

//                                $fieldsForm[] = $fieldForm;
						}
					}
				}
			}
		}

		return $fieldsForm;
	}

	/**
	 * Get the Profile Fields Information, which will show on product profile page.
	 *
	 * @param product object , setkeyasresponse boolean
	 * @return array
	 */
	public function getProfileInfo($subject, $setKeyAsResponse = false) {
		// Getting the default Profile Type id.
		$getFieldId = $this->getDefaultProfileTypeId($subject);
		// Start work to get form values.
		$values = Engine_Api::_()->fields()->getFieldsValues($subject);

		$fieldValues = array();
		// In case if Profile Type available. like User module.
		if (!empty($getFieldId)) {
			// Set the default profile type.
			$this->_profileFieldsArray[$getFieldId] = $getFieldId;
			$_getProfileFields = $this->_getProfileFields();
			$specificProfileFields[$getFieldId] = $_getProfileFields[$getFieldId];
			foreach ($specificProfileFields as $heading => $tempValue) {
				foreach ($tempValue as $key => $value) {
					$key = $value['name'];
					$label = $value['label'];
					$type = $value['type'];
					$parts = @explode('_', $key);
					$heading = $value['heading'];

					if (count($parts) < 3) {
						continue;
					}

					list($parent_id, $option_id, $field_id) = $parts;

					$valueRows = $values->getRowsMatching(array(
						'field_id' => $field_id,
						'item_id' => $subject->getIdentity(),
					));

					if (!empty($valueRows)) {
						foreach ($valueRows as $fieldRow) {

							$tempValue = $fieldRow->value;

							// In case of Select or Multi send the respective label.
							if (isset($value['multiOptions']) && !empty($value['multiOptions']) && isset($value['multiOptions'][$fieldRow->value])) {
								$tempValue = $value['multiOptions'][$fieldRow->value];
							}

							$tempKey = !empty($setKeyAsResponse) ? $key : $label;
							if ($heading) {
								$fieldValues[$heading][$tempKey] = $tempValue;
							} else {
								$fieldValues[$tempKey] = $tempValue;
							}

						}
					}
				}
			}
		} else {
			// In case, If there are no Profile Type available and only Profile Fields are available. like Classified.
			$getType = $subject->getType();
			$_getProfileFields = $this->_getProfileFields($getType);

			foreach ($_getProfileFields as $value) {
				$key = $value['name'];
				$label = $value['label'];
				$parts = @explode('_', $key);

				if (count($parts) < 3) {
					continue;
				}

				list($parent_id, $option_id, $field_id) = $parts;

				$valueRows = $values->getRowsMatching(array(
					'field_id' => $field_id,
					'item_id' => $subject->getIdentity(),
				));

				if (!empty($valueRows)) {
					foreach ($valueRows as $fieldRow) {
						if (!empty($fieldRow->value)) {
							$tempKey = !empty($setKeyAsResponse) ? $key : $label;
							if ($heading) {
								$fieldValues[$heading][$tempKey] = $tempValue;
							} else {
								$fieldValues[$tempKey] = $tempValue;
							}

						}
					}
				}
			}
		}

		return $fieldValues;
	}

	/**
	 * Gets the Profile Types of a Page Based on category
	 *
	 * @param array object of profilefieldmaps
	 *
	 * @return array
	 */
	public function getProfileTypes($profileFields = array()) {

		$topStructure = Engine_Api::_()->fields()->getFieldStructureTop('sitestore_store');
		if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
			$profileTypeField = $topStructure[0]->getChild();
			$options = $profileTypeField->getOptions();

			$options = $profileTypeField->getElementParams('sitestore_store');
			if (isset($options['options']['multiOptions']) && !empty($options['options']['multiOptions']) && is_array($options['options']['multiOptions'])) {
				// Make exist profile fields array.
				foreach ($options['options']['multiOptions'] as $key => $value) {
					if (!empty($key)) {
						$profileFields[$key] = $value;
					}
				}
			}
		}

		return $profileFields;
	}

	public function getInfoFields($subject) {
		$profileFields = $this->getProfileTypes();
		if (!empty($profileFields)) {
			$this->_profileFieldsArray = $profileFields;
		}

		return $this->getProfileInfo($subject);
	}

	/**
	 * Get information of sitepage
	 *
	 * @param sitepage object
	 * @return array
	 */
	public function getInformation($subject) {

		$subsubcategory_name = null;
		$subcategory_name = null;
		$response = $basicinfoarray = array();
		$basicinfoarray[$this->translate('Posted')] = $this->translate(gmdate('M d, Y', strtotime($subject->creation_date)));
		$basicinfoarray[$this->translate('Last Updated')] = $this->translate(gmdate('M d, Y', strtotime($subject->modified_date)));
		$basicinfoarray[$this->translate('Views')] = $subject->view_count;
		$basicinfoarray[$this->translate('Likes')] = $subject->like_count;

		if (!empty($subject->follow_count)) {
			$basicinfoarray[$this->translate('Followers')] = $subject->follow_count;
		}

		// Category
		$tableCategories = Engine_Api::_()->getDbTable('categories', 'sitestore');
		if ($subject->category_id) {
			$categoriesNmae = $tableCategories->getCategory($subject->category_id);
			if (!empty($categoriesNmae->category_name)) {
				$category_name = $categoriesNmae->category_name;
			}

			if ($subject->subcategory_id) {
				$subcategory_name = $tableCategories->getCategory($subject->subcategory_id);
				if (!empty($subcategory_name->category_name)) {
					$subcategory_name = $subcategory_name->category_name;
				}

				// Get sub-sub category
				if ($subject->subsubcategory_id) {
					$subsubcategory_name = $tableCategories->getCategory($subject->subsubcategory_id);
					if (!empty($subsubcategory_name->category_name)) {
						$subsubcategory_name = $subsubcategory_name->category_name;
					}
				}
			}
		}

		$categoryData = "";
		if ($category_name != '') {
			$categoryData = $category_name;
			if ($subcategory_name != '') {
				$categoryData .= " >> " . $subcategory_name;
			}

			if ($subsubcategory_name != '') {
				$categoryData .= " >> " . $subsubcategory_name;
			}

		}

		if (strlen($categoryData) > 1) {
			$basicinfoarray[$this->translate('Category')] = $categoryData;
		}

		$sitestoretags = $subject->tags()->getTagMaps();
		$tagsData = "";
		if (count($sitestoretags) > 0) {
			$tagcount = 0;
			foreach ($sitestoretags as $tag) {
				$tagsData .= " #" . $tag->getTag()->text;
			}
		}

		if (strlen($tagsData) > 1) {
			$basicinfoarray[$this->translate('Tags')] = $tagsData;
		}

		$enableLocation = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.locationfield', 1);
		if ($enableLocation && $subject->location) {
			$basicinfoarray[$this->translate('Location')] = $subject->location;
		}

		$basicinfoarray[$this->translate('Description')] = $subject->body;

		if (!empty($basicinfoarray)) {
			$response['basic_information'] = $basicinfoarray;
		}

		// Set the "Profile Information" in the array
		try {
			$tempGetProfileInfo = $this->getInfoFields($subject);
			if (!empty($tempGetProfileInfo)) {
				$response['profile_information'] = $tempGetProfileInfo;
			}

		} catch (Exception $ex) {
			// blank exception
		}

		return $response;
	}

	/**
	 * Tell a friend Form
	 *
	 * @return array
	 */
	public function getTellAFriendForm() {

		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		$tell[] = array(
			'type' => 'Text',
			'name' => 'sender_name',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Your Name'),
			'hasValidator' => 'true',
		);

		$tell[] = array(
			'type' => 'Text',
			'name' => 'sender_email',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Your Email'),
			'has Validator' => 'true',
		);

		$tell[] = array(
			'type' => 'Text',
			'name' => 'receiver_emails',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate("Receiver's Email"),
			'description' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Separate multiple addresses with commas'),
			'hasValidators' => 'true',
		);

		$tell[] = array(
			'type' => 'Textarea',
			'name' => 'message',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Message'),
			'description' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('You can send a personal note in the mail.'),
			'hasValidator' => 'true',
		);

		if ($viewer_id) {
			$tell[] = array(
				'type' => 'Checkbox',
				'name' => 'send_me',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate("Send a copy to my email address."),
			);
		}

		$tell[] = array(
			'type' => 'Submit',
			'name' => 'send',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Tell a Friend'),
		);

		$response = array();
		$response['form'] = $tell;
		return $response;
	}

	/*
		     * Invite form
	*/

	public function inviteForm() {
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		$invite[] = array(
			'name' => 'emails',
			'label' => $this->translate("Emails Ids"),
			'description' => $this->translate("Enter the emails in comma separated fashion"),
		);

		$invite[] = array(
			'name' => 'message',
			'label' => $this->translate("Message"),
		);

		$invite[] = array(
			'type' => 'Submit',
			'name' => 'send',
			'label' => $this->translate('Invite'),
		);

		return $invite;
	}

	/**
	 * Returns create a review form
	 *
	 * @param array $widgetSettingsReviews
	 * @return array
	 */
	public function getReviewCreateForm($widgetSettingsReviews) {
		// Get viewer info
		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
		$getItemPage = $widgetSettingsReviews['item'];
		$sitepagereview_proscons = $widgetSettingsReviews['settingsReview']['sitepagereview_proscons'];
		$sitepagereview_limit_proscons = $widgetSettingsReviews['settingsReview']['sitepagereview_limit_proscons'];
		$sitepagereview_recommend = $widgetSettingsReviews['settingsReview']['sitepagereview_recommend'];

		if ($sitepagereview_proscons) {
			if ($sitepagereview_limit_proscons) {
				$createReview[] = array(
					'type' => 'Textarea',
					'name' => 'pros',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Pros'),
					'description' => Zend_Registry::get('Zend_Translate')->_("What do you like about this Page?"),
					'hasValidator' => 'true',
				);
			} else {
				$createReview[] = array(
					'type' => 'Textarea',
					'name' => 'pros',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Pros'),
					'description' => Zend_Registry::get('Zend_Translate')->_("What do you like about this Page?"),
					'hasValidator' => 'true',
				);
			}

			if ($sitepagereview_limit_proscons) {
				$createReview[] = array(
					'type' => 'Textarea',
					'name' => 'cons',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Cons'),
					'description' => Zend_Registry::get('Zend_Translate')->_("What do you dislike about this Page?"),
					'hasValidator' => 'true',
				);
			} else {
				$createReview[] = array(
					'type' => 'Textarea',
					'name' => 'cons',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Cons'),
					'description' => Zend_Registry::get('Zend_Translate')->_("What do you dislike about this Page?"),
					'hasValidator' => 'true',
				);
			}
		}

		$createReview[] = array(
			'type' => 'Textarea',
			'name' => 'title',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('One-line summary'),
		);

		$createReview[] = array(
			'type' => 'Textarea',
			'name' => 'body',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Summary'),
		);

		if ($sitepagereview_recommend) {
			$createReview[] = array(
				'type' => 'Radio',
				'name' => 'recommend',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Recommended'),
				'description' => sprintf(Zend_Registry::get('Zend_Translate')->_("Would you recommend this Page to a friend?")),
				'multiOptions' => array(
					1 => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Yes'),
					0 => Engine_Api::_()->getApi('Core', 'siteapi')->translate('No'),
				),
			);
		}

		$createReview[] = array(
			'type' => 'Submit',
			'name' => 'submit',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Submit'),
		);
		return $createReview;
	}

	/*
		     * Returns review update form
		     *
		     * @return array
	*/

	public function getReviewUpdateForm() {

		$updateReview[] = array(
			'type' => 'Textarea',
			'name' => 'body',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Summary'),
		);

		$updateReview[] = array(
			'type' => 'Submit',
			'name' => 'submit',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Add your Opinion'),
		);
		return $updateReview;
	}

	/*
		     * Returns comments on review form
		     *
		     * @return array
	*/

	public function getcommentForm($type, $id) {
		$commentform = array();
		$commentform[] = array(
			'type' => "Text",
			'name' => 'body',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Comment'),
		);
		return $commentform;
	}

	/*
		     *   Adds photo
		     *
		     *
	*/

	public function setPhoto($photo, $subject, $needToUplode = false, $params = array()) {
		try {

			if ($photo instanceof Zend_Form_Element_File) {
				$file = $photo->getFileName();
			} else if (is_array($photo) && !empty($photo['tmp_name'])) {
				$file = $photo['tmp_name'];
			} else if (is_string($photo) && file_exists($photo)) {
				$file = $photo;
			} else {
				throw new Group_Model_Exception('invalid argument passed to setPhoto');
			}
		} catch (Exception $e) {

		}

		$imageName = $photo['name'];
		$name = basename($file);
		$path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

		$params = array(
			'parent_type' => 'siteevent_event',
			'parent_id' => $subject->getIdentity(),
		);

		// Save
		$storage = Engine_Api::_()->storage();

		// Resize image (main)
		$image = Engine_Image::factory();
		$image->open($file)
			->resize(720, 720)
			->write($path . '/m_' . $imageName)
			->destroy();

		// Resize image (profile)
		$image = Engine_Image::factory();
		$image->open($file)
			->resize(200, 400)
			->write($path . '/p_' . $imageName)
			->destroy();

		// Resize image (normal)
		$image = Engine_Image::factory();
		$image->open($file)
			->resize(140, 160)
			->write($path . '/in_' . $imageName)
			->destroy();

		// Resize image (icon)
		$image = Engine_Image::factory();
		$image->open($file);

		$size = min($image->height, $image->width);
		$x = ($image->width - $size) / 2;
		$y = ($image->height - $size) / 2;

		$image->resample($x, $y, $size, $size, 48, 48)
			->write($path . '/is_' . $imageName)
			->destroy();

		// Store
		$iMain = $storage->create($path . '/m_' . $imageName, $params);
		$iProfile = $storage->create($path . '/p_' . $imageName, $params);
		$iIconNormal = $storage->create($path . '/in_' . $imageName, $params);
		$iSquare = $storage->create($path . '/is_' . $imageName, $params);

		$iMain->bridge($iProfile, 'thumb.profile');
		$iMain->bridge($iIconNormal, 'thumb.normal');
		$iMain->bridge($iSquare, 'thumb.icon');

		// Remove temp files
		@unlink($path . '/p_' . $imageName);
		@unlink($path . '/m_' . $imageName);
		@unlink($path . '/in_' . $imageName);
		@unlink($path . '/is_' . $imageName);

		// Update row
		if (empty($needToUplode)) {
			$subject->modified_date = date('Y-m-d H:i:s');
			$subject->save();
		}

		// Add to album
		$viewer = Engine_Api::_()->user()->getViewer();
		$photoTable = Engine_Api::_()->getItemTable('sitepage_photo');
		if (isset($params['album_id']) && !empty($params['album_id'])) {
			$album = Engine_Api::_()->getItem('sitepage_album', $params['album_id']);
			if (!$album->toArray()) {
				$album = $subject->getSingletonAlbum();
			}

		} else {
			$album = $subject->getSingletonAlbum('');
		}

		$photoItem = $photoTable->createRow();
		$photoItem->setFromArray(array(
			'event_id' => $subject->getIdentity(),
			'album_id' => $album->getIdentity(),
			'user_id' => $viewer->getIdentity(),
			'file_id' => $iMain->getIdentity(),
			'collection_id' => $album->getIdentity(),
		));
		$photoItem->save();

		return $subject;
	}

	/**
	 * Review search form
	 *
	 * @return array
	 */
	public function getReviewSearchForm() {

		$order = 1;
		$reviewForm = array();
		$reviewForm[] = array(
			'type' => 'Text',
			'name' => 'search',
			'label' => $this->translate('Search'),
		);

		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

		if ($viewer_id) {
			$reviewForm[] = array(
				'type' => 'Select',
				'name' => 'show',
				'label' => $this->translate('Show'),
				'multiOptions' => array('' => $this->translate("Everyone's Reviews"),
					'friends_reviews' => $this->translate("My Friends' Reviews"),
					'self_reviews' => $this->translate("My Reviews"),
					'featured' => $this->translate("Featured Reviews")),
			);
		}

		$reviewForm[] = array(
			'type' => 'Select',
			'name' => 'type',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Reviews Written By'),
			'multiOptions' => array('' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Everyone'), 'editor' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Editors'), 'user' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Users')),
		);

		$reviewForm[] = array(
			'type' => 'Select',
			'name' => 'order',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Browse By'),
			'multiOptions' => array(
				'recent' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Most Recent'),
				'rating_highest' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Highest Rating'),
				'rating_lowest' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Lowest Rating'),
				'helpfull_most' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Most Helpful'),
				'replay_most' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Most Reply'),
				'view_most' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Most Viewed'),
			),
		);
		$reviewForm[] = array(
			'type' => 'Select',
			'name' => 'rating',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Ratings'),
			'multiOptions' => array(
				'' => '',
				'5' => sprintf($this->translate('%1s Star'), 5),
				'4' => sprintf($this->translate('%1s Star'), 4),
				'3' => sprintf($this->translate('%1s Star'), 3),
				'2' => sprintf($this->translate('%1s Star'), 2),
				'1' => sprintf($this->translate('%1s Star'), 1),
			),
		);

		$reviewForm[] = array(
			'type' => 'Checkbox',
			'name' => 'recommend',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Only Recommended Reviews'),
		);

//        $reviewForm[] = array(
		//            'type' => 'Submit',
		//            'name' => 'done',
		//            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Search'),
		//        );

		return $reviewForm;
	}

	/*
		     *  cart product field array
	*/

	public function cartProductFieldArray() {

	}

	/*
		     * Checkout address form
	*/

	public function sitestoreproduct_Form_Addresses($params) {

		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		$showShippingAddress = $params['showShippingAddress'];
		$local = ($viewer_id) ? $viewer->locale : 'auto';
		$localeObject = new Zend_Locale($local);
		$languages = Zend_Locale::getTranslationList('language', $localeObject);
		$countries = Zend_Locale::getTranslationList('territory', $localeObject);
		$countryArray[''] = "Select Country";
		$shippingCountries = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->getRegionsByName($params);

		foreach ($shippingCountries as $keys => $shippingCountry) {
			foreach ($countries as $keys => $country) {
				if ($shippingCountry['country'] == $keys) {
					$localeCountryArray[$keys] = $country;
					break;
				}
			}
		}

		asort($localeCountryArray);
		$countryArray = array_merge($countryArray, $localeCountryArray);

		$form = $billingForm = $shippingForm = $response = array();

		if (!$viewer_id) {
			$billingForm[] = array(
				'name' => 'email_billing',
				'label' => $this->translate('Email'),
				'type' => 'Text',
				'hasValidator' => 'true',
			);
		}

		$billingForm[] = array(
			'name' => 'f_name_billing',
			'label' => $this->translate('First Name'),
			'type' => 'Text',
			'hasValidator' => 'true',
		);

		$billingForm[] = array(
			'name' => 'l_name_billing',
			'label' => $this->translate('Last Name'),
			'type' => 'Text',
			'hasValidator' => 'false',
		);

		$billingForm[] = array(
			'name' => 'phone_billing',
			'label' => $this->translate('Phone Number'),
			'type' => 'Text',
			'hasValidator' => 'true',
		);

		$billingForm[] = array(
			'name' => 'country_billing',
			'label' => $this->translate('Country'),
			'type' => 'Select',
			'multiOptions' => $countryArray,
			'hasValidator' => 'true',
		);

		$region = array();
		$shippingCountries = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->getRegionsByName($params = array());
		foreach ($shippingCountries as $keys => $shippingCountry) {
			$localeCountryArray[$shippingCountry['country']] = Zend_Locale::getTranslation($shippingCountry['country'], 'country');

			$params['store_id'] = $_REQUEST['store_id'];
			$params['country'] = $shippingCountry['country'];
			$shippingRegionsCountries = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->getRegionsByName($params);
			foreach ($shippingRegionsCountries as $shippingRegionsCountry) {
				if (empty($shippingRegionsCountry['region'])) {
					continue;
				}
				$region[$shippingRegionsCountry['region_id']] = $shippingRegionsCountry['region'];

			}
								
		}

		$billingForm[] = array(
			'name' => 'state_billing',
			'label' => $this->translate('Region / State'),
			'type' => 'Select',
			'multiOptions' => $region,
			'hasValidator' => 'false',
		);

		$billingForm[] = array(
			'name' => 'city_billing',
			'type' => 'Text',
			'label' => $this->translate('City'),
			'hasValidator' => 'true',
		);

		$billingForm[] = array(
			'name' => 'locality_billing',
			'type' => 'Text',
			'label' => $this->translate('Locality'),
			'hasValidator' => 'false',
		);

		$billingForm[] = array(
			'name' => 'zip_billing',
			'type' => 'Text',
			'label' => $this->translate('Zip/Pin Code'),
			'hasValidator' => 'true',
		);

		$billingForm[] = array(
			'name' => 'address_billing',
			'type' => 'Textarea',
			'label' => $this->translate('Address'),
			'hasValidator' => 'true',
		);

		if (isset($showShippingAddress) && !empty($showShippingAddress)) {
			$billingForm[] = array(
				'name' => 'common',
				'type' => 'Checkbox',
				'label' => $this->translate('Same Shipping Address'),
				'value' => $_POST['common'] ? $_POST['common'] : 1,
			);
		}

		$billingForm[] = array(
			'name' => 'continue',
			'type' => 'Button',
			'label' => $this->translate('Continue'),
		);

		if (isset($showShippingAddress) && !empty($showShippingAddress)) {

			$shippingForm[] = array(
				'name' => 'f_name_shipping',
				'label' => $this->translate('First Name'),
				'type' => 'Text',
				'hasValidator' => 'true',
			);

			$shippingForm[] = array(
				'name' => 'l_name_shipping',
				'label' => $this->translate('Last Name'),
				'type' => 'Text',
				'hasValidator' => 'false',
			);

			$shippingForm[] = array(
				'name' => 'phone_shipping',
				'label' => $this->translate('Phone Number'),
				'type' => 'Text',
				'hasValidator' => 'true',
			);

			$shippingForm[] = array(
				'name' => 'country_shipping',
				'label' => $this->translate('Country'),
				'type' => 'Select',
				'multiOptions' => $countryArray,
				'hasValidator' => 'true',
			);

			$shippingForm[] = array(
				'name' => 'state_shipping',
				'label' => $this->translate('Region / State'),
				'type' => 'Select',
				'multiOptions' => array(),
				'hasValidator' => 'false',
			);

			$shippingForm[] = array(
				'name' => 'city_shipping',
				'type' => 'Text',
				'label' => $this->translate('City'),
				'hasValidator' => 'true',
			);

			$shippingForm[] = array(
				'name' => 'locality_shipping',
				'type' => 'Text',
				'label' => $this->translate('Locality'),
				'hasValidator' => 'false',
			);

			$shippingForm[] = array(
				'name' => 'zip_shipping',
				'type' => 'Text',
				'label' => $this->translate('Zip/Pin Code'),
				'hasValidator' => 'true',
			);

			$shippingForm[] = array(
				'name' => 'address_shipping',
				'type' => 'Textarea',
				'label' => $this->translate('Address'),
				'hasValidator' => 'true',
			);
			$response['shippingForm'] = $shippingForm;
		}

		$response['billingForm'] = $billingForm;

		return $response;
	}

	/**
	 * Return checkout shipping methods
	 *
	 * @param array $info
	 * @return array
	 */
	public function getCheckoutShippingMethods($info = array()) {

		$index = 0;
		$shippingMethodTable = Engine_Api::_()->getDbTable('Shippingmethods', 'sitestoreproduct');
		$shippingMethodTableName = $shippingMethodTable->info('name');
		$shippingCountry = $info['shipping_country'];
		$shippingRegion = $info['shipping_region_id'];

		$shippingMethodsArray = array();
		$select = $shippingMethodTable->select()
			->from($shippingMethodTableName)
			->where('store_id = ? AND status = 1', $info['store_id'])
			->where("(country LIKE 'ALL' OR (country LIKE '$shippingCountry' AND (region = 0 OR region = '$shippingRegion')))")
			->order('creation_date ASC');

		$select = $select->query()->fetchALL();

		foreach ($select as $key => $values) {

			if ($values['dependency'] == 1) {
				if ($info['total_weight'] >= $values['ship_start_limit'] && (empty($values['ship_end_limit']) || $info['total_weight'] <= $values['ship_end_limit'])) {
					if ($values['ship_type'] == 0) {
						if ($values['handling_type'] == 0) {
							$shippingMethodsArray[$index]['name'] = $values['title'];
							$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
							$shippingMethodsArray[$index]['charge'] = @round($values['handling_fee'], 2);
							$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
							$index++;
						} else {
							$shippingMethodsArray[$index]['name'] = $values['title'];
							$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
							$shippingMethodsArray[$index]['charge'] = @round(($values['handling_fee'] / 100) * $info['total_price'], 2);
							$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
							$index++;
						}
					} else {
						$shippingMethodsArray[$index]['name'] = $values['title'];
						$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
						$shippingMethodsArray[$index]['charge'] = @round(ceil($info['total_weight']) * $values['handling_fee'], 2);
						$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
						$index++;
					}
				}
			} else {
				if ($info['total_weight'] >= $values['allow_weight_from'] && (empty($values['allow_weight_to']) || $info['total_weight'] <= $values['allow_weight_to'])) {
					if ($values['dependency'] == 0) {
						if ($info['total_price'] >= $values['ship_start_limit'] && (empty($values['ship_end_limit']) || $info['total_price'] <= $values['ship_end_limit'])) {
							if ($values['handling_type'] == 0) {
								$shippingMethodsArray[$index]['name'] = $values['title'];
								$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
								$shippingMethodsArray[$index]['charge'] = @round($values['handling_fee'], 2);
								$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
								$index++;
							} else {
								$shippingMethodsArray[$index]['name'] = $values['title'];
								$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
								$shippingMethodsArray[$index]['charge'] = @round(($values['handling_fee'] / 100) * $info['total_price'], 2);
								$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
								$index++;
							}
						}
					} else {
						if ($info['total_quantity'] >= $values['ship_start_limit'] && (empty($values['ship_end_limit']) || $info['total_quantity'] <= $values['ship_end_limit'])) {
							if ($values['ship_type'] == 0) {
								$shippingMethodsArray[$index]['name'] = $values['title'];
								$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
								$shippingMethodsArray[$index]['charge'] = @round($values['handling_fee'], 2);
								$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
								$index++;
							} else {
								if ($values['handling_type'] == 0) {
									$shippingMethodsArray[$index]['name'] = $values['title'];
									$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
									$shippingMethodsArray[$index]['charge'] = @round($values['handling_fee'] * $info['total_quantity'], 2);
									$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
									$index++;
								} else {
									$shippingMethodsArray[$index]['name'] = $values['title'];
									$shippingMethodsArray[$index]['delivery_time'] = $values['delivery_time'];
									$shippingMethodsArray[$index]['charge'] = @round(($values['handling_fee'] / 100) * $info['total_price'], 2);
									$shippingMethodsArray[$index]['shippingmethod_id'] = $values['shippingmethod_id'];
									$index++;
								}
							}
						}
					}
				}
			}
		}

		return $shippingMethodsArray;
	}

	/*
		     *  get combination price
	*/

	public function getcombinationPrice($combination_id, $product_id) {

		if (!$combination_id || !$product_id) {
			return;
		}

		$initialPrice = 0.00;

		$cartProductFieldsMeta = Engine_Api::_()->getDbTable('CartproductFieldMeta', 'sitestoreproduct');
		$cartProductFieldsOptions = Engine_Api::_()->getDbtable('CartproductFieldOptions', 'sitestoreproduct');
		$combinationAttributesTable = Engine_Api::_()->getDbTable('CombinationAttributes', 'sitestoreproduct');
		$combinationTable = Engine_Api::_()->getDbTable('Combinations', 'sitestoreproduct');
		$combinationAttributeMapsTable = Engine_Api::_()->getDbTable('CombinationAttributeMap', 'sitestoreproduct');
		$combinationTableName = $combinationTable->info('name');
		$combinationAttributesTableName = $combinationAttributesTable->info('name');
		$combinationAttributeMapsTableName = $combinationAttributeMapsTable->info('name');
		$cartProductFieldsMetaTableName = $cartProductFieldsMeta->info('name');
		$cartProductFieldsOptionsTableName = $cartProductFieldsOptions->info('name');

		$select = $combinationAttributesTable->select()
			->from($combinationAttributesTableName, array('price_increment', 'price'))
			->setIntegrityCheck(false)
			->joinInner($combinationAttributeMapsTableName, $combinationAttributeMapsTableName . ".attribute_id = " . $combinationAttributesTableName . ".attribute_id", array())
			->joinInner($combinationTableName, $combinationTableName . ".combination_id = " . $combinationAttributeMapsTableName . ".combination_id", array())
			->where($combinationTableName . ".combination_id = ?", $combination_id)
			->where($combinationAttributesTableName . ".product_id = ?", $product_id);

		$result = $select->query()->fetchAll();
		foreach ($result as $row => $value) {
			if ($value['price_increment']) {
				$initialPrice += $value['price'];
			} else {
				$initialPrice -= $value['price'];
			}

		}

		return $initialPrice;
	}

	/*
		     *  Send invite email
	*/

	public function sendInvites($recipients, $storeinvite_id = null, $storeinvite_userid = null, $invite_message = null) {
		$viewer = Engine_Api::_()->user()->getViewer();
		$settings = Engine_Api::_()->getApi('settings', 'core');
		$translate = Zend_Registry::get('Zend_Translate');
		$message = $this->translate(Engine_Api::_()->getApi('settings', 'core')->invite_message);
		$message = trim($message);

		$template_header = '';
		$template_footer = '';
		$site_title = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.general.site.title');
		$site__template_title = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.site.title', $site_title);
		$site_title_color = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.title.color', "#ffffff");
		$site_header_color = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.font.color', "#79b4d4");
		$template_header .= "<table width='98%' cellspacing='0' border='0'><tr><td width='100%' bgcolor='#f7f7f7' style='font-family:arial,tahoma,verdana,sans-serif;padding:40px;'><table width='620' cellspacing='0' cellpadding='0' border='0'>";
		$template_header .= "<tr><td style='background:" . $site_header_color . "; color:" . $site_title_color . ";font-weight:bold;font-family:arial,tahoma,verdana,sans-serif; padding: 4px 8px;vertical-align:middle;font-size:16px;text-align: left;' nowrap='nowrap'>" . $site__template_title . "</td></tr><tr><td valign='top' style='background-color:#fff; border-bottom: 1px solid #ccc; border-left: 1px solid #cccccc; border-right: 1px solid #cccccc; font-family:arial,tahoma,verdana,sans-serif; padding: 15px;padding-top:0;' colspan='2'><table width='100%'><tr><td colspan='2'>";
		$inviter_name = $viewer->getTitle();
		$sitestoreModHostName = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));

		if ($storeinvite_id) {
			$sitestore = Engine_Api::_()->getItem('sitestore_store', $storeinvite_id);
			if ($sitestore) {
				if (!Engine_Api::_()->core()->hasSubject('sitestore_store')) {
					Engine_Api::_()->core()->setSubject($sitestore);
				}

			}
		}
		$sitestore = Engine_Api::_()->core()->getSubject('sitestore_store');
		$host = $_SERVER['HTTP_HOST'];
		$base_url = (_ENGINE_SSL ? 'https://' : 'http://') . $host . Zend_Controller_Front::getInstance()->getBaseUrl();
		$inviteUrl = (_ENGINE_SSL ? 'https://' : 'http://')
		. $_SERVER['HTTP_HOST']
		. Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
			'store_url' => Engine_Api::_()->sitestore()->getStoreUrl($sitestore->store_id),
		), 'sitestore_entry_view', true);

		//GETTING THE STORE PHOTO.
		$file = $sitestore->getPhotoUrl('thumb.icon');
		if (empty($file)) {
			$storephoto_path = (_ENGINE_SSL ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getBaseUrl() . '/application/modules/Sitestore/externals/images/nophoto_list_thumb_normal.png';
		} else {
			$storephoto_path = $file;
		}

		$inviteUrl_link = '<table><tr valign="top"><td style="color:#999999;font-size:11px;padding-right:15px;"><a href = ' . $inviteUrl . ' target="_blank">' . '<img src="' . $storephoto_path . '" style="width:100px;"/>' . '</a>';
		//GETTING NO OF LIKES TO THIS STORE.
		$num_of_like = Engine_Api::_()->sitestore()->numberOfLike('sitestore_store', $sitestore->store_id);
		$body_message = $inviteUrl_link . $sitestore->title . '<br /> ' . $this->translate(array('%s Person Likes This', '%s People Like This', $num_of_like), $num_of_like);

		$recepients_array = array();

		$site_title_linked = '<a href="' . $base_url . '" target="_blank" >' . $site_title . '</a>';
		$store_title_linked = '<a href="' . $inviteUrl . '" target="_blank" >' . $sitestore->title . '</a>';
		$store_link = '<a href="' . $inviteUrl . '" target="_blank" >' . $inviteUrl . '</a>';
		$isModType = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreinvite.set.type', 0);
		if (empty($isModType)) {
			Engine_Api::_()->getApi('settings', 'core')->setSetting('sitestoreinvite.utility.type', convert_uuencode($sitestoreModHostName));
		}

		$inviteOnlySetting = $settings->getSetting('user.signup.inviteonly', 0);
		if (is_array($recipients) && !empty($recipients) && !empty($storeinvite_id) && !empty($storeinvite_userid)) {

			$table_message = Engine_Api::_()->getDbtable('messages', 'messages');
			$tableName_message = $table_message->info('name');

			$table_user = Engine_Api::_()->getitemtable('user');
			$tableName_user = $table_user->info('name');

			$table_user_memberships = Engine_Api::_()->getDbtable('membership', 'user');
			$tableName_user_memberships = $table_user_memberships->info('name');

			foreach ($recipients as $recipient) {
				// perform tests on each recipient before sending invite
				$recipient = trim($recipient);

				// watch out for poorly formatted emails
				if (!empty($recipient)) {
					//FIRST WE WILL FIND IF THIS USER IS SITE MEMBER
					$select = $table_user->select()
						->setIntegrityCheck(false)
						->from($tableName_user, array('user_id'))
						->where('email = ?', $recipient);
					$is_site_members = $table_user->fetchAll($select);

					//NOW IF THIS USER IS SITE MEMBER THEN WE WILL FIND IF HE IS FRINED OF THE OWNER.
					if (isset($is_site_members[0]) && !empty($is_site_members[0]->user_id) && $is_site_members[0]->user_id != $viewer->user_id) {
						$contact = Engine_Api::_()->user()->getUser($is_site_members[0]->user_id);

						// check that user has not blocked the member
						if (!$viewer->isBlocked($contact)) {
							$recepients_array[] = $is_site_members[0]->user_id;
							$is_suggenabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('suggestion');

							// IF SUGGESTION PLUGIN IS INSTALLED, A SUGGESTION IS SEND
							if ($is_suggenabled) {
								Engine_Api::_()->sitestoreinvite()->sendSuggestion($is_site_members[0], $viewer, $sitestore->store_id);
							}
							// IF SUGGESTION PLUGIN IS NOT INSTALLED, A NOTIFICATION IS SEND
							else {
								Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($is_site_members[0], $viewer, $sitestore, 'sitestore_suggested');
							}
						}
					}
					// BODY OF STORE COMPRISING LIKES
					$body = $inviteUrl_link . '<br/>' . $this->translate(array('%s person likes this', '%s people like this', $num_of_like), $num_of_like) . '</td><td>';

					if (!empty($invite_message)) {
						$body .= $invite_message . "<br />";
					}
					$link = '<a href="' . $base_url . '">' . $base_url . '</a>';
					$template_footer .= "</td></tr></table></td></tr></table></td></tr></td></table></td></tr></table>";

					// IF THE PERSON IS NOT THE SITE MEMBER
					if (!isset($is_site_members[0])) {
						Engine_Api::_()->getApi('mail', 'core')->sendSystem($recipient, 'Sitestoreinvite_User_Invite', array(
							'template_header' => $template_header,
							'template_footer' => $template_footer,
							'inviter_name' => $inviter_name,
							'site_title_linked' => $site_title_linked,
							'store_title_linked' => $store_title_linked,
							'store_link' => $store_link,
							'site_title' => $site_title,
							'body' => $body,
							'store_title' => $sitestore->title,
							'link' => $link,
							'host' => $host,
							'email' => $viewer->email,
							'queue' => true,
						));
					}
					// IF THE PERSON IS A SITE MEMBER
					else {
						Engine_Api::_()->getApi('mail', 'core')->sendSystem($recipient, 'SITESTOREINVITE_MEMBER_INVITE', array(
							'template_header' => $template_header,
							'template_footer' => $template_footer,
							'inviter_name' => $inviter_name,
							'store_title_linked' => $store_title_linked,
							'store_link' => $store_link,
							'site_title' => $site_title,
							'body' => $body,
							'store_title' => $sitestore->title,
							'link' => $link,
							'host' => $host,
							'email' => $viewer->email,
							'queue' => true,
						));
					}
				}
			} // end foreach
		} // end if (is_array($recipients) && !empty($recipients))
		return;
	}

	/**
	 * Translate the text from english to specified language by user
	 *
	 * 	@param message string
	 *   @return string
	 */
	private function translate($message) {
		return Engine_Api::_()->getApi('Core', 'siteapi')->translate($message);
	}

	public function getForm($package_id = null, $subject = array(), $edit = 0, $sitestore = null) {
		if (!empty($edit)) {
			$user = $viewer = $subject;
			$viewer_id = $subject->getIdentity();
			$userlevel_id = $subject->level_id;
			$this->setPackageId($package_id);
			$this->setOwner($user);
		} else {
			$user = $viewer = Engine_Api::_()->user()->getViewer();
			$viewer_id = $viewer->getIdentity();
			$userlevel_id = $viewer->level_id;
			$this->setPackageId($package_id);
			$this->setOwner($user);
		}
		$coreSettings = Engine_Api::_()->getApi('settings', 'core');
		$sitestoreMemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');

		$sitestoreUrlEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreurl');
		$store_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('store_id', Zend_Controller_Front::getInstance()->getRequest()->getParam('store', null));
		$parent_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('parent_id', null);

		$show_url = $coreSettings->getSetting('sitestore.showurl.column', 1);
		$change_url = $coreSettings->getSetting('sitestore.change.url', 1);
		$edit_url = $coreSettings->getSetting('sitestore.edit.url', 0);
		$isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);

		$createForm[] = array(
			'type' => 'Text',
			'name' => 'title',
			'label' => $this->translate('Title'),
			"hasValidator" => true,
		);

		//store url work
		if (!empty($sitestoreUrlEnabled) && !empty($store_id) && !empty($show_url) && !empty($edit_url)) {
			$createForm[] = array(
				'type' => 'Text',
				'name' => 'store_uri',
				'label' => $this->translate('URL'),
				"hasValidator" => true,
			);
		} elseif (empty($store_id)) {
			$createForm[] = array(
				'type' => 'Text',
				'name' => 'store_uri',
				'label' => $this->translate('URL'),
				"hasValidator" => true,
			);
		}

		$createForm[] = array(
			'type' => 'Text',
			'name' => 'tags',
			'label' => $this->translate('Tags'),
			'description' => 'Separate tags with commas.',
			"hasValidator" => true,
		);

		//Store Ctegory Work
		$profileFields = $this->getProfileTypes();
		if (!empty($profileFields)) {
			$this->_profileFieldsArray = $profileFields;
		}
	
		$createFormFields = $this->_getProfileFields();

		$categories = Engine_Api::_()->getDbTable('categories', 'sitestore')->getCategories();
		$categoryProfileTypeMapping = array();

		if (_CLIENT_TYPE && (_CLIENT_TYPE == 'android') && _ANDROID_VERSION && _ANDROID_VERSION > '3.6.4') {

			if (count($categories) != 0) {
	            $getCategories['0'] = '';

	            foreach ($categories as $category) {
	                $subCategories = array();
	                $subCategoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($category->category_id);
	                $getCategories[$category->category_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($category->category_name);

	                $getsubCategories = array();
	                $getsubCategories[0] = "";
	                foreach ($subCategoriesObj as $subcategory) {
	                    $subsubCategoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($subcategory->category_id);
	                    $getsubCategories[$subcategory->category_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($subcategory->category_name);

	                    $subsubCategories = array();
	                    $subsubCategories[0] = "";
	                    foreach ($subsubCategoriesObj as $subsubcategory) {
	                        $subsubCategories[$subsubcategory->category_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($subsubcategory->category_name);
	                    }
	                }
	            }
	        }
	    }

        if (count($categories) != 0) {

            $getCategories['0'] = '';

            foreach ($categories as $category) {
                $subCategories = array();
                $subCategoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($category->category_id);
                $getCategories[$category->category_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($category->category_name);

                $getsubCategories = array();
                $getsubCategories[0] = "";
                foreach ($subCategoriesObj as $subcategory) {
                    $subsubCategoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($subcategory->category_id);
                    $getsubCategories[$subcategory->category_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($subcategory->category_name);


                    
                    // $CategoryProfile_type2 = $subcategory->profile_type;

                    // if (!empty($CategoryProfile_type2)){
                    //     $categoryProfileTypeMapping["subcategory_id_".$subcategory->category_id] = $CategoryProfile_type2;
                    // }
                    
                    $subsubCategories = array();
                    $subsubCategories[0] = "";
                    foreach ($subsubCategoriesObj as $subsubcategory) {
                        $subsubCategories[$subsubcategory->category_id] = Engine_Api::_()->getApi('Core', 'siteapi')->translate($subsubcategory->category_name);

                        if (isset($subsubCategories) && !empty($subsubCategories) && count($subsubCategories) > 0)
                        $subsubCategoriesForm = array(
                                'type' => 'Select',
                                'name' => 'subsubcategory_id',
                                'hasSubForm' => !empty($subsubcategory->profile_type) ? true : false ,
                                'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('3rd Level Category'),
                                'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($subsubCategories)
                            );  

                        
                    }
                    
                    if (isset($subsubCategoriesForm) && !empty($subsubCategoriesForm) && count($subsubCategoriesForm) > 0 ) {
                        

                        $responseForm['fields']["subcategory_id_".$subcategory->category_id][] =
                        $form[$subcategory->category_id]['form'] = $subsubCategoriesForm;
                    
                        $subcategoriesForm = array();
                    }
                }

                
               
                if ((isset($subsubCategoriesForm) && !empty($getsubCategories)) || (count($getsubCategories) > 1) )
                        $subcategoriesForm = array(
                            'type' => 'Select',
                            'name' => 'subcategory_id',
                            'hasSubForm' => true,
                            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Sub-Category'),
                            'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getsubCategories),
                        );

                if (isset($subcategoriesForm) && !empty($subcategoriesForm) && count($subcategoriesForm
                ) > 0) {

                    $responseForm['fields']["category_id_".$category->category_id][] =
                    $form[$category->category_id]['form'] = $subcategoriesForm;
                    $subcategoriesForm = array();
                }

            }
            $categoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($sitestoreproduct->category_id);
             foreach ($categoriesObj as $category) {
                    $getSubCategories[$category->category_id] = $category->category_name;
                }
            if((isset($subcategoriesForm) && !empty($subcategoriesForm)) || (count($getCategories) > 0)  )
                $createForm[] = array(
                    'type' => 'Select',
                    'name' => 'category_id',
                    "hasSubForm" => true,
                    'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Category'),
                    'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getCategories),
                    'hasValidator' => true
                );
            else
		        $createForm[] = array(
		        'type' => 'Select',
		        'name' => 'category_id',
		        'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Category'),
		        'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getCategories),
		        'hasValidator' => true
		    );
		}
		if(!empty($sitestore)) {
			$subCategoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($sitestore->category_id);
            $getSubCategories[0] = "";
            foreach ($subCategoriesObj as $subcategory) {
                $getSubCategories[$subcategory->category_id] = $subcategory->category_name;
            }
            if (_CLIENT_TYPE == 'android') {
				if (isset($getSubCategories) && !empty($getSubCategories) && count($getSubCategories) > 0) {
	                if((isset($subsubCategoriesForm) && !empty($subsubCategoriesForm)) || (count($getsubCategories) > 0) ) {
	                    $createForm[] = array(
	                        'type' => 'Select',
	                        'name' => 'subcategory_id',
	                        "hasSubForm" => true,
	                        'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('SubCategory'),
	                        'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getSubCategories),
	                    );
	                }
	                else
	                    $createForm[] = array(
	                        'type' => 'Select',
	                        'name' => 'subcategory_id',
	                        'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('SubCategory'),
	                        'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getSubCategories),
	                    );

	            }
        	}
        	$subsubCategoriesObj = Engine_Api::_()->getDbTable('categories', 'sitestore')->getSubCategories($sitestore->subcategory_id);

            //$getSubSubCategories[0] = "";
            foreach ($subsubCategoriesObj as $subsubcategory) {
                $getSubSubCategories[$subsubcategory->category_id] = $subsubcategory->category_name;
            }
            if(!empty($getSubSubCategories)){
	            if (isset($getSubSubCategories) && !empty($getSubSubCategories) && count($getSubSubCategories) > 1) {

	            	$createForm[] = array(
	                        'type' => 'Select',
	                        'name' => 'subsubcategory_id',
	                        'hasSubForm' => true,
	                        'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('3rd Level Category'),
	                        'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getSubSubCategories),
	                    );
	            }
                else
                    $createForm[] = array(
                        'type' => 'Select',
                        'name' => 'subsubcategory_id',
                        'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('3rd Level Category'),
                        'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($getSubSubCategories),
                    );
            
        	
    		}


	        // Set profile fields along with create form on editing
	        if (isset($sitestore) && !empty($sitestore) && isset($defaultProfileId) && !empty($defaultProfileId) && is_array($createFormFields)) {
	        
	            if (isset($createFormFields[$defaultProfileId]) && !empty($createFormFields[$defaultProfileId])) {
	                $createForm = array_merge($createForm, $createFormFields[$defaultProfileId]);
	            }
	        }
	    }

		if ($coreSettings->getSetting('sitestore.description.allow', 1)) {
			if ($coreSettings->getSetting('sitestore.requried.description', 1)) {
				$createForm[] = array(
					'type' => 'Textarea',
					'name' => 'body',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Description'),
					'hasValidator' => true,
				);
			} else {
				$createForm[] = array(
					'type' => 'Textarea',
					'name' => 'body',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Description'),
				);
			}
		}

		if ($coreSettings->getSetting('sitestore.requried.photo', 1) && empty($edit)) {
			$createForm[] = array(
				'type' => 'File',
				'name' => 'photo',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Photo'),
				'hasValidator' => true,
			);
		} elseif (empty($edit)) {
			$createForm[] = array(
				'type' => 'File',
				'name' => 'photo',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Photo'),
			);
		}

		if ($coreSettings->getSetting('sitestore.price.field', 0)) {
			$createForm[] = array(
				'type' => 'Text',
				'name' => 'price',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Price'),
			);
		}

		if (Engine_Api::_()->getDbtable("modules", "core")->isModuleEnabled("sitecredit") && $isAdminDrivenStore && $coreSettings->getSetting('sitecredit.store.credit.redemption', 'all_store') == 'store_wise') {
			$createForm[] = array(
				'type' => 'Text',
				'name' => 'credit_limit',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Credit Limit (%)'),
				'description' => 'Set limit for credit redemption on purchase from this store.',
			);
		}

		if ($coreSettings->getSetting('sitestore.locationfield', 1)) {
			$createForm[] = array(
				'type' => 'Text',
				'name' => 'location',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Location'),
				'description' => 'Eg: Fairview Park, Berkeley, CA',
			);
		}

		$storeadminsetting = $coreSettings->getSetting('sitestore.manageadmin', 1);
		if (!empty($storeadminsetting)) {
			$ownerTitle = "Store Admins";
		} else {
			$ownerTitle = "Just Me";
		}

		//START SITESTOREMEMBER PLUGIN WORK
		$allowMemberInLevel = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'smecreate');
		$allowMemberInthisPackage = false;
		$allowMemberInthisPackage = Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestoremember");

		if ($sitestoreMemberEnabled) {
			if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
				if ($allowMemberInthisPackage) {

					$memberTitle = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.member.title', 1);
					if (!empty($memberTitle)) {
						$createForm[] = array(
							'type' => 'Text',
							'name' => 'member_title',
							'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('What will members be called?'),
							'description' => 'Ex: Dance Lovers, Hikers, Innovators, Music Lovers, etc.',
						);
					}
				}

				$memberInvite = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.invite.option', 1);
				if (!empty($memberInvite)) {
					$createForm[] = array(
						'type' => 'Radio',
						'name' => 'member_invite',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Invite member'),
						'multiOptions' => array(
							'0' => 'Yes, members can invite other people.',
							'1' => 'No, only store admins can invite other people.',
						),
						'value' => '1',
					);
				}

				$member_approval = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.member.approval.option', 1);
				if (!empty($member_approval)) {
					$createForm[] = array(
						'type' => 'Radio',
						'name' => 'member_approval',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Approve members?'),
						'multiOptions' => array(
							'1' => 'New members can join immediately.',
							'0' => 'New members must be approved.',
						),
						'value' => '1',
					);
				}
			} else if (!empty($allowMemberInLevel)) {
				$memberTitle = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.member.title', 1);
				if (!empty($memberTitle)) {
					$createForm[] = array(
						'type' => 'Text',
						'name' => 'member_title',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('What will members be called?'),
						'description' => 'Ex: Dance Lovers, Hikers, Innovators, Music Lovers, etc.',
					);
				}

				$createForm[] = array(
					'type' => 'Radio',
					'name' => 'member_invite',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Invite member'),
					'multiOptions' => array(
						'0' => 'Yes, members can invite other people.',
						'1' => 'No, only store admins can invite other people.',
					),
					'value' => '1',
				);

				$createForm[] = array(
					'type' => 'Radio',
					'name' => 'member_approval',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Approve members?'),
					'multiOptions' => array(
						'1' => 'New members can join immediately.',
						'0' => 'New members must be approved.',
					),
					'value' => '1',
				);
			}
		}

		$createForm[] = array(
			'type' => 'Select',
			'name' => 'all_post',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Post in Updates Tab'),
			'multiOptions' => array("1" => "Everyone", "0" => "Store Admins"),
			'description' => 'Who is allowed to post in this store?',
		);

		//END STORE MEMBER WORK
		$availableLabels = array(
			'everyone' => 'Everyone',
			'registered' => 'All Registered Members',
			'owner_network' => 'Friends and Networks',
			'owner_member_member' => 'Friends of Friends',
			'owner_member' => 'Friends Only',
		);
		if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
			$availableLabels['member'] = 'Store Members Only';
		} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
			$availableLabels['member'] = 'Store Members Only';
		}
		$availableLabels['owner'] = $ownerTitle;

		// View
		$view_options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_view');
		$view_options = array_intersect_key($availableLabels, array_flip($view_options));
		$createForm[] = array(
			'type' => 'Select',
			'name' => 'auth_view',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('View Privacy'),
			'multiOptions' => $view_options,
			'value' => key($view_options),
		);

		// Comment
		$comment_options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_comment');
		$comment_options = array_intersect_key($availableLabels, array_flip($comment_options));

		$createForm[] = array(
			'type' => 'Select',
			'name' => 'auth_comment',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Comment Privacy'),
			'multiOptions' => $comment_options,
			'value' => key($comment_options),
		);

		//START DISCUSSION PRIVACY WORK
		if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorediscussion')) {
			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);

			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_sdicreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestorediscussion")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'sdicreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}

				if ($can_show_list) {
					$createForm[] = array(
						'type' => 'Select',
						'name' => 'sdicreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Discussion Topic Post Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		//START PHOTO PRIVACY WORK
		if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorealbum')) {

			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_spcreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));
			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestorealbum")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'spcreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {
					$createForm[] = array(
						'type' => 'Select',
						'name' => 'spcreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Photo Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		//START SITESTOREDOCUMENT PLUGIN WORK
		$sitestoreDocumentEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoredocument');
		if ((Engine_Api::_()->hasModuleBootstrap('document') && Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore'))) || $sitestoreDocumentEnabled) {
			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_sdcreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestoredocument")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'sdcreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {

					$createForm[] = array(
						'type' => 'Select',
						'name' => 'sdcreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Documents Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		//START SITESTOREVIDEO PLUGIN WORK
		$sitestoreVideoEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorevideo');
		if ($sitestoreVideoEnabled || (Engine_Api::_()->hasModuleBootstrap('sitevideo') && Engine_Api::_()->getDbtable('modules', 'sitevideo')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_svcreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestorevideo")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'svcreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {
					$createForm[] = array(
						'type' => 'Select',
						'name' => 'svcreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Videos Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		$sitestorePollEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorepoll');
		if ($sitestorePollEnabled) {

			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_splcreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestorepoll")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'splcreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {
					$createForm[] = array(
						'type' => 'Select',
						'name' => 'splcreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Polls Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		$sitestoreNoteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorenote');
		if ($sitestoreNoteEnabled) {
			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_sncreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestorenote")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'sncreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {

					$createForm[] = array(
						'type' => 'Select',
						'name' => 'sncreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Notes Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		$sitestoreEventEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorenote');
		if ($sitestoreEventEnabled || (Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_secreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestoreevent")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'secreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {

					$createForm[] = array(
						'type' => 'Select',
						'name' => 'secreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Event Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		//START SITESTOREMUSIC PLUGIN WORK
		$sitestoreMusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremusic');
		if ($sitestoreMusicEnabled) {
			$availableLabels = array(
				'registered' => 'All Registered Members',
				'owner_network' => 'Friends and Networks',
				'owner_member_member' => 'Friends of Friends',
				'owner_member' => 'Friends Only',
				'like_member' => 'Who Liked This Store',
			);
			if (!empty($sitestoreMemberEnabled) && $allowMemberInthisPackage) {
				$availableLabels['member'] = 'Store Members Only';
			} elseif (!empty($sitestoreMemberEnabled) && $allowMemberInLevel) {
				$availableLabels['member'] = 'Store Members Only';
			}
			$availableLabels['owner'] = $ownerTitle;

			$options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitestore_store', $user, 'auth_smcreate');
			$options_create = array_intersect_key($availableLabels, array_flip($options));

			if (!empty($options_create)) {
				$can_show_list = true;
				if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
					if (!Engine_Api::_()->sitestore()->allowPackageContent($this->getPackageId(), "modules", "sitestoremusic")) {
						$can_show_list = false;
					}
				} else {
					$can_create = Engine_Api::_()->authorization()->getPermission($userlevel_id, 'sitestore_store', 'smcreate');
					if (!$can_create) {
						$can_show_list = false;
					}
				}
				if ($can_show_list) {

					$createForm[] = array(
						'type' => 'Select',
						'name' => 'smcreate',
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Music Creation Privacy'),
						'multiOptions' => $options_create,
						'value' => @array_search(@end($options_create), $options_create),
					);
				}
			}
		}

		//NETWORK BASE STORE VIEW PRIVACY
		if (Engine_Api::_()->getApi('subCore', 'sitestore')->storeBaseNetworkEnable()) {
			// Make Network List
			$table = Engine_Api::_()->getDbtable('networks', 'network');
			$select = $table->select()
				->from($table->info('name'), array('network_id', 'title'))
				->order('title');
			$result = $table->fetchAll($select);

			$networksOptions = array('0' => 'Everyone');
			foreach ($result as $value) {
				$networksOptions[$value->network_id] = $value->title;
			}
			if (count($networksOptions) > 0) {

				$createForm[] = array(
					'type' => 'Multiselect',
					'name' => 'networks_privacy',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Networks Selection'),
					'multiOptions' => $networksOptions,
					'value' => array(0),
				);
			}
		}

		$table = Engine_Api::_()->getDbtable('listmemberclaims', 'sitestore');
		$select = $table->select()
			->where('user_id = ?', $viewer_id)
			->limit(1);

		$row = $table->fetchRow($select);
		if ($row !== null) {

			$createForm[] = array(
				'type' => 'Checkbox',
				'name' => 'userclaim',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Show "Claim this Store" link on this store.'),
				'value' => 1,
			);
		}

		$createForm[] = array(
			'type' => 'Select',
			'name' => 'draft',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Show "Claim this Store" link on this store.'),
			'multiOptions' => array("1" => "Published", "0" => "Saved As Draft"),
			'description' => 'If this entry is published, it cannot be switched back to draft mode.',
			'value' => 1,
		);

		$createForm[] = array(
			'type' => 'Checkbox',
			'name' => 'search',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Show this store in search results.'),
			'value' => 1,
		);
//        $createForm[] = array(
		//            'type' => 'Radio',
		//            'name' => 'toggle_products_status',
		//            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Product Status'),
		//            'multiOptions' => array(
		//                '1' => 'Yes',
		//                '0' => 'No',
		//            ),
		//            'value' => '0',
		//        );

		$createForm[] = array(
			'type' => 'Submit',
			'name' => 'submit',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Create'),
		);

		if (isset($createForm) && !empty($createForm)) {
			$responseForm['form'] = $createForm;
		}

		if (isset($form) && !empty($form)) {
			$responseForm['subcategories'] = $form;
		}

		// $profileFields = $this->getProfileTypes();
		// if (!empty($profileFields)) {
		// 	$this->_profileFieldsArray = $profileFields;
		// }
		// $this->_create = 1;
		// $createFormFields = $this->_getProfileFields();

		//START PACKAGE WORK
		$profileField_level = 1;
		if ($hasPackageEnable) {
			$packageId = Zend_Controller_Front::getInstance()->getRequest()->getParam('package_id');
			$packageObject = Engine_Api::_()->getItem('sitestore_package', $packageId);
			if (!empty($packageObject)) {
				$profileField_level = $packageObject->profile;
			} else {
				$profileField_level = 1;
			}

		}
		if (isset($profileField_level) && !empty($profileField_level)) {
			if (_CLIENT_TYPE && (_CLIENT_TYPE == 'android') && _ANDROID_VERSION && _ANDROID_VERSION > '3.6.4') {

				if (is_array($createFormFields) && is_array($categoryProfileTypeMapping)) {

	                foreach ($categoryProfileTypeMapping as $key => $value) {
	                    


	                    if (isset($createFormFields[$value]) && !empty($createFormFields[$value])) {

	                        if(!$responseForm['fields'][$key]) {
	                            $responseForm['fields'][$key] = array();
	                        }

	                        $responseForm['fields'][$key] = array_merge($responseForm['fields'][$key],$createFormFields[$value]);

	                        $createFormFieldsForm[$key] = $createFormFields[$value];
	                    }
	                }
	            }
        	}
        	else{
				if (is_array($createFormFields) && is_array($categoryProfileTypeMapping)) {
					foreach ($categoryProfileTypeMapping as $key => $value) {
						if (isset($createFormFields[$value]) && !empty($createFormFields[$value])) {
							$createFormFieldsForm[$key] = $createFormFields[$value];
						}
					}
					if (isset($createFormFieldsForm) && !empty($createFormFieldsForm)) {
						$responseForm['fields'] = $createFormFieldsForm;
					}

				}
			}
		}
		return $responseForm;
	}


	public function setProfileFields($sitestore, $data) {
		// Iterate over values
		$values = Engine_Api::_()->fields()->getFieldsValues($sitestore);

		$fVals = $data;
		$privacyOptions = Fields_Api_Core::getFieldPrivacyOptions();

		foreach ($fVals as $key => $value) {

			if (strstr($key, 'oauth')) {
				continue;
			}

			$parts = explode('_', $key);
			if (count($parts) < 3) {
				continue;
			}

			list($parent_id, $option_id, $field_id) = $parts;

			// Array mode
			if (is_array($value)) {

				// Lookup
				$valueRows = $values->getRowsMatching(array(
					'field_id' => $field_id,
					'item_id' => $sitestore->getIdentity(),
				));

				// Delete all
				$prevPrivacy = null;
				foreach ($valueRows as $valueRow) {
					if (!empty($valueRow->privacy)) {
						$prevPrivacy = $valueRow->privacy;
					}
					$valueRow->delete();
				}
				if ($field_id == 0) {
					continue;
				}

				// Insert all
				$indexIndex = 0;
				if (is_array($value) || !empty($value)) {
					foreach ((array) $value as $singleValue) {

						$valueRow = $values->createRow();
						$valueRow->field_id = $field_id;
						$valueRow->item_id = $sitestore->getIdentity();
						$valueRow->index = $indexIndex++;
						$valueRow->value = $singleValue;
						$valueRow->save();
					}
				} else {
					$valueRow = $values->createRow();
					$valueRow->field_id = $field_id;
					$valueRow->item_id = $sitestore->getIdentity();
					$valueRow->index = 0;
					$valueRow->value = '';
					$valueRow->save();
				}
			}

			// Scalar mode
			else {
				// Lookup
				$valueRow = $values->getRowMatching(array(
					'field_id' => $field_id,
					'item_id' => $sitestore->getIdentity(),
					'index' => 0,
				));
				// Remove value row if empty
				if (empty($value)) {
					if ($valueRow) {
						$valueRow->delete();
					}
					continue;
				}

				if ($field_id == 0) {
					continue;
				}

				// Create if missing
				$isNew = false;
				if (!$valueRow) {
					$isNew = true;
					$valueRow = $values->createRow();
					$valueRow->field_id = $field_id;
					$valueRow->item_id = $sitestore->getIdentity();
				}
				$valueRow->value = htmlspecialchars($value);
				$valueRow->save();
			}
		}
		return;
	}

	public function getProfileTypeLabel($option_id) {

		if (empty($option_id)) {
			return;
		}
		$table = Engine_Api::_()->getDbtable('options', 'sitestore');
		//GET FIELD OPTION TABLE NAME
		$tableFieldOptionsName = $table->info('name');

		//FETCH PROFILE TYPE LABEL
		$profileTypeLabel = $table->select()
			->from($tableFieldOptionsName, array('label'))
			->where('option_id = ?', $option_id)
			->query()
			->fetchColumn();

		return $profileTypeLabel;
	}

	public function getCategoryMapProfileType($category_id = 0) {
		if (empty($category_id)) {
			return 0;
		}

		$table = Engine_Api::_()->getDbtable('profilemaps', 'sitestore');
		$tableFieldOptionsName = $table->info('name');

		//FETCH PROFILE TYPE LABEL
		$profileType = $table->select()
			->from($tableFieldOptionsName, array('profile_type'))
			->where('category_id = ?', $category_id)
			->query()
			->fetchColumn();

		return $profileType;
	}

	public function getProfileType($categoryIds = array(), $categoryId = 0, $profileTypeName = 'profile_type') {

		$table = Engine_Api::_()->getDbtable('profilemaps', 'sitestore');
		$tableFieldOptionsName = $table->info('name');

		if (!empty($categoryIds)) {
			$profile_type = 0;
			foreach ($categoryIds as $value) {
				$profile_type = $table->select()
					->from($tableFieldOptionsName, array("$profileTypeName"))
					->where("category_id = ?", $value)
					->query()
					->fetchColumn();

				if (!empty($profile_type)) {
					return $profile_type;
				}
			}

			return $profile_type;
		} elseif (!empty($categoryId)) {

			//FETCH DATA
			$profile_type = $table->select()
				->from($tableFieldOptionsName, array("$profileTypeName"))
				->where("category_id = ?", $categoryId)
				->query()
				->fetchColumn();

			return $profile_type;
		}

		return 0;
	}

	public function setStorePhoto($photo, $sitestore) {
		try {

			if ($photo instanceof Zend_Form_Element_File) {
				$file = $photo->getFileName();
			} else if (is_array($photo) && !empty($photo['tmp_name'])) {
				$file = $photo['tmp_name'];
			} else if (is_string($photo) && file_exists($photo)) {
				$file = $photo;
			} else {
				throw new Group_Model_Exception('invalid argument passed to setPhoto');
			}
		} catch (Exception $e) {

		}

		$imageName = $photo['name'];
		$name = basename($file);
		$path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

		$params = array(
			'parent_type' => 'sitestore_store',
			'parent_id' => $sitestore->getIdentity(),
		);

		// Save
		$storage = Engine_Api::_()->storage();

		// Resize image (main)
		$image = Engine_Image::factory();
		$image->open($file)
			->resize(720, 720)
			->write($path . '/m_' . $imageName)
			->destroy();

		// Resize image (profile)
		$image = Engine_Image::factory();
		$image->open($file)
			->resize(200, 400)
			->write($path . '/p_' . $imageName)
			->destroy();

		// Resize image (normal)
		$image = Engine_Image::factory();
		$image->open($file)
			->resize(140, 160)
			->write($path . '/in_' . $imageName)
			->destroy();

		// Resize image (icon)
		$image = Engine_Image::factory();
		$image->open($file);

		$size = min($image->height, $image->width);
		$x = ($image->width - $size) / 2;
		$y = ($image->height - $size) / 2;

		$image->resample($x, $y, $size, $size, 48, 48)
			->write($path . '/is_' . $imageName)
			->destroy();

		// Store
		$iMain = $storage->create($path . '/m_' . $imageName, $params);
		$iProfile = $storage->create($path . '/p_' . $imageName, $params);
		$iIconNormal = $storage->create($path . '/in_' . $imageName, $params);
		$iSquare = $storage->create($path . '/is_' . $imageName, $params);

		$iMain->bridge($iProfile, 'thumb.profile');
		$iMain->bridge($iIconNormal, 'thumb.normal');
		$iMain->bridge($iSquare, 'thumb.icon');

		// Remove temp files
		@unlink($path . '/p_' . $imageName);
		@unlink($path . '/m_' . $imageName);
		@unlink($path . '/in_' . $imageName);
		@unlink($path . '/is_' . $imageName);

		// Add to album
		$viewer = Engine_Api::_()->user()->getViewer();
		$photoTable = Engine_Api::_()->getItemTable('sitestore_photo');
		$album_id = '';
		$sitestoreAlbum = $sitestore->getSingletonAlbum($album_id);
		$photoItem = $photoTable->createRow();
		$photoItem->setFromArray(array(
			'store_id' => $sitestore->getIdentity(),
			'album_id' => $sitestoreAlbum->getIdentity(),
			'user_id' => $viewer->getIdentity(),
			'file_id' => $iMain->getIdentity(),
			'collection_id' => $sitestoreAlbum->getIdentity(),
		));
		$photoItem->save();

		// Update row
		$sitestore->modified_date = date('Y-m-d H:i:s');
		$sitestore->photo_id = $photoItem->file_id;
		$sitestore->save();

		return $sitestore;
	}

	function getPayPalForm($mainForm = array(), $paypalEnable = 0) {
		$payPalForm = array();
		$payPalForm = $mainForm;
		$settings = Engine_Api::_()->getApi('settings', 'core');
		if (_CLIENT_TYPE == 'ios') {
			$type = 'Label';
		} else {
			$type = 'Dummy';
		}
		$payPalForm[] = array(
			'type' => $type,
			"subType" => 'payment_method',
			"isActive" => $paypalEnable,
			'name' => 'PaypalHeading',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Pay Pal'),
		);
		$payPalForm[] = array(
			'type' => 'Text',
			'name' => 'email_paypal',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Paypal Email'),
			'hasValidator' => true,
		);

		$payPalForm[] = array(
			'type' => 'Text',
			'name' => 'username_paypal',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('API Username'),
		);
		$payPalForm[] = array(
			'type' => 'Text',
			'name' => 'password_paypal',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('API Password'),
		);

		$payPalForm[] = array(
			'type' => 'Text',
			'name' => 'signature_paypal',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('API Signature'),
		);

		$showExtraInfo = true;
		$isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);
		if (empty($isAdminDrivenStore)) {
			$isPaymentToSiteEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.payment.for.orders', 0);
			if (empty($isPaymentToSiteEnable)) {
				$showExtraInfo = false;
			}
		}
		if (!empty($showExtraInfo)) {
			$payPalForm[] = array(
				'type' => 'Radio',
				'name' => 'signature_paypal',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enabled?'),
				'multiOptions' => array(
					'1' => 'Yes',
					'0' => 'No',
				),
				'value' => '0',
			);
		}

		$payPalForm[] = array(
			'type' => 'Checkbox',
			'name' => 'isPaypalChecked',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable PayPal'),
			'value' => $paypalEnable,
		);

		return $payPalForm;
	}

	function getMangoPayForm($mainForm = array(), $isEnable = 0) {
		$mangoPayForm = array();
		$mangoPayForm = $mainForm;
		$settings = Engine_Api::_()->getApi('settings', 'core');
		if (_CLIENT_TYPE == 'ios') {
			$type = 'Label';
		} else {
			$type = 'Dummy';
		}
		$mangoPayForm[] = array(
			'type' => $type,
			"subType" => 'payment_method',
			'name' => 'mangopayHeading',
			"isActive" => $isEnable,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Mango Pay'),
		);
		$mangoPayForm[] = array(
			'type' => 'Text',
			'name' => 'first_name',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('First Name'),
			'hasValidator' => true,
		);

		$mangoPayForm[] = array(
			'type' => 'Text',
			'name' => 'last_name',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Last Name'),
			'hasValidator' => true,
		);
		$mangoPayForm[] = array(
			'type' => 'Text',
			'name' => 'email_mango',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Email'),
			'hasValidator' => true,
		);

		$mangoPayForm[] = array(
			'type' => 'Date',
			'name' => 'birthday',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Birthday'),
			'hasValidator' => true,
		);

		$countryCodes = array(
			"AD" => "AD", "AE" => "AE", "AF" => "AF", "AG" => "AG", "AI" => "AI",
			"AL" => "AL", "AM" => "AM", "AO" => "AO", "AQ" => "AQ", "AR" => "AR",
			"AS" => "AS", "AT" => "AT", "AU" => "AU", "AW" => "AW", "AX" => "AX",
			"AZ" => "AZ", "BA" => "BA", "BB" => "BB", "BD" => "BD", "BE" => "BE",
			"BF" => "BF", "BG" => "BG", "BH" => "BH", "BI" => "BI", "BJ" => "BJ",
			"BL" => "BL", "BM" => "BM", "BN" => "BN", "BO" => "BO", "BQ" => "BQ",
			"BR" => "BR", "BS" => "BS", "BT" => "BT", "BV" => "BV", "BW" => "BW",
			"BY" => "BY", "BZ" => "BZ", "CA" => "CA", "CC" => "CC", "CD" => "CD",
			"CF" => "CF", "CG" => "CG", "CH" => "CH", "CI" => "CI", "CK" => "CK",
			"CL" => "CL", "CM" => "CM", "CN" => "CN", "CO" => "CO", "CR" => "CR",
			"CU" => "CU", "CV" => "CV", "CW" => "CW", "CX" => "CX", "CY" => "CY",
			"CZ" => "CZ", "DE" => "DE", "DJ" => "DJ", "DK" => "DK", "DM" => "DM",
			"DO" => "DO", "DZ" => "DZ", "EC" => "EC", "EE" => "EE", "EG" => "EG",
			"EH" => "EH", "ER" => "ER", "ES" => "ES", "ET" => "ET", "FI" => "FI",
			"FJ" => "FJ", "FK" => "FK", "FM" => "FM", "FO" => "FO", "FR" => "FR",
			"GA" => "GA", "GB" => "GB", "GD" => "GD", "GE" => "GE", "GF" => "GF",
			"GG" => "GG", "GH" => "GH", "GI" => "GI", "GL" => "GL", "GM" => "GM",
			"GN" => "GN", "GP" => "GP", "GQ" => "GQ", "GR" => "GR", "GS" => "GS",
			"GT" => "GT", "GU" => "GU", "GW" => "GW", "GY" => "GY", "HK" => "HK",
			"HM" => "HM", "HN" => "HN", "HR" => "HR", "HT" => "HT", "HU" => "HU",
			"ID" => "ID", "IE" => "IE", "IL" => "IL", "IM" => "IM", "IN" => "IN",
			"IO" => "IO", "IQ" => "IQ", "IR" => "IR", "IS" => "IS", "IT" => "IT",
			"JE" => "JE", "JM" => "JM", "JO" => "JO", "JP" => "JP", "KE" => "KE",
			"KG" => "KG", "KH" => "KH", "KI" => "KI", "KM" => "KM", "KN" => "KN",
			"KP" => "KP", "KR" => "KR", "KW" => "KW", "KY" => "KY", "KZ" => "KZ",
			"LA" => "LA", "LB" => "LB", "LC" => "LC", "LI" => "LI", "LK" => "LK",
			"LR" => "LR", "LS" => "LS", "LT" => "LT", "LU" => "LU", "LV" => "LV",
			"LY" => "LY", "MA" => "MA", "MC" => "MC", "MD" => "MD", "ME" => "ME",
			"MF" => "MF", "MG" => "MG", "MH" => "MH", "MK" => "MK", "ML" => "ML",
			"MM" => "MM", "MN" => "MN", "MO" => "MO", "MP" => "MP", "MQ" => "MQ",
			"MR" => "MR", "MS" => "MS", "MT" => "MT", "MU" => "MU", "MV" => "MV",
			"MW" => "MW", "MX" => "MX", "MY" => "MY", "MZ" => "MZ", "NA" => "NA",
			"NC" => "NC", "NE" => "NE", "NF" => "NF", "NG" => "NG", "NI" => "NI",
			"NL" => "NL", "NO" => "NO", "NP" => "NP", "NR" => "NR", "NU" => "NU",
			"NZ" => "NZ", "OM" => "OM", "PA" => "PA", "PE" => "PE", "PF" => "PF",
			"PG" => "PG", "PH" => "PH", "PK" => "PK", "PL" => "PL", "PM" => "PM",
			"PN" => "PN", "PR" => "PR", "PS" => "PS", "PT" => "PT", "PW" => "PW",
			"PY" => "PY", "QA" => "QA", "RE" => "RE", "RO" => "RO", "RS" => "RS",
			"RU" => "RU", "RW" => "RW", "SA" => "SA", "SB" => "SB", "SC" => "SC",
			"SD" => "SD", "SE" => "SE", "SG" => "SG", "SH" => "SH", "SI" => "SI",
			"SJ" => "SJ", "SK" => "SK", "SL" => "SL", "SM" => "SM", "SN" => "SN",
			"SO" => "SO", "SR" => "SR", "SS" => "SS", "ST" => "ST", "SV" => "SV",
			"SX" => "SX", "SY" => "SY", "SZ" => "SZ", "TC" => "TC", "TD" => "TD",
			"TF" => "TF", "TG" => "TG", "TH" => "TH", "TJ" => "TJ", "TK" => "TK",
			"TL" => "TL", "TM" => "TM", "TN" => "TN", "TO" => "TO", "TR" => "TR",
			"TT" => "TT", "TV" => "TV", "TW" => "TW", "TZ" => "TZ", "UA" => "UA",
			"UG" => "UG", "UM" => "UM", "US" => "US", "UY" => "UY", "UZ" => "UZ",
			"VA" => "VA", "VC" => "VC", "VE" => "VE", "VG" => "VG", "VI" => "VI",
			"VN" => "VN", "VU" => "VU", "WF" => "WF", "WS" => "WS", "YE" => "YE",
			"YT" => "YT", "ZA" => "ZA", "ZM" => "ZM", "ZW" => "ZW",
		);

		$mangoPayForm[] = array(
			'type' => 'Select',
			'name' => 'nationality',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Nationality'),
			'multiOptions' => $countryCodes,
			'hasValidator' => true,
		);
		$mangoPayForm[] = array(
			'type' => 'Select',
			'name' => 'residence',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Country Residence'),
			'multiOptions' => $countryCodes,
			'hasValidator' => true,
		);

		$mangoPayForm[] = array(
			'type' => 'Checkbox',
			'name' => 'isMangopay',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable Mango Pay'),
			'value' => 0,
		);

		return $mangoPayForm;
	}

	public function getMangoPayBankDetail() {
		$accountTypes = array('IBAN' => 'IBAN');
		$mangoPayBankDetailForm = array();
		$mangoPayBankDetailForm[] = array(
			'type' => 'Select',
			'name' => 'account_type',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Bank account type'),
			'multiOptions' => $accountTypes,
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'owner_name',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Owner name'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Textarea',
			'name' => 'owner_address',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Owner address Line1'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Textarea',
			'name' => 'owner_address2',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Owner address Line2'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'city',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('City'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'region',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Region'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'postal_code',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Postal Code'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Select',
			'name' => 'country',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Country Country'),
			'multiOptions' => $countryCodes,
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'iban',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('IBAN'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'bic',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('BIC'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'sort_code',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Sort code'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'account_number',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Account number'),
			'hasValidator' => true,
		);

		$depositAccountTypeArr = array('CHECKING' => 'CHECKING', 'SAVINGS' => 'SAVINGS');

		$mangoPayBankDetailForm[] = array(
			'type' => 'Select',
			'name' => 'deposit_account_type',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Deposit account type'),
			'multiOptions' => $depositAccountTypeArr,
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'us_account_number',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Account number'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'branch_code',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Country Country'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'bank_name',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Bank name'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'institution_number',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Institution number'),
			'hasValidator' => true,
		);
		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'ca_account_number',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Account number'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'other_bic',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('BIC'),
			'hasValidator' => true,
		);

		$mangoPayBankDetailForm[] = array(
			'type' => 'Text',
			'name' => 'other_account_number',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Account number'),
			'hasValidator' => true,
		);
		return $mangoPayBankDetailForm;
	}

	public function getStripForm($mainForm = array(), $isstripEnable = 0) {
		$stripForm = array();
		$stripForm = $mainForm;
		if (_CLIENT_TYPE == 'ios') {
			$type = 'Label';
		} else {
			$type = 'Dummy';
		}
		$stripForm[] = array(
			'type' => $type,
			'name' => 'stripHeading',
			"subType" => 'payment_method',
			"isActive" => $isstripEnable,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Stripe'),
		);
		$stripForm[] = array(
			'type' => 'Text',
			'name' => 'secret',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('API Secret Key'),
			'hasValidator' => true,
		);
		$stripForm[] = array(
			'type' => 'Text',
			'name' => 'publishable',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('API Publishable Key'),
			'hasValidator' => true,
		);

		$stripForm[] = array(
			'type' => 'Checkbox',
			'name' => 'isStripeChecked',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable Stripe'),
			'value' => $isstripEnable,
		);

		return $stripForm;
	}

	public function getShippingMethodForm($store_id = null, $item = null, $edit = 0) {

		$tempCountryArray['ALL'] = "All Countries";
		$shippingForm = array();
		$shippingCountries = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->getRegionsByName($params = array());

		foreach ($shippingCountries as $keys => $shippingCountry) {
			$localeCountryArray[$shippingCountry['country']] = Zend_Locale::getTranslation($shippingCountry['country'], 'country');
		}

		asort($localeCountryArray);

		$countryArray = array_merge($tempCountryArray, $localeCountryArray);

		$shippingForm[] = array(
			'type' => 'Text',
			'name' => 'title',
			"order" => 1,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Title'),
			'hasValidator' => true,
		);
		$shippingForm[] = array(
			'type' => 'Text',
			'name' => 'delivery_time',
			"order" => 2,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Delivery Time : Ex: 2-5 Days'),
			'description' => 'Eg: 2-5 Days, 3-9 Working Days, 2-6 Business Days',
		);
		$isDisable = false;
		if (!empty($item)) {
			$isDisable = true;
		}
		$shippingForm[] = array(
			'type' => 'Select',
			'name' => 'country',
			"order" => 3,
			"isDisable" => $isDisable,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Country'),
			'multiOptions' => $countryArray,
			'value' => key($countryArray),
			"hasSubForm" => true,
			'hasValidator' => true,
		);
		$parentRecord = array();
		if (!empty($edit) && $item->country != 'ALL') {
			$shippingForm[] = array(
				'type' => 'Radio',
				'name' => 'all_regions',
				"hasSubForm" => true,
				"isDisable" => true,
				"order" => 4,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable shipping method for all Regions / States'),
				'multiOptions' => array("yes" => "Yes", "no" => "No"),
				'value' => 'no',
			);

			$region = array();
			$params['store_id'] = $store_id;
			$params['country'] = $item->country;
			$shippingCountries = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->getRegionsByName($params);
			$i = 0;
			foreach ($shippingCountries as $shippingCountry) {
				if (empty($shippingCountry['region'])) {
					continue;
				}

				$region[$shippingCountry['region_id']] = $shippingCountry['region'];
				if ($i == 4) {
					break;
				}

				$i++;
			}

			if (_CLIENT_TYPE && _CLIENT_TYPE == 'ios') {
				$type = 'MultiCheckbox';
			} else {
				$type = 'Multiselect';
			}

			if (count($region) > 0 && empty($item->all_regions)) {
				$shippingForm[] = array(
					'type' => $type,
					'name' => 'state',
					"isDisable" => true,
					"order" => 4,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Regions / States'),
					'multiOptions' => $region,
				);

				$response['country'] = array(
					"child" => 'country_' . $item->country,
				);
			}
		}

		$temp_shipping_fee_type_array = array("0" => "Fixed", "1" => "Percentage");
		if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore_shipping_extra_content', 1)) {
			$shippingForm[] = array(
				'type' => 'Select',
				'name' => 'dependency',
				"order" => 5,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Method Dependency'),
				"hasSubForm" => true,
				'multiOptions' => array("" => "", "0" => "Cost & Weight", "1" => "Weight only", "2" => "Quantity & Weight"),
			);

			//dependency field
			if (!empty($edit)) {
				$shippingeditForm = $this->getDependency($shippingForm, $item->dependency, $item);
				if ($item->dependency == '0') {
					$response['dependency'] = array(
						"child" => 'dependency_' . $item->dependency,
					);
					if ($item->handling_type == '0') {
						$response['handling_type'] = array(
							"child" => 'handling_type_fixed',
							'parent' => 'dependency',
						);
					} else {
						$response['handling_type'] = array(
							"child" => 'handling_type_percentage',
							"parent" => 'dependency',
						);
					}
				} elseif ($item->dependency == '1') {
					$response['dependency'] = array(
						"child" => 'dependency_' . $item->dependency,
					);

					if ($item->handling_type == '0') {
						$response['handling_type'] = array(
							"child" => 'handling_type_fixed',
							'parent' => 'dependency',
						);
					} else {
						$response['handling_type'] = array(
							"child" => 'handling_type_percentage',
							"parent" => 'dependency',
						);
					}
				} else {

					$response['dependency'] = array(
						"child" => 'dependency_' . $item->dependency,
					);
					if ($item->ship_type == '1') {
						$response['ship_type'] = array(
							"child" => 'ship_type_per_item',
							"parent" => 'dependency',
						);

						if ($item->handling_type == '0') {
							$response['handling_type'] = array(
								"child" => 'handling_type_fixed',
								'parent' => 'ship_type',
							);
						} else {
							$response['handling_type'] = array(
								"child" => 'handling_type_percentage',
								"parent" => 'ship_type',
							);
						}
					} else {
						$response['ship_type'] = array(
							"child" => 'ship_type_per_order',
							"parent" => 'dependency',
						);
					}
				}
			}
			// $temp_shipping_fee_type_array = array("0" => "Fixed", "1" => "Percentage", "2" => "Per Unit Weight");
		}

		$shippingForm[] = array(
			'type' => 'Checkbox',
			'name' => 'status',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Activate this shipping method for your store. (If enabled, then this method will be available to users for selection in the Shipping Methods section during the checkout process of an order from your store.)'),
			'value' => 1,
			'order' => 6,
		);

		$shippingForm[] = array(
			'type' => 'submit',
			'name' => 'submit',
			'order' => 7,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Save Setting'),
		);

//        $subform = $this->changestate($localeCountryArray, $store_id);
		//
		$response['form'] = $shippingForm;
		if (!empty($edit)) {
			$shippingeditForm[] = array(
				'type' => 'Checkbox',
				'name' => 'status',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Activate this shipping method for your store. (If enabled, then this method will be available to users for selection in the Shipping Methods section during the checkout process of an order from your store.)'),
				'value' => 1,
				'order' => 13,
			);

			$shippingeditForm[] = array(
				'type' => 'submit',
				'name' => 'submit',
				'order' => 14,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Save Setting'),
			);
			$response['editForm'] = $shippingeditForm;
		}
//        if (!empty($subform)) {
		//            $response['subForm'] = $subform;
		//        }

		$response['fields'] = $this->dependentField($currencyName, $localeCountryArray, $store_id, $edit);
		//$response['editForm'] =$this->geteditForm($shippingForm,$response['fields'],$item);
		return $response;
	}

	public function changestate($country = array(), $store_id = null, $edit = null) {

		$emptyRegionIdArray = $countryArray = array();
		$countryArray = array();
		$regionForm = array();
		foreach ($country as $key => $value) {
			$region = array();
			$params['store_id'] = $store_id;
			$params['country'] = $key;
			$shippingCountries = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->getRegionsByName($params);
			$i = 0;
			foreach ($shippingCountries as $shippingCountry) {
				if (empty($shippingCountry['region'])) {
					continue;
				}

				$region[$shippingCountry['region_id']] = $shippingCountry['region'];
				if ($i == 4) {
					break;
				}

				$i++;
			}
			if (_CLIENT_TYPE && _CLIENT_TYPE == 'ios') {
				$type = 'MultiCheckbox';
			} else {
				$type = 'Multiselect';
			}

			if (!empty($edit)) {
				$isDisable = true;
			} else {
				$isDisable = false;
			}
			if (count($region) > 0) {
				$regionForm['country_' . $key][] = array(
					'type' => 'Select',
					'name' => 'all_regions',
					"order" => 4,
					'isDisable' => $isDisable,
					"hasSubForm" => true,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable shipping method for all Regions / States'),
					'multiOptions' => array("yes" => "Yes", "no" => "No"),
					'value' => 'yes',
				);

				$regionForm['all_regions_no'][] = array(
					'type' => $type,
					'name' => 'state',
					'isDisable' => $isDisable,
					"order" => 4,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Regions / States'),
					'multiOptions' => $region,
				);
			}
		}
		return $regionForm;
	}

	public function dependentField($currencyName = null, $country = array(), $store_id = null, $edit = null) {
		$viewer = Engine_Api::_()->user()->getViewer();
		$local = ($viewer_id) ? $viewer->locale : 'auto';
		$localeObject = new Zend_Locale($local);

		$region = $this->changestate($country, $store_id, $edit);

		$currencyCode = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
		$currencyName = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $currencyCode);
		$field = array();
		$cost_wieght[] = array(
			'type' => 'Text',
			'name' => 'ship_start_limit',
			"order" => 7,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Cost Start (US Dollar)'),
		);

		$cost_wieght[] = array(
			'type' => 'Text',
			'name' => 'ship_end_limit',
			"order" => 8,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Cost End (US Dollar)'),
		);

		$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');

		$cost_wieght[] = array(
			'type' => 'Text',
			'name' => 'allow_weight_from',
			"order" => 9,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Total Order Weight From (In ' . $weightUnit . ')'),
		);

		$cost_wieght[] = array(
			'type' => 'Text',
			"order" => 10,
			'name' => 'allow_weight_to',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Total Order Weight To (In ' . $weightUnit . ')'),
		);

		$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage");
		$cost_wieght[] = array(
			'type' => 'Select',
			'name' => 'handling_type',
			"order" => 11,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee Type'),
			"hasSubForm" => true,
			'multiOptions' => $temp_shipping_fee_type_array,
		);

		$weight_only = array();

		$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');

		$weight_only[] = array(
			'type' => 'Text',
			"order" => 7,
			'name' => 'ship_start_limit',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Weight Start (In ' . $weightUnit . ')'),
		);

		$weight_only[] = array(
			'type' => 'Text',
			"order" => 8,
			'name' => 'ship_end_limit',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Weight End(In ' . $weightUnit . ')'),
		);

		$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage", "unit_weight" => "Per Unit Weight");
		$weight_only[] = array(
			'type' => 'Select',
			'name' => 'handling_type',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee Type'),
			"order" => 9,
			"hasSubForm" => true,
			'multiOptions' => $temp_shipping_fee_type_array,
		);

		$Quantity_weight = array();
		$Quantity_weight[] = array(
			'type' => 'Text',
			'name' => 'ship_start_limit',
			"order" => 7,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Products Quantity Start'),
		);

		$Quantity_weight[] = array(
			'type' => 'Text',
			'name' => 'ship_end_limit',
			"order" => 8,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Products Quantity End'),
		);

		$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');

		$Quantity_weight[] = array(
			'type' => 'Text',
			'name' => 'allow_weight_from',
			"order" => 9,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Weight handling range start for this method (In ' . $weightUnit . ')'),
		);

		$Quantity_weight[] = array(
			'type' => 'Text',
			"order" => 10,
			'name' => 'allow_weight_to',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Weight handling range end for this method (In ' . $weightUnit . ')'),
		);

		$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage");
		$Quantity_weight[] = array(
			'type' => 'Select',
			'name' => 'ship_type',
			"order" => 11,
			"hasSubForm" => true,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Type'),
			'multiOptions' => array("" => "", "per_order" => "Per Order", "per_item" => "Per Item"),
		);

		$per_order = array();
		$per_item = array();
		$per_order[] = array(
			'type' => 'Text',
			'name' => 'price',
			"order" => 12,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
		);
		$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage");
		$per_item[] = array(
			'type' => 'Select',
			'name' => 'handling_type',
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee Type'),
			"order" => 6,
			"hasSubForm" => true,
			'multiOptions' => $temp_shipping_fee_type_array,
		);

		$fixed = array();
		$percentage = array();
		$fixed[] = array(
			'type' => 'Text',
			'name' => 'price',
			"order" => 12,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
		);

		$percentage[] = array(
			'type' => 'Text',
			'name' => 'rate',
			"order" => 12,
			'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Rate (%)'),
		);
		$field['dependency_0'] = $cost_wieght;
		$field['dependency_1'] = $weight_only;
		$field['dependency_2'] = $Quantity_weight;
		$field['handling_type_fixed'] = $fixed;
		$field['handling_type_percentage'] = $percentage;
		$field['handling_type_unit_weight'] = $fixed;
		$field['ship_type_per_order'] = $per_order;
		$field['ship_type_per_item'] = $per_item;

		$field = array_merge($field, $region);
		return $field;
	}

//    public function geteditForm($shippingForm=array(),$subfield=array(),$item){
	//        $editForm=array();
	//        foreach($shippingForm as $form){
	//             $editForm[]=$form;
	//            if(isset($form['hasSubForm']) && !empty($form['hasSubForm'])){
	//                $key=$form['name'];
	//                if(isset($subfield['fields'][$key.'_'.$item->$key]) && count($subfield['fields'][$key.'_'.$item->$key])>0)
	//                        foreach($subfield['fields'][$key.'_'.$item->$key] as $subFieldValue){
	//                         $editForm[]=$subFieldValue;
	//                        }
	//
	//            }
	//        }
	//    }

	public function getDependency($form, $dependency, $item = null) {
		$viewer = Engine_Api::_()->user()->getViewer();
		$local = ($viewer_id) ? $viewer->locale : 'auto';
		$localeObject = new Zend_Locale($local);
		$currencyCode = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
		$currencyName = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $currencyCode);
		if ($dependency == '0') {

			$form[] = array(
				'type' => 'Text',
				'name' => 'ship_start_limit',
				"order" => 7,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Cost Start (US Dollar)'),
			);

			$form[] = array(
				'type' => 'Text',
				'name' => 'ship_end_limit',
				"order" => 8,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Cost End (US Dollar)'),
			);

			$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');

			$form[] = array(
				'type' => 'Text',
				'name' => 'allow_weight_from',
				"order" => 9,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Total Order Weight from (In ' . $weightUnit . ')'),
			);

			$form[] = array(
				'type' => 'Text',
				"order" => 10,
				'name' => 'allow_weight_to',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Total Order Weight To (In ' . $weightUnit . ')'),
			);

			$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage");
			$form[] = array(
				'type' => 'Select',
				'name' => 'handling_type',
				"order" => 11,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee Type'),
				"hasSubForm" => true,
				'multiOptions' => $temp_shipping_fee_type_array,
			);

			if ($item->handling_type == '0') {
				$form[] = array(
					'type' => 'Text',
					'name' => 'price',
					"order" => 12,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
				);
			} else {
				$form[] = array(
					'type' => 'Text',
					'name' => 'rate',
					"order" => 12,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Rate (%)'),
				);
			}
		} elseif ($dependency == '1') {
			$weight_only = array();

			$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');

			$form[] = array(
				'type' => 'Text',
				"order" => 7,
				'name' => 'ship_start_limit',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Weight Start(In ' . $weightUnit . ')'),
			);

			$form[] = array(
				'type' => 'Text',
				"order" => 8,
				'name' => 'ship_end_limit',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Order Weight End(In ' . $weightUnit . ')'),
			);

			$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage", "unit_weight" => "Per Unit Weight");
			$form[] = array(
				'type' => 'Select',
				'name' => 'handling_type',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee Type'),
				"order" => 9,
				"hasSubForm" => true,
				'multiOptions' => $temp_shipping_fee_type_array,
			);

			if ($item->handling_type == '0') {
				$form[] = array(
					'type' => 'Text',
					'name' => 'price',
					"order" => 12,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
				);
			} elseif ($item->handling_type == '1') {
				$form[] = array(
					'type' => 'Text',
					'name' => 'rate',
					"order" => 12,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Rate (%)'),
				);
			} else {
				$form[] = array(
					'type' => 'Text',
					'name' => 'price',
					"order" => 12,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
				);
			}
		} else {
			$Quantity_weight = array();
			$form[] = array(
				'type' => 'Text',
				'name' => 'ship_start_limit',
				"order" => 7,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Products Quantity Start'),
			);

			$form[] = array(
				'type' => 'Text',
				'name' => 'ship_end_limit',
				"order" => 8,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Products Quantity End'),
			);

			$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');

			$form[] = array(
				'type' => 'Text',
				'name' => 'allow_weight_from',
				"order" => 9,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Weight handling range start for this method (In ' . $weightUnit . ')'),
			);

			$form[] = array(
				'type' => 'Text',
				"order" => 10,
				'name' => 'allow_weight_to',
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Weight handling range end for this method (In ' . $weightUnit . ')'),
			);

			$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage");
			$form[] = array(
				'type' => 'Select',
				'name' => 'ship_type',
				"order" => 11,
				"hasSubForm" => true,
				'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Type'),
				'multiOptions' => array("" => "", "per_order" => "Per Order", "per_item" => "Per Item"),
			);

			if ($item->ship_type == '1') {
				$temp_shipping_fee_type_array = array("" => "", "fixed" => "Fixed", "percentage" => "Percentage");
				$form[] = array(
					'type' => 'Select',
					'name' => 'handling_type',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee Type'),
					"order" => 6,
					"hasSubForm" => true,
					'multiOptions' => $temp_shipping_fee_type_array,
				);

				if ($item->handling_type == '0') {
					$form[] = array(
						'type' => 'Text',
						'name' => 'price',
						"order" => 12,
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
					);
				} elseif ($item->handling_type == '1') {
					$form[] = array(
						'type' => 'Text',
						'name' => 'rate',
						"order" => 12,
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Rate (%)'),
					);
				} else {
					$form[] = array(
						'type' => 'Text',
						'name' => 'price',
						"order" => 12,
						'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
					);
				}
			} else {
				$form[] = array(
					'type' => 'Text',
					'name' => 'price',
					"order" => 12,
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Shipping Fee ' . '(' . $currencyName . ')'),
				);
			}
		}

		return $form;
	}

}
