<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestore
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    FormValidators.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestore_Api_Siteapi_FormValidators extends Siteapi_Api_Validators {
    /*
     * form validators for album of day
     */

    public function albumOfDayValidators() {
        $formValidators['startdate'] = array(
            'required' => true,
            'allowEmpty' => false,
        );

        $formValidators['enddate'] = array(
            'required' => true,
            'allowEmpty' => false,
        );

        return $formValidators;
    }

    /*
     *  billing fields form validators 
     */

    public function billingAddressValidators() {
        $billingFields = array('f_name_billing', 'phone_billing', 'address_billing', 'country_billing', 'city_billing', 'zip_billing');

        $formValidators = array();

        foreach ($billingFields as $row => $value)
            $formValidators[$value] = array('required' => true, 'allowEmpty' => false);

        return $formValidators;
    }

    /*
     *  shipping fields form validators 
     */

    public function shippingAddressValidators() {
        $shippingFields = array('f_name_shipping', 'phone_shipping', 'address_shipping', 'country_shipping', 'city_shipping', 'zip_shipping');

        $formValidators = array();

        foreach ($shippingFields as $row => $value)
            $formValidators[$value] = array('required' => true, 'allowEmpty' => false);

        return $formValidators;
    }

    public function tellaFriendFormValidators() {
        $formValidators = array();

        $formValidators['sender_name'] = array(
            'required' => true,
            'allowEmpty' => false,
        );

        $formValidators['sender_email'] = array(
            'required' => true,
            'allowEmpty' => false,
        );

        $formValidators['receiver_emails'] = array(
            'required' => true,
            'allowEmpty' => false,
        );

        $formValidators['message'] = array(
            'required' => true,
            'allowEmpty' => false,
        );

        return $formValidators;
    }

    public function storeCreateFormValidators() {
        $formValidators = array();

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $sitestoreMemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');

        $sitestoreUrlEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreurl');
        $store_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('store_id', Zend_Controller_Front::getInstance()->getRequest()->getParam('store', null));
        $parent_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('parent_id', null);

        $show_url = $coreSettings->getSetting('sitestore.showurl.column', 1);
        $change_url = $coreSettings->getSetting('sitestore.change.url', 1);
        $edit_url = $coreSettings->getSetting('sitestore.edit.url', 0);
        $isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);

        $formValidators['title'] = array(
            'required' => true,
            'allowEmpty' => false,
        );
        if ((!empty($sitestoreUrlEnabled) && !empty($store_id) && !empty($show_url) && !empty($edit_url)) || empty($store_id)) {
            $formValidators['store_uri'] = array(
                'required' => true,
                'allowEmpty' => false,
            );
        }
        $formValidators['category_id'] = array(
            'required' => true,
            'allowEmpty' => false,
        );
        $formValidators['body'] = array(
            'required' => true,
            'allowEmpty' => false,
        );
//        if ($coreSettings->getSetting('sitestore.requried.photo', 1)) {
//            $formValidators['photo'] = array(
//                'required' => true,
//                'allowEmpty' => false,
//            );
//        }
        
        return $formValidators;
        
    }
    
    
    public function getFieldsFormValidations($values) {
        $option_id = $values['profile_type'];

        $mapData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMaps('sitestore_store');
        $getRowsMatching = $mapData->getRowsMatching('option_id', $option_id);
        $fieldArray = array();
        $getFieldInfo = Engine_Api::_()->fields()->getFieldInfo();
        foreach ($getRowsMatching as $map) {
            $meta = $map->getChild();
            $type = $meta->type;
           
            $profileLabel=$meta->label;
            if (!empty($type) && ($type == 'heading'))
                continue;

           // if (!isset($meta->show) || empty($meta->show))
                //continue;

            $fieldForm = $getMultiOptions = array();
            $key = $map->getKey();

            if (!empty($meta->alias))
                $key = $key . '_' . 'alias_' . $meta->alias;
            else {
                $key = $key . '_' . 'field_' . $meta->field_id;
            }

            if (isset($meta->required) && !empty($meta->required))
                $fieldArray[$key] = array(
                    'required' => true,
                    'label'=>$profileLabel,
                    'allowEmpty' => false
                );

            if (isset($mets->validators) && !empty($mets->validators)) {
                $fieldArray[$key]['validators'] = $mets->validators;
            }
        }
        return $fieldArray;
    }


}
