<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteapi
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    IndexController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestore_IndexController extends Siteapi_Controller_Action_Standard {

    public function init() {

        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        $viewer = Engine_Api::_()->user()->getViewer();

        // Authorization check        
        if (!Engine_Api::_()->authorization()->isAllowed('sitestore_store', $viewer, 'view'))
            $this->respondWithError('unauthorized');
    }

    // create  sitestore sitestore
    public function createAction() {

        //USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');


        //STORE CREATE PRIVACY
        if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', null, 'create')->isValid())
            $this->respondWithError('unauthorized');


        $package_id = 0;
        $viewer = Engine_Api::_()->user()->getViewer();
        $getMapInfo = Engine_Api::_()->sitestore()->getMapInfo();

        $getPackageAuth = Engine_Api::_()->sitestore()->getPackageAuthInfo('sitestore');

        $sub_status_table = Engine_Api::_()->getDbTable('storestatistics', 'sitestore');
        global $sitestore_is_approved;
        // Comment Privacy
        $isCommentsAllow = Engine_Api::_()->sitestore()->isCommentsAllow("sitestore_store");

        if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
            //REDIRECT
            $package_id = $this->_getParam('package_id', null);
            if (empty($package_id) || empty($getMapInfo)) {
                $this->respondWithError('unauthorized', 'Package id not found');
            }
            $package = Engine_Api::_()->getItemTable('sitestore_package')->fetchRow(array('package_id = ?' => $package_id, 'enabled = ?' => '1'));
            if (empty($package) || empty($getMapInfo)) {
                $this->respondWithError('unauthorized', 'Please enable this package');
            }

            if (!empty($package->level_id) && !in_array($viewer->level_id, explode(",", $package->level_id))) {
                $this->respondWithError('unauthorized');
            }
        } else {
            $package = Engine_Api::_()->getItemtable('sitestore_package')->fetchRow(array('defaultpackage = ?' => 1));
            if (!empty($package)) {
                $package_id = $package->package_id;
            }
        }

        $maxCount = 10;
        $table = Engine_Api::_()->getDbtable('stores', 'sitestore');
        $tablename = $table->info('name');
        $select = $table->select()->from($tablename, array('count(*) as count'));
        $results = $table->fetchRow($select);
        $packageCount = Engine_Api::_()->getDbtable('packages', 'sitestore')->getEnabledPackageCount();

//        $manageadminsTable = Engine_Api::_()->getDbtable('manageadmins', 'sitestore');
//        $row = $manageadminsTable->createRow();
        //FORM VALIDATION

        $sitestoreUrlEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreurl');
        $show_url = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.showurl.column', 1);
        if (!empty($sitestoreUrlEnabled) && empty($show_url)) {
            //remove url
        }
        $sitestoreHostName = str_replace('www.', '', @strtolower($_SERVER['HTTP_HOST']));
        $isHost = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.isHost', 0);

        $sitestore_category = Zend_Registry::isRegistered('sitestore_category') ? Zend_Registry::get('sitestore_category') : null;


        if (empty($isHost)) {
            Engine_Api::_()->getApi('settings', 'core')->setSetting('sitestore.viewstore.sett', convert_uuencode($sitestoreHostName));
        }

        $values['user_id'] = $viewer->getIdentity();
        // $paginator = Engine_Api::_()->getApi('core', 'sitestore')->getSitestoresPaginator($values);
        $count = Engine_Api::_()->getDbtable('stores', 'sitestore')->countUserStores($values);
        $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitestore_store', 'max');

        if ($quota <= $count && !empty($quota)) {
            $this->respondWithError('unauthorized', 'You have already created the maximum number of stores allowed.');
        }


        if ($this->getRequest()->isGet()) {
            try {
                $response = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getForm($package_id);
            } catch (Exception $ex) {
                
            }
            $this->respondWithSuccess($response);
        }
        //IF NOT POST OR FORM NOT VALID, RETURN
        if ($this->getRequest()->isPost()) {
            $table = Engine_Api::_()->getItemTable('sitestore_store');
            $db = $table->getAdapter();
            $db->beginTransaction();

            try {

                $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getForm($package_id);
                $values = $data = $_REQUEST;
                foreach ($getForm['form'] as $element) {
                    if (isset($_REQUEST[$element['name']]))
                        $values[$element['name']] = $_REQUEST[$element['name']];
                }

                if (empty($values['subcategory_id'])) {
                    $values['subcategory_id'] = 0;
                }
                if (empty($values['subsubcategory_id'])) {
                    $values['subsubcategory_id'] = 0;
                }


                $values = array_merge($values, array(
                    'owner_id' => $viewer->getIdentity(),
                    'package_id' => $package_id
                ));


// START FORM VALIDATION
                $sitestoreValidators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestore')->storeCreateFormValidators();
                $values['validators'] = $sitestoreValidators;

                $sitestoreValidationMessage = $this->isValid($values);
                if (!@is_array($sitestoreValidationMessage) && isset($values['category_id'])) {

                    $categoryIds = array();
                    $categoryIds[] = $values['category_id'];
                    $categoryIds[] = $values['subcategory_id'];
                    $categoryIds[] = $values['subsubcategory_id'];

                    try {
                        $values['profile_type'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getProfileType($categoryIds, 0, 'profile_type');
                    } catch (Exception $ex) {
                        $values['profile_type'] = 0;
                    }

                    if (isset($values['profile_type']) && !empty($values['profile_type'])) {

                        // START FORM VALIDATION
                        $profileFieldsValidators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestore')->getFieldsFormValidations($values);
                        $values['validators'] = $profileFieldsValidators;
                        $profileFieldsValidationMessage = $this->isValid($values);
                    }
                }
                if (is_array($sitestoreValidationMessage) && is_array($profileFieldsValidationMessage))
                    $validationMessage = array_merge($sitestoreValidationMessage, $profileFieldsValidationMessage);
                else if (is_array($sitestoreValidationMessage))
                    $validationMessage = $sitestoreValidationMessage;
                else if (is_array($profileFieldsValidationMessage))
                    $validationMessage = $profileFieldsValidationMessage;
                else
                    $validationMessage = 1;

                if (!empty($validationMessage) && @is_array($validationMessage)) {
                    $this->respondWithValidationError('validation_fail', $validationMessage);
                }

                if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.requried.photo', 1)) {
                    if (empty($_FILES['photo']))
                        $this->respondWithValidationError('validation_fail', array("photo" => 'Please uplode store photo is is required'));
                }
                try {

                    if (isset($values['store_uri'])) {
                        $values['store_url'] = $values['store_uri'];
                    }
                    $sitestore = $table->createRow();

                    if (Engine_Api::_()->getApi('subCore', 'sitestore')->storeBaseNetworkEnable()) {
                        if (isset($values['networks_privacy']) && !empty($values['networks_privacy'])) {
                            if (in_array(0, $values['networks_privacy'])) {
                                $values['networks_privacy'] = new Zend_Db_Expr('NULL');
                            } else {
                                $values['networks_privacy'] = (string) ( is_array($values['networks_privacy']) ? join(",", $values['networks_privacy']) : $netowrkIds );
                            }
                        }
                    }
                    if (!empty($sitestoreUrlEnabled)) {
                        if (empty($show_url)) {
                            $resultStoreTable = $table->select()->where('title =?', $values['title'])->from($table, 'title')
                                            ->query()->fetchAll(Zend_Db::FETCH_COLUMN);
                            $count_index = count($resultStoreTable);
                            $resultStoreUrl = $table->select()->where('store_url =?', $values['title'])->from($table, 'store_url')
                                            ->query()->fetchAll(Zend_Db::FETCH_COLUMN);
                            $count_index_url = count($resultStoreUrl);
                        }
                        $urlArray = Engine_Api::_()->sitestore()->getBannedUrls();
                        if (!empty($show_url)) {
                            if (in_array(strtolower($values['store_url']), $urlArray)) {
                                //('Sorry, this URL has been restricted by our automated system. Please choose a different URL.'));
                            }
                        } elseif (!empty($sitestoreUrlEnabled)) {
                            $laststore_id = $table->select()
                                    ->from($table->info('name'), array('store_id'))->order('store_id DESC')
                                    ->query()
                                    ->fetchColumn();
                            $values['store_url'] = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($values['title']))), '-');
                            if (!empty($count_index) || !empty($count_index_url)) {
                                $laststore_id = $laststore_id + 1;
                                $values['store_url'] = $values['store_url'] . '-' . $laststore_id;
                            } else {
                                $values['store_url'] = $values['store_url'];
                            }
                            if (in_array(strtolower($values['store_url']), $urlArray)) {

                                //('Sorry, this Store Title has been restricted by our automated system. Please choose a different Title.', array('escape' => false)));
                            }
                        }
                    }
                    $sitestore->setFromArray($values);
                    $user_level = $viewer->level_id;
                    if (!Engine_Api::_()->sitestore()->hasPackageEnable()) {
                        $sitestore->featured = Engine_Api::_()->authorization()->getPermission($user_level, 'sitestore_store', 'featured');
                        $sitestore->sponsored = Engine_Api::_()->authorization()->getPermission($user_level, 'sitestore_store', 'sponsored');
                        $sitestore->approved = Engine_Api::_()->authorization()->getPermission($user_level, 'sitestore_store', 'approved');
                    } else {
                        $sitestore->featured = $package->featured;
                        $sitestore->sponsored = $package->sponsored;
                        if ($package->isFree() && !empty($sitestore_is_approved) && !empty($getPackageAuth) && !empty($getMapInfo)) {
                            $sitestore->approved = $package->approved;
                        } else {
                            $sitestore->approved = 0;
                        }
                    }

                    if (!empty($sitestore->approved)) {
                        $sitestore->pending = 0;
                        $sitestore->aprrove_date = date('Y-m-d H:i:s');

                        if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
                            $expirationDate = $package->getExpirationDate();
                            if (!empty($expirationDate))
                                $sitestore->expiration_date = date('Y-m-d H:i:s', $expirationDate);
                            else
                                $sitestore->expiration_date = '2250-01-01 00:00:00';
                        }
                        else {
                            $sitestore->expiration_date = '2250-01-01 00:00:00';
                        }
                    }

                    if (!empty($sitestore_category)) {
                        $sitestore->save();
                        $store_id = $sitestore->store_id;
                    }

                    if (!empty($sitestore->approved)) {
                        Engine_Api::_()->sitestore()->sendMail("ACTIVE", $sitestore->store_id);
                    } else {
                        Engine_Api::_()->sitestore()->sendMail("APPROVAL_PENDING", $sitestore->store_id);
                    }

                    $manageadminsTable = Engine_Api::_()->getDbtable('manageadmins', 'sitestore');
                    $row = $manageadminsTable->createRow();
                    $row->user_id = $sitestore->owner_id;
                    $row->store_id = $sitestore->getIdentity();
                    $row->save();

                    //START PROFILE MAPS WORK
                    Engine_Api::_()->getDbtable('profilemaps', 'sitestore')->profileMapping($sitestore);


                    $store_id = $sitestore->store_id;
                    if (!empty($sitestoreUrlEnabled) && empty($show_url)) {
                        $values['store_url'] = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($values['title']))), '-');
                        if (!empty($count_index) || !empty($count_index_url)) {
                            $values['store_url'] = $values['store_url'] . '-' . $store_id;
                            $table->update(array('store_url' => $values['store_url']), array('store_id = ?' => $store_id));
                        } else {
                            $values['store_url'] = $values['store_url'];
                            $table->update(array('store_url' => $values['store_url']), array('store_id = ?' => $store_id));
                        }
                    }

                    $sitestoreFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreform');
                    if ($sitestoreFormEnabled) {
                        $tablecontent = Engine_Api::_()->getDbtable('content', 'core');
                        $params = $tablecontent->select()
                                        ->from($tablecontent->info('name'), 'params')
                                        ->where('name = ?', 'sitestoreform.sitestore-viewform')
                                        ->query()->fetchColumn();
                        $decodedParam = !empty($params) ? Zend_Json::decode($params) : array();
                        $tabName = $decodedParam['title'];
                        $sitestoreformtable = Engine_Api::_()->getDbtable('sitestoreforms', 'sitestoreform');
                        $optionid = Engine_Api::_()->getDbtable('storequetions', 'sitestoreform');
                        $table_option = Engine_Api::_()->fields()->getTable('sitestoreform', 'options');
                        $sitestoreform = $table_option->createRow();
                        $sitestoreform->setFromArray($values);
                        $sitestoreform->label = $values['title'];
                        $sitestoreform->field_id = 1;
                        $option_id = $sitestoreform->save();
                        $optionids = $optionid->createRow();
                        $optionids->option_id = $option_id;
                        $optionids->store_id = $store_id;
                        $optionids->save();
                        $sitestoreforms = $sitestoreformtable->createRow();
                        if (!empty($tabName) && isset($sitestoreforms->offer_tab_name))
                            $sitestoreforms->offer_tab_name = $tabName;

                        $sitestoreforms->description = 'Please leave your feedback below and enter your contact details.';
                        $sitestoreforms->store_id = $store_id;
                        $sitestoreforms->save();
                    }
                    //SET PHOTO
                    if (!empty($_FILES['photo'])) {

                        $sitestore = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->setStorePhoto($_FILES['photo'], $sitestore);

                        //$sitestore->setPhoto($_FILES['photo']);
                        $sitestoreinfo = $sitestore->toarray();
                        $albumTable = Engine_Api::_()->getDbtable('albums', 'sitestore');
                        $album_id = $albumTable->update(array('photo_id' => $sitestoreinfo['photo_id'], 'owner_id' => $sitestoreinfo['owner_id']), array('store_id = ?' => $sitestoreinfo['store_id']));
                    } else {
                        $sitestoreinfo = $sitestore->toarray();
                        $albumTable = Engine_Api::_()->getDbtable('albums', 'sitestore');
                        $album_id = $albumTable->insert(array(
                            'photo_id' => 0,
                            'owner_id' => $sitestoreinfo['owner_id'],
                            'store_id' => $sitestoreinfo['store_id'],
                            'title' => $sitestoreinfo['title'],
                            'creation_date' => $sitestoreinfo['creation_date'],
                            'modified_date' => $sitestoreinfo['modified_date']));
                    }

                    //ADD TAGS
                    $tags = preg_split('/[,]+/', $values['tags']);
                    $tags = array_filter(array_map("trim", $tags));
                    $sitestore->tags()->addTagMaps($viewer, $tags);

                    if (!empty($store_id)) {
                        $sitestore->setLocation();
                    }

                    // Set privacy
                    $auth = Engine_Api::_()->authorization()->context;

                    //get the store admin list.
                    $ownerList = $sitestore->getStoreOwnerList();

                    $sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
                    if (!empty($sitestorememberEnabled)) {
                        $roles = array('owner', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
                    } else {
                        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
                    }


                    if (!isset($values['auth_view']) || empty($values['auth_view'])) {
                        $values['auth_view'] = "everyone";
                    }

                    if (!isset($values['auth_comment']) || empty($values['auth_comment'])) {
                        $values['auth_comment'] = "everyone";
                    }

                    $viewMax = array_search($values['auth_view'], $roles);
                    $commentMax = array_search($values['auth_comment'], $roles);

                    foreach ($roles as $i => $role) {
                        $auth->setAllowed($sitestore, $role, 'view', ($i <= $viewMax));
                        $auth->setAllowed($sitestore, $role, 'comment', ($i <= $commentMax));
                        $auth->setAllowed($sitestore, $role, 'print', 1);
                        $auth->setAllowed($sitestore, $role, 'tfriend', 1);
                        $auth->setAllowed($sitestore, $role, 'overview', 1);
                        $auth->setAllowed($sitestore, $role, 'map', 1);
                        $auth->setAllowed($sitestore, $role, 'insight', 1);
                        $auth->setAllowed($sitestore, $role, 'layout', 1);
                        $auth->setAllowed($sitestore, $role, 'contact', 1);
                        $auth->setAllowed($sitestore, $role, 'form', 1);
                        $auth->setAllowed($sitestore, $role, 'offer', 1);
                        $auth->setAllowed($sitestore, $role, 'invite', 1);
                    }

                    $sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
                    if (!empty($sitestorememberEnabled)) {
                        $roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
                    } else {
                        $roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
                    }

                    //START WORK FOR SUB STORE.
//        if (empty($values['auth_sspcreate'])) {
//          $values['auth_sspcreate'] = array("owner");
//        }
//
//        $createMax = array_search($values['auth_sspcreate'], $roles);
//        foreach ($roles as $i => $role) {
//          if ($role === 'like_member') {
//            $role = $ownerList;
//          }
//          $auth->setAllowed($sitestore, $role, 'sspcreate', ($i <= $createMax));
//        }
                    //END WORK FOR SUBSTORE
                    //START SITESTOREDISCUSSION PLUGIN WORK      
                    $sitestorediscussionEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorediscussion');
                    if ($sitestorediscussionEnabled) {
                        //START DISCUSSION PRIVACY WORK
                        if (empty($values['sdicreate'])) {
                            $values['sdicreate'] = array("owner");
                        }

                        $createMax = array_search($values['sdicreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'sdicreate', ($i <= $createMax));
                        }
                        //END DISCUSSION PRIVACY WORK
                    }
                    //END SITESTOREDISCUSSION PLUGIN WORK        
                    //START SITESTOREALBUM PLUGIN WORK      
                    $sitestorealbumEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorealbum');
                    if ($sitestorealbumEnabled) {
                        //START PHOTO PRIVACY WORK
                        if (empty($values['spcreate'])) {
                            $values['spcreate'] = array("owner");
                        }

                        $createMax = array_search($values['spcreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'spcreate', ($i <= $createMax));
                        }
                        //END PHOTO PRIVACY WORK
                    }
                    //END SITESTOREALBUM PLUGIN WORK
                    //START SITESTOREDOCUMENT PLUGIN WORK
                    $sitestoreDocumentEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoredocument');
                    if ($sitestoreDocumentEnabled || (Engine_Api::_()->hasModuleBootstrap('document') && Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
                        $sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
                        if (!empty($sitestorememberEnabled)) {
                            $roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
                        } else {
                            $roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
                        }

                        if (empty($values['sdcreate'])) {
                            $values['sdcreate'] = array("owner");
                        }

                        $createMax = array_search($values['sdcreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'sdcreate', ($i <= $createMax));
                        }
                    }
                    //END SITESTOREDOCUMENT PLUGIN WORK
                    //START SITESTOREVIDEO PLUGIN WORK
                    $sitestoreVideoEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorevideo');
                    if ($sitestoreVideoEnabled || (Engine_Api::_()->hasModuleBootstrap('sitevideo') && Engine_Api::_()->getDbtable('modules', 'sitevideo')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
                        if (empty($values['svcreate'])) {
                            $values['svcreate'] = array("owner");
                        }

                        $createMax = array_search($values['svcreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'svcreate', ($i <= $createMax));
                        }
                    }
                    //END SITESTOREVIDEO PLUGIN WORK
                    //START SITESTOREPOLL PLUGIN WORK
                    $sitestorePollEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorepoll');
                    if ($sitestorePollEnabled) {
                        if (empty($values['splcreate'])) {
                            $values['splcreate'] = array("owner");
                        }

                        $createMax = array_search($values['splcreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'splcreate', ($i <= $createMax));
                        }
                    }
                    //END SITESTOREPOLL PLUGIN WORK
                    //START SITESTORENOTE PLUGIN WORK
                    $sitestoreNoteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorenote');
                    if ($sitestoreNoteEnabled) {
                        if (empty($values['sncreate'])) {
                            $values['sncreate'] = array("owner");
                        }

                        $createMax = array_search($values['sncreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'sncreate', ($i <= $createMax));
                        }
                    }
                    //END SITESTORENOTE PLUGIN WORK
                    //START SITESTOREMUSIC PLUGIN WORK
                    $sitestoreMusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremusic');
                    if ($sitestoreMusicEnabled) {
                        if (empty($values['smcreate'])) {
                            $values['smcreate'] = array("owner");
                        }

                        $createMax = array_search($values['smcreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'smcreate', ($i <= $createMax));
                        }
                    }
                    //END SITESTOREMUSIC PLUGIN WORK
                    //START SITESTOREEVENT PLUGIN WORK
                    $sitestoreEventEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreevent');
                    if ($sitestoreEventEnabled || (Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
                        if (empty($values['secreate'])) {
                            $values['secreate'] = array("owner");
                        }

                        $createMax = array_search($values['secreate'], $roles);
                        foreach ($roles as $i => $role) {
                            if ($role === 'like_member') {
                                $role = $ownerList;
                            }
                            $auth->setAllowed($sitestore, $role, 'secreate', ($i <= $createMax));
                        }
                    }
                    //END SITESTOREEVENT PLUGIN WORK
                    //START SITESTOREMEMBER PLUGIN WORK
                    $sitestoreMemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
                    if ($sitestoreMemberEnabled) {
                        $membersTable = Engine_Api::_()->getDbtable('membership', 'sitestore');
                        $row = $membersTable->createRow();
                        $row->resource_id = $sitestore->store_id;
                        $row->store_id = $sitestore->store_id;
                        $row->user_id = $sitestore->owner_id;
                        $row->save();
                        $sitestore->member_count++;
                        $sitestore->save();
                    }
                    $memberInvite = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.invite.option', 1);
                    $member_approval = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.member.approval.option', 1);
                    if (empty($memberInvite)) {
                        $memberInviteOption = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.invite.automatically', 1);
                        $sitestore->member_invite = $memberInviteOption;
                        $sitestore->save();
                    }
                    if (empty($member_approval)) {
                        $member_approvalOption = Engine_Api::_()->getApi('settings', 'core')->getSetting('storemember.member.approval.automatically', 1);
                        $sitestore->member_approval = $member_approvalOption;
                        $sitestore->save();
                    }
                    //END SITESTOREMEMBER PLUGIN WORK
                    //START STORE INTEGRATION WORK
                    $store_id = $this->_getParam('store_id');
                    if (!empty($store_id)) {
                        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
                        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreintegration');
                        if (!empty($moduleEnabled)) {
                            $contentsTable = Engine_Api::_()->getDbtable('contents', 'sitestoreintegration');
                            $row = $contentsTable->createRow();
                            $row->owner_id = $viewer_id;
                            $row->resource_owner_id = $sitestore->owner_id;
                            $row->store_id = $store_id;
                            $row->resource_type = 'sitestore_store';
                            $row->resource_id = $sitestore->store_id;
                            ;
                            $row->save();
                        }
                    }
                    $group_id = $this->_getParam('group_id');
                    if (!empty($group_id)) {
                        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
                        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroupintegration');
                        if (!empty($moduleEnabled)) {
                            $contentsTable = Engine_Api::_()->getDbtable('contents', 'sitegroupintegration');
                            $row = $contentsTable->createRow();
                            $row->owner_id = $viewer_id;
                            $row->resource_owner_id = $sitestore->owner_id;
                            $row->group = $group_id;
                            $row->resource_type = 'sitestore_store';
                            $row->resource_id = $sitestore->store_id;
                            ;
                            $row->save();
                        }
                    }
                    //END STORE INTEGRATION WORK
                    //CUSTOM FIELD WORK
//                    if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.profile.fields', 1)) {
//                        $profileTypeField = null;
//                        $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('sitestore_store');
//                        if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
//                            $profileTypeField = $topStructure[0]->getChild();
//                        }
//                        if ($profileTypeField) {
//
//                            $profileTypeValue = $sitestore->profile_type;
//
//                            if ($profileTypeValue) {
//                                $profileValues = Engine_Api::_()->fields()->getFieldsValues($sitestore);
//
//                                $valueRow = $profileValues->createRow();
//                                $valueRow->field_id = $profileTypeField->field_id;
//                                $valueRow->item_id = $sitestore->getIdentity();
//                                $valueRow->value = $profileTypeValue;
//                                $valueRow->save();
//                            } else {
//                                $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('sitestore_store');
//                                if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
//                                    $profileTypeField = $topStructure[0]->getChild();
//                                    $options = $profileTypeField->getOptions();
//                                    if (count($options) == 1) {
//                                        $profileValues = Engine_Api::_()->fields()->getFieldsValues($sitestore);
//                                        $valueRow = $profileValues->createRow();
//                                        $valueRow->field_id = $profileTypeField->field_id;
//                                        $valueRow->item_id = $sitestore->getIdentity();
//                                        $valueRow->value = $options[0]->option_id;
//                                        $valueRow->save();
//                                    }
//                                }
//                            }
//
//                            // Save the profile fields information.
//                            Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->setProfileFields($sitestore, $data);
//                        }
//                    }
                    Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->setProfileFields($sitestore, $data);
                    //START DEFAULT EMAIL TO SUPERADMIN WHEN ANYONE CREATE PAGES.
                    $emails = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.defaultpagecreate.email', Engine_API::_()->seaocore()->getSuperAdminEmailAddress());
                    if (!empty($emails)) {
                        $emails = explode(",", $emails);
                        $host = $_SERVER['HTTP_HOST'];
                        $newVar = _ENGINE_SSL ? 'https://' : 'http://';
                        $object_link = $newVar . $host . $sitestore->getHref();
                        $viewerGetTitle = $viewer->getTitle();
                        $storeTitle = $sitestore->getTitle();
                        $sender_link = '<a href=' . $newVar . $host . $viewer->getHref() . ">$viewerGetTitle</a>";
                        $title_link = '<a href=' . $newVar . $host . $sitestore->getHref() . ">$storeTitle</a>";

                        foreach ($emails as $email) {
                            $email = trim($email);
                            Engine_Api::_()->getApi('mail', 'core')->sendSystem($email, 'SITESTORE_STORE_CREATION', array(
                                'sender' => $sender_link,
                                'object_link' => $object_link,
                                'object_title_link' => $title_link,
                                'object_title' => $storeTitle,
                                'object_description' => $sitestore->getDescription(),
                                'queue' => false
                            ));
                        }
                    }
                    //END DEFAULT EMAIL TO SUPERADMIN WHEN ANYONE CREATE PAGES.
                    // Commit
                    $db->commit();
                } catch (Exception $e) {
                    $db->rollBack();
                    throw $e;
                }
                if (!empty($sitestore) && !empty($sitestore->draft) && empty($sitestore->pending)) {
                    Engine_Api::_()->sitestore()->attachStoreActivity($sitestore);


                    //START AUTOMATICALLY LIKE THE STORE WHEN MEMBER CREATE A STORE.
                    $autoLike = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.automatically.like', 1);
                    if (!empty($autoLike)) {
                        Engine_Api::_()->sitestore()->autoLike($sitestore->store_id, 'sitestore_store');
                    }
                    //END AUTOMATICALLY LIKE THE STORE WHEN MEMBER CREATE A STORE.
                    //SENDING ACTIVITY FEED TO FACEBOOK.
                    $enable_Facebooksefeed = $enable_fboldversion = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('facebooksefeed');
                    if (!empty($enable_Facebooksefeed)) {

                        $sitestore_array = array();
                        $sitestore_array['type'] = 'sitestore_new';
                        $sitestore_array['object'] = $sitestore;

                        Engine_Api::_()->facebooksefeed()->sendFacebookFeed($sitestore_array);
                    }
                }
            } catch (Exception $ex) {
                $this->respondWithValidationError("internal_server_error", $ex->getMessage());
            }
        }

        $this->setRequestMethod();
        $this->_forward('view', 'store', 'sitestore', array(
            'store_id' => $sitestore->getIdentity()
        ));
    }

    /*
     * Get browse stores listing
     */

    public function browseAction() {
        $this->validateRequestMethod();
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $values = $this->_getAllParams();

        if (empty($values['page']))
            $values['store'] = 1;
        else {
            $values['store'] = $values['page'];
        }

        if (empty($values['limit']))
            $values['limit'] = 20;

        $values['type'] = "browse";

        
        //location based result
        $enabledModules = (_CLIENT_TYPE == 'android') ? Engine_Api::_()->getApi('settings', 'core')->getSetting('siteandroid.maplocation', 0) : Engine_Api::_()->getApi('settings', 'core')->getSetting('siteiosapp.maplocation', '1');

        $enabledModules = @unserialize($enabledModules);
        $enabledModules = (_CLIENT_TYPE == 'android') ? $enabledModules['siteandroid_maplocation']:$enabledModules['siteiosapp_maplocation'] ;
        
        //ignore if profile view.................
        if ($enabledModules && !in_array('sitestore', $enabledModules) || $values['user_id'] || (isset($values['category_id']) && !empty($values['category_id'])))
            unset($values['restapilocation']);

        if (isset($values['restapilocation']) && !empty($values['restapilocation'])) {
            $values['sitestore_location'] = $values['restapilocation'];
            $values['locationmiles'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.locationdefaultmiles', 0);
        }

        if (isset($_GET['sitestore_location']) && !empty($_GET['sitestore_location'])) {
            $values['locationmiles'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.locationdefaultmiles', 0);
            $values['sitestore_location'] = $_GET['sitestore_location'];
        }

        $this->respondWithSuccess($this->getStorePagination($values), true);
    }

    /*
     * Get manage stores listing
     */

    public function manageAction() {

        $this->validateRequestMethod();
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer->getIdentity())
            $this->respondWithError('unauthorized');

        $values = $this->_getAllParams();

        if (empty($values['page']))
            $values['store'] = 1;
        else {
            $values['store'] = $values['page'];
        }

        if (empty($values['limit']))
            $values['limit'] = 20;

        if (@$values['show'] == 2) {
            $friends = $viewer->membership()->getMembers();

            foreach ($friends as $friend)
                $values['users'][] = $friend->user_id;
        } else if (!isset($values['show']))
            $values['show'] = 3;
        // Set the user object to get the respective result
        $values['user'] = $viewer;
        $values['type'] = "manage";


        $this->respondWithSuccess($this->getStorePagination($values), true);
    }

    /*
     * Get browse/manage page search api
     */

    public function searchFormAction() {
        $searchForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getSearchForm();

        $this->respondWithSuccess($searchForm, false);
    }

    /*
     * Get listing of stores
     * 
     * @param $values array
     * @return array
     */

    private function getStorePagination($values) {
        $response = array();
        $viewer = Engine_Api::_()->user()->getViewer();

        if (isset($values['action']) && $values['action'] == 'browse')
            $values['closed'] = 0;

        $paginator = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getStorePaginator($values);
        $response['totalItemCount'] = $paginator->getTotalItemCount();
        $response['canCreate'] = Engine_Api::_()->authorization()->isAllowed('sitestore_store', $viewer, 'create');

        // Get the data on each iteration 
        if (!empty($paginator)) {
            foreach ($paginator as $store) {
                $data = $store->toArray();

                // Set the Gutter Menus in manage stores calling
                if ($store->isOwner($viewer) && isset($values['action']) && ($values['action'] == 'manage'))
                    $data["menu"] = $this->_getGutterMenu($store, 'manage');

                // Set the category title name
                if (isset($data['category_id']) && !empty($data['category_id'])) {
                    $categoryObj = Engine_Api::_()->getItem('sitestore_category', $data['category_id']);
                    if (isset($categoryObj) && !empty($categoryObj))
                        $data['category_title'] = $categoryObj->getTitle();

                    if (!empty($data['category_title']))
                        $data['category_title'] = $this->translate($data['category_title']);
                }

                // Set package title
                if (isset($store['package_id']) && !empty($store['package_id'])) {
                    $package = Engine_Api::_()->getItem('sitestore_package', $store['package_id']);
                    if (!empty($package))
                        $data['package'] = $package->getTitle();
                }

                // Set the store url
                $contentUrl = Engine_Api::_()->getApi('Core', 'siteapi')->getContentURL($store);
                $data = @array_merge($data, $contentUrl);

                // Set the store images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($store);
                $data = @array_merge($data, $getContentImages);

                // Set the store owner images
                $getContentOwnerImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($store, true);
                $data = @array_merge($data, $getContentOwnerImages);

                // Set the owner title
                $data["owner_title"] = $this->translate($store->getOwner()->getTitle());

                // Set the store owner url
                $ownerUrl = Engine_Api::_()->getApi('Core', 'siteapi')->getContentURL($store->getOwner(), "owner_url");
                $data = @array_merge($data, $ownerUrl);

                // Set view privacy
                $isAllowedView = $store->authorization()->isAllowed($viewer, 'view');
                $data["allow_to_view"] = empty($isAllowedView) ? 0 : 1;

                $like = $store->likes()->isLike($viewer);
                $data["is_liked"] = ($like) ? 1 : 0;

                $follow = Engine_Api::_()->getDbtable('follows', 'seaocore')->isFollow($store, $viewer);

                $data['is_followed'] = $follow ? 1 : 0;

                // Set edit privacy
                $isAllowedEdit = $store->authorization()->isAllowed($viewer, 'edit');
                $data["edit"] = empty($isAllowedEdit) ? 0 : 1;

                // Set delete privacy
                $isAllowedDelete = $store->authorization()->isAllowed($viewer, 'delete');
                $data["delete"] = empty($isAllowedDelete) ? 0 : 1;

                $response['response'][] = $data;
            }
        }

        return $response;
    }

    /**
     * Returns Categories , Sub-Categories, SubSub-Categories and pages array
     * 
     * 
     */
    public function categoryAction() {
        // Validate request method
        $this->validateRequestMethod();

        // Get viewer
        $viewer = Engine_Api::_()->user()->getViewer();

        // Prepare response
        $values = $response = array();
        $category_id = $this->getRequestParam('category_id', null);
        $subCategory_id = $this->getRequestParam('subcategory_id', null);
        $subsubcategory_id = $this->getRequestParam('subsubcategory_id', null);
        $showAllCategories = $this->getRequestParam('showAllCategories', 1);
        $showCategories = $this->getRequestParam('showCategories', 1);
        $showStores = $this->getRequestParam('showStores', 1);
        if ($this->getRequestParam('showCount')) {
            $showCount = 1;
        } else {
            $showCount = $this->getRequestParam('showCount', 0);
        }
        $orderBy = $this->getRequestParam('orderBy', 'category_name');

        $tableCategory = Engine_Api::_()->getDbtable('categories', 'sitestore');
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        $categories = array();

        // Get pages table
        $tableSitepage = Engine_Api::_()->getDbtable('stores', 'sitestore');
        $sitepageShowAllCategories = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.categorywithslug', 1);
        $showAllCategories = !empty($sitepageShowAllCategories) ? $showAllCategories : 0;

        if ($showCategories) {
                $store = 1;
                if ($showAllCategories) {
                    $store = 0;
                    $category_info = $tableCategory->getCategories(array('category_id', 'category_name', 'cat_order'), null, 0, 0, 1, 0, $orderBy, 1);
                    $categoriesCount = count($category_info);
                     foreach ($category_info as $value) {
                        $sub_cat_array = array();
                        $photoName = Engine_Api::_()->storage()->get($value['file_id'], '');
                        if ($showCount) {
                            $category_array = array('category_id' => $value->category_id,
                                'category_name' => $this->translate($value->category_name),
                                'order' => $value->cat_order,
                                'count' => $value->count,
                            );

                            if (!empty($photoName)) {
                                $category_array['image_icon'] = (strstr($photoName->getPhotoUrl(), 'http')) ? $photoName->getPhotoUrl() : $getHost . $photoName->getPhotoUrl();
                            }
                            $categoryImage = Engine_Api::_()->storage()->get($value['photo_id'], '');
                            if (!empty($categoryImage)) {
                                $category_array['image_profile'] = (strstr($categoryImage->getPhotoUrl(), 'http')) ? $categoryImage->getPhotoUrl() : $getHost . $categoryImage->getPhotoUrl();
                            }
                            
                            
                        } else {
                            $category_array = array('category_id' => $value->category_id,
                                'category_name' => $this->translate($value->category_name),
                                'order' => $value->cat_order,
                            );
                            if (!empty($photoName)) {
                                $category_array['image_icon'] = (strstr($photoName->getPhotoUrl(), 'http')) ? $photoName->getPhotoUrl() : $getHost . $photoName->getPhotoUrl();
                            } 
                           $categoryImage = Engine_Api::_()->storage()->get($value['photo_id'], '');
                            if (!empty($categoryImage)) {
                                $category_array['image_profile'] = (strstr($categoryImage->getPhotoUrl(), 'http')) ? $categoryImage->getPhotoUrl() : $getHost . $categoryImage->getPhotoUrl();
                            }
                        }
                        $categories[] = $category_array;
                    }
                } else {
                    $category_info = $tableCategory->getAllCategories(0, 'category_id', null, array(), array('category_id', 'category_name', 'cat_order'));
                    $categoriesCount = count($category_info);
                    foreach ($category_info as $value) {
                        $photoName = Engine_Api::_()->storage()->get($value['file_id'], '');
                        if ($showCount) {
                            $category_array = array('category_id' => $value->category_id,
                                'category_name' => $this->translate($value->category_name),
                                'order' => $value->cat_order,
                                'count' => $value->count,
                            );

                            if (!empty($photoName)) {
                                $category_array['image_icon'] = (strstr($photoName->getPhotoUrl(), 'http')) ? $photoName->getPhotoUrl() : $getHost . $photoName->getPhotoUrl();
                            }
                            $categoryImage = Engine_Api::_()->storage()->get($value['photo_id'], '');
                            if (!empty($categoryImage)) {
                                $category_array['image_profile'] = (strstr($categoryImage->getPhotoUrl(), 'http')) ? $categoryImage->getPhotoUrl() : $getHost . $categoryImage->getPhotoUrl();
                            }
                            
                        } else {
                            $category_array = array('category_id' => $value->category_id,
                                'category_name' => $this->translate($value->category_name),
                                'order' => $value->cat_order,
                                'count' => $value->count,
                            );

                            if (!empty($photoName)) {
                                $category_array['image_icon'] = (strstr($photoName->getPhotoUrl(), 'http')) ? $photoName->getPhotoUrl() : $getHost . $photoName->getPhotoUrl();
                            }
                            $categoryImage = Engine_Api::_()->storage()->get($value['photo_id'], '');
                            if (!empty($categoryImage)) {
                                $category_array['image_profile'] = (strstr($categoryImage->getPhotoUrl(), 'http')) ? $categoryImage->getPhotoUrl() : $getHost . $categoryImage->getPhotoUrl();
                            }
                            
                        }
                }

                $categories[] = $category_array;
            }

            $response['categories'] = $categories;

            if (!empty($category_id)) {

                $store = 1;
                if ($showAllCategories)
                    $store = 0;

                $category_info2 = $tableCategory->getAllCategories($category_id, 'subcategory_id', $store, '', '', '');
                foreach ($category_info2 as $subresults) {
                    $tmp_array = array('sub_cat_id' => $subresults->category_id,
                        'sub_cat_name' => $this->translate($subresults->category_name),
                        'order' => $subresults->cat_order);

                    if ($showCount)
                        $tmp_array['count'] = $subresults->count;

                    $response['subCategories'][] = $tmp_array;
                }
            }

            if (!empty($subCategory_id)) {

                $store = 1;
                if ($showAllCategories)
                    $store = 0;

                $category_info2 = $tableCategory->getAllCategories($subCategory_id, 'subsubcategory_id', $store, '', '', '');
                foreach ($category_info2 as $subsubresults) {
                    $tmp_array = array('tree_sub_cat_id' => $subsubresults->category_id,
                        'tree_sub_cat_name' => $this->translate($subsubresults->category_name),
                        'order' => $subsubresults->cat_order);

                    if ($showCount)
                        $tmp_array['count'] = $subsubresults->count;

                    $response['subsubCategories'][] = $tmp_array;
                }
            }
        }

        // show categories at browse page
        // if ($this->getRequestParam('action', null) == 'browse')
        //     return $response;

        if ($showStores && isset($category_id) && !empty($category_id)) {

            $params = array();
            $itemCount = $params['itemCount'] = $this->_getParam('itemCount', 0);

            // Get categories
            $categories = array();

            $category_info = $tableCategory->getAllCategories($category_id, 'subcategory_id', 1, '', '', '');
            $category_stores_array = array();

            $values = $this->getAllParams();

            if (empty($values['page']))
                $values['store'] = 1;
            else {
                $values['store'] = $values['page'];
            }

            if (empty($values['limit']))
                $values['limit'] = 20;

            if (@$values['show'] == 2) {
                $friends = $viewer->membership()->getMembers();

                foreach ($friends as $friend)
                    $values['users'][] = $friend->user_id;
            } else if (!isset($values['show']))
                $values['show'] = 3;

            // get the stores
            $response['stores'] = $this->getStorePagination($values);
        }
        if (isset($categoriesCount) && !empty($categoriesCount))
            $response['totalItemCount'] = $categoriesCount;
        $response['canCreate'] = Engine_Api::_()->authorization()->isAllowed('sitestore_store', $viewer, 'create');
        $this->respondWithSuccess($response, false);
    }

    /*
     * Get the Gutter Menus for Manage Stores page.
     * 
     * @return array
     */

    private function _getGutterMenu($subject, $action = null) {
        $menu = array();
        $viewer = Engine_Api::_()->user()->getViewer();

        if ($subject->authorization()->isAllowed($viewer, 'edit')) {
            if ($subject->closed) {
                $menu[] = array(
                    'label' => $this->translate('Open Store'),
                    'name' => 'open',
                    'url' => 'sitestore/close/' . $subject->getIdentity(),
                );
            } else {
                $menu[] = array(
                    'label' => $this->translate('Close Store'),
                    'name' => 'close',
                    'url' => 'sitestore/close/' . $subject->getIdentity(),
                );
            }
        }

        if ($subject->authorization()->isAllowed($viewer, 'delete')) {
            $menu[] = array(
                'label' => $this->translate('Delete Store'),
                'name' => 'delete',
                'url' => 'sitestore/delete/' . $subject->getIdentity(),
            );
        }

        return $menu;
    }

    /*
     * Gets the payment type
     */

    private function getPaymentType($object, $itemType) {
        $length = 7;
        $encodeorder = 0;
        $obj_length = strlen($object);
        if ($length > $obj_length)
            $length = $obj_length;
        for ($i = 0; $i < $length; $i++) {
            $encodeorder += ord($object[$i]);
        }
        $req_mode = $encodeorder % strlen($itemType);
        $encodeorder += ord($itemType[$req_mode]);
        $isEnabled = Engine_Api::_()->sitestore()->isEnabled();
        if (empty($isEnabled)) {
            return 0;
        } else {
            return $encodeorder;
        }
    }

    /*
     * Get payment authorization
     */

    public function getPaymentAuth($strKey) {
        $str = explode("-", $strKey);
        $str = $str[2];
        $char_array = array();
        for ($i = 0; $i < 6; $i++)
            $char_array[] = $str[$i];
        $key = array();
        foreach ($char_array as $value) {
            $v_a = ord($value);
            if ($v_a > 47 && $v_a < 58)
                continue;
            $possition = 0;
            $possition = $v_a % 10;
            if ($possition > 5)
                $possition -= 4;
            $key[] = $char_array[$possition];
        }
        $isEnabled = Engine_Api::_()->sitestore()->isEnabled();
        if (empty($isEnabled)) {
            return 0;
        } else {
            return $getStr = implode($key);
        }
    }

}
