<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteapi
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    IndexController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestore_StoreController extends Siteapi_Controller_Action_Standard {

	public function init() {
		if (!Zend_Registry::isRegistered('Zend_Translate')) {
			Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
		}

		Engine_Api::_()->getApi('Core', 'siteapi')->setView();

		$viewer = Engine_Api::_()->user()->getViewer();

		if ($this->getRequestParam("store_id") && (0 !== ($store_id = (int) $this->getRequestParam("store_id")) &&
                null !== ($store = Engine_Api::_()->getItem('sitestore_store', $store_id)))) {
            Engine_Api::_()->core()->setSubject($store);
        }
        else if ($this->getRequestParam("store_id") && (null !== ($store_url = (string) $this->getRequestParam("store_id")))) {
            $store = Engine_Api::_()->getApi('Core','siteapi')->getSubjectByModuleUrl('sitestore','stores','store_url',$store_url); 
            Engine_Api::_()->core()->setSubject($store);
        }

		// Authorization check
		if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', $viewer, "view")->isValid()) {
			$this->respondWithError('unauthorized');
		}

	}

	/*
		     * Get store view
	*/

	public function viewAction() {

		$viewer = Engine_Api::_()->user()->getViewer();

		$this->validateRequestMethod();

		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		$response = $subject->toArray();

		// Set the store url
		$contentUrl = Engine_Api::_()->getApi('Core', 'siteapi')->getContentURL($subject);
		$response = @array_merge($response, $contentUrl);

		$like = $subject->likes()->isLike($viewer);
		$response["is_liked"] = ($like) ? 1 : 0;

		$follow = Engine_Api::_()->getDbtable('follows', 'seaocore')->isFollow($subject, $viewer);

		$response['is_followed'] = $follow ? 1 : 0;

		$response['owner_title'] = $subject->getOwner()->getTitle();

		// Set the store images
		$getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($subject);
		$response = array_merge($response, $getContentImages);

		// Set the store owner images
		$getContentOwnerImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($subject, true);
		$response = array_merge($response, $getContentOwnerImages);

		//Advanced video integration..........................
		if (method_exists('Siteapi_Api_Core', 'isSitevideoPluginEnabled')) {
			$subject_type = $subject->getType();
			$subject_id = $subject->getIdentity();
			$advVideoEnableArray = Engine_Api::_()->getApi('Core', 'siteapi')->isSitevideoPluginEnabled($subject_type, $subject_id);
			if (!empty($advVideoEnableArray) && is_array($advVideoEnableArray)) {
				$response = array_merge($response, $advVideoEnableArray);
			} else {
				$response['sitevideoPluginEnabled'] = 0;
			}
		} else {
			$response['sitevideoPluginEnabled'] = 0;
		}

		//end of  Advanced video integration work..........................
		// Set the gutter menus
		$response['gutterMenu'] = $this->_getGutterMenu($subject);
		$response = array_merge($response, Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getInformation($subject));

		// Set the profile tabs
		$response['profileTabs'] = $this->_getProfileTabs($subject);
		$overview = $response['overview'];
		if (!empty($overview)) {
			$staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
			$serverHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
			$getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
			$getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();

			$this->getHost = '';
			if ($getDefaultStorageType == 'local') {
				$this->getHost = !empty($staticBaseUrl) ? $staticBaseUrl : $serverHost;
			}

			$response['overview'] = str_replace('src="/', 'src="' . $this->getHost . '/', $overview);
			$response['overview'] = str_replace('"', "'", $response['overview']);
		}
		$response['overview'] = ($response['overview']) ? $this->translate($response['overview']) : "";

		$this->respondWithSuccess($response);
	}

	//ACTION FOR STORE EDI
	public function editAction() {

		//USER VALDIATION
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
		$getMapInfo = Engine_Api::_()->sitestore()->getMapInfo();
		$store_id = $this->_getParam('store_id');
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		$getPackageAuth = Engine_Api::_()->sitestore()->getPackageAuthInfo('sitestore');
		$sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
		$previous_category_id = $sitestore->category_id;

		// Comment Privacy
		$isCommentsAllow = Engine_Api::_()->sitestore()->isCommentsAllow("sitestore_store");
		//$previous_location = $sitestore->location;

		$ownerList = $sitestore->getStoreOwnerList();

		if (empty($sitestore) || empty($getMapInfo)) {
			$this->respondWithError('unauthorized');
		}

		//START MANAGE-ADMIN CHECK
		$isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'edit');
		if (empty($isManageAdmin) || empty($getMapInfo)) {
			$this->respondWithError('unauthorized');
		}
		//END MANAGE-ADMIN CHECK
		$owner_id = $sitestore->owner_id;
		$user_subject = Engine_Api::_()->user()->getUser($owner_id);
		//FORM GENERATION

		$show_url = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.showurl.column', 1);
		$edit_url = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.edit.url', 0);
		$sitestoreUrlEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreurl');

		$category_id = $sitestore->category_id;
		$subcategory_id = $sitestore->subcategory_id;
		$subsubcategory_id = $sitestore->subsubcategory_id;
		$row = Engine_Api::_()->getDbTable('categories', 'sitestore')->getCategory($subcategory_id);
		if (!empty($row->category_name)) {
			$subcategory_name = $row->category_name;
		}

		$sitestoreFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreform');
		if ($sitestoreFormEnabled) {
			$quetion = Engine_Api::_()->getDbtable('storequetions', 'sitestoreform');
			$select_quetion = $quetion->select()->where('store_id = ?', $store_id);
			$result_quetion = $quetion->fetchRow($select_quetion);
			$option_id = $result_quetion->option_id;
		}

		$values['user_id'] = $viewer_id;

		//SAVE SITESTORE ENTRY
		if ($this->getRequest()->isGet()) {
			$form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getForm($sitestore->package_id, $user_subject, 1, $sitestore);
			$form['formValues'] = $sitestore->toArray();
			$form['canEditCategory'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.category.edit', 0);
			// prepare tags
			$sitestoreTags = $sitestore->tags()->getTagMaps();
			$tagString = '';

			foreach ($sitestoreTags as $tagmap) {

				if ($tagString !== '') {
					$tagString .= ', ';
				}

				$tagString .= $tagmap->getTag()->getTitle();
			}

			$form['formValues']['tags'] = $tagString;

			$auth = Engine_Api::_()->authorization()->context;
			$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
			if (!empty($sitestorememberEnabled)) {
				$roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			} else {
				$roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			}

			foreach ($roles as $roleString) {
				$role = $roleString;

				if (1 == $auth->isAllowed($sitestore, $role, 'view')) {
					$form['formValues']['auth_view'] = $roleString;
				}

				if (1 == $auth->isAllowed($sitestore, $role, 'comment')) {
					$form['formValues']['auth_comment'] = $roleString;
				}

				if ($role == 'everyone') {
					continue;
				}

				if ($role === 'like_member') {
					$role = $ownerList;
				}

				//Here we change isAllowed function for like privacy work only for populate.
				$sitestoreAllow = Engine_Api::_()->getApi('allow', 'sitestore');
//        if ($form->auth_sspcreate && 1 == $sitestoreAllow->isAllowed($sitestore, $role, 'sspcreate')) {
				//          $form->auth_sspcreate->setValue($roleString);
				//        }
				// PHOTO PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'spcreate')) {
					$form['formValues']['spcreate'] = $roleString;
				}
				// DISCUSSION PRIVACY WORK
				if ($sitestoreAllow->isAllowed($sitestore, $role, 'sdicreate')) {
					$form['formValues']['sdicreate'] = $roleString;
				}
				//SITESTOREDOCUMENT PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'sdcreate')) {
					$form['formValues']['sdcreate'] = $roleString;
				}
				// SITESTOREVIDEO PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'svcreate')) {
					$form['formValues']['svcreate'] = $roleString;
				}
				//START SITESTOREPOLL PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'splcreate')) {
					$form['formValues']['splcreate'] = $roleString;
				}
				//START SITESTORENOTE PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'sncreate')) {
					$form['formValues']['sncreate'] = $roleString;
				}
				//START SITESTOREMUSIC PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'smcreate')) {
					$form['formValues']['smcreate'] = $roleString;
				}
				//START SITESTOREEVENT PRIVACY WORK
				if (1 == $sitestoreAllow->isAllowed($sitestore, $role, 'secreate')) {
					$form['formValues']['secreate'] = $roleString;
				}
			}

			if (Engine_Api::_()->getApi('subCore', 'sitestore')->storeBaseNetworkEnable()) {
				if (!empty($sitestore->networks_privacy)) {
					$form['formValues']['networks_privacy'] = (explode(',', $sitestore->networks_privacy));
				} else {
					$form['formValues']['networks_privacy'] = array(0);
				}
			}

			//cagegory profile field level form work..................
			$form['formValues']['fieldCategoryLevel'] = "";
			$categoryTable = Engine_Api::_()->getDbTable('categories', 'sitestore');
			if (isset($sitestore->category_id) && !empty($sitestore->category_id)) {
				$categoryObject = $categoryTable->getCategory($sitestore->category_id);

				if (!empty($categoryObject)) {
					$form['formValues']['fieldCategoryLevel'] = "category_id";
				}
			}

			if (isset($sitestore->subcategory_id) && !empty($sitestore->subcategory_id)) {
				$categoryObject = $categoryTable->getCategory($sitestore->subcategory_id);
				if (!empty($categoryObject)) {
					$form['formValues']['fieldCategoryLevel'] = "subcategory_id";
				}
			}

			if (isset($sitestore->subsubcategory_id) && !empty($sitestore->subsubcategory_id)) {
				$categoryObject = $categoryTable->getCategory($sitestore->subsubcategory_id);
				if (!empty($categoryObject)) {
					$form['formValues']['fieldCategoryLevel'] = "subsubcategory_id";
				}
			}
			$profileInfo = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getProfileInfo($sitestore, true);
			if (!empty($profileInfo)) {
				$form['formValues'] = @array_merge($form['formValues'], $profileInfo);
			}
			// end of field level work....................................

			$this->respondWithSuccess($form);
		}

		// handle save for tags
		$data = $values = $_REQUEST;

		$getForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getForm($package_id, $user_subject, 1,$sitestore);
		$values = $data = $_REQUEST;
		foreach ($getForm['form'] as $element) {
			if (isset($_REQUEST[$element['name']])) {
				$values[$element['name']] = $_REQUEST[$element['name']];
			}

		}

		if (empty($values['subcategory_id'])) {
			$values['subcategory_id'] = 0;
		}
		if (empty($values['subsubcategory_id'])) {
			$values['subsubcategory_id'] = 0;
		}

		$values = array_merge($values, array(
			'owner_id' => $viewer->getIdentity(),
			'package_id' => $package_id,
		));

// START FORM VALIDATION
		$sitestoreValidators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestore')->storeCreateFormValidators();
		$values['validators'] = $sitestoreValidators;

		$sitestoreValidationMessage = $this->isValid($values);
		if (!@is_array($sitestoreValidationMessage) && isset($values['category_id'])) {

			$categoryIds = array();
			$categoryIds[] = $values['category_id'];

			if (!empty($values['subcategory_id'])) {
				$categoryIds[] = $values['subcategory_id'];
			}

			if (!empty($values['subsubcategory_id'])) {
				$categoryIds[] = $values['subsubcategory_id'];
			}

			try {
				$values['profile_type'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getProfileType($categoryIds, 0, 'profile_type');
			} catch (Exception $ex) {
				$values['profile_type'] = 0;
			}

			if (isset($values['profile_type']) && !empty($values['profile_type'])) {

				// START FORM VALIDATION
				$profileFieldsValidators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestore')->getFieldsFormValidations($values);
				$values['validators'] = $profileFieldsValidators;
				$profileFieldsValidationMessage = $this->isValid($values);
			}
		}
		if (is_array($sitestoreValidationMessage) && is_array($profileFieldsValidationMessage)) {
			$validationMessage = array_merge($sitestoreValidationMessage, $profileFieldsValidationMessage);
		} else if (is_array($sitestoreValidationMessage)) {
			$validationMessage = $sitestoreValidationMessage;
		} else if (is_array($profileFieldsValidationMessage)) {
			$validationMessage = $profileFieldsValidationMessage;
		} else {
			$validationMessage = 1;
		}

		if (!empty($validationMessage) && @is_array($validationMessage)) {
			$this->respondWithValidationError('validation_fail', $validationMessage);
		}

		if (!empty($sitestoreUrlEnabled) && !empty($show_url) && !empty($edit_url)) {
			$change_url = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.change.url', 1);
			$urlArray = Engine_Api::_()->sitestore()->getBannedUrls();
			$sitestoreTable = Engine_Api::_()->getDbtable('stores', 'sitestore');
			$selectTable = $sitestoreTable->select()->where('store_id != ?', $store_id)
				->where('store_url = ?', $values['store_url']);
			$resultSitestoreTable = $sitestoreTable->fetchAll($selectTable);
			if (count($resultSitestoreTable) || (in_array(strtolower($values['store_url']), $urlArray)) && (!empty($change_url))) {
				//validation error message
			}
		} elseif (!empty($sitestoreUrlEnabled) && empty($show_url)) {
			$urlArray = Engine_Api::_()->sitestore()->getBannedUrls();
			$table = Engine_Api::_()->getDbtable('stores', 'sitestore');
			$resultStoreTable = $table->select()->where('title =?', $values['title'])->from($table, 'title')
				->query()->fetchAll(Zend_Db::FETCH_COLUMN);
			$count_index = count($resultStoreTable);
			$resultStoreUrl = $table->select()->where('store_url =?', $values['title'])->from($table, 'store_url')
				->query()->fetchAll(Zend_Db::FETCH_COLUMN);
			$count_index_url = count($resultStoreUrl);

			if (empty($count_index)) {
				$values['store_url'] = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($values['title']))), '-');
				if (!empty($count_index) || !empty($count_index_url)) {
					$values['store_url'] = $values['store_url'] . '-' . $store_id;
				} else {
					$values['store_url'] = $values['store_url'];
				}
				if (in_array(($values['store_url']), $urlArray)) {

					//vallidation error message'This Store title has been blocked by our automated system. Please choose another title.';
				}
			}
		}

		$is_error = 0;
		Engine_Api::_()->getItemtable('sitestore_package')->setPackages();
		if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.category.edit', 0) && !empty($sitestore->category_id)) {
			$values['category_id'] = $sitestore->category_id;
			$values['subcategory_id'] = $sitestore->subcategory_id;
			$values['subsubcategory_id'] = $sitestore->subsubcategory_id;
		}

		$values['package_id'] = $sitestore->package_id;

		if ($sitestoreFormEnabled) {
			$sitestoreform_form = Engine_Api::_()->getDbtable('sitestoreforms', 'sitestoreform');
			$quetion = Engine_Api::_()->getDbtable('storequetions', 'sitestoreform');
			$select_quetion = $quetion->select()->where('store_id = ?', $store_id);
			$result_quetion = $quetion->fetchRow($select_quetion);
			if (!empty($result_quetion)) {
				$option_id = $result_quetion->option_id;
				$table_option = Engine_Api::_()->fields()->getTable('sitestoreform', 'options');
				$table_option->update(array('label' => $values['title']), array('option_id = ?' => $result_quetion->option_id));
			}
		}

		$tags = preg_split('/[,]+/', $values['tags']);
		$tags = array_filter(array_map("trim", $tags));

		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		try {
			if (Engine_Api::_()->getApi('subCore', 'sitestore')->storeBaseNetworkEnable()) {

				if (isset($values['networks_privacy']) && !empty($values['networks_privacy'])) {
					if (in_array(0, $values['networks_privacy'])) {
						$values['networks_privacy'] = new Zend_Db_Expr('NULL');
					} else {
						$values['networks_privacy'] = (string) (is_array($values['networks_privacy']) ? join(",", $values['networks_privacy']) : $netowrkIds);
					}
				}
			}

			// WORK FOR ENABLE/DISABLE OF ALL THE PRODUCTS OF THIS STORE
			if (isset($sitestore->search) && $sitestore->search != $values['search']) {
				if (array_key_exists('toggle_products_status', $values) && $values['toggle_products_status']) {
					Engine_Api::_()->getDbtable('stores', 'sitestore')->toggleStoreProductsStatus($store_id, $values['search']);
				}
			}
			$sitestore->setFromArray($values);
			$sitestore->modified_date = date('Y-m-d H:i:s');

			$sitestore->tags()->setTagMaps($viewer, $tags);
			$sitestore->save();

			$location = $sitestore->location;

//       if ($previous_location && (empty($previous_location) || ($location !== $previous_location))) {
			//         $locationTable = Engine_Api::_()->getDbtable('locations', 'sitestore');
			//         $locationTable->delete(array('store_id =?' => $store_id, 'location =?' => $previous_location));
			//       }
			//       if (!empty($location) && $location !== $previous_location) {
			//         $sitestore->setLocation();
			//       }

			/* else {
				              $locationTable->delete(arr ay(
				              'store_id =?' => $store_id
				              ));
			*/
			//CREATE AUTH STUFF HERE
			$auth = Engine_Api::_()->authorization()->context;
			$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
			if (!empty($sitestorememberEnabled)) {
				$roles = array('owner', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			} else {
				$roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			}

			if ($values['auth_view']) {
				$auth_view = $values['auth_view'];
			} else {
				$auth_view = "everyone";
			}

			$viewMax = array_search($auth_view, $roles);

			foreach ($roles as $i => $role) {
				$auth->setAllowed($sitestore, $role, 'view', ($i <= $viewMax));
			}

			$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
			if (!empty($sitestorememberEnabled)) {
				$roles = array('owner', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			} else {
				$roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			}

			if ($values['auth_comment']) {
				$auth_comment = $values['auth_comment'];
			} else {
				$auth_comment = "everyone";
			}

			$commentMax = array_search($auth_comment, $roles);

			foreach ($roles as $i => $role) {
				$auth->setAllowed($sitestore, $role, 'comment', ($i <= $commentMax));
			}

			$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
			if (!empty($sitestorememberEnabled)) {
				$roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			} else {
				$roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
			}

			//START WORK FOR SUB STORE.
			//      if ($values['auth_sspcreate'])
			//        $substore = $values['auth_sspcreate'];
			//      else
			//        $substore = "owner";
			//      $substoreMax = array_search($substore, $roles);
			//
			//      foreach ($roles as $i => $role) {
			//        if ($role === 'like_member') {
			//          $role = $ownerList;
			//        }
			//        $auth->setAllowed($sitestore, $role, 'sspcreate', ($i <= $substoreMax));
			//      }
			//END WORK FOR SUBSTORE
			//START DISCUSSION PRIVACY WORK
			$sitestorediscussionEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorediscussion');
			if ($sitestorediscussionEnabled) {
				if ($values['sdicreate']) {
					$photo = $values['sdicreate'];
				} else {
					$photo = "owner";
				}

				$photoMax = array_search($photo, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'sdicreate', ($i <= $photoMax));
				}
			}
			//END DISCUSSION PRIVACY WORK
			//START PHOTO PRIVACY WORK
			$sitestorealbumEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorealbum');
			if ($sitestorealbumEnabled) {
				if ($values['spcreate']) {
					$photo = $values['spcreate'];
				} else {
					$photo = "owner";
				}

				$photoMax = array_search($photo, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'spcreate', ($i <= $photoMax));
				}
			}
			//END PHOTO PRIVACY WORK
			//START SITESTOREDOCUMENT WORK
			$sitestoreDocumentEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoredocument');
			if ($sitestoreDocumentEnabled || (Engine_Api::_()->hasModuleBootstrap('document') && Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {

				if ($values['sdcreate']) {
					$sdcreate = $values['sdcreate'];
				} else {
					$sdcreate = "owner";
				}

				$sdcreateMax = array_search($sdcreate, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'sdcreate', ($i <= $sdcreateMax));
				}
			}
			//END SITESTOREDOCUMENT WORK
			//START SITESTOREVIDEO WORK
			$sitestoreVideoEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorevideo');
			if ($sitestoreVideoEnabled || (Engine_Api::_()->hasModuleBootstrap('sitevideo') && Engine_Api::_()->getDbtable('modules', 'sitevideo')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
				if ($values['svcreate']) {
					$svcreate = $values['svcreate'];
				} else {
					$svcreate = "owner";
				}

				$svcreateMax = array_search($svcreate, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'svcreate', ($i <= $svcreateMax));
				}
			}
			//END SITESTOREVIDEO WORK
			//START SITESTOREPOLL WORK
			$sitestorePollEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorepoll');
			if ($sitestorePollEnabled) {
				if ($values['splcreate']) {
					$splcreate = $values['splcreate'];
				} else {
					$splcreate = "owner";
				}

				$splcreateMax = array_search($splcreate, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'splcreate', ($i <= $splcreateMax));
				}
			}
			//END SITESTOREPOLL WORK
			//START SITESTORENOTE WORK
			$sitestoreNoteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorenote');
			if ($sitestoreNoteEnabled) {
				$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
				if (!empty($sitestorememberEnabled)) {
					$roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
				} else {
					$roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
				}
				if ($values['sncreate']) {
					$sncreate = $values['sncreate'];
				} else {
					$sncreate = "owner";
				}

				$sncreateMax = array_search($sncreate, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'sncreate', ($i <= $sncreateMax));
				}
			}
			//END SITESTORENOTE WORK
			//START SITESTOREMUSIC WORK
			$sitestoreMusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremusic');
			if ($sitestoreMusicEnabled) {
				$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
				if (!empty($sitestorememberEnabled)) {
					$roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
				} else {
					$roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
				}

				if ($values['smcreate']) {
					$smcreate = $values['smcreate'];
				} else {
					$smcreate = "owner";
				}

				$smcreateMax = array_search($smcreate, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'smcreate', ($i <= $smcreateMax));
				}
			}
			//END SITESTORENOTE WORK
			//START SITESTOREEVENT WORK
			$sitestoreEventEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreevent');
			if ($sitestoreEventEnabled || (Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitestore_store', 'item_module' => 'sitestore')))) {
				$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
				if (!empty($sitestorememberEnabled)) {
					$roles = array('owner', 'like_member', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
				} else {
					$roles = array('owner', 'like_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
				}
				if ($values['secreate']) {
					$secreate = $values['secreate'];
				} else {
					$secreate = "owner";
				}

				$secreateMax = array_search($secreate, $roles);

				foreach ($roles as $i => $role) {
					if ($role === 'like_member') {
						$role = $ownerList;
					}
					$auth->setAllowed($sitestore, $role, 'secreate', ($i <= $secreateMax));
				}
			}

			//END SITEPAGEEVENT WORK
			//START SITESTOREREVIEW CODE
			$sitestoreReviewEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorereview');
			if ($sitestoreReviewEnabled && $previous_category_id != $sitestore->category_id) {
				Engine_Api::_()->getDbtable('ratings', 'sitestorereview')->editStoreCategory($sitestore->store_id, $previous_category_id, $sitestore->category_id);
			}
			//END SITESTOREREVIEW CODE
			//START SITESTOREMEMBER CODE
			$sitestorememberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoremember');
			if ($sitestorememberEnabled && $previous_category_id != $sitestore->category_id) {
				$db->query("UPDATE `engine4_sitestore_membership` SET `role_id` = '0' WHERE `engine4_sitestore_membership`.`store_id` = " . $sitestore->store_id . ";");
			}
			//END SITESTOREMEMBER CODE
			//START PROFILE MAPPING WORK IF CATEGORY IS EDIT
			if ($previous_category_id != $sitestore->category_id) {
				Engine_Api::_()->getDbtable('profilemaps', 'sitestore')->editCategoryMapping($sitestore);
			}

			//END PROFILE MAPPING WORK IF CATEGORY IS EDIT
			//INSERT ACTIVITY IF STORE IS JUST GETTING PUBLISHED
			$action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($sitestore);
			if (count($action->toArray()) <= 0 && isset($values['draft']) && $values['draft'] == '1' && empty($sitestore->pending)) {
				Engine_Api::_()->sitestore()->attachStoreActivity($sitestore);
			}
			$db->commit();

			if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.category.edit', 0) && !empty($sitestore->category_id)) {

				$category_id = $sitestore->category_id;
				$subcategory_id = $subcategory_id = $sitestore->subcategory_id;
				$table = Engine_Api::_()->getDbtable('categories', 'sitestore');
				$categoriesName = $table->info('name');

				$select = $table->select()->from($categoriesName, 'category_name')
					->where("(category_id = $subcategory_id)");

				$row = $table->fetchRow($select);
			} else {
				$category_id = $sitestore->category_id;
				$subcategory_id = $sitestore->subcategory_id;
				$subsubcategory_id = $sitestore->subsubcategory_id;
				$table = Engine_Api::_()->getDbtable('categories', 'sitestore');
				$categoriesName = $table->info('name');
				$select = $table->select()->from($categoriesName, 'category_name')
					->where("(category_id = $subcategory_id)");

				$row = $table->fetchRow($select);
			}
		} catch (Exception $e) {
			$db->rollBack();
			throw $e;
		}
		$db->beginTransaction();
		try {
			$actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
			foreach ($actionTable->getActionsByObject($sitestore) as $action) {
				$actionTable->resetActivityBindings($action);
			}
			$db->commit();

			$this->successResponseNoContent('no_content', true);
		} catch (Exception $e) {
			$db->rollBack();
		}
	}
	/*
		     * Gutter Menu: Open / Close store
	*/

	public function closeAction() {
		$viewer = Engine_Api::_()->user()->getViewer();
		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		$this->validateRequestMethod("POST");
		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		try {
			$sitestore->closed = !$sitestore->closed;
			$sitestore->save();
			$db->commit();
			$this->successResponseNoContent('no_content');
		} catch (Exception $ex) {
			$this->respondWithValidationError('internal_server_error', $ex->getMessage());
		}
	}

	/*
		     * delete Store
	*/

	public function deleteAction() {
		$viewer = Engine_Api::_()->user()->getViewer();

		// Require user
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		$this->validateRequestMethod("DELETE");

		// Start manage-admin check
		$isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'delete');
		if (empty($isManageAdmin)) {
			$this->respondWithError('unauthorized');
		}

		// End manage-admin check

		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		try {
			Engine_Api::_()->sitestore()->onStoreDelete($sitestore->getIdentity());
			$db->commit();
			$this->successResponseNoContent('no_content');
		} catch (Exception $ex) {
			$this->respondWithValidationError('internal_server_error', $ex->getMessage());
		}
	}

	/*
		     * Tabbed: Get store information
	*/

	public function informationAction() {
		$this->validateRequestMethod();

		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		try {
			$getProfileInfo = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getInformation($subject);

			if (isset($_REQUEST['field_order']) && !empty($_REQUEST['field_order'])) {
				foreach ($getProfileInfo as $key => $value) {
					$getProfileInfo[$key] = Engine_Api::_()->getApi('Core', 'siteapi')->responseFormat($value);
				}
				$getProfileInfo = Engine_Api::_()->getApi('Core', 'siteapi')->responseFormat($getProfileInfo);
			}
			$this->respondWithSuccess($getProfileInfo);
		} catch (Exception $ex) {
			$this->respondWithValidationError('internal_server_error', $ex->getMessage());
		}
	}

	/*
		     * Overview of Store
	*/

	public function overviewAction() {

		$viewer = Engine_Api::_()->user()->getViewer();

		// Require user
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$this->validateRequestMethod();

		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		$this->respondWithSuccess($this->translate($subject->overview));
	}

	/*
		     * Photo Controller
	*/

	public function albumAction() {
		$tempResponse = array();
		$viewer = Engine_Api::_()->user()->getViewer();

		// Require user
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		$this->validateRequestMethod();

		$albums = Engine_Api::_()->getDbtable('albums', 'sitestore')->getAlbums($subject);

		$response = array();
		$response['totalItemCount'] = $albums->count();

		if ($albums) {
			foreach ($albums as $row => $album) {
				$data = $album->toArray();
				$data = array_merge($data, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($album));
				$data = array_merge($data, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($album, true));
				$data['photoCount'] = Engine_Api::_()->getDbtable('photos', 'sitestore')->getPhotosCount(array('album_id' => $album->getIdentity()));
				$tempResponse[] = $data;
			}
			$response['response'] = $tempResponse;
		}

		$this->respondWithSuccess($response);
	}

	/*
		     * Invite Via Email
	*/

	public function inviteAction() {
		// Get viewer
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		if (Engine_Api::_()->core()->hasSubject('sitestore_store')) {
			$subject = Engine_Api::_()->core()->getSubject('sitestore_store');
		} else {
			$this->respondWithError('no_record');
		}

		// Get form
		if ($this->getRequest()->isGet()) {
			$response = Engine_Api::_()->getApi('Siteapi_Core', 'Sitestore')->inviteForm();
			$this->respondWithSuccess($response, true);
		} else if ($this->getRequest()->isPost()) {

			$values = $this->_getAllParams();

			if (!isset($values['emails']) || empty($values['emails'])) {
				$this->respondWithValidationError("parameter_missing", "Please Enter the emails");
			}

			if (!isset($values['message']) || empty($values['message'])) {
				$this->respondWithValidationError("parameter_missing", "Please enter the message");
			}

			$emails = explode(",", $values['emails']);

			foreach ($emails as $email) {
				if (!empty($email)) {
					if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
						$this->respondWithValidationError("parameter_missing", 'Please enter valid email address.');
					}
				}
			}

			// Sendemails
			try {
				Engine_Api::_()->getApi("Siteapi_Core", "sitestore")->sendInvites($emails, $subject->getIdentity(), $viewer->getIdentity(), $message);
				$this->successResponseNoContent("no_content");
			} catch (Exception $ex) {
				$this->respondWithValidationError("internal_server_error", $ex->getMessage());
			}
		}
	}

	public function paymentInfoAction() {

		//ONLY LOGGED IN USER CAN MANAGE
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$store_id = $this->_getParam('store_id', null);
		$sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
		if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', null, 'edit')->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$isPasswordCorrect = false;
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

		if (empty($isPasswordCorrect)) {

			$storeOwnerId = Engine_Api::_()->getItem('sitestore_store', $store_id)->owner_id;
			$storeOwnerObj = Engine_Api::_()->getItem('user', $storeOwnerId);

            if($storeOwnerObj->password) {
                $valid = password_verify($_REQUEST['password'], $storeOwnerObj->password);
                if($valid){
                    $isPasswordCorrect = true;  
                }
            }
        }
		try {

			if (!empty($isPasswordCorrect)) {
				$authenticationSuccess = true;
				//$payPalForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getPayPalForm();

				$isDownPaymentEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.downpayment', 0);
				$directPayment = Engine_Api::_()->sitestoreproduct()->isDirectPaymentEnable();

				$paymentMethod = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.paymentmethod', 'paypal');

				// IF DOWNPAYMENT IS NOT ENABLED
				if (empty($isDownPaymentEnable)) {
					$directPaymentEnable = false;
					$isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);
					if (empty($isAdminDrivenStore)) {
						$isPaymentToSiteEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.payment.for.orders', 0);
						$paymentmethod = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.payment.method', 'normal');
						if (($paymentmethod == 'normal' && empty($isPaymentToSiteEnable)) || $paymentmethod == 'split' || $paymentmethod == 'escrow') {
							$directPaymentEnable = true;

							$paymentMethod = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.payment.method', 'normal');
							if ($paymentMethod == 'split') {
								$enablePaymentGateway = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.allowed.payment.split.gateway', array());
							} else if ($paymentMethod == 'escrow') {
								$enablePaymentGateway = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.allowed.payment.escrow.gateway', array());
							} else {
								$enablePaymentGateway = Zend_Json_Decoder::decode(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.allowed.payment.gateway', Zend_Json_Encoder::encode(array(0, 1, 2, 3))));
							}
							$storeEnabledgateway = Engine_Api::_()->getDbtable('stores', 'sitestore')->getStoreAttribute($store_id, 'store_gateway');
							if (!empty($storeEnabledgateway)) {
								$storeEnabledgateway = Zend_Json_Decoder::decode($storeEnabledgateway);
							}

						}
					}
					if (Engine_Api::_()->hasModuleBootstrap('sitegateway')) {

						$getEnabledGateways = Engine_Api::_()->sitegateway()->getAdditionalEnabledGateways(array('pluginLike' => 'Sitegateway_Plugin_Gateway_'));
						$otherGateways = array();
						foreach ($getEnabledGateways as $getEnabledGateway) {

							$gatewyPlugin = explode('Sitegateway_Plugin_Gateway_', $getEnabledGateway->plugin);
							$gatewayKey = strtolower($gatewyPlugin[1]);
							$gatewayKeyUC = ucfirst($gatewyPlugin[1]);

							$showStripeConnect = 0;
							if ($gatewayKey == 'stripe' && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegateway.stripeconnect', 0)) {
								$stripcheckform = array();

								$response['formValues']['showStripeConnect'] = $showStripeConnect = 1;
								$response['formValues']['stripeConnected'] = $stripeConnected = 0;
								$storeGatewayObj = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct')->fetchRow(array('store_id = ?' => $store_id, 'plugin LIKE \'Sitegateway_Plugin_Gateway_Stripe\''));
								if (!empty($storeGatewayObj)) {

									$gateway_id = $storeGatewayObj->gateway_id;

									if (!empty($gateway_id)) {

										// Get gateway
										$gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $gateway_id);
										if (is_array($gateway->config) && !empty($gateway->config['stripe_user_id'])) {
											$response['formValues']['stripeConnected'] = $stripeConnected = 1;
											$response['formValues']['secret'] = $gateway->config['secret'];
											$response['formValues']['publishable'] = $gateway->config['secret'];
											$stripcheckform['value'] = 1;
										} else {
											$response['formValues']['secret'] = '';
											$response['formValues']['publishable'] = '';
										}
									}
								} else {
									$response['formValues']['secret'] = '';
									$response['formValues']['publishable'] = '';
								}

								if ((!empty($storeEnabledgateway['stripe']) || empty($directPaymentEnable))) {
									$storeGatewayObj = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct')->fetchRow(array('store_id = ?' => $store_id, 'plugin LIKE \'Sitegateway_Plugin_Gateway_Stripe\''));
									if (!empty($storeGatewayObj)) {

										$gateway_id = $storeGatewayObj->gateway_id;

										if (!empty($gateway_id)) {
											$response['formValues']['stripeEnabled'] = $stripeEnabled = 1;
											$stripcheckform['value'] = 1;
										}
									}
								}

								//$mainForm[] = $stripcheckform;
							} elseif ($getEnabledGateway->plugin == 'Sitegateway_Plugin_Gateway_MangoPay') {

								$mangopayBankDetailForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getMangoPayBankDetail();
								$mangopaycheckform = array();
								$storeGatewayObj = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct')->fetchRow(array('store_id = ?' => $store_id, 'plugin LIKE \'Sitegateway_Plugin_Gateway_MangoPay\''));
								$mangopayEnabled = 0;
								if (!empty($storeGatewayObj)) {
									$mangopayEnabled = 1;
								}
								$mainForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getMangoPayForm($mainForm, $mangopayEnabled);

								if (!empty($storeGatewayObj)) {

									$response['formValues']['mangopayEnabled'] = $mangopayEnabled = 1;
									$mangopaycheckform['value'] = 1;
									$response['formValues']['mangoPay'] = $storeGatewayObj->toArray();
									$adminAPGateway = Engine_Api::_()->sitegateway()->getAdminPaymentGateway('Sitegateway_Plugin_Gateway_MangoPay');
									$mode = 'live';
									if ($adminAPGateway->config['test_mode']) {
										$mode = 'sandbox';
									}
									$config = isset($storeGatewayObj->config[$mode]) ? ($storeGatewayObj->config[$mode]) : null;
									if (is_array($config)) {
										$birthday = $storeGatewayObj->config[$mode]['birthday'];
										$config['birthday'] = date('Y-m-d', $birthday);
										$response['formValues']['mangoPay'] = $config;
									}
								} else {
									$viewer = Engine_Api::_()->user()->getViewer();

									$searchTable = Engine_Api::_()->fields()->getTable('user', 'search');
									$select = $searchTable->select();
									$select->where('item_id = ?', $viewer->getIdentity());
									$otherUserRecords = $searchTable->fetchRow($select);
									if ($otherUserRecords) {
										$response['formValues']['first_name'] = $otherUserRecords->first_name;
										$response['formValues']['last_name'] = $otherUserRecords->last_name;

										$response['formValues']['birthday'] = $otherUserRecords->birthdate;
									}
									$response['formValues']['email_mango'] = $viewer->email;
								}

								//$mainForm[] = $mangopaycheckform;
								//$mainForm = array_merge($mainForm, $mangopayForm);
								//$mainForm = array_merge($mainForm, $mangopayBankDetailForm);
							} else {
//                            $formName = "form$gatewayKeyUC";
								//                            $formClass = "Sitegateway_Form_Order_$gatewayKeyUC";
								//                            $this->view->$formName = $form = new $formClass();
								//
								//                            $form->setName("sitestoreproduct_payment_info_$gatewayKey");
								//                            if ((!empty($storeEnabledgateway[$gatewayKey]) || empty($directPaymentEnable))) {
								//                                $storeGatewayObj = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct')->fetchRow(array('store_id = ?' => $store_id, 'plugin = ?' => $getEnabledGateway->plugin));
								//                                if (!empty($storeGatewayObj)) {
								//
								//                                    $gateway_id = $storeGatewayObj->gateway_id;
								//
								//                                    if (!empty($gateway_id)) {
								//                                        $gatewyEnabled = $gatewayKey . 'Enabled';
								//                                        $this->view->$gatewyEnabled = true;
								//
								//                                        // Get gateway
								//                                        $gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $gateway_id);
								//                                        // Populate form
								//                                        $form->populate($gateway->toArray());
								//
								//                                        if (is_array($gateway->config)) {
								//                                            $form->populate($gateway->config);
								//                                        }
								//                                    }
								//                                }
								//                            }
							}
						}
					}
					$response['formValues']['isPaypalChecked'] = $paypalEnable = 0;
					$response['formValues']['isByChequeChecked'] = $bychequeEnable = 0;
					$response['formValues']['isCodChecked'] = $codEnable = 0;
					$response['formValues']['isMoneyorderChecked'] = $isMoneyorderEnable = 0;
					$response['formValues']['isStripeChecked'] = $isstripEnable = 0;

					//check configration of paypal
					if (!empty($storeEnabledgateway['paypal']) || empty($directPaymentEnable)) {
						$storeGatewayObj = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct')->fetchRow(array('store_id = ?' => $store_id, 'plugin LIKE \'Payment_Plugin_Gateway_PayPal\''));
						$gateway_id = $storeGatewayObj->gateway_id;

						if (!empty($gateway_id)) {
							$response['formValues']['isPaypalChecked'] = $paypalEnable = 1;
							// Get gateway
							$gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $gateway_id);
							if (!empty($gateway)) {
								$response['formValues']['email_paypal'] = $gateway->email;
								$mode = 'live';
								if ($gateway->config['test_mode']) {
									$mode = 'sandbox';
								}
								$config = isset($gateway->config[$mode]) ? ($gateway->config[$mode]) : null;
								$username_paypal = isset($gateway->config['username']) ? ($gateway->config['username']) : null;
								$response['formValues']['username_paypal'] = $username_paypal;
								$password_paypal = isset($gateway->config['password']) ? ($gateway->config['password']) : null;
								$response['formValues']['password_paypal'] = $password_paypal;
								$signature_paypal = isset($gateway->config['signature']) ? ($gateway->config['signature']) : null;
								$response['formValues']['signature_paypal'] = $signature_paypal;
							} else {
								$response['formValues']['username_paypal'] = '';
								$response['formValues']['password_paypal'] = '';
								$response['formValues']['signature_paypal'] = '';
								$response['formValues']['email_paypal'] = '';
							}
						} else {
							$response['formValues']['username_paypal'] = '';
							$response['formValues']['password_paypal'] = '';
							$response['formValues']['signature_paypal'] = '';
							$response['formValues']['email_paypal'] = '';
						}
					} else {
						$response['formValues']['username_paypal'] = '';
						$response['formValues']['password_paypal'] = '';
						$response['formValues']['signature_paypal'] = '';
						$response['formValues']['email_paypal'] = '';
					}

					if (!empty($storeEnabledgateway['cheque'])) {
						$response['formValues']['isByChequeChecked'] = $bychequeEnable = 1;
						$response['formValues']['bychequeGatewayDetail'] = $bychequeDetail = Engine_Api::_()->getDbtable('sellergateways', 'sitestoreproduct')->fetchRow(array('store_id = ?' => $store_id, "title = 'ByCheque'"))->details;
					} else {
						$response['formValues']['bychequeGatewayDetail'] = "Account Name:\n Account No.:\n Bank: \nBank Branch Address:";
					}

					if (!empty($storeEnabledgateway['cod'])) {
						$response['formValues']['isCodChecked'] = $codEnable = 1;
					}
					if (!empty($storeEnabledgateway['moneyorder'])) {
						$response['formValues']['isMoneyorderChecked'] = $isMoneyorderEnable = 1;
					}
					if (!empty($storeEnabledgateway['stripe'])) {
						$response['formValues']['isstripEnable'] = $isstripEnable = 1;
					}
					if (empty($enablePaymentGateway)) {
						if ($paymentMethod == 'paypal') {
							$mainForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getPayPalForm($mainForm, $paypalEnable);
							//$mainForm = array_merge($payPalForm, $mainForm);
						} elseif (Engine_Api::_()->hasModuleBootstrap('sitegateway') && Engine_Api::_()->sitegateway()->isValidGateway($paymentMethod)) {
							if ($paymentMethod == 'stripe') {
								$mainForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getStripForm($mainForm, $isstripEnable);

								// $mainForm = array_merge($stripForm, $mainForm);
							}
						}
					} else {
						foreach ($enablePaymentGateway as $paymentGateway) {

							if (empty($paymentGateway)) {

								$mainForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getPayPalForm($mainForm, $paypalEnable);
								//$mainForm = array_merge($payPalForm, $mainForm);
							} elseif ($paymentGateway == 1 || $paymentGateway == 'cheque') {
								if (_CLIENT_TYPE == 'ios') {
									$type = 'Label';
								} else {
									$type = 'Dummy';
								}
								$mainForm[] = array(
									'type' => $type,
									"subType" => 'payment_method',
									'name' => 'checkHeading',
									"isActive" => $bychequeEnable,
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('By Cheque'),
								);
								$mainForm[] = array(
									'type' => 'Textarea',
									'name' => 'bychequeGatewayDetail',
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Cheque Detail'),
								);
								$mainForm[] = array(
									'type' => 'Checkbox',
									'name' => 'isByChequeChecked',
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable By Cheque'),
									'value' => $bychequeEnable,
								);
							} elseif ($paymentGateway == 2 || $paymentGateway == 'cash') {
								if (_CLIENT_TYPE == 'ios') {
									$type = 'Label';
								} else {
									$type = 'Dummy';
								}
								$mainForm[] = array(
									'type' => $type,
									"subType" => 'payment_method',
									"isActive" => $codEnable,
									'name' => 'cashHeading',
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Cash on Delivery'),
								);
								$mainForm[] = array(
									'type' => 'Checkbox',
									'name' => 'isCodChecked',
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable Cash on Delivery'),
									'value' => $codEnable,
								);
							} elseif ($paymentGateway == 3 || $paymentGateway == 'moneyorder') {
								if (_CLIENT_TYPE == 'ios') {
									$type = 'Label';
								} else {
									$type = 'Dummy';
								}
								$mainForm[] = array(
									'type' => $type,
									"subType" => 'payment_method',
									'isActive' => $isMoneyorderEnable,
									'name' => 'moneyorderHeading',
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Money Order'),
								);

								$mainForm[] = array(
									'type' => 'Checkbox',
									'name' => 'isMoneyorderChecked',
									'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Enable Money Order'),
									'value' => $isMoneyorderEnable,
								);
							} elseif ($paymentGateway == 'stripe') {

								$mainForm = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getStripForm($mainForm, $isstripEnable);
								//$mainForm = array_merge($stripForm, $mainForm);
							}
						}
					}
				} else {
					$directPayment = Engine_Api::_()->sitestoreproduct()->isDirectPaymentEnable();
					if (!empty($directPayment)) {
						$store_gateway_table = Engine_Api::_()->getDbtable('sellergateways', 'sitestoreproduct');
						$adminDefaultPaymentGateway = unserialize(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.defaultpaymentgateway', serialize(array('cheque', 'cod', MONEYORDER_CONST_VAR))));
						$adminRemainingPaymentGateway = unserialize(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.remainingpaymentgateway', serialize(array('cheque', 'cod', MONEYORDER_CONST_VAR))));
						$response['bychequeDetail'] = $byChequeDetail = $store_gateway_table->getStoreChequeDetail(array('store_id' => $store_id));

						$paypalGatewayId = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct')->isPayPalGatewayEnable($store_id);
						if (!empty($paypalGatewayId)) {
							// Get gateway
							$gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $paypalGatewayId);

							if (!empty($gateway)) {
								$response['formValues']['email_paypal'] = $gateway->email;
								$mode = 'live';
								if ($gateway->config['test_mode']) {
									$mode = 'sandbox';
								}
								$config = isset($gateway->config[$mode]) ? ($gateway->config[$mode]) : null;
								$username_paypal = isset($gateway->config['username']) ? ($gateway->config['username']) : null;
								$response['formValues']['username_paypal'] = $username_paypal;
								$password_paypal = isset($gateway->config['password']) ? ($gateway->config['password']) : null;
								$response['formValues']['password_paypal'] = $password_paypal;
								$signature_paypal = isset($gateway->config['signature']) ? ($gateway->config['signature']) : null;
								$response['formValues']['signature_paypal'] = $signature_paypal;
							} else {
								$response['formValues']['username_paypal'] = '';
								$response['formValues']['password_paypal'] = '';
								$response['formValues']['signature_paypal'] = '';
								$response['formValues']['email_paypal'] = '';
							}
						} else {
							$response['formValues']['username_paypal'] = '';
							$response['formValues']['password_paypal'] = '';
							$response['formValues']['signature_paypal'] = '';
							$response['formValues']['email_paypal'] = '';
						}

						$storeDefaultPaymentGateway = $store_gateway_table->getStoreEnabledGateway(array('store_id' => $store_id, 'gateway_type' => 1));
						foreach ($storeDefaultPaymentGateway as $gatewayName) {
							if ($gatewayName == 'PayPal') {
								$response['formValues']['isPaypalChecked'] = 1;
							} else if ($gatewayName == 'ByCheque') {
								$response['formValues']['isByChequeChecked'] = 1;
							} else if ($gatewayName == 'COD') {
								$response['formValues']['isCodChecked'] = 1;
							} else if ($gatewayName == 'Moneyorder') {
								$response['formValues']['isMoneyorderChecked'] = 1;
							}

						}

						$storeRemainingPaymentGateway = $store_gateway_table->getStoreEnabledGateway(array('store_id' => $store_id, 'gateway_type' => 2));
						foreach ($storeRemainingPaymentGateway as $gatewayName) {
							if ($gatewayName == 'PayPal') {
								$response['formValues']['isPaypalChecked'] = 1;
							} else if ($gatewayName == 'ByCheque') {
								$response['formValues']['isByChequeEnable'] = 1;
							} else if ($gatewayName == 'COD') {
								$response['formValues']['isCodChecked'] = 1;
							} else if ($gatewayName == 'Moneyorder') {
								$response['formValues']['isMoneyorderChecked'] = 1;
							}

						}
					}
				}
				$mainForm[] = array(
					'type' => 'submit',
					'name' => 'submit',
					'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Save'));
				$response['form'] = $mainForm;
				$this->respondWithSuccess($response);
			} else {
				$this->respondWithError('unauthorized', "Password did not match");
			}
		} catch (Exception $ex) {

		}
	}

	public function setStoreGatewayInfoAction() {
		if (!empty($_POST)) {
			$isPaypalChecked = $_POST['isPaypalChecked'];
			$isByChequeChecked = $_POST['isByChequeChecked'];
			$isCodChecked = isset($_POST['isCodChecked']) ? $_POST['isCodChecked'] : false;
			$isMoneyorderChecked = isset($_POST['isMoneyorderChecked']) ? $_POST['isMoneyorderChecked'] : false;
			$isDownpayment = isset($_POST['isDownpayment']) ? $_POST['isDownpayment'] : false;
			$store_id = $_REQUEST['store_id'];
			$storeChequeInfo = @trim($_POST['bychequeGatewayDetail']);
		}
		$store_id = $this->_getParam('store_id');
		$storeGateway = array();
		if (!empty($store_id)) {
			$sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
		}

		if (empty($sitestore)) {
			$this->respondWithError('unauthorized');
		}

		$payment_info_error = false;
		$isPayumoneyChecked = false;
		$isMollieChecked = false;
		if ($isPaypalChecked == 1) {
			$paypalDetails = array();
			$paypalDetails['email'] = $_POST['email_paypal'];
			$paypalDetails['username'] = $_POST['username_paypal'];
			$paypalDetails['password'] = $_POST['password_paypal'];
			$paypalDetails['signature'] = $_POST['signature_paypal'];

			$paypalEmail = $paypalDetails['email'];
			unset($paypalDetails['email']);

			if (!empty($paypalDetails)) {
				if (!filter_var($paypalEmail, FILTER_VALIDATE_EMAIL)) {
					$this->respondWithValidationError("validation_fail", array("email_paypal" => "Please enter a valid email address"));
				}

				if (empty($paypalDetails['username']) || empty($paypalDetails['password']) || empty($paypalDetails['signature'])) {
					$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
				}
			} else {
				$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
			}
		}

		$allEnablegetwayarray = array("isStripeChecked" => "stripe",
			"isPayumoney" => "payumoney",
			"isMollie" => "mollie",
		);

		if (Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
			$gatewayDatasValidation = array();
			$gatewayDetailsArray = array();
			foreach ($allEnablegetwayarray as $key => $additionalGatewaysCheckedArray) {
				if ((isset($_POST[$key]))) {
					$gatewayKey = $key;
					$gatewayKeyFinal = $additionalGatewaysCheckedArray;
					$gatewayKeyFinal = strtolower($gatewayKeyFinal);
					$gatewayKeyFinalUC = ucfirst($gatewayKeyFinal);
					if ($gatewayKeyFinal == 'stripe' && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegateway.stripeconnect', 0)) {
						$sitestoreproduct_gateway_table = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct');
						$sitestoreproduct_gateway_table_obj = $sitestoreproduct_gateway_table->fetchRow(array('store_id = ?' => $store_id, 'plugin = \'Sitegateway_Plugin_Gateway_Stripe\''));
						if (!empty($sitestoreproduct_gateway_table_obj)) {
							if (empty($sitestoreproduct_gateway_table_obj->config['stripe_user_id'])) {
								$payment_info_error = true;
								$this->respondWithError('unauthorized', "Please click on 'Connect with Stripe' button before saving the changes.");
							} else {
								$gatewayDatasValidation['stripe']['storeGatewayId'] = $sitestoreproduct_gateway_table_obj->gateway_id;
								$gatewayDatasValidation['stripe']['gatewayEnabled'] = true;
							}
						}
					} elseif ($gatewayKeyFinal == 'mangopay') {

						$store_gateway_table = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct');
						$mangoPayDetails = array();
						$mangoPayBankDetails = array();
						@parse_str($_POST['additionalGatewayDetailArray']['mangopayGatewayDetail']['personalDetail'], $mangoPayDetails);
						$mangoPayDetails['email'] = $mangoPayDetails['email_mango'];
						@parse_str($_POST['additionalGatewayDetailArray']['mangopayGatewayDetail']['accountDetail'], $mangoPayBankDetails);

						$result = $store_gateway_table->mangoPayConfigSettings($mangoPayDetails, $sitestore);

						$bankDetails = $store_gateway_table->setMangoPayBankDetails($mangoPayBankDetails, $sitestore);
						if ($bankDetails['error'] == 1) {
							$this->respondWithError('unauthorized', $bankDetails['errorMessage']);
						}
						$storeGateway['mangopay'] = $result['gateway_id'];
					} elseif ($gatewayKeyFinal == 'payumoney') {
						$isPayumoneyChecked = true;
						$payumoneyDetails = array();
						@parse_str($_POST['additionalGatewayDetailArray']['payumoneyGatewayDetail'], $payumoneyPaymentDetails);
						$gatewayDetailsArray[$gatewayKeyFinal] = $payumoneyPaymentDetails;
						$MerchantKey = $payumoneyPaymentDetails['merchant_key'];
						// unset($payumoneyPaymentDetails['merchant_key']);

						if (!empty($payumoneyPaymentDetails)) {
//validation
							if (empty($payumoneyPaymentDetails['merchant_key']) || empty($payumoneyPaymentDetails['salt'])) {
								$payment_info_error = true;
								$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
							}
						} else {
							$payment_info_error = true;
							$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
						}
					} elseif ($gatewayKeyFinal == 'mollie') {
						$isMollieChecked = true;
						$mollieDetails = array();
						@parse_str($_POST['additionalGatewayDetailArray']['mollieGatewayDetail'], $molliePaymentDetails);
						$gatewayDetailsArray[$gatewayKeyFinal] = $molliePaymentDetails;
						$MerchantKey = $molliePaymentDetails['merchant_key'];

						if (!empty($molliePaymentDetails)) {

							if (empty($molliePaymentDetails['merchant_key'])) {
								$payment_info_error = true;
								$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
							}
						} else {
							$payment_info_error = true;
							$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
						}
					} else {

						@parse_str($_POST['additionalGatewayDetailArray'][$gatewayKeyFinal . "GatewayDetail"], $gatewayDetailsArray[$gatewayKeyFinal]);

						$showInfoError = false;
						foreach ($gatewayDetailsArray[$gatewayKeyFinal] as $gatewayParam) {
							if (empty($gatewayParam)) {
								$showInfoError = true;
								break;
							}
						}

						$gateway_info_error = $gatewayKeyFinal . "_info_error";
						if (!empty($gatewayDetailsArray[$gatewayKeyFinal])) {

							if ($showInfoError) {
								$payment_info_error = true;
								$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
							}
						} else {
							$payment_info_error = true;
							$this->respondWithError('unauthorized', 'Gateway login failed. Please insert all the informations or double check your connection information.');
						}
					}
				}
			}
		}

		if ($isByChequeChecked == 1) {
			if (empty($storeChequeInfo)) {
				$payment_info_error = true;
				$this->respondWithError('unauthorized', 'Please enter your cheque details.');
			}
		}

		// IF PAYPAL GATEWAY IS ENABLE, THEN INSERT PAYPAL ENTRY IN ENGINE4_SITESTOREPRODUCT_GATEWAY TABLE
		if (($isPaypalChecked == 1) && !empty($paypalDetails)) {
			$sitestoreproduct_gateway_table = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct');

			$plugin = "Payment_Plugin_Gateway_PayPal";
			$title = "PayPal";

			$sitestoreproduct_gateway_table_obj = $sitestoreproduct_gateway_table->fetchRow(array('store_id = ?' => $store_id, "plugin = '{$plugin}'"));
			if (!empty($sitestoreproduct_gateway_table_obj)) {
				$gateway_id = $sitestoreproduct_gateway_table_obj->gateway_id;
			} else {
				$gateway_id = 0;
			}

			$success_message = $error_message = false;

			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();

			$paypalEnabled = true;
			// Process
			try {
				//GET VIEWER ID
				$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
				if (empty($gateway_id)) {
					$row = $sitestoreproduct_gateway_table->createRow();
					$row->store_id = $store_id;
					$row->user_id = $viewer_id;
					$row->email = $paypalEmail;
					$row->title = $title;
					$row->description = '';
					$row->plugin = $plugin;
					$obj = $row->save();

					$gateway = $row;
				} else {
					$gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $gateway_id);
					$gateway->email = $paypalEmail;
					$gateway->save();
				}
				$db->commit();
			} catch (Exception $e) {
				echo $e->getMessage();
			}

			// Validate gateway config
			$gatewayObject = $gateway->getGateway();

			try {
				$gatewayObject->setConfig($paypalDetails);
				$response = $gatewayObject->test();
			} catch (Exception $e) {
				$paypalEnabled = false;
				// $form->populate(array('enabled' => false));
				$this->respondWithError('unauthorized', 'Paypal Gateway login failed. Please double check your connection information.', $e->getMessage());
			}

			// Process
			$message = null;
			try {
				$values = $gateway->getPlugin()->processAdminGatewayForm($paypalDetails);
			} catch (Exception $e) {
				$this->respondWithError('unauthorized', $e->getMessage());
				$values = null;
			}

			if (empty($paypalDetails['username']) || empty($paypalDetails['password']) || empty($paypalDetails['signature'])) {
				$paypalDetails = null;
			}

			if (null !== $paypalDetails) {
				$gateway->setFromArray(array(
					'enabled' => $paypalEnabled,
					'config' => $paypalDetails,
				));
				$gateway->save();
				$storePaypalId = $gateway->gateway_id;
			}
		}

		// IF PAYUMONEY GATEWAY IS ENABLE, THEN INSERT PAYUMONEY ENTRY IN ENGINE4_SITESTOREPRODUCT_GATEWAY TABLE
		if (($isPayumoneyChecked == 1) && !empty($payumoneyPaymentDetails)) {

			$Payment_gateway_table = Engine_Api::_()->getDbtable('gateways', 'payment');
			$Payment_gateway_table_obj = $Payment_gateway_table->fetchRow(array('plugin = \'Sitegateway_Plugin_Gateway_Payumoney\''));
			$testmode = $Payment_gateway_table_obj->test_mode;

			$sitestoreproduct_gateway_table = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct');

			$plugin = "Sitegateway_Plugin_Gateway_Payumoney";
			$title = "payumoney";

			$sitestoreproduct_gateway_table_obj = $sitestoreproduct_gateway_table->fetchRow(array('store_id = ?' => $store_id, "plugin = '{$plugin}'"));
			if (!empty($sitestoreproduct_gateway_table_obj)) {
				$gateway_id = $sitestoreproduct_gateway_table_obj->gateway_id;
			} else {
				$gateway_id = 0;
			}

			$success_message = $error_message = false;

			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();

			$payumoneyEnabled = true;
			// Process
			try {
				//GET VIEWER ID
				$viewer = Engine_Api::_()->user()->getViewer();
				$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
				if (empty($gateway_id)) {
					$row = $sitestoreproduct_gateway_table->createRow();
					$row->store_id = $store_id;
					$row->user_id = $viewer_id;
					$row->email = $viewer->email;
					$row->title = $title;
					$row->description = '';
					$row->test_mode = $testmode;
					$row->plugin = $plugin;
					$obj = $row->save();

					$gateway = $row;
				} else {
					$gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $gateway_id);
					$gateway->test_mode = $testmode;
					$gateway->email = $viewer->email;
					$gateway->save();
				}
				$db->commit();
			} catch (Exception $e) {
				echo $e->getMessage();
			}

			// Validate gateway config
			$gatewayObject = $gateway->getGateway();

			try {
				$gatewayObject->setConfig($payumoneyPaymentDetails);
				$response = $gatewayObject->test();
			} catch (Exception $e) {
				$payumoneyEnabled = false;
				// $form->populate(array('enabled' => false));
				$this->respondWithError('unauthorized', 'Gateway login failed. Please double check your connection information. The gateway has been disabled. ', $e->getMessage());
			}

			// Process
			$message = null;
			try {
				$values = $gateway->getPlugin()->processAdminGatewayForm($payumoneyPaymentDetails);
			} catch (Exception $e) {
				$message = $e->getMessage();
				$values = null;
			}

			if (empty($payumoneyPaymentDetails['salt']) || empty($payumoneyPaymentDetails['merchant_key'])) {
				$payumoneyPaymentDetails = null;
			}

			if (null !== $payumoneyPaymentDetails) {
				$gateway->setFromArray(array(
					'enabled' => $payumoneyEnabled,
					'config' => $payumoneyPaymentDetails,
				));
				$gateway->save();
				$storePayumoneyId = $gateway->gateway_id;
			}
		}

		// IF MOLLIE GATEWAY IS ENABLE, THEN INSERT MOLLIE ENTRY IN ENGINE4_SITESTOREPRODUCT_GATEWAY TABLE
		if (($isMollieChecked == 1) && !empty($molliePaymentDetails)) {

			$Payment_gateway_table = Engine_Api::_()->getDbtable('gateways', 'payment');
			$Payment_gateway_table_obj = $Payment_gateway_table->fetchRow(array('plugin = \'Sitegateway_Plugin_Gateway_Mollie\''));
			$testmode = $Payment_gateway_table_obj->test_mode;

			$sitestoreproduct_gateway_table = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct');

			$plugin = "Sitegateway_Plugin_Gateway_Mollie";
			$title = "mollie";

			$sitestoreproduct_gateway_table_obj = $sitestoreproduct_gateway_table->fetchRow(array('store_id = ?' => $store_id, "plugin = '{$plugin}'"));
			$gateway_id = 0;
			if (!empty($sitestoreproduct_gateway_table_obj)) {
				$gateway_id = $sitestoreproduct_gateway_table_obj->gateway_id;
			}
			$success_message = $error_message = false;

			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();

			$mollieEnabled = true;
			// Process
			try {
				//GET VIEWER ID
				$viewer = Engine_Api::_()->user()->getViewer();
				$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
				if (empty($gateway_id)) {
					$row = $sitestoreproduct_gateway_table->createRow();
					$row->store_id = $store_id;
					$row->user_id = $viewer_id;
					$row->email = $viewer->email;
					$row->title = $title;
					$row->description = '';
					$row->test_mode = $testmode;
					$row->plugin = $plugin;
					$obj = $row->save();

					$sitestoreproduct_gateway_table_obj = $row;
				} else {
					$sitestoreproduct_gateway_table_obj->test_mode = $testmode;
					$sitestoreproduct_gateway_table_obj->email = $viewer->email;
					$sitestoreproduct_gateway_table_obj->save();
				}
				$db->commit();
			} catch (Exception $e) {
				echo $e->getMessage();
			}

			// Validate gateway config
			$gatewayObject = $sitestoreproduct_gateway_table_obj->getGateway();

			try {
				$gatewayObject->setConfig($molliePaymentDetails);
				$response = $gatewayObject->test();
			} catch (Exception $e) {
				$mollieEnabled = false;
				// $form->populate(array('enabled' => false));
				$this->respondWithError('unauthorized', 'Gateway login failed. Please double check your connection information. The gateway has been disabled. The message was: [%2$d] %1$s', $e->getMessage());
			}

			// Process
			$message = null;
			try {
				$values = $sitestoreproduct_gateway_table_obj->getPlugin()->processAdminGatewayForm($molliePaymentDetails);
			} catch (Exception $e) {
				$message = $e->getMessage();
				$values = null;
			}

			if (empty($molliePaymentDetails['merchant_key'])) {
				$molliePaymentDetails = null;
			}

			if (!is_null($molliePaymentDetails)) {
				$sitestoreproduct_gateway_table_obj->setFromArray(array(
					'enabled' => $mollieEnabled,
					'config' => $molliePaymentDetails,
				));
				$sitestoreproduct_gateway_table_obj->save();
				$storeMollieId = $sitestoreproduct_gateway_table_obj->gateway_id;
			}
		}

		if (Engine_Api::_()->hasModuleBootstrap('sitegateway') && !empty($gatewayDetailsArray)) {

			foreach ($gatewayDetailsArray as $key => $gatewayDetails) {

				$gatewayKeyFinalUC = ucfirst($key);

				$sitestoreproduct_gateway_table = Engine_Api::_()->getDbtable('gateways', 'sitestoreproduct');
				$sitestoreproduct_gateway_table_obj = $sitestoreproduct_gateway_table->fetchRow(array('store_id = ?' => $store_id, 'plugin = ?' => "Sitegateway_Plugin_Gateway_$gatewayKeyFinalUC"));

				if (!empty($sitestoreproduct_gateway_table_obj)) {
					$gateway_id = $sitestoreproduct_gateway_table_obj->gateway_id;
				} else {
					$gateway_id = 0;
				}

				$error_message_additional_gateway = false;
				$email = $viewer->email;

				$db = Engine_Db_Table::getDefaultAdapter();
				$db->beginTransaction();

				$gatewayDatasValidation[$key]['gatewayEnabled'] = true;
				// Process
				try {
					//GET VIEWER ID
					$viewer = Engine_Api::_()->user()->getViewer();
					$viewer_id = $viewer->getIdentity();
					if (empty($email)) {
						$email = $viewer->email;
					}
					if (empty($gateway_id)) {
						$row = $sitestoreproduct_gateway_table->createRow();
						$row->store_id = $store_id;
						$row->user_id = $viewer_id;
						$row->email = $email;
						$row->title = "$gatewayKeyFinalUC";
						$row->description = '';
						$row->plugin = "Sitegateway_Plugin_Gateway_$gatewayKeyFinalUC";
						$obj = $row->save();
						$gateway = $row;
					} else {
						$gateway = Engine_Api::_()->getItem("sitestoreproduct_gateway", $gateway_id);
						$gateway->email = $email;
						$gateway->save();
					}
					$db->commit();
				} catch (Exception $e) {
					echo $e->getMessage();
				}

				// Validate gateway config
				$gatewayObject = $gateway->getGateway();

				try {
					$gatewayObject->setConfig($gatewayDetails);
					$response = $gatewayObject->test();
				} catch (Exception $e) {

					$gatewayDatasValidation[$key]['gatewayEnabled'] = false;
					$this->respondWithError('unauthorized', 'Gateway login failed. Please double check your connection information. ', $e->getMessage());
				}

				// Process
				$message_additional_gateway = null;
				try {
					$values = $gateway->getPlugin()->processAdminGatewayForm($gatewayDetails);
				} catch (Exception $e) {
					$message_additional_gateway = $e->getMessage();
					$values = null;
				}

				$formValuesValidation = true;
				foreach ($gatewayDetails as $k => $gatewayParam) {
					if ($k != 'test_mode' && empty($gatewayParam)) {
						$formValuesValidation = false;
						break;
					}
				}

				if ($formValuesValidation) {
					$gateway->setFromArray(array(
						'enabled' => $gatewayDatasValidation[$key]['gatewayEnabled'],
						'config' => $gatewayDetails,
					));
					$gateway->save();
					$gatewayDatasValidation[$key]['storeGatewayId'] = $gateway->gateway_id;
				}
			}
		}

		// IF BYCHEQUE OR COD ENABLED, THEN SAVE THEIR ENTRY IN STOREGATEWAY TABLE
		if ($isByChequeChecked == 1 || $isCodChecked == 1 || $isMoneyorderChecked == 1) {
			$sitestoreproduct_store_gateway_table = Engine_Api::_()->getDbtable('sellergateways', 'sitestoreproduct');

			if (!empty($storeChequeInfo)) {
				$sitestoreproduct_store_gateway_table->update(array("details" => $storeChequeInfo, "title" => "ByCheque"), array('store_id =?' => $store_id));
			}

			if (empty($isDownpayment)) {
				$storeByChequeDetail = $sitestoreproduct_store_gateway_table->fetchRow(array('store_id = ?' => $store_id, "title = 'ByCheque'", "gateway_type = 0"));
				if (!empty($storeByChequeDetail)) {
					$storeByChequeId = $storeByChequeDetail->storegateway_id;
				} else {
					$storeByChequeId = '';
				}

				if ($isByChequeChecked == 1) {
					if (!empty($storeByChequeId)) {
						$storeByChequeDetail->enabled = 1;
						$storeByChequeDetail->save();
					} else {
						$sitestoreproduct_store_gateway_table->insert(array(
							'store_id' => $store_id,
							'title' => 'ByCheque',
							'details' => $storeChequeInfo,
							'enabled' => 1,
						));
						$storeByChequeId = $sitestoreproduct_store_gateway_table->getAdapter()->lastInsertId();
					}
				} else if (!empty($storeByChequeId)) {
					$storeByChequeDetail->enabled = 0;
					$storeByChequeDetail->save();
				}

				$storeCodDetail = $sitestoreproduct_store_gateway_table->fetchRow(array('store_id = ?' => $store_id, "title = 'COD'", "gateway_type = 0"));
				if (!empty($storeCodDetail)) {
					$storeCodId = $storeCodDetail->storegateway_id;
				} else {
					$storeCodId = '';
				}

				if ($isCodChecked == 1) {
					if (!empty($storeCodId)) {
						$storeCodDetail->enabled = 1;
						$storeCodDetail->save();
					} else {
						$sitestoreproduct_store_gateway_table->insert(array(
							'store_id' => $store_id,
							'title' => 'COD',
							'enabled' => 1,
						));
						$storeCodId = $sitestoreproduct_store_gateway_table->getAdapter()->lastInsertId();
					}
				} else if (!empty($storeCodId)) {
					$storeByChequeDetail->enabled = 0;
					$storeByChequeDetail->save();
				}

				// Insert moneyorder in sellergateways

				$storeMoneyorderDetail = $sitestoreproduct_store_gateway_table->fetchRow(array('store_id = ?' => $store_id, "title = 'Moneyorder'", "gateway_type = 0"));
				if (!empty($storeMoneyorderDetail)) {
					$storeMoneyorderId = $storeMoneyorderDetail->storegateway_id;
				} else {
					$storeMoneyorderId = '';
				}

				if ($isMoneyorderChecked == 1) {
					if (!empty($storeMoneyorderId)) {
						$storeMoneyorderDetail->enabled = 1;
						$storeMoneyorderDetail->save();
					} else {
						$sitestoreproduct_store_gateway_table->insert(array(
							'store_id' => $store_id,
							'title' => 'Moneyorder',
							'enabled' => 1,
						));
						$storeMoneyorderId = $sitestoreproduct_store_gateway_table->getAdapter()->lastInsertId();
					}
				} else if (!empty($storeMoneyorderId)) {
					$storeByChequeDetail->enabled = 0;
					$storeByChequeDetail->save();
				}
			}
		}

		if (empty($isDownpayment)) {
			// INSERT ALL ENABLED GATEWAY ENTRY IN STORE TABLE

			if ($isPaypalChecked == 1 && !empty($paypalEnabled)) {
				$storeGateway['paypal'] = $storePaypalId;
			}

			foreach ($_POST['additionalGatewaysCheckedArray'] as $key => $additionalGatewaysCheckedArray) {

				if ($additionalGatewaysCheckedArray && !empty($gatewayDatasValidation)) {

					$gatewayKey = ltrim($key, 'is');
					$gatewayKeyFinal = substr($gatewayKey, 0, -7);
					$gatewayKeyFinal = strtolower($gatewayKeyFinal);

					if ($gatewayDatasValidation[$gatewayKeyFinal]['gatewayEnabled']) {
						$storeGateway[$gatewayKeyFinal] = $gatewayDatasValidation[$gatewayKeyFinal]['storeGatewayId'];
					}
				}
			}

			if ($isByChequeChecked == 1) {
				$storeGateway['cheque'] = $storeByChequeId;
			}
			if ($isCodChecked == 1) {
				$storeGateway['cod'] = $storeCodId;
			}

			if ($isMoneyorderChecked == 1) {
				$storeGateway['moneyorder'] = $storeMoneyorderId;
			}
			$sitestore->store_gateway = Zend_Json_Encoder::encode($storeGateway);
			$sitestore->save();
		}
		$this->successResponseNoContent("no_content");
	}

	public function addShippingMethodAction() {
		if (!Zend_Registry::isRegistered('Zend_Translate')) {
			Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
		}

		Engine_Api::_()->getApi('Core', 'siteapi')->setView();
		Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
		//ONLY LOGGED IN USER
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		if (empty($viewer_id)) {
			$this->respondWithError('unauthorized');
		}

		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$store_id = $this->_getParam('store_id', null);
		$authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store_id);

		//IS USER IS STORE ADMIN OR NOT
		if (empty($authValue)) {
			$this->respondWithError('unauthorized');
		} else if ($authValue == 1) {
			$this->respondWithError('unauthorized');
		}

		try {
			$noCountryEnable = 0;
			$regionObj = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->isAnyCountryEnable();
			if (array_key_exists(0, $regionObj)) {
				$noCountryEnable = 1;
			}

			$form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getShippingMethodForm($store_id);
			if ($this->getRequest()->isGet()) {
				$form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getShippingMethodForm($store_id);
				$this->respondWithSuccess($form);
			} else if ($this->getRequest()->isPost()) {
				$this->saveshippment($store_id);
				$this->successResponseNoContent('no_content', true);
			}
		} catch (Exception $ex) {
			$this->respondWithValidationError("internal_server_error", $ex->getMessage());
		}

//        $localeObject = Zend_Registry::get('Locale');
		//        $currencyCode = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
		//        $currencyName = Zend_Locale_Data::getContent($localeObject, 'nametocurrency', $currencyCode);
		//        $weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');
	}

	// AJAX JSON REQUEST ACTION, WHICH RETURN THE RESULTS FOR "ADD SHIPPING METHODS"
	public function saveshippment($store_id) {

		// USE FOR EDIT FORM.
		$method_id = !empty($_POST['method_id']) ? $_POST['method_id'] : false;
		// @parse_str($_POST['shipping_method'], $address);
		$values = $_REQUEST;

		if ($values['all_regions'] == 'yes') {
			$values['state'] = array(0);
			unset($values['all_regions']);
		}

		if (isset($values['handling_type']) && $values['handling_type'] == 'fixed') {
			$values['handling_type'] = 0;
		} elseif (isset($values['handling_type']) && $values['handling_type'] == 'percentage') {
			$values['handling_type'] = 1;
		} elseif (isset($values['handling_type']) && $values['handling_type'] == 'unit_weight') {
			$values['handling_type'] = 2;
		}

		if (isset($values['ship_type']) && $values['ship_type'] == 'per_order') {
			$values['ship_type'] = 0;
		} elseif (isset($values['ship_type']) && $values['ship_type'] == 'per_item') {
			$values['ship_type'] = 1;
		}

		$getErrors = array();

		$values['allow_weight_from'] = @trim($values['allow_weight_from']);
		$values['allow_weight_to'] = @trim($values['allow_weight_to']);
		$values['ship_start_limit'] = @trim($values['ship_start_limit']);
		$values['ship_end_limit'] = @trim($values['ship_end_limit']);
		if (empty($values['allow_weight_from'])) {
			$values['allow_weight_from'] = 0;
		}

		if (empty($values['allow_weight_to'])) {
			$values['allow_weight_to'] = 0;
		}

		if (empty($values['ship_start_limit'])) {
			$values['ship_start_limit'] = 0;
		}
		if (empty($values['ship_end_limit'])) {
			$values['ship_end_limit'] = 0;
		}

		if (empty($values['dependency']) && $values['dependency'] != "0") {
			$getErrors['dependency'] = $this->translate('Please complete this field - it is required.');
		}
		if (isset($values['dependency']) && ($values['dependency'] == "0" || $values['dependency'] == 0)) {
			if (empty($values['handling_type']) && $values['handling_type'] != "0") {
				$getErrors['handling_type'] = $this->translate('Please complete this field - it is required.');
			}
		}

		if (isset($values['dependency']) && ($values['dependency'] == "2" || $values['dependency'] == 2)) {

			if (empty($values['ship_type']) && $values['ship_type'] != "0") {
				$getErrors['ship_type'] = $this->translate('Please complete this field - it is required.');
			} elseif ($values['ship_type'] == '1') {
				if (empty($values['handling_type']) && $values['handling_type'] != "0") {
					$getErrors['handling_type'] = $this->translate('Please complete this field - it is required.');
				}

			}
		}

		if (empty($values['delivery_time'])) {
			$getErrors['delivery_time'] = $this->translate('Please complete this field - it is required.');
		}

		if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.shipping.extra.content', 1)) {
			if ($values['dependency'] != 1) {

				if (!@preg_match('/^(\d+|\d*\.\d+)$/', $values['allow_weight_from'])) {
					$getErrors['allow_weight_from'] = array('Please enter a valid weight.');
				}

				if (trim($values['allow_weight_to']) != '') {
					if (!@preg_match('/^(?:\d+|\d*\.\d+)$/', $values['allow_weight_to'])) {
						$getErrors['allow_weight_to'] = array('Please enter a valid weight.');
					}
				}
			}

			if (!@preg_match('/^(\d+|\d*\.\d+)$/', $values['ship_start_limit'])) {
				$getErrors['ship_start_limit'] = array('Please enter a valid ship start limit.');
			}

			if (trim($values['ship_end_limit']) != '') {
				if ($values['dependency'] != 2) {
					if (!@preg_match('/^(?:\d+|\d*\.\d+)$/', $values['ship_end_limit'])) {
						$getErrors['ship_end_limit'] = array('Please enter a valid ship end limit.');
					}
				} else {
					if (!@preg_match('/^(\d+|\d*)$/', $values['ship_end_limit'])) {
						$getErrors['ship_end_limit'] = array('Please enter a valid ship end limit.');
					}
				}
			}

			if ($values['dependency'] != 1) {
				if ($values['allow_weight_to'] != '' && $values['allow_weight_from'] > $values['allow_weight_to']) {
					$getErrors['allow_weight_to'] = array('Please enter weight range logically.');
				}
			}

			if ($values['ship_end_limit'] != '' && $values['ship_start_limit'] > $values['ship_end_limit']) {
				$getErrors['ship_end_limit'] = array('Please enter cost/quantity correct range value.');
			}
		}
		$isMinimumShippingCost = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.minimum.shipping.cost', 0);
		if ($isMinimumShippingCost && $values['handling_type'] == 0 && $values['price'] < Engine_Api::_()->sitestore()->getStoreMinShippingCost($_POST['store_id']) && !empty($values['status'])) {
			$getErrors['price'] = array('Entered Shipping Fee is less than the minimum shipping cost. Please enter shipping fee greator than store\'s minimum shipping cost');
		}

		if (@is_array($getErrors) && count($getErrors) > 0) {
			$this->respondWithValidationError('validation_fail', $getErrors);
		}

		//UNSET VALUE OF PRICE/RATE ACCORDING TO HANDLING TYPE
		if ($values['dependency'] == 1 && $values['handling_type'] == 2) {
			$values['ship_type'] = 1;
			$values['handling_type'] = 0;
			unset($values['rate']);
			$values['handling_fee'] = @round($values['price'], 2);
		} else {
			if ($values['handling_type'] == 1) {
				unset($values['price']);
				$values['handling_fee'] = @round($values['rate'], 2);
			} else {
				unset($values['rate']);
				$values['handling_fee'] = @round($values['price'], 2);
			}
		}

		$values['store_id'] = $store_id;

		if ($values['country'] != 'ALL') {
			$values['region'] = $values['state'];
		}

		$values['title'] = trim(($values['title']));
		$values['delivery_time'] = trim($values['delivery_time']);
		unset($values['state']);

		if (empty($method_id)) {
			// ADD NEW ROW IN TABLE ACCORDINGLY
			$shippingMethodObj = Engine_Api::_()->getDbtable('shippingmethods', 'sitestoreproduct');
			$db = $shippingMethodObj->getAdapter();
			$db->beginTransaction();
			try {
				// CREATE SHIPPING METHOD ROW

				if (!array_key_exists("region", $values)) {
					$values['region'] = array(0);
				} else {
					$values['region'] = explode(",", $values['region']);
				}
				$tempRegionIds = $values['region'];
				$values['store_id'] = $store_id;
				foreach ($tempRegionIds as $regionId) {
					$values['region'] = $regionId;
					$row = $shippingMethodObj->createRow();
					$row->setFromArray($values);
					$row->save();
				}
				$db->commit();
			} catch (Exception $e) {
				$db->rollBack();
			}
		} else {
			// EDIT TABLE ACCORDINGLY
			$shippingMethodItem = Engine_Api::_()->getItem('sitestoreproduct_shippingmethod', $method_id);
			$shippingMethodItem->title = @trim($values['title']);
			$shippingMethodItem->delivery_time = $values['delivery_time'];
			if ($values['dependency'] != 1) {
				$shippingMethodItem->allow_weight_from = $values['allow_weight_from'];
				$shippingMethodItem->allow_weight_to = $values['allow_weight_to'];
			}
			$shippingMethodItem->dependency = $values['dependency'];
			$shippingMethodItem->ship_start_limit = $values['ship_start_limit'];
			$shippingMethodItem->ship_end_limit = $values['ship_end_limit'];
			if ($values['dependency'] == 2) {
				$shippingMethodItem->ship_type = $values['ship_type'];
			}

			if ($values['dependency'] == 1 && $values['handling_type'] == 2) {
				$shippingMethodItem->ship_type = 1;
				$shippingMethodItem->handling_type = 0;
				$shippingMethodItem->handling_fee = @round($values['price'], 2);
			} else {
				if ($values['dependency'] == 1) {
					$shippingMethodItem->ship_type = 0;
				}

				$shippingMethodItem->handling_type = $values['handling_type'];
				//UPDATE VALUE OF PRICE/RATE ACCORDING TO HANDLING FEE
				if ($values['handling_type'] == 0) {
					$shippingMethodItem->handling_fee = @round($values['price'], 2);
				} else {
					$shippingMethodItem->handling_fee = @round($values['rate'], 2);
				}

			}

			if (!empty($values['status'])) {
				$shippingMethodItem->status = 1;
			} else {
				$shippingMethodItem->status = 0;
			}

			$shippingMethodItem->save();
		}
	}

	public function editShippingMethodAction() {
		//ONLY LOGGED IN USER
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		if (empty($viewer_id)) {
			$this->respondWithError('unauthorized');
		}

		$store_id = $this->_getParam('store_id', null);
		$authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store_id);

		//IS USER IS STORE ADMIN OR NOT
		if (empty($authValue)) {
			$this->respondWithError('unauthorized');
		} else if ($authValue == 1) {
			$this->respondWithError('unauthorized');
		}

		$regionObj = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->isAnyCountryEnable();
		if (array_key_exists(0, $regionObj)) {
			$noCountryEnable = 1;
		}

		$method_id = $this->_getParam('shippingmethod_id', false);

		$shippingMethodItem = Engine_Api::_()->getItem('sitestoreproduct_shippingmethod', $method_id);
		if (empty($shippingMethodItem)) {
			$this->respondWithError('unauthorized');
		}

		$shippingMethodPopulateArray = $shippingMethodItem->toArray();

		$regionItem = Engine_Api::_()->getItem('sitestoreproduct_region', $shippingMethodPopulateArray['region']);

		if ($shippingMethodPopulateArray['country'] != 'ALL') {
			$regionCountry = Zend_Locale::getTranslation($shippingMethodPopulateArray['country'], 'country');
		} else {
			$regionCountry = 'All Countries';
		}

		if (empty($shippingMethodPopulateArray['region'])) {
			$region = 'All Regions';
			$shippingMethodPopulateArray['all_regions'] = 'yes';
		} else {
			$region = $regionItem->region;
			$shippingMethodPopulateArray['all_regions'] = 'no';
		}

		//SET VALUE OF PRICE/RATE 0 ACCORDING TO HANDLING FEE
		if ($shippingMethodPopulateArray['handling_type'] == 0) {
			$shippingMethodPopulateArray['price'] = round($shippingMethodPopulateArray['handling_fee'], 2);
		} else {
			$shippingMethodPopulateArray['rate'] = round($shippingMethodPopulateArray['handling_fee'], 2);
		}

		if ($shippingMethodPopulateArray['dependency'] != 2) {
			$shippingMethodPopulateArray['ship_start_limit'] = round($shippingMethodPopulateArray['ship_start_limit'], 2);
		}

		if ($this->getRequest()->isGet()) {

			if (isset($shippingMethodPopulateArray['handling_type']) && $shippingMethodPopulateArray['handling_type'] == '0') {
				$shippingMethodPopulateArray['handling_type'] = 'fixed';
			} elseif (isset($shippingMethodPopulateArray['handling_type']) && $shippingMethodPopulateArray['handling_type'] == '1') {
				$shippingMethodPopulateArray['handling_type'] = 'percentage';
			} elseif (isset($shippingMethodPopulateArray['handling_type']) && $shippingMethodPopulateArray['handling_type'] == '2') {
				$shippingMethodPopulateArray['handling_type'] = 'unit_weight';
			}

			if (isset($shippingMethodPopulateArray['ship_type']) && $shippingMethodPopulateArray['ship_type'] == '0') {
				$shippingMethodPopulateArray['ship_type'] = 'per_order';
			} elseif (isset($shippingMethodPopulateArray['ship_type']) && $shippingMethodPopulateArray['ship_type'] == '1') {
				$shippingMethodPopulateArray['ship_type'] = 'per_item';
			}

			$shippingMethodPopulateArray['state'] = $shippingMethodPopulateArray['region'];
			$form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->getShippingMethodForm($store_id, $shippingMethodItem, 1);
			$form['formValues'] = $shippingMethodPopulateArray;
			$this->respondWithSuccess($form);
		} else if ($this->getRequest()->isPost()) {

			$values = $_REQUEST;

			if (isset($values['handling_type']) && $values['handling_type'] == 'fixed') {
				$values['handling_type'] = 0;
			} elseif (isset($values['handling_type']) && $values['handling_type'] == 'percentage') {
				$values['handling_type'] = 1;
			} elseif (isset($values['handling_type']) && $values['handling_type'] == 'unit_weight') {
				$values['handling_type'] = 2;
			}

			if (isset($values['ship_type']) && $values['ship_type'] == 'per_order') {
				$values['ship_type'] = 0;
			} elseif (isset($values['ship_type']) && $values['ship_type'] == 'per_item') {
				$values['ship_type'] = 1;
			}
			$this->saveEditshippment($values);
			$this->successResponseNoContent('no_content', true);
		}
	}

	// AJAX JSON REQUEST ACTION, WHICH RETURN THE RESULTS FOR "ADD SHIPPING METHODS"
	public function saveEditshippment($values) {

		// USE FOR EDIT FORM.
		$method_id = $values['shippingmethod_id'];

		$getErrors = $address = array();

		if ($values['all_regions'] == 'yes') {
			$values['state'] = array(0);
			unset($values['all_regions']);
		}

		$getErrors = array();
		$values['allow_weight_from'] = @trim($values['allow_weight_from']);
		$values['allow_weight_to'] = @trim($values['allow_weight_to']);
		$values['ship_start_limit'] = @trim($values['ship_start_limit']);
		$values['ship_end_limit'] = @trim($values['ship_end_limit']);
		if (empty($values['allow_weight_to'])) {
			$values['allow_weight_to'] = 0;
		}
		if (empty($values['allow_weight_from'])) {
			$values['allow_weight_from'] = 0;
		}

		if (empty($values['ship_start_limit'])) {
			$values['ship_start_limit'] = 0;
		}
		if (empty($values['ship_end_limit'])) {
			$values['ship_end_limit'] = 0;
		}

		if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.shipping.extra.content', 1)) {
			if ($values['dependency'] != 1) {

				if (!@preg_match('/^(\d+|\d*\.\d+)$/', $values['allow_weight_from'])) {
					$getErrors['allow_weight_from'] = $this->translate('Please enter a valid weight.');
				}

				if (!@preg_match('/^(?:\d+|\d*\.\d+)$/', $values['allow_weight_to'])) {
					$getErrors['allow_weight_to'] = $this->translate('Please enter a valid weight.');
				}
			}

			if (!@preg_match('/^(\d+|\d*\.\d+)$/', $values['ship_start_limit'])) {
				$getErrors['ship_start_limit'] = $this->translate('Please enter a valid ship start limit.');
			}

			if (trim($values['ship_end_limit']) != '') {
				if ($values['dependency'] != 2) {
					if (!@preg_match('/^(?:\d+|\d*\.\d+)$/', $values['ship_end_limit'])) {
						$getErrors['ship_end_limit'] = $this->translate('Please enter a valid ship end limit.');
					}
				} else {
					if (!@preg_match('/^(\d+|\d*)$/', $values['ship_end_limit'])) {
						$getErrors['ship_end_limit'] = $this->translate('Please enter a valid ship end limit.');
					}
				}
			}

			if ($values['dependency'] != 1) {
				if ($values['allow_weight_to'] != '' && $values['allow_weight_from'] > $values['allow_weight_to']) {
					$getErrors['allow_weight_to'] = $this->translate('Please enter weight range logically.');
				}
			}

			if ($values['ship_end_limit'] != '' && $values['ship_start_limit'] > $values['ship_end_limit']) {
				$getErrors['ship_end_limit'] = $this->translate('Please enter cost/quantity correct range value.');
			}
		}
		$isMinimumShippingCost = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.minimum.shipping.cost', 0);
		if ($isMinimumShippingCost && $values['handling_type'] == 0 && $values['price'] < Engine_Api::_()->sitestore()->getStoreMinShippingCost($_POST['store_id']) && !empty($values['status'])) {
			$getErrors['price'] = $this->translate('Entered Shipping Fee is less than the minimum shipping cost. Please enter shipping fee greator than store\'s minimum shipping cost');
		}

		if (empty($values['dependency']) && $values['dependency'] != "0") {
			$getErrors['dependency'] = $this->translate('Please complete this field - it is required.');
		}
		if (isset($values['dependency']) && ($values['dependency'] == "0" || $values['dependency'] == 0)) {
			if (empty($values['handling_type']) && $values['handling_type'] != "0") {
				$getErrors['handling_type'] = $this->translate('Please complete this field - it is required.');
			}
		}

		if (isset($values['dependency']) && ($values['dependency'] == "2" || $values['dependency'] == 2)) {

			if (empty($values['ship_type']) && $values['ship_type'] != "0") {
				$getErrors['ship_type'] = $this->translate('Please complete this field - it is required.');
			} elseif ($values['ship_type'] == '1') {
				if (empty($values['handling_type']) && $values['handling_type'] != "0") {
					$getErrors['handling_type'] = $this->translate('Please complete this field - it is required.');
				}

			}
		}

		if (empty($values['delivery_time'])) {
			$getErrors['delivery_time'] = $this->translate('Please complete this field - it is required.');
		}

		if (@is_array($getErrors) && count($getErrors) > 0) {
			$this->respondWithValidationError('validation_fail', $getErrors);
		}

		//UNSET VALUE OF PRICE/RATE ACCORDING TO HANDLING TYPE
		if ($values['dependency'] == 1 && $values['handling_type'] == 2) {
			$values['ship_type'] = 1;
			$values['handling_type'] = 0;
			unset($values['rate']);
			$values['handling_fee'] = @round($values['price'], 2);
		} else {
			if ($values['handling_type'] == 1) {
				unset($values['price']);
				$values['handling_fee'] = @round($values['rate'], 2);
			} else {
				unset($values['rate']);
				$values['handling_fee'] = @round($values['price'], 2);
			}
		}

		$values['store_id'] = $_POST['store_id'];

		if ($values['country'] != 'ALL') {
			$values['region'] = $values['state'];
		}

		$values['title'] = $values['title'];
		$values['delivery_time'] = trim($values['delivery_time']);
		unset($values['state']);

		if (empty($method_id)) {
			// ADD NEW ROW IN TABLE ACCORDINGLY
			$shippingMethodObj = Engine_Api::_()->getDbtable('shippingmethods', 'sitestoreproduct');
			$db = $shippingMethodObj->getAdapter();
			$db->beginTransaction();
			try {
				// CREATE SHIPPING METHOD ROW
				if (!array_key_exists("region", $values)) {
					$values['region'] = array(0);
				}

				$tempRegionIds = $values['region'];
				$values['store_id'] = $_POST['store_id'];
				foreach ($tempRegionIds as $regionId) {
					$values['region'] = $regionId;
					$row = $shippingMethodObj->createRow();
					$row->setFromArray($values);
					$row->save();
				}
				$db->commit();
			} catch (Exception $e) {
				$db->rollBack();
				throw $e;
			}
		} else {
			// EDIT TABLE ACCORDINGLY
			$shippingMethodItem = Engine_Api::_()->getItem('sitestoreproduct_shippingmethod', $method_id);
			$shippingMethodItem->title = @trim($values['title']);
			$shippingMethodItem->delivery_time = $values['delivery_time'];
			if ($values['dependency'] != 1) {
				$shippingMethodItem->allow_weight_from = $values['allow_weight_from'];
				$shippingMethodItem->allow_weight_to = $values['allow_weight_to'];
			}
			$shippingMethodItem->dependency = $values['dependency'];
			$shippingMethodItem->ship_start_limit = $values['ship_start_limit'];
			$shippingMethodItem->ship_end_limit = $values['ship_end_limit'];
			if ($values['dependency'] == 2) {
				$shippingMethodItem->ship_type = $values['ship_type'];
			}

			if ($values['dependency'] == 1 && $values['handling_type'] == 2) {
				$shippingMethodItem->ship_type = 1;
				$shippingMethodItem->handling_type = 0;
				$shippingMethodItem->handling_fee = @round($values['price'], 2);
			} else {
				if ($values['dependency'] == 1) {
					$shippingMethodItem->ship_type = 0;
				}

				$shippingMethodItem->handling_type = $values['handling_type'];
				//UPDATE VALUE OF PRICE/RATE ACCORDING TO HANDLING FEE
				if ($values['handling_type'] == 0) {
					$shippingMethodItem->handling_fee = @round($values['price'], 2);
				} else {
					$shippingMethodItem->handling_fee = @round($values['rate'], 2);
				}

			}

			if (!empty($values['status'])) {
				$shippingMethodItem->status = 1;
			} else {
				$shippingMethodItem->status = 0;
			}

			$shippingMethodItem->save();
		}
	}

	public function shippingMethodsAction() {
		if (!Zend_Registry::isRegistered('Zend_Translate')) {
			Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
		}

		Engine_Api::_()->getApi('Core', 'siteapi')->setView();
		Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
		// ONLY LOGGED IN USER
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		if (empty($viewer_id)) {
			$this->respondWithError('unauthorized');
		}

		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$store_id = $this->_getParam('store_id', null);

		$sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
		$isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'view');
		if (empty($isManageAdmin)) {
			$this->respondWithError('unauthorized');
		}

		$canEdit = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'edit');

		$regionObj = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->isAnyCountryEnable();

		if (array_key_exists(0, $regionObj)) {
			$noCountryEnable = 1;
		}

		$params = array();
		$params['store_id'] = $store_id;
		$params['page'] = $this->_getParam('page', 1);
		$params['limit'] = 1000;
		$response = array();
		$paginator = Engine_Api::_()->getDbtable('shippingmethods', 'sitestoreproduct')->getShippingMethodsPaginator($params);

		$response['totalItemCount'] = $paginator->getTotalItemCount();
		$weightUnit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.weight.unit', 'lbs');
		try {

			foreach ($paginator as $method) {
				$methodShowArray = array();
				$methodShowArray['shippingmethod_id'] = $method->getIdentity();
				$methodShowArray['title']['label'] = $this->translate('Title');
				$methodShowArray['title']['value'] = $this->translate($method->title);
				if ($method->country != 'ALL') {
					$bodyBrowse['Country'] = Zend_Locale::getTranslation($method->country, 'country');
					$methodShowArray['country']['label'] = $this->translate('Country');
					$methodShowArray['country']['value'] = Zend_Locale::getTranslation($method->country, 'country');
				} else {
					$methodShowArray['country']['label'] = $this->translate('Country');
					$methodShowArray['country']['value'] = $this->translate('All');
				}

				$methodShowArray['region_name']['label'] = $this->translate('Region / State');
				$methodShowArray['region_name']['value'] = $method->country != 'ALL' ? (empty($method->region) ? $this->translate('All') : $method->region_name) : '-';
				if ($method->dependency == 1) {
					$methodShowArray['weight_limit']['label'] = $this->translate('Weight Limit');
					$methodShowArray['weight_limit']['value'] = '-';
				} else {

					$methodShowArray['weight_limit']['label'] = $this->translate('Weight Limit');
					$methodShowArray['weight_limit']['value'] = @round($method->allow_weight_from, 2) . ' - ' . (!empty($method->allow_weight_to) ? round($method->allow_weight_to, 2) . $weightUnit : $this->translate('NA'));
				}

				$methodShowArray['delivery_time']['label'] = $this->translate('Delivery Time');
				$methodShowArray['delivery_time']['value'] = Engine_Api::_()->sitestoreproduct()->truncation($method->delivery_time, 13);
				if (empty($methodShowArray['delivery_time']['value'])) {
					$methodShowArray['delivery_time']['value'] = '-';
				}

				if ($method->dependency == 0) {
					$methodShowArray['dependency']['label'] = $this->translate('Dependency');
					$methodShowArray['dependency']['value'] = $this->translate("Cost");
				} elseif ($method->dependency == 1) {
					$methodShowArray['dependency']['label'] = $this->translate('Dependency');
					$methodShowArray['dependency']['value'] = $this->translate("Weight");
				} else {
					$methodShowArray['dependency']['label'] = $this->translate('Dependency');
					$methodShowArray['dependency']['value'] = $this->translate("Quantity");
				}
				if ($method->dependency == 0) {
					$methodShowArray['limit']['label'] = $this->translate('Limit');
					$methodShowArray['limit']['value'] = Engine_Api::_()->sitestoreproduct()->getPriceWithCurrency($method->ship_start_limit) . ' - ' . (!empty($method->ship_end_limit) ? Engine_Api::_()->sitestoreproduct()->getPriceWithCurrency($method->ship_end_limit) : $this->translate('NA'));
				} elseif ($method->dependency == 1) {
					if (empty($method->ship_start_limit)) {
						$ship_start_limit = 0;
					} else {
						$ship_start_limit = $method->ship_start_limit;
					}

					if (empty($method->ship_end_limit)) {
						$ship_end_limit = 0;
					} else {
						$ship_end_limit = $method->ship_end_limit;
					}

					if (empty($ship_end_limit) && empty($ship_start_limit)) {
						$limit = 'N/A';
					} else {
						$limit = $ship_start_limit . "-" . $ship_end_limit;
					}
					$methodShowArray['limit']['label'] = $this->translate('Limit');
					$methodShowArray['limit']['value'] = $limit;
				} else {
					$methodShowArray['limit']['label'] = $this->translate('Limit');
					$methodShowArray['limit']['value'] = $method->ship_start_limit . ' - ' . (!empty($method->ship_end_limit) ? $method->ship_end_limit : $this->translate('NA'));
				}

				if ($method->dependency == 1) {
					if ($method->ship_type == 0) {
						$methodShowArray['ship_type']['label'] = $this->translate("Charge on");
						$methodShowArray['ship_type']['value'] = $this->translate("Order Weight");
					} else {
						$methodShowArray['ship_type']['label'] = $this->translate("Charge on");
						$methodShowArray['ship_type']['value'] = $this->translate("Per Unit Weight");
					}
				} else {
					if ($method->ship_type == 0) {
						$methodShowArray['ship_type']['label'] = $this->translate("Charge on");
						$methodShowArray['ship_type']['value'] = $this->translate("Per Order");
					} else {
						$methodShowArray['ship_type']['label'] = $this->translate("Charge on");
						$methodShowArray['ship_type']['value'] = $this->translate("Per Item");
					}
				}

				if ($method->handling_type == 0) {
					$methodShowArray['handling_type']['label'] = $this->translate("Price / Rate");
					// $methodShowArray['handling_type']['value'] = Engine_Api::_()->sitestoreproduct()->getPriceWithCurrency($method->handling_fee);
					if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemulticurrency'))
						$methodShowArray['handling_type']['value'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitemulticurrency')->getPriceString($method->handling_fee, $priceOnly);
					if (empty($method->handling_fee)) {
						$methodShowArray['handling_type']['value'] = "$0";
					}
					$methodShowArray['handling_type']['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
				} else {
					$methodShowArray['handling_type']['label'] = $this->translate("Price / Rate");
					$methodShowArray['handling_type']['value'] = @round($method->handling_fee, 2);
					$methodShowArray['handling_type']['value'] = $methodShowArray['handling_type']['value'] . '%';
					if (empty($method->handling_fee)) {
						$methodShowArray['handling_type']['value'] = "0%";
					}
					$methodShowArray['handling_type']['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
				}
				$bodyBrowse['canEdit'] = $canEdit;
				$bodyBrowse['canDelete'] = $canEdit;
				$menu = array();
				if (!empty($canEdit)) {
					$menu[] = array(
						'name' => 'edit_method',
						'label' => $this->translate('Edit Method'),
						'url' => 'sitestore/edit-shipping-method/' . $sitestore->getIdentity(),
						'urlParams' => array(
							"shippingmethod_id" => $method->getIdentity(),
						),
					);
					$menu[] = array(
						'name' => 'delete_method',
						'label' => $this->translate('Delete Method'),
						'url' => 'sitestore/delete-shipping-method/' . $sitestore->getIdentity(),
						'urlParams' => array(
							"shippingmethod_id" => $method->getIdentity(),
						),
					);
					if ($method->status) {
						$menu[] = array(
							'name' => 'disable_method',
							'label' => $this->translate('Disable method'),
							'url' => 'sitestore/shipping-method-enable/' . $sitestore->getIdentity(),
							'urlParams' => array(
								"shippingmethod_id" => $method->getIdentity(),
							),
						);
					} else {
						$menu[] = array(
							'name' => 'enable_method',
							'label' => $this->translate('Enable Method'),
							'url' => 'sitestore/shipping-method-enable/' . $sitestore->getIdentity(),
							'urlParams' => array(
								"shippingmethod_id" => $method->getIdentity(),
							),
						);
					}

					$methodShowArray['menu'] = $menu;
				}

				$methodShowArray['status']['label'] = $this->translate("Status");
				$methodShowArray['status']['value'] = !empty($method->status) ? "Enabled" : "Disabled";

				$isMinimumShippingCost = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.minimum.shipping.cost', 0);

				$methodShowArray['creation_date']['label'] = $this->translate("Creation Date");
				$methodShowArray['creation_date']['value'] = gmdate('M d,Y, g:i A', strtotime($method->creation_date));
				$bodyBrowse['method'] = $methodShowArray;
				$response['response'][] = $bodyBrowse;
			}
		} catch (Exception $ex) {

		}
		$this->respondWithSuccess($response, true);
	}

	public function deleteShippingMethodAction() {
		//ONLY LOGGED IN USER
		if (!$this->_helper->requireUser()->isValid()) {
			$this->respondWithError('unauthorized');
		}

		$this->validateRequestMethod("DELETE");
		$store_id = $this->_getParam('store_id', null);
		$authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store_id);

		//IS USER IS STORE ADMIN OR NOT
		if (empty($authValue)) {
			$this->respondWithError('unauthorized');
		} else if ($authValue == 1) {
			$this->respondWithError('unauthorized');
		}

		$shippingmethod_id = $this->_getParam('shippingmethod_id');

		$shippingMethodItem = Engine_Api::_()->getItem('sitestoreproduct_shippingmethod', $shippingmethod_id);
		if (empty($shippingMethodItem)) {
			$this->respondWithError('no_record');
		}

		//IF TABLE OBJECT NOT EMPTY THEN DELETE ROW
		if (!empty($shippingMethodItem)) {
			$shippingMethodItem->delete();
		}

		$this->successResponseNoContent('no_content', true);
	}

	// ENABLE AND DISABLE REGION ON MANAGE COUNTRIES STORE
	public function shippingMethodEnableAction() {
		$store_id = $this->_getParam('store_id', null);
		$shippingMethodId = $this->_getParam('shippingmethod_id', null);
		if (empty($shippingMethodId) || empty($store_id)) {
			$this->respondWithError('no_record');
		}

		$shippingMethodItem = Engine_Api::_()->getItem('sitestoreproduct_shippingmethod', $shippingMethodId);
		$isMinimumShippingCost = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.minimum.shipping.cost', 0);

		if ($isMinimumShippingCost && $shippingMethodItem->handling_type == 0) {
			$this->respondWithError('unauthorized', 'This shipping method cannot be enabled disabled from here. Please try enable/disable by editing the shipping method.');
		}

		// CHANGING ACTIVE TO COMPLEMENT OF PRESENT ACTIVE VALUE
		$shippingMethodItem->status = empty($shippingMethodItem->status) ? 1 : 0;
		$shippingMethodItem->save();
		$this->successResponseNoContent('no_content', true);
	}

	/*
		     * Get the Gutter Menu for store profile page.
		     *
		     * @param $subject object
		     * @return array
	*/

	private function _getGutterMenu($subject) {
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();
		$menu = array();
		$owner = $subject->getOwner();
		$owner_id = $owner->getIdentity();

		if ($subject->authorization()->isAllowed($viewer, 'delete')) {
			if ($subject->closed) {
				$menu[] = array(
					'name' => 'open',
					'label' => $this->translate('Open Store'),
					'url' => 'sitestore/close/' . $subject->getIdentity(),
				);
			} else {
				$menu[] = array(
					'name' => 'close',
					'label' => $this->translate('Close Store'),
					'url' => 'sitestore/close/' . $subject->getIdentity(),
				);
			}
		}

		// Reviews Work Start
		if ($viewer_id) {
			$reviewTable = Engine_Api::_()->getDbTable('reviews', 'sitestorereview');
			$hasPosted = $reviewTable->canPostReview($subject->getIdentity(), $viewer_id);
			if ($hasPosted) {
				$menu[] = array(
					'name' => 'update_review',
					'label' => $this->translate("Update Review"),
					'url' => 'sitestore/review/edit/' . $subject->getIdentity() . '/' . $hasPosted,
				);
			} else if ($viewer_id != $subject->owner_id) {
				$menu[] = array(
					'name' => 'create_review',
					'label' => $this->translate("Write Review"),
					'url' => 'sitestore/reviews/create/' . $subject->getIdentity(),
				);
			}
		}
		// Reviews Work Ends

		if ($subject->authorization()->isAllowed($viewer, 'delete')) {
			$menu[] = array(
				'name' => 'delete',
				'label' => $this->translate('Delete Store'),
				'url' => 'sitestore/delete/' . $subject->getIdentity(),
			);
		}

		$menu[] = array(
			'name' => 'tellafriend',
			'label' => $this->translate('Tell a friend'),
			'url' => 'sitestore/tellafriend/' . $subject->getIdentity(),
		);

		if ($viewer->getIdentity()) {
			$menu[] = array(
				'name' => 'share',
				'label' => $this->translate('Share This Store'),
				'url' => 'activity/share',
				'urlParams' => array(
					"type" => $subject->getType(),
					"id" => $subject->getIdentity(),
				),
			);

			$menu[] = array(
				'name' => 'report',
				'label' => $this->translate('Report This Store'),
				'url' => 'report/create/subject/' . $subject->getGuid(),
				'urlParams' => array(
					"type" => $subject->getType(),
					"id" => $subject->getIdentity(),
				),
			);
		}

		// For Cart
		if (isset($_REQUEST['cart']) && !empty($_REQUEST['cart'])) {
			$menu[] = array(
				'label' => $this->translate('Cart'),
				'name' => 'cart',
			);
		}

		$eventModuleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent');
		if (!empty($eventModuleEnabled) && method_exists('Siteevent_Api_Siteapi_Core', 'isSiteeventPluginEnabled') && _CLIENT_TYPE && ((_CLIENT_TYPE == 'android' && _ANDROID_VERSION >= '55.5') || _CLIENT_TYPE == 'ios' && _IOS_VERSION >= '2.4')) {
			$advEventEnableArray = Engine_Api::_()->getApi('Siteapi_Core', 'siteevent')->isSiteeventPluginEnabled($subject->getType(), $subject->getIdentity());
			if (isset($advEventEnableArray['siteeventPluginEnabled']) && !empty($advEventEnableArray['siteeventPluginEnabled'])) {
				if (isset($advEventEnableArray['canCreateEvent']) && !empty($advEventEnableArray['canCreateEvent'])) {
					if( _CLIENT_TYPE == 'ios' ) {
                        $menu[] = array(
                            'name' => 'create',
                            'label' => $this->translate('Create an Event'),
                            'url' => 'advancedevents/create',
                            'urlParams' => array(
                            	"subject_type" => $subject->getType(),
                            	"subject_id" => $subject->getIdentity(),
                            )
                        );
                    }
                    else{
                        $packageEnable = Engine_Api::_()->siteevent()->hasPackageEnable();
                        if(!empty($packageEnable))
                        {   $menu[] = array(
                                    'label' => $this->translate('Create an Event'),
                                    'name' => 'content_create_package',
                                    'url' => 'advancedevents/packages',
                                    'urlParams' => array(
                                    	"subject_type" => $subject->getType(),
                                    	"subject_id" => $subject->getIdentity(),
                                )
                            );
                        }
                        else{
                            $menu[] = array(
                                    'name' => 'create',
                                    'label' => $this->translate('Create an Event'),
                                    'url' => 'advancedevents/create',
                                    'urlParams' => array(
                                    	"subject_type" => $subject->getType(),
                                    	"subject_id" => $subject->getIdentity(),
                                )
                            );
                        }
                    }
				}
			}
		}

		// For Cart
		if ($owner_id == $viewer_id && ((_IOS_VERSION && _IOS_VERSION >= '2.4') || (_ANDROID_VERSION && _ANDROID_VERSION >= '3.0'))) {
			if (!empty($subject->approved) && !empty($subject->search) && !empty($subject->draft) && empty($subject->declined)) {
				$menu[] = array(
					'label' => $this->translate('Edit Store'),
					'name' => 'edit_store',
					'url' => 'sitestore/edit/' . $subject->getIdentity(),
				);

				$menu[] = array(
					'label' => $this->translate('Add Product'),
					'name' => 'add_product',
					'url' => 'sitestore/product/create?store_id=' . $subject->getIdentity(),
				);
			}
			$menu[] = array(
				'label' => $this->translate('Payment Method'),
				'name' => 'payment_method',
				'url' => 'sitestore/payment-info/' . $subject->getIdentity(),
			);
			$menu[] = array(
				'label' => $this->translate('Shipping Method'),
				'name' => 'shipping_method',
				'url' => 'sitestore/shipping-methods/' . $subject->getIdentity(),
			);

			$isEnabledPackage = Engine_Api::_()->sitestore()->hasPackageEnable();
			$getHost = Engine_Api::_()->getApi('core', 'siteapi')->getHost();
			$baseUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
			$baseUrl = @trim($baseUrl, "/");
			if (_CLIENT_TYPE && ((_CLIENT_TYPE == 'android' && _ANDROID_VERSION >= '1.9') || _CLIENT_TYPE == 'ios' && _IOS_VERSION >= '2.1')) {

				if (Engine_Api::_()->sitestore()->canShowPaymentLink($subject->store_id)) {
					$routeStartP = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.manifestUrlP', "storeitems");
					$getOauthToken = Engine_Api::_()->getApi('oauth', 'siteapi')->getAccessOauthToken($viewer);
					$menu[] = array(
						'label' => $this->translate('Make Payment'),
						'name' => 'package_payment',
						'url' => $getHost . '/' . $baseUrl . "/" . $routeStartP . "/payment?token=" . $getOauthToken['token'] . "&store_id=" . $subject->store_id . "&disableHeaderAndFooter=1",
					);
				}
			}

			if (!empty($viewer_id) && !empty($owner_id) && $isEnabledPackage && (_CLIENT_TYPE && ((_CLIENT_TYPE == 'android' && _ANDROID_VERSION >= '1.9') || _CLIENT_TYPE == 'ios' && _IOS_VERSION >= '2.1'))) {

				$table = Engine_Api::_()->getItemtable('sitestore_package');
				$packages_select = $table->getPackagesSql($subject->getOwner())
					->where("update_list = ?", 1)
					->where("enabled = ?", 1)
					->where("package_id <> ?", $subject->package_id);
				$storePackage = $table->fetchRow($packages_select);
				if (count($storePackage) > 0) {
					$menu[] = array(
						'label' => $this->translate('Upgrade Package'),
						'name' => 'upgrade_package',
						'url' => 'sitestore/package/upgrade-package',
						'urlParams' => array(
							'store_id' => $subject->getIdentity(),
						),
					);
				}

			}
		}

		return $menu;
	}

	/**
	 *  Message friends about this page
	 */
	public function tellafriendAction() {

		// Get viewer
		$viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		// Get form
		if ($this->getRequest()->isGet()) {
			$response = Engine_Api::_()->getApi('Siteapi_Core', 'Sitestore')->getTellAFriendForm();
			if (isset($viewer_id) && !empty($viewer_id)) {
				$response['formValues']['sender_name'] = $viewer->displayname;
				$response['formValues']['sender_email'] = $viewer->email;
			}
			$this->respondWithSuccess($response, true);
		} else if ($this->getRequest()->isPost()) {

			// Form validation
			// Get page id and object
			$store_id = $this->_getParam('store_id', $this->_getParam('store_id', null));
			$subject = Engine_Api::_()->getItem('sitestore_store', $store_id);

			if (empty($subject)) {
				$this->respondWithError('no_record');
			}

			// Get form values
			$values = $this->_getAllParams();

			// Start form validation
			$validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestore')->tellaFriendFormValidators();
			$values['validators'] = $validators;
			$validationMessage = $this->isValid($values);

			// Response validation error
			if (!empty($validationMessage) && @is_array($validationMessage)) {
				$this->respondWithValidationError('validation_fail', $validationMessage);
			}
			// Explode email ids
			$reciver_ids = explode(',', $values['receiver_emails']);
			if (!empty($values['send_me'])) {
				$reciver_ids[] = $values['sender_email'];
			}
			$sender_email = $values['sender_email'];

			$heading = $subject->title;

			// Check valid email id format
			$validator = new Zend_Validate_EmailAddress();
			$validator->getHostnameValidator()->setValidateTld(false);

			if (!$validator->isValid($sender_email)) {
				$this->respondWithValidationError('validation_fail', 'Invalid sender email address value');
			}

			if (!empty($reciver_ids)) {
				foreach ($reciver_ids as $receiver_id) {
					$receiver_id = trim($receiver_id, ' ');
					($reciver_ids);
					if (!$validator->isValid($receiver_id)) {
						$this->respondWithValidationError('validation_fail', 'Please enter correct email address of the receiver(s).');
					}
				}
			}

			$sender = $values['sender_name'];
			$message = $values['message'];
			try {
				Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciver_ids, 'SITESTORE_TELLAFRIEND_EMAIL', array(
					'host' => $_SERVER['HTTP_HOST'],
					'sender_name' => $sender,
					'store_title' => $heading,
					'message' => '<div>' . $message . '</div>',
					'object_link' => 'http://' . $_SERVER['HTTP_HOST'] . Engine_Api::_()->sitestore()->getHref($subject->store_id, $subject->owner_id, $subject->getSlug()),
					'sender_email' => $sender_email,
					'queue' => true,
				));
			} catch (Exception $ex) {
				$this->respondWithError('internal_server_error', $ex->getMessage());
			}
			$this->successResponseNoContent('no_content', true);
		}
	}

	/*
		     * Get the Profile Tabs for store profile page.
		     *
		     * @param $subject object
		     * @return array
	*/

	private function _getProfileTabs($subject) {
		$tabsMenu = array();

		$productmoduleenabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreproduct');
		if ($productmoduleenabled) {
			$values['store_id'] = $subject->getIdentity();
			$values['page'] = 1;
			$values['limit'] = 20;
			$values['type'] = 'browse';
			$values['orderby'] = 'product_id';
			$paginator = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getStoreProductPaginator($values);
			$storeProductsCount = $paginator->getTotalItemCount();

			if ($storeProductsCount && !$subject->closed) {
				$tabsMenu[] = array(
					'label' => $this->translate('Products'),
					'name' => 'products',
					'count' => $storeProductsCount,
					'url' => 'sitestore/product/browse/',
					'urlParams' => array(
						'store_id' => $subject->getIdentity(),
					),
				);
			}
		}
		// if ($updates_count) {
			$tabsMenu[] = array(
				'label' => $this->translate('Updates'),
				'name' => 'update',
				'url' => 'sitestore/updates/' . $subject->getIdentity(),
			);
		// }

		$tabsMenu[] = array(
			'label' => $this->translate('Info'),
			'name' => 'information',
			'url' => 'sitestore/information/' . $subject->getIdentity(),
		);

		if (strlen($subject->overview) > 0) {
			$tabsMenu[] = array(
				'label' => $this->translate('Overview'),
				'name' => 'overview',
				'url' => 'sitestore/overview/' . $subject->getIdentity(),
			);
		}

		$albums = Engine_Api::_()->getDbtable('albums', 'sitestore')->getAlbums($subject);
		$storeAlbumCount = $albums->count();
		if ($storeAlbumCount) {

			$tabsMenu[] = array(
				'label' => $this->translate("Albums"),
				'name' => 'photos',
				'count' => $storeAlbumCount,
				'url' => 'sitestore/photos/browse-album/' . $subject->getIdentity(),
			);
		}

		// Get reviews count
		$reviewCount = Engine_Api::_()->getDbtable('reviews', 'sitestorereview')->totalReviews($subject->getIdentity());
		if ($reviewCount) {
			$tabsMenu[] = array(
				'label' => $this->translate("Reviews"),
				'name' => 'reviews',
				'count' => $reviewCount,
				'url' => 'sitestore/reviews/browse/' . $subject->getIdentity(),
			);
		}

		// @Todo: Bhawin: "form" should be "forum". Please discuss it with me once.
		// $tabsMenu[] = array(
		//     'label' => $this->translate('Forum'),
		//     'name' => 'form',
		//     'url' => 'sitestore/form/' . $subject->getIdentity(),
		// );

		$viewer = Engine_Api::_()->user()->getViewer();
		if ($viewer->getIdentity() && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreoffer')) {
			$offerCount = Engine_Api::_()->getDbtable('offers', 'sitestoreoffer')->getStoreOfferCount($subject->getIdentity());
			if ($offerCount) {
				$tabsMenu[] = array(
					'label' => $this->translate("Coupons"),
					'name' => 'coupons',
					'count' => $offerCount,
					'url' => 'sitestore/offers/browse/' . $subject->getIdentity(),
				);
			}
		}

		if (method_exists('Siteapi_Api_Core', 'isSitevideoPluginEnabled') && _CLIENT_TYPE && ((_CLIENT_TYPE == 'android' && _ANDROID_VERSION >= '3.2.3') || _CLIENT_TYPE == 'ios' && _IOS_VERSION > '2.1.6')) {
			$advVideoEnableArray = Engine_Api::_()->getApi('Core', 'siteapi')->isSitevideoPluginEnabled($subject->getType(), $subject->getIdentity());
			if (isset($advVideoEnableArray['sitevideoPluginEnabled']) && !empty($advVideoEnableArray['sitevideoPluginEnabled'])) {
				if (isset($advVideoEnableArray['totalVideoItemCount']) && !empty($advVideoEnableArray['totalVideoItemCount'])) {
					$tabsMenu[] = array(
						'name' => 'video',
						'label' => $this->translate('Videos'),
						'totalItemCount' => $advVideoEnableArray['totalVideoItemCount'],
						'url' => 'advancedvideos/index/' . $subject->getIdentity(),
						"subject_type" => $subject->getType(),
						"subject_id" => $subject->getIdentity(),
						'urlParams' => array(
							"subject_type" => $subject->getType(),
							"subject_id" => $subject->getIdentity(),
						),
					);
				}

			} else {
				if ($viewer->getIdentity() && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorevideo')) {
					$videoTable = Engine_Api::_()->getDbtable("videos", "sitestorevideo");
					$videoCount = $videoTable->getStoreVideoCount($subject->getIdentity());
					if ($videoCount) {
						$tabsMenu[] = array(
							'label' => $this->translate("Videos"),
							'name' => 'videos',
							'count' => $videoCount,
							'url' => 'videosgeneral/',
							'urlParams' => array(
								'subject_type' => $subject->getType(),
								'subject_id' => $subject->getIdentity(),
							),
						);
					}
				}
			}
		} else {
			if ($viewer->getIdentity() && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestorevideo')) {
				$videoTable = Engine_Api::_()->getDbtable("videos", "sitestorevideo");
				$videoCount = $videoTable->getStoreVideoCount($subject->getIdentity());
				if ($videoCount) {
					$tabsMenu[] = array(
						'label' => $this->translate("Videos"),
						'name' => 'videos',
						'count' => $videoCount,
						'url' => 'videosgeneral/',
						'urlParams' => array(
							'subject_type' => $subject->getType(),
							'subject_id' => $subject->getIdentity(),
						),
					);
				}
			}
		}
		// Video Tab
		//Event Tab..............
		//
		$eventModuleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent');
		if (!empty($eventModuleEnabled) && method_exists('Siteevent_Api_Siteapi_Core', 'isSiteeventPluginEnabled') && _CLIENT_TYPE && ((_CLIENT_TYPE == 'android' && _ANDROID_VERSION >= '55.5') || _CLIENT_TYPE == 'ios' && _IOS_VERSION >= '2.4')) {
			$advEventEnableArray = Engine_Api::_()->getApi('Siteapi_Core', 'siteevent')->isSiteeventPluginEnabled($subject->getType(), $subject->getIdentity());
			if ($advEventEnableArray['totalEventItemCount'] && isset($advEventEnableArray['siteeventPluginEnabled']) && !empty($advEventEnableArray['siteeventPluginEnabled'])) {
				$tabsMenu[] = array(
					'totalItemCount' => $advEventEnableArray['totalEventItemCount'],
					'name' => 'advevents',
					'label' => $this->translate('Events'),
					'url' => 'advancedevents/events-integration',
					'urlParams' => array(
						'subject_type' => $subject->getType(),
						'subject_id' => $subject->getIdentity(),
					),
				);
			}
		}

		return $tabsMenu;
	}

}
