<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestorealbum
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2013-09-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestorealbum_Form_Admin_Global extends Engine_Form {

  public function init() {

    $this
            ->setTitle('General Settings')
            ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'sitestorealbum_manifestUrl', array(
			'label' => 'Store Albums URL alternate text for "store-albums"',
			'allowEmpty' => false,
			'required' => true,
			'description' => 'Please enter the text below which you want to display in place of "storealbums" in the URLs of this plugin.',
			'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorealbum.manifestUrl', "store-albums"),
    ));
    
		$view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $URL = $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'lightbox'), 'admin_default', true);
    $description = sprintf(Zend_Registry::get('Zend_Translate')->_('The settings for the Advanced Lightbox Viewer have been moved to the SocialApps.tech Core Plugin. Please %1svisit here%2s to see and configure these settings.'),
    "<a href='" . $URL ."' target='_blank'>", "</a>");
    $this->addElement('Dummy', 'sitestorealbum_photolightbox_show', array(
        'label' => 'Photos Lightbox Viewer',
        'description' => $description,
    ));

    $this->getElement('sitestorealbum_photolightbox_show')->getDecorator('Description')->setOptions(array('placement', 'APPEND', 'escape' => false));

     // Order of store album store
    $this->addElement('Radio', 'sitestorealbum_order', array(
        'label' => 'Default Ordering in Store Albums listing',
        'description' => 'Select the default ordering of albums in Store Albums listing. (This widgetized store will list all Store Albums. Sponsored albums are albums created by paid Stores.)',
        'multiOptions' => array(
            1 => 'All albums in descending order of creation.',
            2 => 'All albums in alphabetical order.',
            3 => 'Featured albums followed by others in descending order of creation.',
            4 => 'Sponsored albums followed by others in descending order of creation.(If you have enabled packages.)',
            5 => 'Featured albums followed by sponsored albums followed by others in descending order of creation.(If you have enabled packages.)',
            6 => 'Sponsored albums followed by featured albums followed by others in descending order of creation.(If you have enabled packages.)',
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorealbum.order', 1),
    ));

    $this->addElement('Radio', 'sitestorealbum_hide_autogenerated', array(
        'label' => 'Show / Hide Default Albums',
        'description' => "Do you want to show default albums of stores and their various extensions on your site which are created by the system automatically? (If you select No, then albums like 'Overview Photos', 'Note Photos', 'Discussion Photos', etc will not be displayed anywhere on the site.)",
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorealbum.hide.autogenerated', 1),
    ));

    $this->addElement('Radio', 'sitestorealbum_albumsorder', array(
        'label' => 'Choose Order',
        'description' => "Select the order below to display the albums on your site.",
        'multiOptions' => array(
            1 => 'Newer to older',
            0 => 'Older to newer'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorealbum.albumsorder', 1),
    ));

    $this->addElement('Text', 'sitestorealbum_truncation_limit', array(
        'label' => 'Title Truncation Limit',
        'allowEmpty' => false,
        'maxlength' => '3',
        'required' => true,
        'description' => 'What maximum limit should be applied to the number of characters in the title of items in the widgets? (Enter a number between 1 and 999. Titles having more characters than this limit will be truncated. Complete titles will be shown on mouseover.)',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorealbum.truncation.limit', 13),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

    $this->addElement('Button', 'submit', array(
        'label' => 'Save Changes',
        'type' => 'submit',
        'ignore' => true
    ));
  }

}

?>