<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestoredocument
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Documents.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestoredocument_Model_DbTable_Documents extends Engine_Db_Table {

  protected $_name = 'sitestoredocument_documents';
  protected $_rowClass = 'Sitestoredocument_Model_Document';

  /**
   * Get sitestoredocument detail
   * @param array $params : contain desirable sitestoredocument info
   * @return  object of sitestoredocument
   */
  public function getSitestoredocumentsPaginator($params = array(), $customParams = null) {
    $paginator = Zend_Paginator::factory($this->getSitestoredocumentsSelect($params, $customParams));
    if (!empty($params['store'])) {
      $paginator->setCurrentPageNumber($params['store']);
    }
    if (!empty($params['limit'])) {
      $paginator->setItemCountPerPage($params['limit']);
    }
    return $paginator;
  }

  /**
   * Get sitestoredocuments 
   * @param array $params : contain desirable sitestoredocument info
   * @return  array of sitestoredocuments
   */
  public function getSitestoredocumentsSelect($params = array(), $customParams = null) {


    //GET DOCUMENT TABLE NAME
    $tableDocumentName = $this->info('name');

		$select = $this->select();

    if (isset($params['show_count']) && $params['show_count'] == 1) {

      $searchTable = Engine_Api::_()->fields()->getTable('sitestoredocument_document', 'search')->info('name');
      $select = $select
                      ->setIntegrityCheck(false)
                      ->from($tableDocumentName, array(
                          'COUNT(*) AS show_count'));
      //->group("$tableDocumentName.document_id");
    } else {

				if(!empty($params['orderby'])) {
					$select = $select->order($params['orderby'].' DESC');
				}
        else {
          $select = $select->order('highlighted DESC')
													 ->order('document_id DESC');
        }
				if(!empty($params['orderby']) && $params['orderby'] != 'document_id') {
					$select = $select->order('document_id DESC');
				}

				$searchTable = Engine_Api::_()->fields()->getTable('sitestoredocument_document', 'search')->info('name');
				$select = $select
												->setIntegrityCheck(false)
												->from($tableDocumentName, array('document_id', 'owner_id', 'store_id', 'sitestoredocument_title', 'sitestoredocument_description', 'doc_id', 'thumbnail', 'creation_date', 'rating', 'comment_count', 'like_count', 'views', 'search', 'draft', 'featured','highlighted', 'approved', 'status'))
												->group("$tableDocumentName.document_id");
    }

    if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
      $select->where($tableDocumentName . '.owner_id = ?', $params['user_id']);
    }

    if (!empty($params['user']) && $params['user'] instanceof User_Model_User) {
      $select->where($tableDocumentName . '.owner_id = ?', $params['user_id']->getIdentity());
    }

    if (!empty($params['users'])) {
      $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
      $select->where($tableDocumentName . '.owner_id in (?)', new Zend_Db_Expr($str));
    }

    if (isset($params['owner_id'])) {
      $select->where($tableDocumentName . '.owner_id = ?', $params['owner_id']);
    }

    if (isset($params['draft'])) {
      $select->where($tableDocumentName . '.draft = ?', $params['draft']);
    }

    if (isset($params['approved'])) {
      $select->where($tableDocumentName . '.approved = ?', $params['approved']);
    }

    if (isset($params['store_id'])) {
      $select->where($tableDocumentName . '.store_id = ?', $params['store_id']);
    }

    if (isset($params['featured'])) {
      $select->where($tableDocumentName . '.featured = ?', $params['featured']);
    }

     if (isset($params['highlighted'])) {
      $select->where($tableDocumentName . '.highlighted = ?', $params['highlighted']);
    }

    if (isset($params['status'])) {
      $select->where($tableDocumentName . '.status = ?', $params['status']);
    }

    if (!empty($params['search'])) {
      $select->where($tableDocumentName . ".fulltext LIKE ? OR " . $tableDocumentName . ".sitestoredocument_title LIKE ? OR " . $tableDocumentName . ".sitestoredocument_description LIKE ?", '%' . $params['search'] . '%');
    }

    if (!empty($params['show_document']) && empty($params['search']) && empty($params['featured'])  && empty($params['highlighted'])) {
      $select->where($tableDocumentName . ".draft = ?", 0)
              ->where($tableDocumentName . ".approved = ?", 1)
              ->where($tableDocumentName . ".status = ?", 1)
              ->where($tableDocumentName . ".search = ?", 1)
              ->orwhere($tableDocumentName . ".owner_id = ?", $params['document_owner_id']);
    }

    if (!empty($params['show_document']) && (!empty($params['search']) || !empty($params['featured']) || !empty($params['highlighted']))) {
      $select->where("($tableDocumentName.draft = 0 AND $tableDocumentName.approved = 1 AND $tableDocumentName.status = 1 AND $tableDocumentName.search = 1)  OR ($tableDocumentName.owner_id = " . $params['document_owner_id'] . ")");
    }

    if (isset($params['store_id'])) {
      $select->where($tableDocumentName . '.store_id = ?', $params['store_id']);
    }

    return $select;
  }

	/**
   * Return document data
   *
   * @param array params
   * @return Zend_Db_Table_Select
   */
	public function widgetDocumentsData($params = array(),$widgetType = null) {

		if(isset($params['profile_store_widget']) && !empty($params['profile_store_widget'])) {
			$select = $this->select()
								->from($this->info('name'), array('document_id', 'owner_id', 'doc_id', 'fulltext', 'thumbnail', 'status', 'activity_feed'))
								->where('draft = ?', 0)
								->where('approved = ?', 1)
								->where('status = ?', 0)
								->where('search = ?', 1)
								->where('store_id = ?', $params['store_id']);
      if(isset($params['highlighted']) && !empty($params['highlighted'])) {
        $select->where('highlighted  = ?', 1);
      }
			$select->order('document_id ASC')
							->limit(5);
		}
		elseif(isset($params['view_action']) && !empty($params['view_action'])) {
			$select = $this->select()
								->from($this->info('name'), array('sitestoredocument_title', 'rating', 'owner_id', 'thumbnail',
										'views', 'creation_date', 'modified_date', 'comment_count', 'document_id'))
								->where('store_id = ?', $params['store_id'])
								->where('document_id != ?', $params['document_id'])
								->where('approved = ?', 1)
								->where('draft = ?', 0)
								->where('status = ?', 1)
								->where('search = ?', 1)
								->order('document_id DESC')
								->limit($params['limit']);
		}
		else {
      $tableStore = Engine_Api::_()->getDbtable('stores', 'sitestore');
      $storeTableName = $tableStore->info('name');
      $tableDocumentName = $this->info('name');
      $storePackagesTable = Engine_Api::_()->getDbtable('packages', 'sitestore');
      $storePackageTableName = $storePackagesTable->info('name');
			$select = $this->select()
								->setIntegrityCheck(false)
								->from($this->info('name'), array('document_id', 'store_id', 'owner_id', 'sitestoredocument_title', 'creation_date', 'thumbnail', 'rating', 'comment_count', 'like_count', 'views', 'featured','sitestoredocument_description'))
								->joinLeft($storeTableName, "$storeTableName.store_id = $tableDocumentName.store_id", array('store_id', 'title AS store_title', 'closed', 'approved', 'declined', 'draft', 'expiration_date', 'owner_id', 'photo_id as store_photo_id'))
								->joinLeft($storePackageTableName, "$storePackageTableName.package_id = $storeTableName.package_id",array('package_id', 'price'))
								->where($tableDocumentName .'.draft = ?', 0)
								->where($tableDocumentName .'.approved = ?', 1)
								->where($tableDocumentName .'.status = ?', 1)
								->where($tableDocumentName .'.search = ?', 1);
			if(isset($params['zero_count']) && !empty($params['zero_count'])) {
				$select = $select->where($tableDocumentName . '.' . $params['zero_count'].'!= ?', 0);
			}

			if(isset($params['featured']) && !empty($params['featured'])) {
				$select = $select->where($tableDocumentName .'.featured = ?', 1);
			}

      if(isset($params['highlighted']) && !empty($params['highlighted'])) {
				$select = $select->where($tableDocumentName .'.highlighted = ?', 1);
			}
	
			if(isset($params['orderby']) && !empty($params['orderby'])) {
				$select = $select->order($tableDocumentName . '.' . $params['orderby']);
			}
	
			if(isset($params['store_id']) && !empty($params['store_id'])) {
				$select = $select->where($tableDocumentName .'.store_id = ?', $params['store_id']);
			}

      if (!empty($params['title'])) {
				$select->where($storeTableName . ".title LIKE ? ", '%' . $params['title'] . '%');
      }
    
		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
		if(isset($params['show']) && $params['show'] == 'my_document') {
			$select->where($tableDocumentName . '.owner_id = ?', $viewer_id);
		}
		elseif ((isset($params['show']) && $params['show'] == 'sponsored document') || !empty($params['sponsoreddocument']) || !empty($params['sponsored'])) {
				
				$select->where($storePackageTableName . '.price != ?', '0.00');
				$select->order($storePackageTableName . '.price' . ' DESC');
		}
		elseif (isset($params['show']) && $params['show'] == 'Networks') {
				$select = $storeTable->getNetworkBaseSql($select, array('browse_network' => 1));

		}
		elseif((isset($params['show']) && $params['show'] == 'featured') || !empty($params['featureddocument'])) {
			$select = $select
											->where($tableDocumentName . '.featured = ?', 1)
											->order($tableDocumentName .'.creation_date DESC');
		}
    elseif((isset($params['show']) && $params['show'] == 'highlighted') || !empty($params['highlighteddocument'])) {
			$select = $select
											->where($tableDocumentName . '.highlighted = ?', 1)
											->order($tableDocumentName .'.creation_date DESC');
		}
    elseif (isset($params['show']) && $params['show'] == 'my_like') {
			$likeTableName = Engine_Api::_()->getDbtable('likes', 'core')->info('name');
			$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
      $select
              ->join($likeTableName, "$likeTableName.resource_id = $storeTableName.store_id")
							->where($likeTableName . '.poster_type = ?', 'user')
							->where($likeTableName . '.poster_id = ?', $viewer_id)
              ->where($likeTableName . '.resource_type = ?', 'sitestore_store');
    }
   
		if ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'view_count') || !empty($params['vieweddocument'])) {
			$select = $select
											->order($tableDocumentName .'.views DESC')
											->order($tableDocumentName .'.creation_date DESC');
		} elseif ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'comment_count') || !empty($params['commenteddocument'])) {
			$select = $select
											->order($tableDocumentName .'.comment_count DESC')
											->order($tableDocumentName .'.creation_date DESC');
		} elseif ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'rating') || !empty($params['rateddocument'])) {
			$select = $select
											->order($tableDocumentName .'.rating DESC')
											->order($tableDocumentName .'.creation_date DESC');
			} elseif ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'like_count') || !empty($params['likeddocument'])) {
				$select = $select
												->order($tableDocumentName .'.like_count DESC')
												->order($tableDocumentName .'.creation_date DESC');
		}

    if (!empty($params['search_document'])) {
        $select->where($tableDocumentName . ".sitestoredocument_title LIKE ? OR " . $tableDocumentName . ".sitestoredocument_description LIKE ?", '%' . $params['search_document'] . '%');
				
    }

    if (!empty($params['document_category_id'])) {
      $select->where($tableDocumentName . '.category_id = ?', $params['document_category_id']);
    }

    if (!empty($params['category_id'])) {
      $select->where($storeTableName . '.category_id = ?', $params['category_id']);
    }

		if (!empty($params['subcategory'])) {
      $select->where($storeTableName . '.subcategory_id = ?', $params['subcategory']);
    }

    if (!empty($params['subcategory_id'])) {
      $select->where($storeTableName . '.subcategory_id = ?', $params['subcategory_id']);
    }

    if (!empty($params['subsubcategory'])) {
      $select->where($storeTableName . '.subsubcategory_id = ?', $params['subsubcategory']);
    }

    if (!empty($params['subsubcategory_id'])) {
      $select->where($storeTableName . '.subsubcategory_id = ?', $params['subsubcategory_id']);
    }

    if( empty($params['orderby_browse'])) {
			$order = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoredocument.order', 1);
			switch ($order) {
				case "1":
					$select->order($tableDocumentName . '.creation_date DESC');
					break;
				case "2":
					$select->order($tableDocumentName . '.sitestoredocument_title');
					break;
				case "3":
					$select->order($tableDocumentName . '.featured' . ' DESC');
					break;
				case "4":
					$select->order($storePackageTableName . '.price' . ' DESC');
					break;
				case "5":
					$select->order($tableDocumentName . '.featured' . ' DESC');
					$select->order($storePackageTableName . '.price' . ' DESC');
					break;
				case "6":
					$select->order($storePackageTableName . '.price' . ' DESC');
					$select->order($tableDocumentName . '.featured' . ' DESC');
					break;
			}
    }

      if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
				$select->where($storeTableName . '.expiration_date  > ?', date("Y-m-d H:i:s"));
      }  
			$select = $select->order($tableDocumentName .'.document_id DESC');

			if(isset($params['limit']) && !empty($params['limit'])) {
        if (!isset($params['start_index']))
        $params['start_index'] = 0;
				$select->limit($params['limit'], $params['start_index']);
				//$select = $select->limit($params['limit']);
			}
		}
    if($widgetType == 'browsedocument') {
      return Zend_Paginator::factory($select);
    }
    else {
			return $this->fetchAll($select);
    }
	}

  /**
   * Return document of the day
   *
   * @return Zend_Db_Table_Select
   */
  public function documentOfDay() {

    //CURRENT DATE TIME
    $date = date('Y-m-d');

    //GET ITEM OF THE DAY TABLE NAME
    $documentOfTheDayTableName = Engine_Api::_()->getDbtable('itemofthedays', 'sitestore')->info('name');

		//GET STORE TABLE NAME
		$storeTableName = Engine_Api::_()->getDbtable('stores', 'sitestore')->info('name');

    //GET DOCUMENT TABLE NAME
    $documentTableName = $this->info('name');

    //MAKE QUERY
    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($documentTableName)
                    ->join($documentOfTheDayTableName, $documentTableName . '.document_id = ' . $documentOfTheDayTableName . '.resource_id')
										->join($storeTableName, $documentTableName . '.store_id = ' . $storeTableName . '.store_id', array(''))
										->where($storeTableName.'.approved = ?', '1')
										->where($storeTableName.'.declined = ?', '0')
										->where($storeTableName.'.draft = ?', '1')
                    ->where('resource_type = ?', 'sitestoredocument_document')
                    ->where('start_date <= ?', $date)
                    ->where('end_date >= ?', $date)
                    ->order('Rand()');

		//STORE SHOULD BE AUTHORIZED
    if (Engine_Api::_()->sitestore()->hasPackageEnable())
      $select->where($storeTableName.'.expiration_date  > ?', date("Y-m-d H:i:s"));

		//STORE SHOULD BE AUTHORIZED
    $stusShow = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.status.show', 1);
    if ($stusShow == 0) {
      $select->where($storeTableName.'.closed = ?', '0');
    }

    //RETURN RESULTS
    return $this->fetchRow($select);
  }

  public function topcreatorData($limit = null,$category_id) {

    //DOCUMENT TABLE NAME
    $documentTableName = $this->info('name');

    //STORE TABLE
    $storeTable = Engine_Api::_()->getDbtable('stores', 'sitestore');
    $storeTableName = $storeTable->info('name');

    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($storeTableName, array('photo_id', 'title as sitestore_title','store_id'))
                    ->join($documentTableName, "$storeTableName.store_id = $documentTableName.store_id", array("COUNT($storeTableName.store_id) AS item_count"))
                    ->where($storeTableName.'.approved = ?', '1')
										->where($storeTableName.'.declined = ?', '0')
										->where($storeTableName.'.draft = ?', '1')
                    ->group($documentTableName . ".store_id")
                    ->order('item_count DESC')
                    ->limit($limit);
    if (!empty($category_id)) {
      $select->where($storeTableName . '.category_id = ?', $category_id);
    }
    return $select->query()->fetchAll();
  }

}

?>