<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestoreproduct
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2013-09-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestoreproduct_PhotoController extends Siteapi_Controller_Action_Standard {

    //COMMON ACTION WHICH CALL BEFORE EVERY ACTION OF THIS CONTROLLER
    public function init() {
        //AUTHORIZATION CHECK
        if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', null, "view")->isValid())
            $this->respondWithError('unauthorized');

        if (!$this->_helper->requireAuth()->setAuthParams('sitestoreproduct_product', null, "view")->isValid())
            $this->respondWithError('unauthorized');

        //SET SUBJECT
        if (!Engine_Api::_()->core()->hasSubject()) {

            if (0 != ($photo_id = (int) $this->_getParam('photo_id')) &&
                    null != ($photo = Engine_Api::_()->getItem('sitestoreproduct_photo', $photo_id))) {
                Engine_Api::_()->core()->setSubject($photo);
            } else if (0 != ($product_id = (int) $this->_getParam('product_id')) &&
                    null != ($sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id))) {
                Engine_Api::_()->core()->setSubject($sitestoreproduct);
            }
        }
    }

    //ACTION FOR UPLOAD PHOTO
    public function uploadPhotoAction() {
        try {


            $viewer = Engine_Api::_()->user()->getViewer();
            $viewer_id = $viewer->getIdentity();
            $product_id = $this->_getParam('product_id');
            $sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);
            if (empty($sitestoreproduct)) {
                $this->respondWithError('no_record');
            }
            $can_edit = $sitestoreproduct->authorization()->isAllowed($viewer, "edit");
            $allowed_upload_photo = Engine_Api::_()->authorization()->isAllowed($sitestoreproduct, $viewer, "photo");
            if (empty($allowed_upload_photo))
                $this->respondWithError('unauthorized');


            if (!$this->_helper->requireUser()->checkRequire()) {
                $this->respondWithError('unauthorized', 'Max file size limit exceeded (probably).');
            }


            if (empty($_FILES['photo'])) {
                $this->respondWithError('unauthorized', "No photo selected");
            }

            if (!isset($_FILES['photo']) || !is_uploaded_file($_FILES['photo']['tmp_name'])) {
                $this->respondWithError('unauthorized', "Invalid Upload");
            }
            $tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitestoreproduct');
            $db = $tablePhoto->getAdapter();
            $db->beginTransaction();

            try {
                $album = $sitestoreproduct->getSingletonAlbum();
                $rows = $tablePhoto->fetchRow($tablePhoto->select()->from($tablePhoto->info('name'), 'order')->order('order DESC')->limit(1));
                $order = 0;
                if (!empty($rows)) {
                    $order = $rows->order + 1;
                }

                foreach ($_FILES as $photoupload) {
                    $params = array(
                        'collection_id' => $album->getIdentity(),
                        'album_id' => $album->getIdentity(),
                        'product_id' => $sitestoreproduct->getIdentity(),
                        'user_id' => $viewer->getIdentity(),
                        'order' => $order
                    );
                    $order++;
                    $tempphoto = Engine_Api::_()->sitestoreproduct()->createPhoto($params, $photoupload);
                }
                if (!empty($tempphoto)) {
                    $photo_id = $tempphoto->photo_id;
                } else {
                    $photo_id = $tempphoto->photo_id;
                }

                if (!$sitestoreproduct->photo_id) {
                    $sitestoreproduct->photo_id = $photo_id;
                    $sitestoreproduct->save();
                }

                $db->commit();
                $photoCount = Engine_Api::_()->getDbTable('photos', 'sitestoreproduct')->GetProductPhoto($sitestoreproduct->getIdentity());
                $response=array();
                $response['photoCount'] = count($photoCount);
                $this->respondWithSuccess($response, true);
                //$this->successResponseNoContent('no_content');
            } catch (Exception $e) {
                $db->rollBack();
                $this->respondWithError('internal_server_error', $e->getMessage());
            }
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
    }

}

?>
