<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteapi
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Core.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestories_Api_Siteapi_Core extends Core_Api_Abstract {

    Public function sellSomthingForm() {
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
        $sellSomethingForm = array();
        $sellSomethingForm[] = array(
            "type" => 'Text',
            "name" => 'title',
            "label" => Engine_Api::_()->getApi('Core', 'siteapi')->translate('What to sell?'),
            "hasValidator" => true,
        );
        if (Engine_Api::_()->hasModuleBootstrap('sitemulticurrency')) {
            $currency = Engine_Api::_()->getDbTable('currencyrates', 'sitemulticurrency')->getAllowedCurrencies();
            $selected = Engine_Api::_()->sitemulticurrency()->getSelectedCurrency();
        } else {
            $translationList = Zend_Locale::getTranslationList('nametocurrency', Zend_Registry::get('Locale'));
            $symbols = array_keys($translationList);
            $currency = array_combine($symbols, $symbols);
            $selected = 'USD';
        }
        $sellSomethingForm[] = array(
            "type" => 'Select',
            "name" => 'currency',
            "label" => 'Currency',
            'multiOptions' => $currency,
            'value' => $selected,
            "hasValidator" => true
        );
        $sellSomethingForm[] = array(
            "type" => 'Text',
            "name" => 'price',
            "label" => 'What is price?',
            "inputType" => 'number',
            "hasValidator" => true
        );
        $sellSomethingForm[] = array(
            "type" => 'Text',
            "name" => 'location',
            "label" => 'Where to sell?',
            "hasValidator" => true
        );
        $sellSomethingForm[] = array(
            "type" => 'Textarea',
            "name" => 'description',
            "label" => 'Product description',
        );
        $sellSomethingForm[] = array(
            "type" => 'File',
            "name" => 'photo',
            "label" => 'Add Photo',
        );
        return $sellSomethingForm;
    }

    public function getStoryForm() {
        $searchForm = array();
        $viewer = Engine_Api::_()->user()->getViewer();
        $memberlevelSetting = array(
            'everyone' => 'Everyone',
            'networks' => 'Friends and Networks',
            'friends' => 'Friends Only',
        );

        $searchForm[] = array(
            'type' => 'Textarea',
            'name' => 'description',
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Description'),
        );

        $privacyStatus = Engine_Api::_()->getDbtable('userprivacies', 'sitestories')->getUserStoryPrivacyStatus($viewer->getIdentity());
        $searchForm[] = array(
            'type' => 'Radio',
            'name' => 'privacy',
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('View Privacy'),
            'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($memberlevelSetting),
            'value' => $privacyStatus
        );

        return $searchForm;
    }

    public function setPhoto($photo, $values, $setRow = true) {
        if ($photo instanceof Zend_Form_Element_File) {
            $file = $photo->getFileName();
        } else if (is_array($photo) && !empty($photo['tmp_name'])) {
            $file = $photo['tmp_name'];
        } else if (is_string($photo) && file_exists($photo)) {
            $file = $photo;
        } else {
            throw new Banner_Model_Exception('invalid argument passed to setPhoto');
        }
        $imageName = $photo['name'];
        $name = basename($file);
        $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

        $params = array(
            'parent_type' => $values->getType(),
            'parent_id' => $values->getIdentity(),
        );

// Save
        $storage = Engine_Api::_()->storage();

// Resize image (main)
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize(720, 750)
                ->write($path . '/m_' . $imageName)
                ->destroy();

// Resize image (icon)
        $image = Engine_Image::factory();
        $image->open($file);

        $size = min($image->height, $image->width);
        $x = ($image->width - $size) / 2;
        $y = ($image->height - $size) / 2;

        $image->resample($x, $y, $size, $size, 48, 48)
                ->write($path . '/is_' . $imageName)
                ->destroy();
// Store
        $iMain = $storage->create($path . '/m_' . $imageName, $params);
        $iSquare = $storage->create($path . '/is_' . $imageName, $params);

        $iMain->bridge($iSquare, 'thumb.icon');

// Remove temp files

        @unlink($path . '/m_' . $imageName);
        @unlink($path . '/is_' . $imageName);

// Update row
        if (!empty($setRow)) {
            $values->photo_id = $iMain->getIdentity();
            $values->save();
        }
        return $values;
    }

    public function getVideoUrl($video) { // Uploded Videos
        $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
        $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
        $baseParentUrl = @trim($baseParentUrl, "/");
        $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);

        $getHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
        $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
        $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();

        $host = '';
        if ($getDefaultStorageType == 'local')
            $host = !empty($staticBaseUrl) ? $staticBaseUrl : $getHost;

        $video_location = Engine_Api::_()->storage()->get($video->file_id, $video->getType())->getHref();

        $video_location = strstr($video_location, 'http') ? $video_location : $host . $video_location;

        if (!strstr($video_location, 'http'))
            $video_location = $getParentHost . DIRECTORY_SEPARATOR . $baseParentUrl . $video_location;

        return $video_location;
    }

    public function isAllowMessage($viewer, $story) {
        if (empty($story) || empty($viewer))
            return 0;

        $subject = $story->getOwner();

        if (empty($subject))
            return 0;

        $permissionsTable = Engine_Api::_()->getDbtable('permissions', 'authorization');
        // Get level id
        $id = $subject->level_id;
    
        $messagesAuth = $permissionsTable->getAllowed('messages', $id, 'auth');

        if($messagesAuth == 'everyone')
            return 1;
        
        if($messagesAuth == 'friends'){
            $select = $subject->membership()->getMembersOfSelect();
            $friends = $paginator = Zend_Paginator::factory($select);
            $paginator->setItemCountPerPage(1000);
            $paginator->setCurrentPageNumber(1);
            $ids = array();
            //$ids[] = $subject->getIdentity();
            foreach ($friends as $friend) {
                $ids[] = $friend->resource_id;
            }
            if (in_array($viewer->getIdentity(), $ids)) {
                return 1;
            } else
                return 0;
        }else{
            return 0;
        }
    }

    public function getHostUrl($imageUrl = '') {
        $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
        $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
        $baseParentUrl = @trim($baseParentUrl, "/");
        $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
        // Check IF default service "Local Storage" or not.
        $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
        $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();
        $host = '';
        if ($getDefaultStorageType == 'local')
            $host = !empty($staticBaseUrl) ? $staticBaseUrl : $getParentHost;
        $imageUrl = (!strstr($imageUrl, "application/modules") && !strstr($imageUrl, 'http')) ? $host . $imageUrl : $imageUrl;
        if (!strstr($imageUrl, 'http'))
            $imageUrl = $getParentHost . DIRECTORY_SEPARATOR . $baseParentUrl . $imageUrl;
        return $imageUrl;
    }

    public function getStoryPrivacyForm() {
        $searchForm = array();
        $viewer = Engine_Api::_()->user()->getViewer();
        $memberlevelSetting = array(
            'everyone' => 'Public',
            'friends' => 'Friends',
            'custom' => 'Custom',
        );
        $privacyStatus = Engine_Api::_()->getDbtable('userprivacies', 'sitestories')->getUserStoryPrivacyStatus($viewer->getIdentity());
        $searchForm[] = array(
            'type' => 'Radio',
            'name' => 'stories_privacy',
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('View Privacy'),
            'multiOptions' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($memberlevelSetting),
            'value' => $privacyStatus
        );

        return $searchForm;
    }

}
