<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetheme
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Htmlblock.php 2013-11-22 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitetheme_Form_Htmlblock extends Engine_Form {

    protected $_htmlBlocks;
    // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
    public $_SHOWELEMENTSBEFOREACTIVATE = array(
        "submit_lsetting", "environment_mode", "landing_page_layout"
    );

    public function setHtmlBlocks($id) {
        $this->_htmlBlocks = $id;
        return $this;
    }

    public function init() {

        $this->setTitle(sprintf(Zend_Registry::get('Zend_Translate')->_("Global Settings")))
                ->setDescription(sprintf(Zend_Registry::get('Zend_Translate')->_("These settings affect all members in your community.")));


        // Start LICENSE Form Elements.
        $this->addElement('Text', 'sitetheme_lsettings', array(
            'label' => 'Enter License key',
            'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitetheme.lsettings'),
        ));
        
        $this->addElement('Radio', 'landing_page_layout', array(
            'label' => 'Change Landing Page Layout',
            'description' => "Do you want the layout of your home page to be changed as per the default set-up of this theme ? If you choose 'Yes' then your current layout of Home page will be replaced with a new one.",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => 1,
        ));

        if (APPLICATION_ENV == 'production') {
            $this->addElement('Checkbox', 'environment_mode', array(
                'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few pages of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
                'description' => 'System Mode',
            ));
        } else {
            $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
        }

        //Add submit button
        $this->addElement('Button', 'submit_lsetting', array(
            'label' => 'Activate Your Plugin Now',
            'type' => 'submit',
            'ignore' => true
        ));
        // End LICENSE Form Elements.
        

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $newHtmlBlockCount = Zend_Controller_Front::getInstance()->getRequest()->getParam('newBlock', 0);

        $tempHtmlBlockNo = 0;
        $htmlBlockCount = 1;
        $htmlBlockKeys = array();

        @ksort($this->_htmlBlocks);
        
        
        $this->addElement('Dummy', 'othersHeading', array(
        'decorators' => array(array('ViewScript', array(
                    'viewScript' => '_createFormHeading.tpl',
                    'label' => 'Store Features Highlighting Block',
                    'description' => 'Below, you can create Store features highlighting block. This block can contain multiple sub-blocks for which you can configure the content below. (This block will be displayed in the widget "Shopping Hub - Store Features Highlighting Block" as configured by you from the Layout Editor.)',
                    'class' => 'form element',
                ))),
    ));
        
        

        foreach ((array) $this->_htmlBlocks as $htmlBlockNo => $htmlBlock) {
            $htmlBlock = !empty($htmlBlock) ? Zend_Json::decode($htmlBlock) : array();
            $htmlBlockKeys[] = $htmlBlockNo;

            if ($tempHtmlBlockNo < $htmlBlockNo)
                $tempHtmlBlockNo = $htmlBlockNo;

            $this->addElement('TinyMce', 'description_' . $htmlBlockNo, array(
                'label' => 'Sub Block Content ' . $htmlBlockCount++,
                'description' => 'Enter the content to be displayed in this sub-block.',
                'attribs' => array('rows' => 24, 'cols' => 80, 'style' => 'width:200px; max-width:200px; height:120px;'),
//           'allowEmpty' => false,
//           'required' => true,
                'value' => $htmlBlock['body'],
                'filters' => array(
                    new Engine_Filter_Html(),
                    new Engine_Filter_Censor()),
                 'editorOptions' => Engine_Api::_()->seaocore()->tinymceEditorOptions(),
            ));

            $this->addElement('Radio', 'status_' . $htmlBlockNo, array(
                'label' => 'Status',
                'multiOptions' => array(
                    "1" => "Yes, display this sub-block.", "0" => "No, don't display this sub-block.", "2" => "No, don't display this sub-block and delete it."
                ),
                'value' => $htmlBlock['status']
            ));

            $this->addElement('Dummy', 'dummy_block_separator_' . $htmlBlockNo, array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_blockSeparator.tpl',
                        )))
            ));
        }

        if (!empty($newHtmlBlockCount)) {
            for ($temphtmlBlockIndex = 1; $temphtmlBlockIndex <= $newHtmlBlockCount; $temphtmlBlockIndex++) {
                $htmlBlockKeys[] = ++$tempHtmlBlockNo;

                $this->addElement('TinyMce', 'description_' . $tempHtmlBlockNo, array(
                    'label' => 'Sub Block Content ' . $htmlBlockCount++,
                    'description' => 'Enter the content to be displayed in this sub-block.',
                    'attribs' => array('rows' => 24, 'cols' => 80, 'style' => 'width:200px; max-width:200px; height:120px;'),
//           'allowEmpty' => false,
//           'required' => true,
                    'filters' => array(
                        new Engine_Filter_Html(),
                        new Engine_Filter_Censor()),
                    'editorOptions' => Engine_Api::_()->seaocore()->tinymceEditorOptions(),
                ));

                $this->addElement('Radio', 'status_' . $tempHtmlBlockNo, array(
                    'label' => 'Status',
                    'multiOptions' => array(
                        "1" => "Yes, display this sub-block.", "0" => "No, don't display this sub-block.", "2" => "No, don't display this sub-block and delete it."
                    ),
                    'value' => 1
                ));

                $this->addElement('Dummy', 'dummy_block_separator_' . $tempHtmlBlockNo, array(
                    'decorators' => array(array('ViewScript', array(
                                'viewScript' => '_blockSeparator.tpl',
                            )))
                ));
            }
        }

        $this->addElement('Hidden', 'html_block_keys', array(
            'value' => Zend_Json::encode($htmlBlockKeys),
            'order' => 1001,
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Submit',
            'order' => '998',
            'type' => 'submit',
            'decorators' => array(
                'ViewHelper',
            ),
        ));

        $this->addElement('Cancel', 'cancel', array(
            'label' => 'Add New Sub Block Content',
            'link' => true,
            'prependText' => ' or ',
            'order' => '999',
            'class' => 'bold',
            'href' => $view->url(array('newBlock' => $newHtmlBlockCount + 1)),
            'decorators' => array(
                'ViewHelper',
            ),
        ));

        $this->addDisplayGroup(array(
            'submit',
            'cancel',
                ), 'buttons', array(
            'decorators' => array(
                'FormElements',
                'DivDivDivWrapper'
            ),
        ));
        $button_group = $this->getDisplayGroup('buttons');
        $button_group->setOrder('999');
    }

}