<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetour
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitetour_Form_Admin_Tour_Create extends Engine_Form
{

  protected $hasEdit = false;

  public function init()
  {

    // Init form
    $this
      ->setTitle('Create New Tour')
      ->setDescription('Create new tour for listed widgetized page to explain its features to your users. Configure various things related to the tour like: duration of the tour, how to display the tour, play options of the tour etc.')
      ->setAttrib('id', 'sitetour-form')
      ->setAttrib('class', 'global_simple_form')
      ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
    ;

    $pageTable = Engine_Api::_()->getItemTable('core_page');
    $pageOptions = array();
    $pageNames = array();
    if( !$this->hasEdit ) {
      $pageNames = Engine_Api::_()->getItemTable('sitetour_tour')->getPageNames();
    }
    foreach( $pageTable->fetchAll($pageTable->select()->order('page_id ASC')) as $page ) {
      $pageId = $page->name ?: $page->page_id;
      if( in_array($page->name, array('header', 'footer')) || stristr($page->name, 'mobi') || in_array($pageId, $pageNames) ) {
        continue;
      }
      $pageOptions[$pageId] = $page->displayname;
    }

    $this->addElement('Select', 'page_name', array(
      'label' => 'Widgetized Page',
      'description' => "Choose the widgetized page from the dropdown for which you want to create the introduction tour.",
      'required' => true,
      'allowEmpty' => false,
      'multiOptions' => $pageOptions
    ));
    $this->addElement('Text', 'duration', array(
      'label' => 'Tour Duration',
      'description' => 'Enter the time duration for keeping the users on 1st step of tour. After that, users will be automatically sent to the next step of the tour.[Note: Duration should  in milliseconds (seconds*1000).]',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        new Engine_Filter_HtmlSpecialChars(),
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '63')),
      ),
      'value' => '5000'
    ));

    $this->addElement('Select', 'show', array(
      'label' => 'Automatically Start Tour',
      'description' => "Do you want to start introduction tour automatically whenever user visits this page?",
      'required' => true,
      'allowEmpty' => false,
      'multiOptions' => array(
        'auto-once' => 'Yes, automatically start the tour for 1st time. Users can click on \'Start Tour\' button from next time onwards.',
        'auto-always' => 'Yes, automatically start the tour every time user visits this page.',
        'user-click' => 'No, do not start the tour automatically. User can click on \'Start Tour\' button to view the tour.'
      ),
      'value' => 'auto-once',
    ));
    $this->addElement('Select', 'tour_button', array(
      'label' => 'Show "Start Tour" Button',
      'value' => 1,
      'multiOptions' => array(
        1 => 'Yes',
        0 => 'No'
      )
    ));

    $this->addElement('MultiCheckbox', 'enable_buttons', array(
      'description' => 'Select the options which you want to be available to users when a tour is being played.',
      'label' => 'Tour Play Options',
      'multiOptions' => array(
        'previous' => 'Previous Step Button',
        'next' => 'Next Step Button',
        'pause_resume' => 'Pause and Resume Tour Button',
        'end' => 'End Tour Button'
      ),
      'value' => array('previous', 'next', 'pause_resume', 'end')
    ));

    $this->addElement('Select', 'buttonType', array(
      'label' => 'Tour Play Buttons Type',
      'value' => 0,
      'multiOptions' => array(
        0 => 'Show Label',
        1 => 'Show Icon'
      )
    ));
    $description = 'Below you can edit button labels of the above selected options for this tour.';
    $this->addElement('Dummy', 'button_label', array(
      'label' => 'Button Labels',
      'description' => $description,
    ));
    $this->button_label->addDecorator('Description', array('escape' => false));

    // Init name
    $this->addElement('Text', 'pre_button_label', array(
      'label' => 'Previous Step Button',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        new Engine_Filter_HtmlSpecialChars(),
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '63')),
      ),
      'value' => 'Pre'
    ));
    $this->addElement('Text', 'next_button_label', array(
      'label' => 'Next Step Button',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        new Engine_Filter_HtmlSpecialChars(),
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '63')),
      ),
      'value' => 'Next'
    ));
    $this->addElement('Text', 'pause_button_label', array(
      'label' => 'Pause Tour Button',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        new Engine_Filter_HtmlSpecialChars(),
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '63')),
      ),
      'value' => 'Pause'
    ));
    $this->addElement('Text', 'resume_button_label', array(
      'label' => 'Resume Tour Button',
      'allowEmpty' => false,
      'required' => true,
      'filters' => array(
        new Engine_Filter_HtmlSpecialChars(),
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_StringLength(array('max' => '63')),
      ),
      'value' => 'Resume'
    ));
    $this->addElement('Hidden', 'end_button_label', array(
      'value' => 'End',
      'order' => time()
    ));

    $this->addElement('Select', 'enabled', array(
      'label' => 'Enabled?',
      'value' => 1,
      'multiOptions' => array(
        1 => 'Yes',
        0 => 'No'
      )
    ));


    // Buttons
    $this->addElement('Button', 'submit', array(
      'label' => 'Create',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array('ViewHelper')
    ));

    $this->addElement('Cancel', 'cancel', array(
      'label' => 'Cancel',
      'link' => true,
      'prependText' => ' or ',
      'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'index')),
      'onClick' => 'javascript:parent.Smoothbox.close();',
      'decorators' => array(
        'ViewHelper'
      )
    ));
    $this->addDisplayGroup(array('submit', 'cancel'), 'buttons');
  }

}