<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetour
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Add.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitetour_Form_Admin_Tour_Step_Add extends Engine_Form
{

  protected $ignoreWidgets = array();
  protected $step;

  public function init()
  {
    $type = Zend_Controller_Front::getInstance()->getRequest()->getParam('type', 'widget');
    // Init form
    $this
      ->setTitle('Add New Tour Step');
    if( $type === 'widget' ) {
      $this->setDescription('Create new tour step for the widget placed on the selected widgetized page. You can add title and description explaining the feature of the related widget. You can set the position of the title and description based on position of widget on the widgetized page. You can also choose to redirect users to another page by adding the URL for that page.');
    } else {
      $this->setDescription('Create new tour step for the web element present on the selected widgetized page. You can add title and description explaining the feature of the related web element. You can set the position of the title and description based on position of web element on the widgetized page. You can also choose to redirect users to another page by adding the URL for that page.');
    }
    $this->setAttrib('id', 'sitetour-step-form')
      ->setDisableTranslator(true)
      ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
    ;

    $tour_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('tour_id', 0);
    $this->addElement('Hidden', 'type', array(
      'order' => 1000,
      'value' => $type,
    ));
    if( $this->step ) {
      $type = $this->step->type;
    }
    if( $type === 'widget' ) {
      $tour = Engine_Api::_()->getItem('sitetour_tour', $tour_id);
      if( empty($this->step) ) {
        foreach( $tour->getSteps() as $step ) {
          $this->ignoreWidgets[] = $step->params['content_id'];
        }
      }
      $this->addElement('Select', 'content_id', array(
        'label' => 'Select Widget',
        'multiOptions' => Engine_Api::_()->sitetour()->getPageWidgetLists($tour->getPage()->page_id, $this->ignoreWidgets),
        'allowEmpty' => false,
        'required' => true,
      ));
    } else {
      $this->addElement('Text', 'content_id', array(
        'label' => 'Element',
        'allowEmpty' => false,
        'required' => true,
      ));
    }

    $this->addElement('Text', 'title', array(
      'label' => 'Title',
      'description' => 'Enter the title of the tour step.',
      'allowEmpty' => true,
      'required' => false,
    ));

    $this->addElement('Textarea', 'body', array(
      'label' => 'Description',
      'description' => 'Enter the description of the tour step.',
      'allowEmpty' => true,
      'required' => false,
    ));


    $this->addElement('Select', 'position', array(
      'label' => 'Info Position',
      'description' => 'Choose the position of the title and description of the tour step.',
      'multiOptions' => array(
        'left' => 'Left',
        'right' => 'Right',
        'top' => 'Top',
        'bottom' => 'Bottom',
      ),
    ));

    $this->addElement('Select', 'backdrop', array(
      'label' => 'Highlight with Overlay',
      'description' => "Do you want to highlight this step with the dark overlay in background when the tour reaches to this step?",
      'multiOptions' => array(
        1 => "Yes",
        0 => "No",
      ),
    ));
    
    $this->addElement('Text', 'next_page_url', array(
      'label' => 'Redirect URL',
      'description' => 'Enter the URL of the page where you want to redirect the user after clicking on next button in this step. You can leave it blank if you don’t want to redirect user on another page. [Note: Enter URL of another page if this is the last step of your tour, otherwise tour will end after this step and other steps won’t get played.]',
    ));

    $this->addElement('Select', 'enabled', array(
      'label' => 'Enabled?',
      'value' => 1,
      'multiOptions' => array(
        1 => 'Yes',
        0 => 'No'
      )
    ));
    // Buttons
    $this->addElement('Button', 'submit', array(
      'label' => 'Create',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array('ViewHelper')
    ));

    $this->addElement('Cancel', 'cancel', array(
      'label' => 'Cancel',
      'link' => true,
      'prependText' => ' or ',
      'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'index')),
      'onClick' => 'javascript:parent.Smoothbox.close();',
      'decorators' => array(
        'ViewHelper'
      )
    ));
    $this->addDisplayGroup(array('submit', 'cancel'), 'buttons');
  }

}
