<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetour
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Sitetour.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitetour_View_Helper_Sitetour extends Zend_View_Helper_Abstract
{
  public function sitetour($pageName)
  {
    if( !Engine_Api::_()->getApi('settings', 'core')->getSetting('sitetour.enabled', 1) ) {
      return;
    }
    $tour = Engine_Api::_()->getItemTable('sitetour_tour')->getTourByPageName($pageName);
    if( empty($tour) || empty($tour->enabled) ) {
      return;
    }
    $steps = $tour->getSteps(array('enabled' => 1));
    if( count($steps) == 0 ) {
      return;
    }
    foreach( $steps as $step ) {
      $stepsList[] = array(
        'title' => $this->view->translate($step->title),
        'content' => $this->view->translate($step->body),
        'element' => $step->params['element'],
        'elementClass' => !empty($step->params['element-class']) ? $step->params['element-class'] : '',
        'placement' => $step->params['position'],
        'backdrop' => !empty($step->params['backdrop']),
        'backdropPadding' => 5,
      );
      if( !empty($step->params['next_page_url']) ) {
        $stepsList[] = array(
          'path' => $step->params['next_page_url'],
        );
      }
    }

    $enable_buttons = array(
      'previous' => true,
      'next' => true,
      'pause_resume' => true,
      'end' => true,
    );
    foreach( array_keys($enable_buttons) as $button ) {
      $enable_buttons[$button] = in_array($button, $tour->params['enable_buttons']);
    }
    $this->renderJSandCSS();
    $allowAutoPlay = true;
    $showIconButton = !empty($tour->params['buttonType']);
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if( $tour->params['show'] == 'auto-once' ) {
      if( $viewer_id ) {
        $viewsTable = Engine_Api::_()->getDbtable('views', 'sitetour');
        $view_id = $viewsTable
          ->select()
          ->from($viewsTable->info('name'), 'view_id')
          ->where('tour_id =?', $tour->tour_id)
          ->where('user_id =?', $viewer_id)
          ->query()
          ->fetchColumn();
        if( empty($view_id) ) {
          $viewsTable->insert(array(
            'tour_id' => $tour->getIdentity(),
            'user_id' => $viewer_id
          ));
        } else {
          $allowAutoPlay = false;
        }
      } else {
        $visibleTours = array();
        if( !empty($_COOKIE['en4_sitetour_visible']) ) {
          $visibleTours = json_decode($_COOKIE['en4_sitetour_visible'], true);
        }
        $allowAutoPlay = $allowAutoPlay && !in_array($tour->getIdentity(), $visibleTours);
        $visibleTours[$tour->getIdentity()] = $tour->getIdentity();
        setcookie('en4_sitetour_visible', json_encode($visibleTours), time() + (86400 * 30), '/');
      }
    }
    $params = array(
      'duration' => $tour->params['duration'],
      'steps' => $stepsList,
      'enable_buttons' => $enable_buttons,
      'showIconButton' => $showIconButton,
      'tourButton' => $tour->params['tour_button'],
      'tourButtonTemplate' => '<button type="button" id="sitetour_button" class="sitetour_btn sitetour_btn-default sitetour_btn-lg"><i class="fa fa-play"></i>' . $this->view->translate("Start Tour") . '</button>',
      'autoStart' => $allowAutoPlay && (empty($tour->params['tour_button']) || $tour->params['show'] != 'user-click'),
      'buttonTexts' => array(
        'previous' => $this->view->translate($tour->params['pre_button_label']),
        'next' => $this->view->translate($tour->params['next_button_label']),
        'pause' => $this->view->translate($tour->params['pause_button_label']),
        'resume' => $this->view->translate($tour->params['resume_button_label']),
        'end' => $this->view->translate($tour->params['end_button_label']),
      )
    );
    $jsonParams = $this->view->jsonInline($params);
    $script = <<<EOF
en4.core.runonce.add(function(){
  en4.sitetour.init($jsonParams);
});
EOF;
    $this->view->headScript()->appendScript($script);
  }

  private function renderJSandCSS()
  {
    $this->view->headScript()->appendFile($this->view->layout()->staticBaseUrl . 'application/modules/Sitetour/externals/scripts/core.js');

    $this->view->headScript()->appendFile($this->view->layout()->staticBaseUrl . 'externals/seao-jquery/jquery.min.js');

    $this->view->headScript()->appendFile($this->view->layout()->staticBaseUrl . 'application/modules/Sitetour/externals/scripts/bootstrap-tour-standalone.min.js');

    $this->view->headLink()
      ->appendStylesheet($this->view->layout()->staticBaseUrl . 'application/modules/Sitetour/externals/styles/tour.css');
  }

}