<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetutorial
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Settings.php 6590 2012-18-05 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitetutorial_Form_Admin_Settings_Settings extends Engine_Form
{
  public function init()
  {
    $this
    ->setTitle('Global Settings')
    ->setDescription('These settings affect all members in your community.');

		$settings = Engine_Api::_()->getApi('settings', 'core');

    $this->addElement('Text', 'sitetutorial_lsettings', array(
        'label' => 'Enter License key',
        'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
        'required' => true,
        'value' => $settings->getSetting('sitetutorial.lsettings'),
    ));

    if (APPLICATION_ENV == 'production') {
      $this->addElement('Checkbox', 'environment_mode', array(
          'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few pages of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
          'description' => 'System Mode',
          'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    // Add submit button
    $this->addElement('Button', 'submit_lsetting', array(
        'label' => 'Activate Your Plugin Now',
        'type' => 'submit',
        'ignore' => true
    ));

    $this->addElement('Radio', 'sitetutorial_link', array(
        'label' => 'Tutorials Link',
        'description' => 'Select the location of the main link for Tutorials.',
        'multiOptions' => array(
            3 => 'Main Navigation Menu',
            2 => 'Mini Navigation Menu',
            1 => 'Footer Menu',
            0 => 'Member Home Page Left side Navigation'
        ),
        'value' => $settings->getSetting('sitetutorial.link', 1),
    ));

		$this->addElement('Radio', 'sitetutorial_tag', array(
    	'label' => 'Tag Field',
      'description' => 'Do you want the Tag field to be displayed in the Tutorial creation form? (Assigning tags to Tutorials will enable the tags to appear in the Tag Cloud. Tags of Tutorials will be used in the SocialEngine Global Search for returning results and to return results in the Related Tutorials widget.)',
      'multiOptions' => array(
        1 => ' 	Yes',
        0 => ' 	No'
      ),
      'value' => $settings->getSetting('sitetutorial.tag', 1),
    ));

		$this->addElement('Radio', 'sitetutorial_search', array(
    	'label' => 'Show This Tutorial in Search Results',
      'description' => 'Do you want creators to be able to choose from the Tutorial creation form if their Tutorial should be searchable? (If you select ‘No’ over here, then users will not be able to choose whether their Tutorials should be searchable or not and the Tutorials created by them will be searchable in this plugin.)',
      'multiOptions' => array(
        1 => ' 	Yes',
        0 => ' 	No'
      ),
      'value' => $settings->getSetting('sitetutorial.search', 1),
    ));

    $this->addElement('Radio', 'sitetutorial_editor', array(
    	'label' => 'WYSIWYG Editor',
			'description' => 'Allow WYSIWYG editor for the answers of Tutorials.',
      'multiOptions' => array(
				1 => 'Yes',
				0 => 'No'
      ),
      'value' => $settings->getSetting('sitetutorial.editor', 1),
    ));

    $this->addElement('Text', 'sitetutorial_categories', array(
      'label' => 'Maximum Categories',
      'description' => 'Enter the maximum number of categories to be associated with an Tutorial.',
			'required' => true,
			'validators' => array(
					array('Int', true),
					array('GreaterThan', true, array(0)),
			),
      'value' => $settings->getSetting('sitetutorial.categories', 2),
    ));

		$this->addElement('Radio', 'sitetutorial_email', array(
			'label' => 'Notification for User Questions',
			'description' => 'Do you want to receive an email notification every time a question is posted for you by a user? (From Member Level Settings, you can choose who all should be able to ask questions.)',
			'multiOptions' => array(
				1 => 'Yes',
				0 => 'No'
			),
			'value' => $settings->getSetting('sitetutorial.email', 1),
		));

		$social_share_default_code = '<div class="addthis_toolbox addthis_default_style ">
		<a class="addthis_button_preferred_1"></a>
		<a class="addthis_button_preferred_2"></a>
		<a class="addthis_button_preferred_3"></a>
		<a class="addthis_button_preferred_4"></a>
		<a class="addthis_button_preferred_5"></a>
		<a class="addthis_button_compact"></a>
		<a class="addthis_counter addthis_bubble_style"></a>
		</div>
		<script type="text/javascript">
		var addthis_config = {
							services_compact: "facebook, twitter, linkedin, google, digg, more",
							services_exclude: "print, email"
		}
		</script>
		<script type="text/javascript" src="https://s7.addthis.com/js/250/addthis_widget.js"></script>';

    $this->addElement('Textarea', 'sitetutorial_code_share', array(
				'label' => 'Social Share Widget Code',
        'description' => "Personalize the code for social sharing buttons by adding your own code generated from: <a href='http://www.addthis.com/' target='_blank'>http://www.addthis.com/</a>. If you do not want to show these buttons, then you can simply empty this field.",
        'value' => $settings->getSetting('sitetutorial.code.share', $social_share_default_code),
    ));
		$this->sitetutorial_code_share->addDecorator('Description', array('placement' => 'PREPEND','class' => 'description', 'escape' => false));


    $this->addElement('Text', 'tutorial_manifestUrlP', array(
        'label' => "Tutorial pages URL alternate text for 'tutorials'",
        'allowEmpty' => false,
        'required' => true,
        'description' => "Please enter the text below which you want to display in place of 'tutorials' in the URLs of this plugin.",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('tutorial.manifestUrlP', "tutorials"),
    ));

    $this->addElement('Text', 'tutorial_manifestUrlS', array(
        'label' => "Tutorials pages URL alternate text for 'tutorial'",
        'allowEmpty' => false,
        'required' => true,
        'description' => "Please enter the text below which you want to display in place of 'tutorial' in the URLs of this plugin.",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('tutorial.manifestUrlS', "tutorial"),
    ));

		$this->addElement('Radio', 'sitetutorial_multilanguage', array(
    	'label' => 'Multiple Languages for Tutorials',
			'description' => "Do you want to enable multiple languages for the Tutorials while creation? (Select ‘Yes’, only if you have installed multiple languages from the 'Language Manager' section of the Admin Panel. Selecting ‘Yes’ over here will enable users to create their Tutorials in multiple languages installed on your site. If you select ‘No’ over here, then the pack you've marked as your 'default' pack, will be the language displayed to members.)",
      'multiOptions' => array(
				1 => 'Yes',
				0 => 'No'
      ),
      'value' => $settings->getSetting('sitetutorial.multilanguage', 0),
    ));

		//GET EXISTING LANGUAGES ARRAY
		$localeMultiOptions = Engine_Api::_()->sitetutorial()->getLanguageArray();

		$this->addElement('MultiCheckbox', 'sitetutorial_languages', array(
			'label' => 'Languages',
			'description' => 'Select the languages for which you want users to be able to create Tutorials.',
			'multiOptions' => $localeMultiOptions,
			'value' => $settings->getSetting('sitetutorial.languages'),
		));

    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }

}