<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetutorial
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 6590 2012-18-05 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitetutorial_Plugin_Menus {

	//TUTORIAL VIEW PRIVACY CHECK
  public function canViewSitetutorials() {

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();

		//CHECK TUTORIAL VIEW PRIVACY
    if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'view')) {
      return false;
    }
    return true;
  }

	//TUTORIAL CREATION PRIVACY CHECK
  public function canCreateSitetutorials() {

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();

		//CHECK TUTORIAL VIEW PRIVACY
    if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'view')) {
      return false;
    }

		//CHECK TUTORIAL CREATION PRIVACY
    if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'create')) {
      return false;
    }
    return true;
  }

	//TUTORIAL CREATION PRIVACY CHECK
  public function canAskQuestions() {

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();

		//CHECK TUTORIAL VIEW PRIVACY
    if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'view')) {
      return false;
    }

		//CHECK TUTORIAL CREATION PRIVACY
    if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'question')) {
      return false;
    }
    return true;
  }

	//ADD TUTORIAL EDIT LINK
  public function onMenuInitialize_SitetutorialGutterAdd($row) {

		//RETURN FALSE IF SUBJECT IS NOT SET
    if (!Engine_Api::_()->core()->hasSubject('sitetutorial_tutorial')) {
      return false;
    }

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		//CHECK TUTORIAL CREATION PRIVACY
    if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'create')) {
      return false;
    }

    return array(
        'class' => 'buttonlink icon_sitetutorial_add',
        'route' => 'sitetutorial_general',
				'action' => 'create',
    );
  }

	//ADD TUTORIAL EDIT LINK
  public function onMenuInitialize_SitetutorialGutterEdit($row) {

		//RETURN FALSE IF SUBJECT IS NOT SET
    if (!Engine_Api::_()->core()->hasSubject('sitetutorial_tutorial')) {
      return false;
    }

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		//GET SUBJECT
    $sitetutorial = Engine_Api::_()->core()->getSubject();

		//TUTORIAL EDIT PRIVACY
    $can_edit = $sitetutorial->authorization()->isAllowed(null, 'edit');

		//AUTHORIZATION CHECK
		if(empty($can_edit) || empty($viewer_id)) {
			return false;
		}

    return array(
        'class' => 'buttonlink icon_sitetutorial_edit',
        'route' => 'sitetutorial_specific',
				'action' => 'edit',
        'params' => array(
            'tutorial_id' => $sitetutorial->getIdentity(),
        ),
    );
  }

	//ADD TUTORIAL PRINT LINK
  public function onMenuInitialize_SitetutorialGutterPrint() {

		//RETURN FALSE IF SUBJECT IS NOT SET
    if (!Engine_Api::_()->core()->hasSubject('sitetutorial_tutorial')) {
      return false;
    }

		$request = Zend_Controller_Front::getInstance()->getRequest();

		$category_id = $request->getParam('category_id', null);
		$subcategory_id = $request->getParam('subcategory_id', null);
		$subsubcategory_id = $request->getParam('subsubcategory_id', null);

		//GET SUBJECT
    $sitetutorial = Engine_Api::_()->core()->getSubject();

    return array(
        'class' => 'buttonlink icon_sitetutorials_print',
        'target' => '_blank',
        'route' => 'sitetutorial_specific',
        'params' => array(
            'action' => 'print-view',
            'tutorial_id' => $sitetutorial->getIdentity(),
						'category_id' => $category_id,
						'subcategory_id' => $subcategory_id,
						'subsubcategory_id' => $subsubcategory_id
        ),
				'target' => '_blank'
    );
  }

	//ADD DOCUMENT PUBLISH LINK
  public function onMenuInitialize_SitetutorialGutterPublish() {

		//RETURN FALSE IF SUBJECT IS NOT SET
    if (!Engine_Api::_()->core()->hasSubject('sitetutorial_tutorial')) {
      return false;
    }

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		//GET SUBJECT
    $sitetutorial = Engine_Api::_()->core()->getSubject();
    if (empty($sitetutorial->draft) || empty($viewer_id)) {
      return false;
    }

    //USER IS ALLOWED FOR PUBLISH OR NOT
    $can_edit = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitetutorial_tutorial', 'edit');
		if(empty($can_edit) || ($can_edit == 1 && $viewer_id != $sitetutorial->owner_id)) {
			return false;
		}

    return array(
        'class' => 'buttonlink smoothbox icon_sitetutorial_publish',
        'route' => 'sitetutorial_specific',
        'params' => array(
						'action' => 'publish',
            'tutorial_id' => $sitetutorial->getIdentity(),
        ),
    );
  }

	//ADD TUTORIAL SHARE LINK
  public function onMenuInitialize_SitetutorialGutterShare() {

		//RETURN FALSE IF SUBJECT IS NOT SET
    if (!Engine_Api::_()->core()->hasSubject('sitetutorial_tutorial')) {
      return false;
    }

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

    //GET USER LEVEL ID
    if (!empty($viewer_id)) {
      $level_id = $viewer->level_id;
    } else {
      $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
    }

		//SHARING IS ALLOWED OR NOT TO THIS MEMBER LEVEL
		$can_share = Engine_Api::_()->authorization()->getPermission($level_id, 'sitetutorial_tutorial', 'share');

		//GET SUBJECT
    $sitetutorial = Engine_Api::_()->core()->getSubject();

		//AUTHORIZATION CHECK
    if (empty($can_share) || empty($viewer_id) || !empty($sitetutorial->draft) || empty($sitetutorial->approved) || empty($sitetutorial->search)) {
      return false;
    }

    return array(
        'class' => 'smoothbox buttonlink icon_sitetutorial_share',
        'route' => 'default',
        'params' => array(
            'module' => 'seaocore',
            'controller' => 'activity',
            'action' => 'share',
            'type' => $sitetutorial->getType(),
            'id' => $sitetutorial->getIdentity(),
            'format' => 'smoothbox',
						'not_parent_refresh' => 1,
        ),
    );
  }

	//ADD TUTORIAL DELETE LINK
  public function onMenuInitialize_SitetutorialGutterDelete() {

		//RETURN FALSE IF SUBJECT IS NOT SET
    if (!Engine_Api::_()->core()->hasSubject('sitetutorial_tutorial')) {
      return false;
    }

		//GET VIEWER
    $viewer = Engine_Api::_()->user()->getViewer();
		$viewer_id = $viewer->getIdentity();

		//GET SUBJECT
    $sitetutorial = Engine_Api::_()->core()->getSubject();

		//TUTORIAL DELETE PRIVACY
    $can_delete = $sitetutorial->authorization()->isAllowed(null, 'delete');

		//AUTHORIZATION CHECK
		if(empty($can_delete) || empty($viewer_id)) {
			return false;
		}

    return array(
        'class' => 'buttonlink smoothbox icon_sitetutorial_delete',
        'route' => 'sitetutorial_specific',
				'action' => 'delete',
        'params' => array(
            'tutorial_id' => $sitetutorial->getIdentity(),
        ),
    );
  }

}