<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteuserexport
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: core.php 2011-11-15 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Siteuserexport_Api_Core extends Core_Api_Abstract {

	public function getUserData($params, $fieldAs = NULL) {

		$userTable = Engine_Api::_()->getDbtable('users', 'user');
		$tableName = $userTable->info('name');

		if (!empty($fieldAs)) {
			$select = $userTable->select()
				->from($tableName, $fieldAs);
		} else {
			$select = $userTable->select()
				->from($tableName);
		}

		if (!empty($params['level_id']) && $params['level_id'] != 0) {
			$select->where("level_id = ?", $params['level_id']);
		}

		if (isset($params['enabled']) && $params['enabled'] != -1) {
			$select->where("enabled = ?", $params['enabled']);
		}

		if (isset($params['approved']) && $params['approved'] != -1) {
			$select->where("approved = ?", $params['approved']);
		}

		if (!empty($params['start_time'])) {
			$select->where("creation_date >= ?", $params['start_time']);
		}

		if (!empty($params['end_time'])) {
			$select->where("creation_date <= ?", $params['end_time']);
		}

		if (!empty($params['option_id'])) {

			$fieldApi = Engine_Api::_()->getApi('Core', 'fields');
			$tableSearch = $fieldApi->getTable($fieldApi->getFieldType('user'), 'search');

			$optionId = (string) $params['option_id'];
			$tableN = $tableSearch->info('name');
			$itemIds = $tableSearch->select()
				->from($tableSearch->info('name'), array('item_id'))
				->where("$tableN.profile_type = ?", $optionId)
				->query()
				->fetchAll(Zend_Db::FETCH_COLUMN);

			if (empty($itemIds)) {
				return array();
			}

			$select->where("user_id IN (?)", $itemIds);
		}

		$data = $userTable->fetchAll($select)->toArray();

		return $data;
	}

	public function getFieldsValue($params) {

		$fieldApi = Engine_Api::_()->getApi('Core', 'fields');
		$tableMeta = $fieldApi->getTable($fieldApi->getFieldType('user'), 'meta');

		$mapData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMaps('user');
		$metaData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMeta('user');

		$secondLevelMaps = array();
		$secondLevelFields = array();
		if (!empty($params['option_id'])) {
			$secondLevelMaps = $mapData->getRowsMatching('option_id', $params['option_id']);
			if (!empty($secondLevelMaps)) {
				foreach ($secondLevelMaps as $map) {
					$secondLevelFields[$map->child_id] = $map->getChild();
				}
			}
		}

		foreach ($secondLevelFields as $key => $value) {
			$allProfileFieldsIds[] = $value->getElementName();
		}

		// getting profile fields all.
		$tableName = $tableMeta->info('name');
		$select = $tableMeta->select()
			->from($tableName, array('field_id', 'label', 'type'))
			->where("$tableName.type != ?", 'heading');

		$rawProfileFields = $tableMeta->fetchAll($select)->toArray(); //  like Array( [0] => Array([field_id] => 3, [label] => First Name))

		$profileTableFields = array();
		$profileFieldType = array();

		foreach ($rawProfileFields as $value) {
			if (in_array($value['field_id'], $allProfileFieldsIds)) {
				$profileTableFields[$value['field_id']] = $value['label'];
				$profileFieldType[$value['field_id']] = $value['type'];
			}

		}

		// defining user fields(all).

		$userTableFields = array('u1' => 'user_id', 'u2' => 'email', 'u3' => 'username', 'u4' => 'displayname', 'u5' => 'status', 'u6' => 'language', 'u7' => 'timezone', 'u8' => 'level_id', 'u9' => 'enabled', 'u10' => 'verified', 'u11' => 'approved', 'u12' => 'creation_date', 'u13' => 'modified_date', 'u14' => 'lastlogin_date');

		// deviding fields into groups, profile fields and user fields
		// we have got value is key here we are deviding into two groups.

		$editedFields = array();
		$UserFields = array();
		if (!empty($params['fields'])) {
			$UserFields = array_intersect_key($userTableFields, $params['fields']); // array ('u1' => 'usertable_field_name')
			foreach ($params['fields'] as $key => $value) {
				if (!empty($userTableFields[$key])) {
					$editedFields[$value] = $userTableFields[$key];
				} else {
					$editedFields[$value] = '';
				}
			}
		}

        $fieldUid = $fieldUser_id = array_search('user_id', $editedFields);
		if(empty($fieldUid)) {
			$editedFields[] = 'user_id';
			$fieldUser_id = 'user_id';
		}
		
		$userData = $this->getUserData($params, $editedFields);

		$userIds = array();

		// getting user ids, will be used to fetch profile fields value
		foreach ($userData as $value) {
			$userIds[] = $value[$fieldUser_id];
		}

		$finalUserFields = array();
		foreach ($UserFields as $key => $value) {
			$finalUserFields[$value] = $value; // this will used to get apropriate data.
		}

		$requiredProfileFields = array();
		$fieldsId = array();
		foreach ($params['fields'] as $key => $value) {
			if (substr($key, 0, 1) != 'u') {
				$requiredProfileFields[] = $key;
				$fieldsId[$key] = $value;
			}
		}

		// getting fields according to search.

		$finalUserFieldValue = array();
		foreach ($userData as $value) {
			$finalUserFieldsValue[] = array_intersect_key($value, $UserFields);
		}

		// get values. of corresponding fields value.
		// 1. getting profile fields value. all

		$tabelvalues = $fieldApi->getTable($fieldApi->getFieldType('user'), 'values');

		$tabelvName = $tabelvalues->info('name');

		if (!empty($allProfileFieldsIds) && !empty($userIds)) {
			$fieldData = $tabelvalues->select()
				->from($tabelvName)
				->where("field_id IN(?)", $allProfileFieldsIds)
				->where("item_id IN(?)", $userIds)
				->order('item_id ASC')
				->order('field_id ASC')
				->query()
				->fetchAll();
		}

		$item_id = $fieldData['0']['item_id'];
		$profileFieldsArray = array();

		foreach ($userIds as $id) {
			$profileFieldsArray[$id] = array_shift($userData);

			if (!empty($requiredProfileFields)) {
				foreach ($profileTableFields as $key => $field) {
					if (in_array($key, $requiredProfileFields)) {
						$profileFieldsArray[$id][$field] = '';
					}
				}
			}
		}
        $p = array();
		$prev_field_id = null;
		$prev_item_id = null;
		foreach ($fieldData as $value) {
			$item_id = $value['item_id'];

			if ($value['field_id'] == $prev_field_id && $item_id == $prev_item_id) {
				$v = $p[$item_id][$value['field_id']];
				$p[$item_id][$value['field_id']] = array($v);
				array_push($p[$item_id][$value['field_id']], $value['value']);
			} else {
				$p[$item_id][$value['field_id']] = $value['value'];
			}

			$prev_item_id = $value['item_id'];
			$prev_field_id = $value['field_id'];
		}

		$tableOptions = $fieldApi->getTable($fieldApi->getFieldType('user'), 'options');
		foreach ($p as $item_id => $values) {
			foreach ($values as $key => $value) {
				if (in_array($key, $requiredProfileFields)) {

					if ($profileFieldType[$key] == 'gender' || $profileFieldType[$key] == 'select') {

						$v = $tableOptions->select()
							->from($tableOptions->info('name'), array('label'))
							->where('field_id = ?', $key)
							->where('option_id = ?', $value)
							->query()
							->fetchAll(Zend_Db::FETCH_COLUMN);

						$profileFieldsArray[$item_id][$profileTableFields[$key]] = $v[0];

					} else if ($profileFieldType[$key] == 'multiselect' || $profileFieldType[$key] == 'multi_checkbox') {
						$prm['field_id'] = $key;
						$prm['option_ids'] = $value;
						$v = $this->getMultiOptionValues($prm);
						$profileFieldsArray[$item_id][$profileTableFields[$key]] = $v;
					} else {
						$profileFieldsArray[$item_id][$profileTableFields[$key]] = $value;
					}

				}
			}
		}

		return $profileFieldsArray;
	}

	public function getFields($option_id) {

		if (empty($option_id)) {
			$getProfileTypes = Engine_Api::_()->getApi('Core', 'siteuserexport')->getProfileTypes();
			if (!empty($getProfileTypes)) {
				reset($getProfileTypes);
				$option_id = key($getProfileTypes);
			}
		}

		// get the fields value and show in multiselct checkbox
		$fieldApi = Engine_Api::_()->getApi('Core', 'fields');
		$tableMeta = $fieldApi->getTable($fieldApi->getFieldType('user'), 'meta');

		$mapData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMaps('user');
		$metaData = Engine_Api::_()->getApi('core', 'fields')->getFieldsMeta('user');

		$secondLevelMaps = array();
		$secondLevelFields = array();
		if (!empty($option_id)) {
			$secondLevelMaps = $mapData->getRowsMatching('option_id', $option_id);
			if (!empty($secondLevelMaps)) {
				foreach ($secondLevelMaps as $map) {
					$secondLevelFields[$map->child_id] = $map->getChild();
				}
			}
		}

		$profileFieldIds = array();
		foreach ($secondLevelFields as $key => $value) {
			$profileFieldIds[] = $value->getElementName();
		}

		$tableName = $tableMeta->info('name');
		$select = $tableMeta->select()
			->from($tableName, array('field_id', 'label'))
			->where("$tableName.type != ?", 'heading');

		$data = $tableMeta->fetchAll($select)->toArray();
		$profileFields = array();

		foreach ($data as $value) {
			if (in_array($value['field_id'], $profileFieldIds)) {
				$profileFields[$value['field_id']] = $value['label'];
			}

		}

		$userTableFields = array('u1' => 'user_id', 'u2' => 'email', 'u3' => 'username', 'u4' => 'displayname', 'u5' => 'status', 'u6' => 'language', 'u7' => 'timezone', 'u8' => 'level_id', 'u9' => 'enabled', 'u10' => 'verified', 'u11' => 'approved', 'u12' => 'creation_date', 'u13' => 'modified_date', 'u14' => 'lastlogin_date');

		foreach ($profileFields as $key => $value) {
			$userTableFields[$key] = $value;
		}

		return $userTableFields;

	}

	public function getProfileTypes() {

		$db = Engine_Db_Table::getDefaultAdapter();
		$select = new Zend_Db_Select($db);

		$tableOption = "engine4_user_fields_options";
		$select = $db->select()
			->from($tableOption, array('option_id', 'label'))
			->where("$tableOption.field_id = ?", 1);

		$data = $db->fetchAll($select);

		$profileTypes = array();
		foreach ($data as $value) {
			$profileTypes[$value['option_id']] = $value['label'];
		}

		return $profileTypes;
	}

	public function getMultiOptionValues($params) {

		$fieldApi = Engine_Api::_()->getApi('Core', 'fields');
		$tableOptions = $fieldApi->getTable($fieldApi->getFieldType('user'), 'options');

		if (!empty($params['option_ids'])) {
			$v = $tableOptions->select()
				->from($tableOptions->info('name'), array('label'))
				->where('field_id = ?', $params['field_id'])
				->where('option_id IN (?)', $params['option_ids'])
				->query()
				->fetchAll(Zend_Db::FETCH_COLUMN);
		}

		if (empty($v)) {
			return NULL;
		}

		return Zend_Json::encode($v);
	}
}
