<?php

class Siteuserkyc_IndexController extends Core_Controller_Action_Standard {

	protected $_engineApi = null;
	protected $_viewer = null;
	protected $_viewer_id = null;
	protected $_kycApi = null;

	public function init() {

		$this->_engineApi = Engine_Api::_();
		$this->_viewer = $this->_engineApi->user()->getViewer();
		$this->_viewer_id = $this->_viewer->getIdentity();
		$this->_kycApi = $this->_engineApi->siteuserkyc();

	}


	public function manageAction() {

		$canViewerManageDocs = new Siteuserkyc_Plugin_Menus();
		$result = $canViewerManageDocs->canManageDocument();
		if ( !$result ) {
			return $this->_forward('requireauth', 'error', 'core');
		}
		if ( $this->_kycApi->isViewerAllow() ) {
			$this->view->isViewerAllow = true;
		}
		$table = $this->_engineApi->getDbtable('kycs', 'siteuserkyc');
		$select = $table->select()->where( 'user_id = ?' , $this->_viewer_id )->where( "document_verification_status like 'approved' or document_verification_status like 'pending' " );
		$this->view->isNonRejectedDocumentExist = $table->fetchRow( $select );
		$this->view->paginator = $paginator = $this->_kycApi->getSiteuserkycsPaginator( $this->_viewer, array( 'user_id' => $this->_viewer_id ) );
		$paginator->setItemCountPerPage($paginator->getTotalItemCount());
		$this->_helper->content->setEnabled();

	}


	public function uploadKycfileAction() {

		// Check if user can upload document or not
		if ( empty($this->_viewer_id) ) {
			return $this->_forward('requireauth', 'error', 'core');
		}
		if ( !$this->_kycApi->isViewerAllow() ) {
			// Do not allow to upload document
			return $this->_forward('requireauth', 'error', 'core');
		}
		$allowedDocuments = $this->_kycApi->getAllowedDocuments();
		if ( count($allowedDocuments) < 1 ) {
			return $this->_forward('requireauth', 'error', 'core');
		}
		$this->view->form = $form = new Siteuserkyc_Form_UserKyc_UploadFile( array( 'allowedDocuments' => $allowedDocuments ) );
		if ( !$this->getRequest()->isPost() ) {
			return;
		}
		if ( !$form->isValid($this->getRequest()->getPost()) ) {
			$formErrors = $form->getMessages();
			foreach ($formErrors as $key => $value) {
				$formErrors[$key] = ( !empty($value) && is_array($value) ) ? implode(', ', $value) : '';
			}
			$this->view->formErrors = $formErrors;
		}
			// Process
		$values = $form->getValues();

		$table = Engine_Api::_()->getDbtable('kycs', 'siteuserkyc'); 	
		$db = $table->getAdapter();
		$db->beginTransaction();

		try {
			$values['user_id'] = $this->_viewer_id;
			$values['document_verification_status'] = 'pending';
			// Create contest
			$kyc = $table->createRow();
			$kyc->setFromArray($values);
			$kyc->save();
			$kyc->uploadKYCPhoto( $form->user_profile_photo,'user_profile_photo');
			$kyc->uploadKYCPhoto( $form->document_front_photo,'document_front_photo');
			if ( !empty($form->document_back_photo->getValue()) ) {
				$kyc->uploadKYCPhoto( $form->document_back_photo,'document_back_photo');
			}
			$db->commit();
		} catch( Exception $e ) {
			$db->rollBack();
			throw $e;
		}
		$this->view->message = Zend_Registry::get('Zend_Translate')->_( "Your Document has been uploaded now 'Submit For Verification'" );
		return $this->_forward('success' ,'utility', 'core', array(
									'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'siteuserkyc', 'controller' => 'index','action' => 'manage'), 'default', true),
									'messages' => Array($this->view->message)
								));

	}


	public function previewAction() {
		//GET THE SITESTOREPRODUCT ITEM
		$this->view->kycItem = $this->_engineApi->getItem('siteuserkyc_kyc', $this->_getParam('id'));
		if( empty( $this->view->kycItem ) ) {
			return $this->_forward('notfound', 'error', 'core');
		}
		$this->_helper->content->setEnabled();
	}


	public function verificationAction() {

		//GET THE SITESTOREPRODUCT ITEM
		$this->view->kyc_id = $kyc_id = $this->_getParam('id', null);
		if ( empty($kyc_id) || empty($this->_viewer_id) ) {
			return $this->_forward('notfound', 'error', 'core');
		}
		$kycItem = $this->_engineApi->getItem('siteuserkyc_kyc', $kyc_id );
		if ( empty($kycItem) || $this->_viewer_id != $kycItem->user_id ) {
			return $this->_forward('notfound', 'error', 'core');
		}

		$autoApproved = $this->_kycApi->canUserVerifyKYCDocuments( $this->_viewer );
		$kycItem->verification = 1;
		if ( $autoApproved ) {
			$kycItem->document_verification_status = 'approved';
		}
		$kycItem->save();

		//Send mail to superadmin
		$allowedUsers = $this->_kycApi->getAllowedAdmins();
		if ( !empty($allowedUsers) ) {
			$allowedUsers = explode( ',', $allowedUsers );
			foreach( $allowedUsers as $user_id ) {
				$user = $this->_engineApi->getItem( 'user', $user_id );
				$this->_kycApi->sendDocumentSubmitMail( $kycItem, $user );
			}
		}
		// Send mail to super admins too
		$authtable = $this->_engineApi->getDbtable('levels', 'authorization');
		$select = $authtable->select()->from( $authtable->info('name'), 'level_id' )->where( "type = 'admin' and flag = 'superadmin' ")->query();
		$levelData = $select->fetchAll();
		if ( !empty($levelData) ) {
			$levelData = array_column($levelData, 'level_id');
			$usersTable = $this->_engineApi->getItemTable('user');
			$select = $usersTable->select()->where('level_id in(?)', $levelData );
			$users = $usersTable->fetchAll($select);
			foreach( $users as $singleUser ) {
				$this->_kycApi->sendDocumentSubmitMail( $kycItem, $singleUser );
			}
		}
		if ( $this->_getParam('format') == 'smoothbox' ) {
			$this->_forward( 'success', 'utility', 'core', array( 'smoothboxClose' => 10, 'parentRefresh' => 10, 'messages' => array('Submitted Succesfully.') ) );	
		} else {
			$this->_redirect('siteuserkyc/index/manage');
		}

	}


	public function deleteAction() {

		//GET THE SITESTOREPRODUCT ITEM
		$this->view->kyc_id = $kyc_id = $this->_getParam('kyc_id', null);
		if ( empty($kyc_id) || empty($this->_viewer_id) ) {
			return $this->_forward('notfound', 'error', 'core');
		}
		$kycItem = $this->_engineApi->getItem('siteuserkyc_kyc', $kyc_id );
		if ( empty($kycItem) || $this->_viewer_id != $kycItem->user_id ) {
			return $this->_forward('notfound', 'error', 'core');
		}
		// check if doucment below to viewer or not
		if ( !$this->getRequest()->isPost() ) {
			return;
		}
		$kycItem->delete(); 
		$this->_redirect('siteuserkyc/index/manage');
	}

}