<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitevod
 * @copyright  Copyright 2018-2019 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: 4.10.3 2018-09-08 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitevod_Api_Core extends Core_Api_Abstract
{

  const STREAM_INITIAL_STATUS = 'initial';
  const STREAM_UPLOADED_ENCODEING = 'encode';
  const STREAM_UPLOADED_STATUS = 'uploaded';
  const STREAM_PROGRESS_STATUS = 'progress';
  const STREAM_COMPLETED_STATUS = 'completed';
  const STREAM_FAILED_STATUS = 'fail';

  // handle video upload
  public function createStream($data, $file)
  {
    // Channel video in temporary storage object for ffmpeg to handle
    $storage = Engine_Api::_()->getItemTable('storage_file');
    $data['service_id'] = $this->getLocalStorageServiceId();
    $storageObject = $storage->createFile($file, $data);
    // Remove temporary file
    @unlink($file);
    $status = Sitevod_Api_Core::STREAM_UPLOADED_ENCODEING;
    $jobName = 'sitevod_stream_encode';
    if( in_array(strtolower($storageObject->extension), array('mp4', 'mov', 'mpg', 'mv4', 'm2ts')) ) {
      $status = Sitevod_Api_Core::STREAM_INITIAL_STATUS;
      $jobName = 'sitevod_stream_uplaod';
    }
    // Add to jobs
    $params = $storageObject->toArray();
    $params['status'] = $status;
    $table = Engine_Api::_()->getDbtable('stream', 'sitevod');
    $table->delete(array('file_id = ?' => $storageObject->getIdentity()));
    $row = $table->createRow();
    $row->setFromArray($params);
    $row->save();
    Engine_Api::_()->getDbtable('jobs', 'core')->addJob($jobName, array(
      'stream_id' => $row->getIdentity(),
    ));
    return $storageObject;
  }

  public function getAwsSourceStreamServiceId()
  {
    $serviceTypesTable = Engine_Api::_()->getDbtable('serviceTypes', 'storage');
    $serviceTypeId = $serviceTypesTable->select()
      ->from($serviceTypesTable, 'servicetype_id')
      ->where('`plugin` = ?', 'Sitevod_Service_S3')
      ->limit(1)
      ->query()
      ->fetchColumn();
    $serviceTable = Engine_Api::_()->getDbtable('services', 'storage');
    return $serviceTable->select()
        ->from($serviceTable, 'service_id')
        ->where('`enabled` = ?', 1)
        ->where('`servicetype_id` = ?', $serviceTypeId)
        ->limit(1)
        ->query()
        ->fetchColumn();
  }

  public function getAwsSourceStreamService()
  {
    return Engine_Api::_()->getDbtable('services', 'storage')->getService($this->getAwsSourceStreamServiceId());
  }

  public function getAwsStreamServiceId()
  {
    $serviceTypesTable = Engine_Api::_()->getDbtable('serviceTypes', 'storage');
    $serviceTypeId = $serviceTypesTable->select()
      ->from($serviceTypesTable, 'servicetype_id')
      ->where('`plugin` = ?', 'Sitevod_Service_StreamS3')
      ->limit(1)
      ->query()
      ->fetchColumn();
    $serviceTable = Engine_Api::_()->getDbtable('services', 'storage');
    return $serviceTable->select()
        ->from($serviceTable, 'service_id')
        ->where('`enabled` = ?', 1)
        ->where('`servicetype_id` = ?', $serviceTypeId)
        ->limit(1)
        ->query()
        ->fetchColumn();
  }

  public function getAwsStreamService()
  {
    return Engine_Api::_()->getDbtable('services', 'storage')->getService($this->getAwsStreamServiceId());
  }

  public function getLocalStorageServiceId()
  {
    $serviceTable = Engine_Api::_()->getDbtable('services', 'storage');
    return $serviceTable->select()
        ->from($serviceTable, 'service_id')
        ->where('`enabled` = ?', 1)
        ->where('`servicetype_id` = ?', 1)
        ->limit(1)
        ->query()
        ->fetchColumn();
  }

  public function hasReady()
  {
    $results = array();
    if( !$this->getLocalStorageServiceId() ) {
      $results['errors'] = 'SITEVOD_LOCAL_STORAGE_NOT_SETUP';
    }
    if( !$this->getAwsSourceStreamServiceId() ) {
      $results['errors'] = 'SITEVOD_AWS_SOURCE_STORAGE_NOT_SETUP';
    }
    if( !$this->getAwsStreamServiceId() ) {
      $results['errors'] = 'SITEVOD_AWS_TARGET_STORAGE_NOT_SETUP';
    }
    $results['status'] = empty($results['errors']);
    return $results;
  }

  public function downloadFiles($service, $extractDir = '')
  {
    $services = array(
      'amazon' => 'aHR0cDovL3NvY2lhbGVuZ2luZWFkZG9ucy5jb20vU29jaWFsRW5naW5lL1NvY2lhbGVuZ2luZU1vZHVsZXMvc2l0ZW90cHZlcmlmaWVyX2xpYnJhcmllcy9zdG9yYWdlL2xpYnJhcnktc2Vhby1hd3MtNC4xMC4zLnRhcg==',
    );
    if( empty($services[$service]) ) {
      return false;
    }
    $fileUrl = base64_decode($services[$service]);
    set_time_limit(0);
    $urlParts = explode('/', trim(parse_url($fileUrl, PHP_URL_PATH), '/'));
    $newfilename = end($urlParts);
    $local_path = str_replace('/', DS, APPLICATION_PATH . '/temporary/package/archives/');
    $extractDir = str_replace('/', DS, APPLICATION_PATH . '/temporary/package/packages');
    $path = $local_path . $newfilename;
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $fileUrl);
    curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
    ob_start();
    $result = curl_exec($ch);
    if( empty($result) ) {
      $result = file_get_contents($fileUrl);
    }
    curl_close($ch);
    ob_end_clean();
    $status = false;
    if( !empty($result) && !strstr(substr($result, 0, 50), 'error') ) {

      $file = fopen($path, 'wb');
      chmod($path, 0777);
      $result = fwrite($file, $result);
      fclose($file);
      $status = true;
    }
    if( $status ) {
      // Try to deflate archive?
      $extractFiles = array($path);
      $packagesInfo = array();
      $toRemove = array();
      try {
        while( count($extractFiles) > 0 ) {
          $current = array_shift($extractFiles);
          // Try to extract
          $outputPath = Engine_Package_Archive::inflate($current, $extractDir);
          // Add to remove after extraction
          $toRemove[] = $outputPath;
          @unlink($current);
        }
      } catch( Exception $e ) {
        $error = $e->getMessage();
        return false;
      }
      $data = file_get_contents($outputPath . DS . 'package.json');
      $data = json_decode($data, true);
      $vfsAdapter = 'system';
      $vfsConfig = array(
        'path' => APPLICATION_PATH,
      );
      $vfs = Engine_Vfs::factory($vfsAdapter, $vfsConfig);
      foreach( $data['structure'] as $structure ) {
        $filesInfo = $structure['structure'];
        $desPath = $structure['path'];
        $paths = explode('/', $desPath);
        $dP = '';
        foreach( $paths as $dirName ) {
          $directory = $vfs->path($dP . $dirName);
          // Already a directory
          if( !$vfs->isDirectory($directory) ) {
            $vfs->makeDirectory($directory, true);
            $vfs->mode($directory, 0777);
          }
          $dP .= $dirName . '/';
        }

        foreach( $filesInfo as $info ) {
          if( $info['path'] == 'manifest.php' ) {
            continue;
          }
          $fP = $desPath . DS . $info['path'];
          if( !empty($info['dir']) ) {
            $vfs->makeDirectory($fP, true);
            $vfs->mode($fP, $info['perms']);
          } else {
            $vfs->makeDirectory(dirname($fP), true);
            $vfs->put($fP, $outputPath . DS . $fP);
            $vfs->mode($fP, $info['perms']);
          }
        }
      }
      // Remove to remove
      foreach( $toRemove as $removeFile ) {
        if( is_dir($removeFile) ) {
          try {
            Engine_Package_Utilities::fsRmdirRecursive($removeFile, true);
          } catch( Exception $e ) {
            
          }
        } elseif( is_file($removeFile) ) {
          @unlink($removeFile);
        }
      }
    }

    return $status;
  }

}