<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitevod
 * @copyright  Copyright 2018-2019 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: 4.10.3 2018-09-08 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
require APPLICATION_PATH . '/application/libraries/SEAO/aws/aws-autoloader.php';
require APPLICATION_PATH . '/application/modules/Sitevod/php-m3u8/vendor/autoload.php';

use Chrisyue\PhpM3u8\M3u8;
use Aws\Sns\Message;
use Aws\Sns\MessageValidator;
use GuzzleHttp\Client;

class Sitevod_SnsController extends Core_Controller_Action_Standard
{

  public function indexAction()
  {
    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $enableStreamType = $coreSettings->getSetting('sitevod.streamType', 'dash'); //'hls'
    // Make sure the request is POST
    if( $_SERVER['REQUEST_METHOD'] !== 'POST' ) {
      http_response_code(405);
      die;
    }

    try {
      // Create a message from the post data and validate its signature
      $message = Message::fromRawPostData();
      $validator = new MessageValidator();
      $validator->validate($message);
    } catch( Exception $e ) {
      // Pretend we're not here if the message is invalid
      http_response_code(404);
      die;
    }    
    if( $message->offsetGet('Type') === 'SubscriptionConfirmation' ) {
      // Send a request to the SubscribeURL to complete subscription
      (new Client)->get($message->offsetGet('SubscribeURL'))->send();
    } elseif( $message->offsetGet('Type') === 'Notification' ) {
      $logfile = APPLICATION_PATH . '/temporary/log/aws-vod-sns.log';
      // Do something with the notification
      file_put_contents($logfile, date('c') . ':' .
        print_r($message->toArray(), true), FILE_APPEND);

      if( stripos($message->offsetGet('Subject'), "Workflow status:: Ingest::") !== false ) {
        $messageBody = json_decode($message->offsetGet('Message'), true);
        $stream = Engine_Api::_()->getDbtable('stream', 'sitevod')->getStreamByFileName($messageBody['srcVideo']);
        if( !$stream ) {
          return;
        }
        $data = array(
          'aws_guid' => $messageBody['guid'],
          'status' => Sitevod_Api_Core::STREAM_PROGRESS_STATUS
        );
        $stream->setFromArray($data);
        $stream->save();
      }
      if( stripos($message->offsetGet('Subject'), "Workflow status:: Complete::") !== false ) {
        $messageBody = json_decode($message->offsetGet('Message'), true);
        $stream = Engine_Api::_()->getDbtable('stream', 'sitevod')->getStreamByFileName($messageBody['srcVideo']);
        if( !$stream ) {
          return;
        }
        $data = array(
          'aws_guid' => $messageBody['guid'],
          'hls_url' => !empty($messageBody['hlsUrl']) ? $messageBody['hlsUrl'] : '',
          'dash_url' => !empty($messageBody['dashUrl']) ? $messageBody['dashUrl'] : '',
          'thumb_url' => !empty($messageBody['thumbNailUrl']) && count($messageBody['thumbNailUrl']) > 0 ? $messageBody['thumbNailUrl'][0] : '',
          'mp4Outputs' => $this->getMp4Files($messageBody),
          'status' => Sitevod_Api_Core::STREAM_COMPLETED_STATUS,
          'duration' => !empty($messageBody['hlsUrl']) ? $this->getHsaDuration($messageBody['hlsUrl']) : $this->getDashDuration($messageBody['dashUrl'])
        );
        $stream->setFromArray($data);
        $stream->save();

        $storageFile = Engine_Api::_()->getItem('storage_file', $stream->file_id);
        $desService = Engine_Api::_()->sitevod()->getAwsStreamService();

        if( $enableStreamType === 'hls' && !empty($stream->hls_url) ) {
          $storageFile->storage_path = str_replace($desService->getBaseUrl(), '', $stream->hls_url);
          $storageFile->service_id = Engine_Api::_()->sitevod()->getAwsStreamServiceId();
          $storageFile->extension = 'm3u8';
          $storageFile->mime_major = 'application';
          $storageFile->mime_minor = 'x-mpegURL';
          $storageFile->save();
        }
        if( $enableStreamType === 'dash' && !empty($stream->dash_url) ) {
          $storageFile->storage_path = str_replace($desService->getBaseUrl(), '', $stream->dash_url);
          $storageFile->service_id = Engine_Api::_()->sitevod()->getAwsStreamServiceId();
          $storageFile->extension = 'mpd';
          $storageFile->mime_major = 'application';
          $storageFile->mime_minor = 'dash+xml';
          $storageFile->save();
        }
        $stream->triggerStatusEvent();

        Engine_Api::_()->getDbtable('jobs', 'core')->addJob('sitevod_stream_remove', array(
          'stream_id' => $stream->getIdentity(),
        ));
      }
    }
    exit(0);
  }

  private function getMp4Files($messageBody)
  {
    $files = array();
    if( empty($messageBody['mp4Urls']) ) {
      return $files;
    }
    foreach( $messageBody['mp4Urls'] as $f ) {
      $key = end(explode('_', basename($f, ".mp4")));
      $files[$key] = $f;
    }
    return $files;
  }

  private function getDashDuration($url)
  {
    $client = Zend_Feed::getHttpClient();
    $client->setUri($url);
    $response = $client->request('GET');
    if( $response->getStatus() !== 200 ) {
      return;
    }
    $body = $response->getBody();
    $doc = new DOMDocument;
    $doc = Zend_Xml_Security::scan($body, $doc);
    $node = $doc->getElementsByTagName('MPD')->item(0);
    if( $node->getAttribute(type) !== 'static' ) {
      return;
    }
    $ISO8601 = $doc->getElementsByTagName('MPD')->item(0)->getAttribute('mediaPresentationDuration');
    preg_match('/\d{1,2}[D]/', $ISO8601, $days);
    preg_match('/\d{1,2}[H]/', $ISO8601, $hours);
    preg_match('/\d{1,2}[M]/', $ISO8601, $minutes);
    preg_match('/[\d+\.]{1,6}[S]/', $ISO8601, $seconds);
    $duration = [
      'days' => $days ? substr($days[0], 0, -1) : 0,
      'hours' => $hours ? substr($hours[0], 0, -1) : 0,
      'minutes' => $minutes ? substr($minutes[0], 0, -1) : 0,
      'seconds' => $seconds ? substr($seconds[0], 0, -1) : 0,
    ];

    return ($duration['days'] * 24 * 60 * 60) + ($duration['hours'] * 60 * 60) + ($duration['minutes'] * 60) + $duration['seconds'];
  }

  private function getHsaDuration($url)
  {
    $m3u8 = file_get_contents($url);
    $url2 = array();
    if( strlen($m3u8) > 3 ) {
      $tmp = strrpos($url, '/');
      if( $tmp !== false ) {
        $base_url = substr($url, 0, $tmp + 1);
        $array = preg_split('/\s*\R\s*/m', trim($m3u8), NULL, PREG_SPLIT_NO_EMPTY);
        foreach( $array as $line ) {
          $line = trim($line);
          if( strlen($line) > 2 && $line[0] != '#' ) {
            //if( is_good_url($line) ) {
            $url2[] = $base_url . $line;
          }
        }
      }
    }

    $content = file_get_contents($url2[0]);
    $m3u8 = new M3u8();
    $m3u8->read($content);
    $duration = 0;
    foreach( $m3u8->getSegments() as $segment ) {
      $duration += $segment->getExtinfTag()->getDuration();
    }
    return $duration;
  }

}