<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions 
 * @package    Suggestion
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2010-08-17 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Suggestion_Api_Siteapi_Core extends Core_Api_Abstract {

    protected $_suggestion_distance;
    protected $_suggestion_previous;
    /*     * getSuggestedFriend
     * @var Number of entries to be shown in the suggestion box
     */
    protected $_temp_suggestion_users_id_array;
    protected $_suggestion_path_limit = 0;
    protected $_final_key_array;
    protected $_reject_user_entity_id;
    protected $_suggestion_get_limit = 3888000;
    protected $_userhome_display_array;
    protected $_first_level_user_array;
    protected $_network_ids;
    protected $_first_level_friend_array;
    protected $_first_level_indication;
    protected $_index;
    protected $level;
    protected $_show_default_image_member;

    /**
     * Return the availability of suggestion.
     *
     * @param $modType: Module Type.
     * @param $limit: Limit.
     * @param $displayUser: Display use
     *
     */
    public function isSuggestion($modType, $limit = 1, $displayUser = null) {

        $modType = strstr($modType, 'friend') ? 'user' : $modType;

        $ismodEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($modType);
        if (empty($ismodEnabled)) {
            return;
        }

        $suggestedArray = $this->getSuggIds($modType, $limit, $displayUser);
        return @COUNT($suggestedArray[0][$modType]);
    }

    /**
     * Return the array of the suggestion which could be any type of entity.
     * @param $modType: Module Type.
     * @param $limit: Limit.
     * @param $displayUser: Display user.
     */
    public function getSuggestions($modType, $limit = 1, $displayUser = null) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        $modDetailed = Engine_Api::_()->getApi('modInfo', 'suggestion')->getPluginDetailed($modType);
        $modDetailed = $modDetailed[$modType];
        $getModSuggestion = $this->getSuggIds($modType, $limit, $displayUser);
        $getSuggObj = Engine_Api::_()->suggestion()->getsuggObj($getModSuggestion);

        if (!empty($getSuggObj)) {

            $modArray['mod_type'] = $modType;
            $keyArray = array_keys($getModSuggestion[0][$modType]);
            $numOfContent = count($keyArray);
            $modArray['count'] = $numOfContent;
            if ($numOfContent == 1 && !empty($getModSuggestion[0][$modType])) {
                $modArray['mod_id'] = implode($getModSuggestion[0][$modType]);
            }
            $modArray['implode'] = implode(',', $getModSuggestion[0][$modType]);
            $modArray['idColumnName'] = $modDetailed['idColumnName'];
            $modArray['viewer_id'] = $viewer_id;
            $modArray['mod_array'] = $getSuggObj;

            return $modArray;
        }
        return null;
    }

    /**
     * This function calling from all widgets which return the Ids of modules, which call for all mod widgets.
     * @param $modName: Module name.
     * @param $limit: limit.
     * @param displayModIdes: Display content string which content should not be return as a suggestion.
     */
    public function getSuggIds($modName, $limit, $displayModIdes = null) {

        $getFunArray = Engine_Api::_()->getApi('modInfo', 'suggestion')->getFunArray($modName);
        $modFunArray = $getFunArray[$modName];
        $notShowIdsArray = array();
        $modView = array();
        $notShowIdsStr = '';
        if (!empty($displayModIdes)) {
            $notShowIdsStr = $displayModIdes;
        }

        $getRejectedStr = Engine_Api::_()->getDbtable('rejecteds', 'suggestion')->getRejectIds($modName);
        $flag = 0;
        while ($flag != $limit) {
            $notShowIdsStr .= implode(',', $notShowIdsArray);
            $randKey = array_rand($modFunArray, 1);
            $functionName = $modFunArray[$randKey];
            $tempLimit = $limit - $flag;
            $getIds = $this->$functionName($modName, $notShowIdsStr, $getRejectedStr, $tempLimit);
            unset($modFunArray[$randKey]);
            if (!empty($getIds)) {
                foreach ($getIds as $id) {
                    $notShowIdsArray[] = $id;
                    $modView[$id] = $id;
                }
            }
            $flag = COUNT($modView);
            if (!COUNT($modFunArray) || ($flag >= $limit)) {
                break;
            }
        }

        $finalArray = $finalView = array();
        $finalView[$modName] = $modView;
        $finalArray[] = $finalView;
        return $finalArray;
    }

    /**
     * Recommendation Widgets: Find out the friend of viewer.
     *
     * @param $modName: Module Name.
     * @param $notShowIds: string of content ids, which will not be display as a suggestion.
     * @param $rejectedStr: string of content ids, Which has been rejected by viewer after clicking on cross (X). This content will not show as a suggestion.
     * @param $limit: Limit.
     * @return Array.
     */
    public function friend_mix_sugg($modName, $notShowIds, $rejectedStr, $limit) {
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        $modInfo = Engine_Api::_()->getApi('modInfo', 'suggestion')->getPluginDetailed($modName);
        $modInfo = $modInfo[$modName];
        $getModCondition = Engine_Api::_()->getApi('modInfo', 'suggestion')->getModCondition($modName);
        $notShowIds = Engine_Api::_()->getApi('coreFun', 'suggestion')->getTrimStr($notShowIds);
        $rejectedStr = Engine_Api::_()->getApi('coreFun', 'suggestion')->getTrimStr($rejectedStr);
        $friend_id_array = $this->suggestion_path($notShowIds, $limit, 'mix');
        return $friend_id_array;
    }

    /**
     * Returns the array of members id, which should be show on the widgets ( PeopleYouMayKnow Widgts ).
     *
     * @param $user: The user to get the suggestions for
     * @param $suggestion_level: The level depth till which friends are to be suggested
     * @param $display_user_str: The string having user IDs of users currently being suggested
     * @param $number_of_users: The number having of require users.
     * @return Array
     */
    public function suggestion_path($displayUserStr, $limit, $flag = null) {
        $this->_show_default_image_member = Engine_Api::_()->suggestion()->getModSettings('user', 'show_default_image_member');
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        $suggestion_level = Engine_Api::_()->suggestion()->getModSettings('user', 'friend_sugg_level');
        $userEligibal = Engine_Api::_()->suggestion()->userFriendsEligible();
        $suggestion_set_type = 1;
        $suggestion_output = array();
        $this->_reject_user_entity_id = array();
        $suggestion_friend_path = 1;
        // WE ASSIGN $level = 1 TO DIRECT CONNECTED FRIENDS.
        $this->level = 1;

        // We are assign blank result in variable becouse of "suggestion_path" function calling from "Few Friend Suggestion" also.
        if (!empty($this->_temp_suggestion_users_id_array)) {
            $this->_temp_suggestion_users_id_array = array();
            $this->_suggestion_distance = array();
            $this->_suggestion_previous = array();
            $this->_reject_user_entity_id = array();
            $this->_userhome_display_array = 0;
            $this->_final_key_array = array();
            $this->_first_level_user_array = array();
            $this->_network_ids = array();
            $this->_first_level_friend_array = array();
            $this->_first_level_indication = 0;
            $this->_index = array();
        }

        $this->_suggestion_distance[$viewer_id] = 0;
        //$INDEX IS THE NUMBER FROM WHERE FOR LOOP STARTS IN find_distance_previous_array FUNCTION.
        $index = 0;
        $this->_temp_suggestion_users_id_array[] = $viewer_id;
        $sugg_attempt = strrev('tpmetta.weiv.noitseggus');

        $this->_userhome_display_array = Engine_Api::_()->getApi('coreFun', 'suggestion')->getTrimStr($displayUserStr);
        $get_path_info = Engine_Api::_()->getApi('settings', 'core')->getSetting('suggestion.path.dir', 0);
        $get_path_info = base64_decode($get_path_info);
        $suggestion_settime = Engine_Api::_()->getApi('settings', 'core')->getSetting('suggestion.invitefriend.info', 0);
        $suggestion_path_type = strrev('lruc');
        // Not consider the rejected user in the case of "Explore Recommendation Widgets", "Recommendation Widgets" and "Find Friend Page".
        if (($flag != 'mix') || ($flag != 'explore') || ($flag != 'findFriend')) {
            $getFriendStr = Engine_Api::_()->getDbTable('rejecteds', 'suggestion')->getRejectIds('friend');
            $this->_reject_user_entity_id = explode(',', $getFriendStr);
            $this->_userhome_display_array = $getFriendStr;
        }
        $strTime = time();
        $suggestion_connection_info = Engine_Api::_()->getApi('settings', 'core')->getSetting('suggestion.connection.info', 0);
        if (empty($userEligibal) || empty($suggestion_friend_path)) {
            return;
        }

        if ($userEligibal == 1) {
            //IF ADMIN SET NETWORK Members SETTING FOR ALLOWING FRIENDS.
            Engine_Api::_()->suggestion()->find_network_friend($limit, $displayUserStr);
            return $this->_final_key_array;
        } elseif ($userEligibal == 2) {//IF ADMIN SET "All Members" SETTING FOR ALLOWING FRIENDS.
            while ($this->level != $suggestion_level) {
                $index = $this->find_distance_suggestion_previous_array($this->_temp_suggestion_users_id_array, $index, $this->level, $displayUserStr, $limit);
                $this->level++;
                if (empty($index) || count($this->_temp_suggestion_users_id_array) == 1) {
                    break;
                }
            }
        }
        if (empty($suggestion_set_type)) {
            Engine_Api::_()->getApi('settings', 'core')->setSetting('suggestion.mixinfo.status', 0);
            Engine_Api::_()->getApi('settings', 'core')->setSetting($sugg_attempt, 1);
            return;
        }
        // This is the condition for If admin set "NOBODY BECOME FRIEND" then we return else we will find more friend in the user network.
        //Codition for network search
        if (count($this->_final_key_array) != $limit) {
            $number_of_network_fri = $limit - count($this->_final_key_array);
            Engine_Api::_()->suggestion()->find_network_friend($number_of_network_fri, $displayUserStr);
            // If there are no friend suggestion in 2nd level & 3rd level or in network then we show suggestion randumly, only if site admin set the friend setting - "All member"
            if (count($this->_final_key_array) < $limit) {
                $number_of_network_fri = $limit - count($this->_final_key_array);
                $this->getRandumFriendSuggestion($number_of_network_fri, $displayUserStr);
                return $this->_final_key_array;
            }
        }
        return $this->_final_key_array;
    }

    /**
     * Returns the index and user level array with current level friend. 
     *
     * @param $temp_suggestion_users_id_array_1: Array which hold the user of the level as a value
     * @param $first_index:Starting number of for loop.
     * @param $level: The level depth till which friends are to be suggested
     * @param $display_user_str: The string having user IDs of users currently being suggested
     * @param $number_of_users: The number having of require users.
     * @return Integer
     */
    public function find_distance_suggestion_previous_array($temp_suggestion_users_id_array_1, $first_index, $level, $display_user_str, $number_of_users) {
        // For the 'first level' finding friend of logged_in user only for the first level.
        if ($level == 1) {
            $this->user_first_level_friend($temp_suggestion_users_id_array_1[0], $number_of_users, '');
            return 1;
        }
        if (empty($this->_final_key_array))
            $this->_final_key_array = array();
        
        $current_user = $temp_suggestion_users_id_array_1[0];

        $getMyFriendArray = Engine_Api::_()->getApi('coreFun', 'suggestion')->getMembership($current_user);
        $index = count($temp_suggestion_users_id_array_1);
        if (!empty($this->_index)) {
            if (!array_key_exists($level, $this->_index)) {
                $this->_index[$level] = $index;
            }
        }
        if (!empty($this->_index[$level])) {
            $index = $this->_index[$level];
        }

        for ($x = $first_index; $x < $index; $x++) {
            $friend_1_id = $temp_suggestion_users_id_array_1[$x];
            // For the 'Logged_in user' finding first level friend in starting of function but if does not find 'frind suggestion' from the 'returned first level friend' then we require again more first level friend then call again this function for finding 1st level friend tell first level friend will not be end.
            if (empty($this->_first_level_indication) && !in_array("$friend_1_id", $this->_first_level_friend_array)) {
                $first_level_friend_veri = $this->user_first_level_friend($temp_suggestion_users_id_array_1[0], $number_of_users, $x);
                if (empty($first_level_friend_veri)) {
                    $this->level--;
                    return $x;
                }
            }
            // Here we are set limit for queary.
            $limit = $number_of_users - count($this->_final_key_array);
            //FETCH USER MEMBER FROM MEMBERSHIP TABLE
            $membershipTable = Engine_Api::_()->getApi('coreFun', 'suggestion')->getMemberTableObj();
            $membershipTableName = $membershipTable->info('name');

            $selfTable = Engine_Api::_()->getApi('coreFun', 'suggestion')->getSelfTableObj('user');
            $selfTableName = $selfTable->info('name');
            $select = $membershipTable->select()
                    ->setIntegrityCheck(false)
                    ->from($membershipTableName, array('resource_id'))
                    ->join($selfTableName, "$selfTableName.user_id = $membershipTableName.user_id", null)
                    ->where($membershipTableName . '.user_id = ?', $friend_1_id)
                    ->where($selfTableName . '.search = ?', 1)
                    ->where($membershipTableName . '.active = ?', 1)
                    ->where($selfTableName . '.enabled = ?', 1)
                    ->where($membershipTableName . '.resource_id != ?', $current_user)
                    ->order('RAND()')
                    ->limit($limit);

            if (empty($this->_show_default_image_member))
                $select->where($selfTableName . '.photo_id != ?', 0);

            $fetch_friends_for_display = $select->query()->fetchAll();

            if (!empty($fetch_friends_for_display)) {
                // variable '$this->_userhome_display_array' consist of string  'display user member' & 'member which are rejected by logged_in user', explode this string in array and then check that that entry should not in array.
                // $this->_userhome_display_array: Contain rejected str.
                // $display_user_str: Which user is displayed.
                // $getMyFriendArray: My 1st level Friend.
                $this->_userhome_display_array .= ',' . $display_user_str;
                $this->_userhome_display_array .= ',' . $getMyFriendArray;
                $this->_userhome_display_array = trim($this->_userhome_display_array, ',');
                $rej_dis_fri_array = explode(',', $this->_userhome_display_array);
                foreach ($fetch_friends_for_display as $row) {
                    $friend_id = $row['resource_id'];
                    if (empty($friend_id)) {
                        return;
                    }
                    $tempFriendObj = Engine_Api::_()->getItem('user', $friend_id);
                    if (empty($tempFriendObj)) {
                        return;
                    }
                    $isSearchable = 0;
                    if (!empty($tempFriendObj->search)) {
                        $isSearchable = $tempFriendObj->search;
                    }
                    if (!empty($isSearchable) && (!empty($temp_suggestion_users_id_array_1['0']) && $friend_id != $temp_suggestion_users_id_array_1['0']) && (((!empty($this->_suggestion_distance[$friend_id]) && $this->_suggestion_distance[$friend_id] > $level) || empty($this->_suggestion_distance[$friend_id])))) {
                        $this->_temp_suggestion_users_id_array[] = $friend_id;
                        $this->_suggestion_distance[$friend_id] = $level;
                        $this->_suggestion_previous[$friend_id] = $friend_1_id;
                        // Insert 'giving id' in array only if that 'id' does not exist in array.
                        if ((!in_array("$friend_id", $rej_dis_fri_array))) {
                            $this->_final_key_array[] = $friend_id;
                        }
                        if (count($this->_final_key_array) == $number_of_users) {
                            return;
                        }
                    }
                }
            } else {
                continue;
            }
        }
        return $index;
    }

    /**
     *
     * @param $user_id: User id for this find out 'first level friend' of this ID.
     * @param $limit: Limit which set by the site admin.
     * @param $status: key of array.
     * @return Empty or Integer.
     */
    public function user_first_level_friend($user_id, $limit, $status) {
        $limit = $limit + $limit;
        $first_level_selected_friend = 0;
        if (!empty($status)) {
            $first_level_selected_friend = implode(",", $this->_first_level_friend_array);
        }

        //FETCH USER MEMBER FROM MEMBERSHIP TABLE
        $membershipTable = Engine_Api::_()->getApi('coreFun', 'suggestion')->getMemberTableObj();
        $membershipTableName = $membershipTable->info('name');

        $selfTable = Engine_Api::_()->getApi('coreFun', 'suggestion')->getSelfTableObj('user');
        $selfTableName = $selfTable->info('name');
        $select = $membershipTable->select()
                ->setIntegrityCheck(false)
                ->from($membershipTableName, array('resource_id'))
                ->joinLeft($selfTableName, "$selfTableName.user_id = $membershipTableName.resource_id", NULL)
                ->where($membershipTableName . '.user_id = ?', $user_id)
                ->where($selfTableName . '.member_count > ?', 1)
                ->where($selfTableName . '.verified = ?', 1)
                ->where($membershipTableName . '.active = ?', 1)
                ->where($selfTableName . '.enabled = ?', 1)
                ->order($selfTableName . '.member_count DESC')
                ->where($membershipTableName . '.resource_id NOT IN (' . $first_level_selected_friend . ')')
                ->order('RAND()')
                ->limit($limit);
        $user_ids_array = $select->query()->fetchAll();

        $num_user_found = count($user_ids_array);
        if (!empty($user_ids_array)) {
            // Set variable for identification that next time 1st level searching will not work.
            if ($num_user_found < $limit) {
                $this->_first_level_indication = $status;
            }

            // From the queary we have array which contain user Id in the 'member count' desending order but we require randum 'user id' from the array.
            $level = 0;
            while ($num_user_found != $level) {
                $friend_array_key = array_rand($user_ids_array, 1);
                $friend_id_array[] = $user_ids_array[$friend_array_key];
                unset($user_ids_array[$friend_array_key]);
                $level++;
            }
            if (!empty($friend_id_array)) {
                foreach ($friend_id_array as $friend_id) {
                    if (empty($status)) {
                        $this->_temp_suggestion_users_id_array[] = $friend_id['resource_id'];
                        $this->_first_level_friend_array[] = $friend_id['resource_id'];
                        $this->_suggestion_distance[$friend_id['resource_id']] = 1;
                        $this->_suggestion_previous[$friend_id['resource_id']] = $user_id;
                    } else {
                        $user_array[] = $friend_id['resource_id'];
                        $this->_first_level_friend_array[] = $friend_id['resource_id'];
                        $this->_suggestion_distance[$friend_id['resource_id']] = 1;
                        $this->_suggestion_previous[$friend_id['resource_id']] = $user_id;
                    }
                }
            }
        } else { // Set variable for identification that next time 1st level searching will not search.
            $this->_first_level_indication = $status;
            return 1;
        }
        if (!empty($user_array)) {
            $previous_split_array = array_slice($this->_temp_suggestion_users_id_array, 0, $status);
            $after_split_array = array_slice($this->_temp_suggestion_users_id_array, $status);
            $this->_temp_suggestion_users_id_array = array_merge($previous_split_array, $user_array, $after_split_array);
        }
        return;
    }

    /**
     * Return the array of randum users to be suggested as friends only if there are no friend in "Network" and "2nd & 3rd level".
     *
     * @param $user_id: User which are login.
     * @param $number_of_users: Number of user which are require.
     * @param $user_home_display_friend : User which are display already in home page use in ajax.
     * @return array
     */
    public function getRandumFriendSuggestion($limit, $displayUser) {
        $notShowIdsStr = 0;
        // For current user.
        if (!empty($this->_final_key_array) && is_array($this->_final_key_array)) {
            $notShowIdsStr .= ',' . implode(",", $this->_final_key_array);
        }
        // For display user.
        if (!empty($this->_userhome_display_array[0]) && is_array($this->_userhome_display_array[0])) {
            $notShowIdsStr .= ',' . implode(",", $this->_userhome_display_array[0]);
        }
        // For rejected user.
        if (!empty($this->_reject_user_entity_id) && is_array($this->_reject_user_entity_id)) {
            $notShowIdsStr .= ',' . implode(",", $this->_reject_user_entity_id);
        }

        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        $displayUser = Engine_Api::_()->getApi('coreFun', 'suggestion')->getTrimStr($displayUser);
        $getMembership = Engine_Api::_()->getApi('coreFun', 'suggestion')->getMembership();

        $notShowIdsStr = Engine_Api::_()->getApi('coreFun', 'suggestion')->getTrimStr($notShowIdsStr);
        $getMembership = Engine_Api::_()->getApi('coreFun', 'suggestion')->getTrimStr($getMembership);


        $selfTable = Engine_Api::_()->getApi('coreFun', 'suggestion')->getSelfTableObj('user');
        $selfTableName = $selfTable->info('name');
        $select = $selfTable->select()
                ->setIntegrityCheck(false)
                ->from($selfTableName, array('user_id'))
                ->where('user_id != ?', $viewer_id)
                ->where('search = ?', 1)
                ->where('enabled = ?', 1)
                ->where('verified = ?', 1)
                ->where("user_id NOT IN ($displayUser)")
                ->where("user_id NOT IN ($notShowIdsStr)")
                ->where("user_id NOT IN ($getMembership)")
                ->order('RAND()')
                ->limit($limit);

        if (empty($this->_show_default_image_member))
            $select->where('photo_id != ?', 0);

        $fetch = $select->query()->fetchAll();
        foreach ($fetch as $randum_user) {
            $this->_final_key_array[] = $randum_user['user_id'];
        }
        return;
    }

}
