<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions 
 * @package    Suggestion
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2010-08-17 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Suggestion_IndexController extends Siteapi_Controller_Action_Standard {

    public function init() {

        // set view
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
    }

    // To list suggestions
    public function suggestionListingAction() {

        // Validate request method
        $this->validateRequestMethod();

        try {
            $modType = 'friend';
            $limit = $this->_getParam('limit', 3);
            $page = $this->_getParam('page', 1);

            // Check whether advancedactivity plugin is enabled or not
            $is_pluginEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('advancedactivity');

            if ($is_pluginEnabled != 1) {
                $this->respondWithError('unauthorized');
            }

            // Prepare data
            $viewer = Engine_Api::_()->user()->getViewer();
            $viewer_id = $viewer->getIdentity();
            $isContent = Engine_Api::_()->getApi('Siteapi_Core', 'suggestion')->isSuggestion($modType, 3);
            $isSuggEnabled = Engine_Api::_()->getApi('modInfo', 'suggestion')->isModEnabled('suggestion');

            // Check validation
            if (empty($viewer_id) || empty($isSuggEnabled)) {
                $this->respondWithError('unauthorized');
            }

//             If there is no suggestion so, totalItemCount = 0, hence the response
            if (empty($isContent)) {
                $tempResponse['totalItemCount'] = 0;
                $this->respondWithSuccess($tempResponse);
            }

            //Sitemobile code, check for when to display suggestions in mobile. (When user have less friends then friendMaxLimit)
            // Getting response array of suggestions
            $modArray = Engine_Api::_()->getApi('Siteapi_Core', 'suggestion')->getSuggestions($modType, 100);
            if (isset($modArray['mod_array'][0]['friend'])) {
                $totalResults = $modArray['mod_array'][0]['friend'];
                $paginator = Zend_Paginator::factory($modArray['mod_array'][0]['friend']);
                $paginator->setItemCountPerPage($limit);
                $paginator->setCurrentPageNumber($page);
                // Processing response array
                foreach ($paginator as $user) {
                    $userObj = $user->toArray();
                    $userObj['displayname'] = $user->getTitle();
                    $userObj = Engine_Api::_()->getApi('Core', 'siteapi')->sanitizeArray($userObj, array('email'));
                    //These not to be included
                    if (isset($userObj['lastlogin_ip']))
                        unset($userObj['lastlogin_ip']);

                    if (isset($userObj['creation_ip']))
                        unset($userObj['creation_ip']);

                    //Friendship  type
                    $userObj['friendship_type'] = Engine_Api::_()->getApi('Siteapi_Core', 'user')->getFriendshipType($user);
                    $mutualfriendCount = Engine_Api::_()->seaocore()->getMutualFriend($user->user_id)->getTotalItemCount();
                    $userObj['mutualfriendCount'] = $mutualfriendCount;
                    //Member verification Work............... 
                    $userObj['showVerifyIcon'] = Engine_Api::_()->getApi('Core', 'siteapi')->getVerifyInfo($user);

                    // Add user images
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
                    $userObj = array_merge($userObj, $getContentImages);

                    // GETTING THE GUTTER-MENUS
                    if ($this->getRequestParam('gutter_menu', true))
                        $userObj['menus'] = $this->_gutterMenus($user);

                    $tempResponse[] = $userObj;
                }
            }
            // Formatting response array
            if (isset($tempResponse) && !empty($tempResponse))
                $response['users'] = $tempResponse;


            //Total Items in response array
            $response['totalItemCount'] = $paginator->getTotalItemCount();

            // Response
            $this->respondWithSuccess($response,"suggestion_listing");
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    // removes a suggestion from list permanently
    public function removeAction() {

        // Validate request methods
        $this->validateRequestMethod('POST');

        $entity = 'friend';
        $entity_id = $this->getRequestParam('user_id', null);

        if (empty($entity_id)) {
            $this->respondWithError('no_record');
        }

        try {
            // Making an entry in suggestion_rejected table to exclude it in suggestions list
            Engine_Api::_()->getDbtable('rejecteds', 'suggestion')->setSettings($entity, $entity_id);

            // Response
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $ex) {

            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    public function sendInviteAction() {
        // Validate request methods
        $this->validateRequestMethod('POST');

        $viewer = Engine_Api::_()->user()->getViewer();

        if (isset($_POST['emails']) && !empty($_POST['emails']))
            $recipients = explode(',', $_POST['emails']);
        else
            $this->respondWithError('no_record');

        try {
            Engine_Api::_()->getApi('Invite', 'Seaocore')->sendInvites($recipients, "nonsitemembers");
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    /**
     * Getting the "Gutter Menus" array.
     * 
     * @return array
     */
    private function _gutterMenus($subject) {
        $menus = array();

        $direction = Engine_Api::_()->getApi('settings', 'core')->getSetting('user.friends.direction',1);
        if($direction == 0)
        {
            $menus[] = array(
                'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Follow'),
                'name' => 'add_friend',
                'url' => 'user/add',
                'urlParams' => array(
                    'user_id' => $subject->getIdentity()
                )
            );
        }
        else
        {   $menus[] = array(
                'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Add Friend'),
                'name' => 'add_friend',
                'url' => 'user/add',
                'urlParams' => array(
                    'user_id' => $subject->getIdentity()
                )
            );

        }
        if($direction == 0)
        $menus[] = array(
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Add Friend'),
            'name' => 'add_friend',
            'url' => 'user/add',
            'urlParams' => array(
                'user_id' => $subject->getIdentity()
            )
        );

        $menus[] = array(
            'label' => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Remove Suggestion'),
            'name' => 'remove_suggestion',
            'url' => 'suggestions/remove',
            'urlParams' => array(
                'user_id' => $subject->getIdentity()
            )
        );

        return $menus;
    }

    // Action to remove notifications
    public function removeNotificationAction() {
        //RECIEVE VALUE FROM AJAX
        $entity = (string) $this->_getParam('entity');
        $entity_id = (int) $this->_getParam('entity_id');
        $notificationType = (string) $this->_getParam('notificationType');
        try {

            if (strstr($entity, "sitereview")) {
                $isReviewEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled("sitereview");
                if (!empty($isReviewEnabled)) {
                    $listingTypeId = Engine_Api::_()->getItem('sitereview_listing', $entity_id)->listingtype_id;
                    $getModId = Engine_Api::_()->suggestion()->getReviewModInfo($listingTypeId);
                    $entity = $entity . "_" . $getModId;
                }
            }
            Engine_Api::_()->getDbtable('suggestions', 'suggestion')->removeSuggestion($entity, $entity_id, $notificationType);
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }
    
    public function suggestToFriendAction() {

        $this->validateRequestMethod('POST');
        $modName = $this->_getParam("modName", 0);
        if (empty($modName)) {
            $modName = $_GET['modName'];
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        if (empty($viewer_id))
            $this->respondWithError('unauthorized');
        $userArrayId = array();
        $values = $this->_getAllParams();
        $friendArrayIds = explode(',', $values['friends_id']);

        foreach ($friendArrayIds as $value) {
            $ownerId = $value;
            $emailParams = array();
            $entity = $values['entity'];
            $entityId = $values['entity_id'];

            if (!empty($values['entity_title']))
                $emailParams['entity_title'] = $values['entity_title'];

            if (!empty($values['entity_link']))
                $emailParams['entity_link'] = $values['entity_link'];
            $notificationType = $values['notification_type'];
            try {
                if (strpos($modName, 'accept_request') !== FALSE) {
                    if ($this->_helper->requireUser()->isValid())
                        Engine_Api::_()->getApi('Invite', 'Seaocore')->addAction($id);
                } else if ($entity == 'friendfewfriend') {
                    Engine_Api::_()->getDbTable('suggestions', 'suggestion')->setSuggestion($entityId, $entity, $ownerId, 'sitevideo_video_suggestion', $emailParams,'sitevideo_video');
                } 
                elseif(strpos($entity, 'sitecrowdfunding') !== FALSE)
                {
//                    $modInfo = Engine_Api::_()->getApi('modInfo', 'suggestion')->getPluginDetailed($modName);
//            $modInfo = $modInfo[$modName];
                     Engine_Api::_()->getDbTable('suggestions', 'suggestion')->setSuggestion($ownerId, $entity, $entityId, 'sitecrowdfunding_suggestion', $emailParams,$entity);
                }
                else {
                    Engine_Api::_()->getDbTable('suggestions', 'suggestion')->setSuggestion($ownerId, $entity, $entityId, 'sitevideo_video_suggestion', $emailParams,'sitevideo_video');
                }
            } catch (Exception $ex) {

                //To do item photo helper
            }
        }
        $this->successResponseNoContent('no_content', true);
    }


}
