<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Twitterclone
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: install.php 2015-06-04 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
require_once realpath(dirname(__FILE__)) . '/sitemodule_install.php';

class Twitterclone_Installer extends SiteModule_Installer
{
  /* If client are used the below plugins then need to check for upgrade */ 
  protected $_deependencyVersion = array(
    // 'advancedactivity' => '4.10.3p20',
    //'seaocore' => '4.10.3p15',
    // 'sitemenu' => '4.10.3p9',
    // 'siteadvsearch' => '4.10.3p2',
  );
  protected $_installConfig = array(
    'sku' => 'twitterclone',
    );
  public function onInstall()
  {
    $this->_createCustomizationFile("/application/themes/twitterclone/customization.css", '/* ADD CUSTOM STYLE */');
    $this->_createCustomizationFile("/public/seaocore_themes/twittercloneThemeGeneralConstants.css", '/* EDIT CONSTANTS, DO NOT UPDATE IT*/');
    $this->updatePage('core_help_privacy', 'Your Privacy - Our Concern', 'We Respect Your Right to Privacy...');
    $this->updatePage('core_help_terms', 'Trust But Verify', 'We Believe on you so You Can');
    $this->updatePage('core_help_contact', 'We Cherish Interactions', 'Because We Know Your Time Is Precious So, Get In Touch Now..');
    parent::onInstall();
  }

 public function onPostInstall()
 {
    parent::onPostInstall();
 }

  public function onEnable()
  {
    $this->hideHeaderFooterOnPages(true);
    parent::onEnable();
  }

  public function onDisable()
  {
    $this->hideHeaderFooterOnPages(false);
    parent::onDisable();
  }

  private function _createCustomizationFile($filePath, $data)
  {
    $filePath = str_replace('/', DS, $filePath);
    $realfilePath = APPLICATION_PATH . $filePath;
    $global_directory_name = dirname($realfilePath);
    $is_dir_exist = @is_dir($global_directory_name);
    if( !$is_dir_exist ) {
      mkdir($global_directory_name);
    }
    @chmod($global_directory_name, 0777);

    if( !is_readable($global_directory_name) ) {
      return $this->_error("<span style='color:red'>Note: You do not have readable permission on the path below, please give 'chmod 777 recursive permission' on it to continue with the installation process : <br /> 
  Path Name: <b>" . $global_directory_name . "</b></span>");
    }

    $is_file_exist = @file_exists($realfilePath);
    if( empty($is_file_exist) ) {
      if( !is_writable($global_directory_name) ) {
        return $this->_error("<span style='color:red'>Note: You do not have writable permission on the path below, please give 'chmod 777 recursive permission' on it to continue with the installation process : <br /> 
  Path Name: " . $global_directory_name . "</span>");
      }

      $fh = @fopen($realfilePath, 'w');
      @fwrite($fh, $data);
      @fclose($fh);

      @chmod($realfilePath, 0777);
    }
  }

  private function updatePage($pageName, $title, $description)
  {
    $db = $this->getDb();
    $page_id = $db->select()
      ->from('engine4_core_pages', 'page_id')
      ->where('name = ?', $pageName)
      ->limit(1)
      ->query()
      ->fetchColumn();
    $tableNameContentName = "engine4_core_content";
    $top_content_id = $db->select()
      ->from($tableNameContentName, 'content_id')
      ->where('page_id =?', $page_id)
      ->where('name =?', 'top')
      ->query()
      ->fetchColumn();
    if( empty($top_content_id) ) {
      $db->insert('engine4_core_content', array(
        'type' => 'container',
        'name' => 'top',
        'page_id' => $page_id,
        'parent_content_id' => null,
        'order' => 1,
        'params' => ''
      ));
      $content_id = $db->lastInsertId('engine4_core_content');
      $middle_content_id = $db->select()
        ->from($tableNameContentName, 'content_id')
        ->where('page_id =?', $page_id)
        ->where('parent_content_id =?', $content_id)
        ->where('name =?', 'middle')
        ->query()
        ->fetchColumn();

      if( empty($middle_content_id) ) {
        $db->insert('engine4_core_content', array(
          'type' => 'container',
          'name' => 'middle',
          'page_id' => $page_id,
          'parent_content_id' => $content_id,
          'order' => 2,
          'params' => ''
        ));

        $content_id = $db->lastInsertId('engine4_core_content');

        $middle_banner_id = $db->select()
          ->from($tableNameContentName, 'content_id')
          ->where('page_id =?', $page_id)
          ->where('parent_content_id =?', $content_id)
          ->where('name =?', 'twitterclone.banner-images')
          ->query()
          ->fetchColumn();
        if( !$middle_banner_id ) {
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'twitterclone.banner-images',
            'page_id' => $page_id,
            'parent_content_id' => $content_id,
            'order' => 1,
            'params' => '{"showBanners":"1","selectedBanners":"","width":"","height":"280","speed":"5000","order":"2","twittercloneHtmlTitle":"' . $title . '","twittercloneHtmlDescription":"' . $description . '","title":"","nomobile":"0","name":"twitterclone.banner-images"}'
          ));
        }
      }
      $db->query("UPDATE `engine4_core_content` SET  `order` =  '2' WHERE  `engine4_core_content`.`page_id` = $page_id AND `engine4_core_content`.`name` = 'main' LIMIT 1 ;");
    } else {
      $middle_content_id = $db->select()
        ->from($tableNameContentName, 'content_id')
        ->where('page_id =?', $page_id)
        ->where('parent_content_id =?', $top_content_id)
        ->where('name =?', 'middle')
        ->query()
        ->fetchColumn();

      if( !empty($middle_content_id) ) {

        $middle_banner_id = $db->select()
          ->from($tableNameContentName, 'content_id')
          ->where('page_id =?', $page_id)
          ->where('parent_content_id =?', $middle_content_id)
          ->where('name =?', 'twitterclone.banner-images')
          ->query()
          ->fetchColumn();

        if( !$middle_banner_id ) {
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'twitterclone.banner-images',
            'page_id' => $page_id,
            'parent_content_id' => $middle_content_id,
            'order' => 1,
            'params' => '{"showBanners":"1","selectedBanners":"","width":"","height":"280","speed":"5000","order":"2","twittercloneHtmlTitle":"' . $title . '","twittercloneHtmlDescription":"' . $description . '","title":"","nomobile":"0","name":"twitterclone.banner-images"}'
          ));
        }
        $db->query("UPDATE `engine4_core_content` SET  `order` =  '2' WHERE  `engine4_core_content`.`page_id` = $page_id AND `engine4_core_content`.`name` = 'main' LIMIT 1;");
        $db->query("DELETE FROM `engine4_core_content` WHERE `engine4_core_content`.`page_id` = $page_id AND `engine4_core_content`.`name` = 'spectacular.banner-images' LIMIT 1;");
      }
    }
  }

  public function hideHeaderFooterOnPages($hide)
  {
    $db = $this->getDb();
    if( $hide ) {
      $db->query("UPDATE `engine4_core_pages` SET `layout` = 'default-simple' WHERE `engine4_core_pages`.`name` = 'user_signup_index';");
    } else {
      $db->query("UPDATE `engine4_core_pages` SET `layout` = 'default' WHERE `engine4_core_pages`.`name` = 'user_signup_index';");
    }
  }

}