<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ClassifiedClassifieds.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_ClassifiedSitereviewListings extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_priority = 5000;
    protected $_currencyType = null;
    protected $_warningMessage = array();

    protected function _initPre() {

        //ALL SUPPORTED CURRENCY
        $_supportedCurrencies = array(
            'AUD',
            'BRL', // This currency is supported as a payment currency and a currency balance for in-country PayPal accounts only.
            'CAD',
            'CHF',
            'CZK', // Not supported by 2Checkout
            'DKK',
            'EUR',
            'GBP',
            'HKD',
            'HUF', // Not supported by 2Checkout
            'ILS', // Not supported by 2Checkout
            'JPY',
            'MXN',
            'MYR', // Not supported by 2Checkout - This currency is supported as a payment currency and a currency balance for in-country PayPal accounts only.
            'NOK',
            'NZD',
            'PHP', // Not supported by 2Checkout
            'PLN', // Not supported by 2Checkout
            'SEK',
            'SGD', // Not supported by 2Checkout
            'THB', // Not supported by 2Checkout
            'TWD', // Not supported by 2Checkout
            'USD',
            'RUB',
            'TRY',
        );
        $value = strtoupper(trim($this->getParam('unit')));
        if (empty($value))
            $value = "USD";
        if (!in_array($value, $_supportedCurrencies))
            $value = "USD";
        //UPDATE THE payment.currency setting
        $this->getToDb()->update('engine4_core_settings', array(
            'value' => $value
                ), array(
            'name = ?' => 'payment.currency'
                )
        );

        $this->_currencyType = $value;
        $this->_fromTable = $this->getFromPrefix() . 'marketplace';
        $this->_toTable = 'engine4_sitereview_listings';
        $this->_warningMessage = array("key" => 'escape', 'value' => '');
    }

    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON CLASSIFIED LISTING
        if ($this->getParam('import_classified_seclassified') == 1 || $data['module_id'] == 'pages')
            return false;

        $listingtype_id = $this->getParam('classifiedlistingtypes');

        if ($listingtype_id == 0)
            return false;

        //GETTING CATEGORY ID
        $category_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'marketplace_category_data', 'category_id')
                ->where('listing_id = ?', $data['listing_id'])
                ->query()
                ->fetchColumn();

        //GETTING CATEGORY NAME
        $category_name = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'marketplace_category', 'name')
                ->where('category_id = ?', $category_id)
                ->query()
                ->fetchColumn();

        //GET SE CATEGORY ID
        $se_category_id = $this->getToDb()->select()
                ->from('engine4_sitereview_categories', 'category_id')
                ->where('category_name = ?', $category_name)
                ->query()
                ->fetchColumn();

        //GET BODY
        $body = $this->getFromDb()->select()
                ->from('phpfox_marketplace_text', 'description_parsed')
                ->where('listing_id = ?', $data['listing_id'])
                ->query()
                ->fetchColumn();
        if ($body === false || is_null($body))
            $body = '';
        //PREPARING AN ARRAY FOR SITEREVIEW LISTING
        $newData['title'] = $data['title'];
        $newData['body'] = $body;
        $newData['owner_id'] = $data['user_id'];
        $newData['listingtype_id'] = $listingtype_id;
        //CHECKING FOR PACKAGE ID COLUMN EXIST OR NOT
        if ($this->_columnExist('engine4_sitereview_listings', 'package_id'))
            $newData['package_id'] = 1;
        $newData['profile_type'] = 0;
        $newData['approved'] = 1;
        $newData['closed'] = $data['is_closed'];
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $newData['approved_date'] = $this->_translateTime($data['time_stamp']);
        if ($data['time_update']) {
            $newData['modified_date'] = $this->_translateTime($data['time_update']);
        } else {
            $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        }
        $newData['comment_count'] = $data['total_comment'];
        $newData['like_count'] = $data['total_like'];
        $newData['search'] = 1;
        $newData['price'] = $data['price'];
        $newData['featured'] = $data['is_featured'];
        $newData['sponsored'] = $data['is_sponsor'];
        $newData['draft'] = 0;
        $newData['category_id'] = $se_category_id;
        $newData['location'] = empty($data['city']) ? ($data['country_iso']) : ($data['city'] . "," . $data['country_iso']);
        if ($this->_columnExist('engine4_sitereview_listings', 'pending'))
            $newData['pending'] = 0;
        if (strtolower($this->_currencyType) != strtolower($data['currency_id']))
            $newData['price'] = 0;

        //INSERT DATA INTO SITEREVIEW LISTING
        $this->getToDb()->insert($this->getToTable(), $newData);
        $sitereviewIdentity = $this->getToDb()->lastInsertId();
        //MAP SITERIVIEW
        $this->setSitereviewMap('classified', $data['listing_id'], $sitereviewIdentity);
        //PRIVACY
        try {
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, 'view', $this->_translateClassifiedPrivacy($data['privacy']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, 'comment', $this->_translateClassifiedPrivacy($data['privacy_comment']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "view_listtype_$listingtype_id", $this->_translateClassifiedPrivacy($data['privacy']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "comment_listtype_$listingtype_id", $this->_translateClassifiedPrivacy($data['privacy_comment']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "photo_listtype_$listingtype_id", $this->_translateClassifiedPrivacy(0));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "video_listtype_$listingtype_id", $this->_translateClassifiedPrivacy(0));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "event_listtype_$listingtype_id", $this->_translateClassifiedPrivacy(0));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "topic_listtype_$listingtype_id", $this->_translateClassifiedPrivacy(0));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $sitereviewIdentity . ' : ' . $e->getMessage());
        }

        $otherInfoData = array();
        $otherInfoData['listing_id'] = $sitereviewIdentity;
        $this->getToDb()->insert('engine4_sitereview_otherinfo', $otherInfoData);
        //PREPARING AN ARRAY FOR SITEREVIEW ALBUM
        $albumData = array();
        $albumData['listing_id'] = $sitereviewIdentity;
        $albumData['title'] = $data['title'];
        $albumData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $albumData['modified_date'] = $this->_translateTime($data['time_stamp']);
        $albumData['search'] = 1;
        //INSERT SITEREVIEW ALBUM
        $this->getToDb()->insert('engine4_sitereview_albums', $albumData);
        $album_id = $this->getToDb()->lastInsertId();

        //GET IMAGE DATA FOR CLASSIFIED
        $imageData = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'marketplace_image', '*')
                ->where('listing_id = ?', $data['listing_id'])
                ->query()
                ->fetchAll();
        $count = count($imageData);
        $photoData = array();
        //INSERT ALL IMAGES OF THIS LISTING
        foreach ($imageData as $images) {
            $photoData['album_id'] = $album_id;
            $photoData['listing_id'] = $sitereviewIdentity;
            $photoData['user_id'] = $data['user_id'];
            $photoData['creation_date'] = $this->_translateTime($data['time_stamp']);
            $photoData['modified_date'] = $this->_translateTime($data['time_stamp']);
            $photoData['collection_id'] = $album_id;

            $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/marketplace' . DIRECTORY_SEPARATOR . $images['image_path']);
            $file = $des[0];
            if (isset($des[1])) {
                $file = $this->getPhotoUrl($des[0], $des[1]);
                if (empty($file))
                    $file = $des[0] . $des[1];
            }

            if ($file) {
                try {
                    if ($this->getParam('resizePhotos', true)) {
                        $file_id = $this->_translatePhoto($file, array(
                            'parent_type' => 'sitereview_listing',
                            'parent_id' => $sitereviewIdentity,
                            'user_id' => @$data['user_id'],
                        ));
                    } else {
                        $file_id = $this->_translateFile($file, array(
                            'parent_type' => 'sitereview_listing',
                            'parent_id' => $sitereviewIdentity,
                            'user_id' => @$data['user_id'],
                                ), true);
                    }
                } catch (Exception $e) {
                    $file_id = null;
                    $this->_logFile($e->getMessage());
                }

                if ($file_id) {
                    $photoData['file_id'] = $file_id;
                    $newData['photo_id'] = $file_id;
                }
            }
            //INSERT PHOTO
            $this->getToDb()->insert('engine4_sitereview_photos', $photoData);
        }
        //UPATE LAST PHOTO ID
        $this->getToDb()->update('engine4_sitereview_listings', array(
            'photo_id' => $newData['photo_id'],
                ), array(
            'listing_id = ?' => $sitereviewIdentity,
        ));
        //UPDATE PHOTO COUNT
        $this->getToDb()->update('engine4_sitereview_albums', array(
            'collectible_count' => $count,
            'photo_id' => $newData['photo_id'],
                ), array(
            'album_id = ?' => $album_id,
            'listing_id = ?' => $sitereviewIdentity,
        ));

        //SEARCH
        if (@$newData['search']) {
            $this->_insertSearch('sitereview_listing', $sitereviewIdentity, @$newData['title'], @$newData['body']);
        }

        return false;
    }

}

/*
CREATE TABLE IF NOT EXISTS `phpfox_marketplace` (
  `listing_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `view_id` tinyint(3) NOT NULL DEFAULT '0',
  `privacy` tinyint(1) NOT NULL DEFAULT '0',
  `privacy_comment` tinyint(1) NOT NULL DEFAULT '0',
  `group_id` int(10) unsigned NOT NULL DEFAULT '0',
  `user_id` int(10) unsigned NOT NULL,
  `is_featured` tinyint(1) NOT NULL DEFAULT '0',
  `is_sponsor` tinyint(1) NOT NULL DEFAULT '0',
  `title` varchar(255) NOT NULL,
  `currency_id` char(3) NOT NULL DEFAULT 'USD',
  `price` decimal(14,2) NOT NULL DEFAULT '0.00',
  `country_iso` char(2) DEFAULT NULL,
  `country_child_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `postal_code` varchar(20) DEFAULT NULL,
  `city` varchar(255) DEFAULT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  `image_path` varchar(75) DEFAULT NULL,
  `server_id` tinyint(1) NOT NULL DEFAULT '0',
  `total_comment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_like` int(10) unsigned NOT NULL DEFAULT '0',
  `total_dislike` int(10) unsigned NOT NULL DEFAULT '0',
  `is_sell` tinyint(1) NOT NULL DEFAULT '0',
  `is_closed` tinyint(1) NOT NULL DEFAULT '0',
  `auto_sell` tinyint(1) NOT NULL DEFAULT '0',
  `mini_description` varchar(255) DEFAULT NULL,
  `is_notified` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`listing_id`),
  KEY `user_id` (`user_id`),
  KEY `view_id` (`view_id`,`privacy`),
  KEY `view_id_2` (`view_id`,`privacy`,`is_featured`),
  KEY `listing_id` (`listing_id`,`view_id`),
  KEY `is_notified` (`is_notified`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 */


/*
CREATE TABLE IF NOT EXISTS `phpfox_marketplace_image` (
  `image_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `listing_id` int(10) unsigned NOT NULL,
  `image_path` varchar(50) NOT NULL,
  `server_id` tinyint(1) NOT NULL,
  `ordering` tinyint(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (`image_id`),
  KEY `listing_id` (`listing_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 */

/*
CREATE TABLE IF NOT EXISTS `engine4_classified_classifieds` (
  `classified_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `body` longtext COLLATE utf8_unicode_ci NOT NULL,
  `owner_id` int(11) unsigned NOT NULL,
  `category_id` int(11) unsigned NOT NULL,
  `photo_id` int(10) unsigned NOT NULL DEFAULT '0',
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `closed` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`classified_id`),
  KEY `owner_id` (`owner_id`),
  KEY `search` (`search`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */

/*
 CREATE TABLE IF NOT EXISTS `engine4_classified_albums` (
  `album_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `classified_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `photo_id` int(11) unsigned NOT NULL DEFAULT '0',
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `collectible_count` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`album_id`),
  KEY `classified_id` (`classified_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */

/*
 CREATE TABLE IF NOT EXISTS `engine4_classified_photos` (
  `photo_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `album_id` int(11) unsigned NOT NULL,
  `classified_id` int(11) unsigned NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `collection_id` int(11) unsigned NOT NULL,
  `file_id` int(11) unsigned NOT NULL,
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  PRIMARY KEY (`photo_id`),
  KEY `album_id` (`album_id`),
  KEY `classified_id` (`classified_id`),
  KEY `user_id` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */