<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Dislikes.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_NestedcommentDislikes extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_priority = 1;
    public $isImportSeGroup = null;
    public $isImportSePage = null;
    public $isImportSeBlog = null;
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'action';
        $this->_toTable = 'engine4_nestedcomment_dislikes';
        $this->_warningMessage = array("key" => 'nestedcomment', 'value' => '<span style="font-weight:bolder;">Warning:</span>  Your PHPfox Nested comments,Dislike content are not migrated into SocialEngine PHP. You may ignore this warning or you can install <a target="_blank" href="http://www.socialengineaddons.com/socialengine-advanced-comments-plugin-nested-comments-replies-voting-attachments" > Advanced Comments Plugin - Nested Comments, Replies, Voting & Attachments </a> plugin on your SocialEngine PHP site to fix this warning.');
    }

    protected function _translateRow(array $data, $key = null) {

        // 'link' 'pages-comment' both type entry done by AbstractActivityLikes
        $this->isImportSeGroup = $this->getParam('import_group_segroup', 1);
        $this->isImportSePage = $this->getParam('import_group_sepage', 1);
        $this->isImportSeBlog = $this->getParam('import_blog_seblog', 1);
        $newData = array();
        switch ($data['item_type_id']) {
            case 'blog':
                $result = $this->findBlogResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;
            case 'video' :
                $result = $this->findVideoResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;
            case 'photo-album':
                $result = $this->findPhotoAlbumResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;
            case 'photo' :
                $result = $this->findPhotoResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;
            case 'pages' :
                $result = $this->findPagesResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;
            case 'marketplace' :
                $result = $this->findMarketPlaceResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;
            case 'music-song' :
                //Return false because In SE no dislike option in music , In SE Dislike option in music album.
                return false;
            case 'poll' :
                $resourceType = $data['item_type_id'];
                $resourceTypeId = $data['item_id'];
            case 'comment' :
                // comment dislike code done in AbstractActivityComments.php and AbstractComments.php file
                return false;
            case 'user-status':
            case 'link' :
            case 'pages-comment' :
            case 'event-comment':
                $result = $this->findLinkResourceType($data, $resourceType, $resourceTypeId);
                if (!$result)
                    return false;
                break;

            default :return false;
        }
        $newData = array(
            'resource_type' => $resourceType,
            'resource_id' => $resourceTypeId,
            'poster_type' => 'user',
            'poster_id' => $data['user_id'],
            'creation_date' => $this->_translateTime($data['time_stamp'])
        );
        return $newData;
    }

    /*
     * INSERT THE BLOG DISLIKE
     */

    protected function findBlogResourceType($data, &$resourceType, &$resourceTypeId) {
        $resourceType = 'blog';
        $resourceTypeId = $data['item_id'];
        $pageInfo = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog', null)
                ->join($this->getfromPrefix() . 'pages', $this->getfromPrefix() . 'pages.page_id=' . $this->getfromPrefix() . 'blog.item_id', array('type_id', 'page_id'))
                ->where($this->getfromPrefix() . 'blog.blog_id = ?', $data['item_id'])
                ->where($this->getfromPrefix() . 'blog.module_id = ?', 'pages')
                ->query()
                ->fetch();
        if ($pageInfo) {
            if ((($this->isImportSeGroup == 1) && $pageInfo['type_id'] == 3) || (($isImportSePage == 1) && $pageInfo['type_id'] != 3))
                return false;
            else if (($this->isImportSeGroup == 2) && $pageInfo['type_id'] == 3) {
                $resourceType = 'sitegroupnote_note';
            } else if (($this->isImportSePage == 2) && $pageInfo['type_id'] != 3) {
                $resourceType = 'sitepagenote_note';
            }
        } else if (($this->isImportSeBlog == 2)) {
            $resourceTypeId = $this->getSitereviewMap('blog', $resourceTypeId);
            $resourceType = 'sitereview_listing';
        }
        return true;
    }

    /*
     * INSERT THE VIDEO DISLIKE
     */

    protected function findVideoResourceType($data, &$resourceType, &$resourceTypeId) {
        $resourceType = 'video';
        $resourceTypeId = $data['item_id'];
        $pageInfo = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'video', null)
                ->join($this->getfromPrefix() . 'pages', $this->getfromPrefix() . 'pages.page_id=' . $this->getfromPrefix() . 'video.item_id', array('type_id', 'page_id'))
                ->where($this->getfromPrefix() . 'video.video_id = ?', $data['item_id'])
                ->where($this->getfromPrefix() . 'video.module_id = ?', 'pages')
                ->query()
                ->fetch();
        if ($pageInfo) {
            if ((($this->isImportSeGroup == 1) && $pageInfo['type_id'] == 3) || (($isImportSePage == 1) && $pageInfo['type_id'] != 3))
                return false;
            else if (($this->isImportSeGroup == 2) && $pageInfo['type_id'] == 3) {
                $resourceType = 'sitegroupvideo_video';
            } else if (($this->isImportSePage == 2) && $pageInfo['type_id'] != 3) {
                $resourceType = 'sitepagevideo_video';
            }
        }
        return true;
    }

    /*
     * INSERT THE ALBUM DISLIKE
     */

    protected function findPhotoAlbumResourceType($data, &$resourceType, &$resourceTypeId) {
        $resourceType = 'album';
        $resourceTypeId = $data['item_id'];
        //GET Group id
        $pageInfo = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'photo_album', null)
                ->join($this->getfromPrefix() . 'pages', $this->getfromPrefix() . 'pages.page_id=' . $this->getfromPrefix() . 'photo_album.group_id', array('type_id', 'page_id'))
                ->where($this->getfromPrefix() . 'photo_album.album_id= ?', $data['item_id'])
                ->where($this->getfromPrefix() . 'photo_album.module_id= ?', 'pages')
                ->query()
                ->fetch();
        if ($pageInfo) {

            if ($this->isImportSeGroup == 1 && $this->isImportSePage == 1)
                $resourceType = 'group_album';
            else if ($this->isImportSeGroup == 2 && $pageInfo['type_id'] == 3) {
                $resourceType = 'sitegroup_album';
            } else if ($this->isImportSePage == 2 && $pageInfo['type_id'] != 3) {
                $resourceType = 'sitepage_album';
            }
        }
        return true;
    }

    /*
     * INSERT THE PHOTO DISLIKE
     */

    protected function findPhotoResourceType($data, &$resourceType, &$resourceTypeId) {
        $resourceType = 'album_photo';
        $resourceTypeId = $data['item_id'];
        //GET Group id
        $pageInfo = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'photo', null)
                ->join($this->getfromPrefix() . 'pages', $this->getfromPrefix() . 'pages.page_id=' . $this->getfromPrefix() . 'photo.group_id', array($this->getfromPrefix() . 'pages.type_id', 'page_id'))
                ->where('photo_id= ?', $data['item_id'])
                ->where($this->getfromPrefix() . 'photo.module_id= ?', 'pages')
                ->query()
                ->fetch();
        if ($pageInfo) {
            if ($this->isImportSeGroup == 1 && $this->isImportSePage == 1)
                $resourceType = 'group_photo';
            else if ($this->isImportSeGroup == 2 && $pageInfo['type_id'] == 3) {
                $resourceType = 'sitegroup_photo';
            } else if ($this->isImportSePage == 2 && $pageInfo['type_id'] != 3) {
                $resourceType = 'sitepage_photo';
            }
        }
        return true;
    }

    /*
     * INSERT THE PAGES DISLIKE
     */

    protected function findPagesResourceType($data, &$resourceType, &$resourceTypeId) {
        $resourceType = 'group';
        $resourceTypeId = $data['item_id'];
        if ($this->isImportSeGroup == 2 && $pageInfo['type_id'] == 3) {
            $resourceType = 'sitegroup_group';
        } else if ($this->isImportSePage == 2 && $pageInfo['type_id'] != 3) {
            $resourceType = 'sitepage_page';
        }
        return true;
    }

    /*
     * INSERT THE CLASSIFIED DISLIKE
     */

    protected function findMarketPlaceResourceType($data, &$resourceType, &$resourceTypeId) {
        $resourceType = 'classified';
        $resourceTypeId = $data['item_id'];

        return true;
    }

    /*
     * INSERT THE LINK,USER-STATUS,EVENT-COMMENT DISLIKE
     */

    protected function findLinkResourceType($data, &$resourceType, &$resourceTypeId) {

        if ($data['item_type_id'] == 'pages-comment')
            $data['item_type_id'] = 'pages_comment';
        elseif ($data['item_type_id'] == 'event-comment')
            $data['item_type_id'] = 'event_comment';
        elseif ($data['item_type_id'] == 'user-status')
            $data['item_type_id'] = 'user_status';
        $resourceType = 'activity_action';
        $itemId = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'feed', 'feed_id')
                ->where('type_id = ?', $data['item_type_id'])
                ->where('item_id = ?', $data['item_id'])
                ->query()
                ->fetchColumn();
        if (!$itemId) {
            $itemId = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'event_feed', 'feed_id')
                    ->where('type_id = ?', $data['item_type_id'])
                    ->where('item_id = ?', $data['item_id'])
                    ->query()
                    ->fetchColumn();
            if (!$itemId)
                return false;
        }

        $resourceTypeId = $itemId;
        return true;
    }

}
