<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    SitegroupmusicPlaylists.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_SitegroupmusicPlaylists extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_fromWhere = array('module_id=?' => 'pages');
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_truncateTable($this->getToDb(), 'engine4_sitegroupmusic_playlist_songs');
        $this->_fromTable = $this->getFromPrefix() . 'music_album';
        $this->_toTable = 'engine4_sitegroupmusic_playlists';
        $this->_warningMessage = array("key" => 'groupkit', 'value' => '<span style="font-weight:bolder;">Warning:</span>  Your PHPfox Groups Blogs, PHPfox Groups Music and PHPfox Groups Videos content are not migrated into SocialEngine PHP. You may ignore this warning or you can install <a target="_blank" href="http://www.socialengineaddons.com/socialengine-groups-communities-plugin" >Groups - Product Kit </a> on your SocialEngine PHP site to fix this warning. ');
    }

    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON GROUP COMMUNITY PLUGIN
        if ($this->getParam('import_group_segroup', 1) == 1)
            return false;
        $type_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'pages', 'type_id')
                ->where('page_id = ?', $data['item_id'])
                ->query()
                ->fetchColumn();

        if ($type_id != 3) {
            return false;
        }

        //Get Owner UserId
        $userId = $this->getFromDb()->query("SELECT  " . $this->getfromPrefix() . "pages.user_id FROM " . $this->getfromPrefix() . "user left join  " . $this->getfromPrefix() . "pages on page_id=profile_page_id where profile_page_id<>0 and  " . $this->getfromPrefix() . "user.user_id=" . $data['user_id'])->fetchColumn(0);
        if ($userId)
            $data['user_id'] = $userId;

        //GET TEXT
        $text = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'music_album_text', 'text_parsed')
                ->where('album_id = ?', $data['album_id'])
                ->query()
                ->fetchColumn();

        //MAKING  ARRAY FOR INSERTION OF MUSIC PLAYLIST
        $newData = array();
        $newData['playlist_id'] = $data['album_id'];
        $newData['title'] = $data['name'];
        $newData['description'] = $text ? $text : '';
        $newData['group_id'] = $data['item_id'];
        $newData['search'] = 1;
        $newData['owner_id'] = $data['user_id'];
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        $newData['comment_count'] = $data['total_comment'];
        $newData['play_count'] = $data['total_play'];
        $newData['like_count'] = $data['total_like'];
        $newData['featured'] = $data['is_featured'];
        //INSERT THE MUSIC MAIN PHOTO
        if ($data['image_path']) {
            $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/music' . DIRECTORY_SEPARATOR . $data['image_path']);
            $file = $des[0];
            if (isset($des[1])) {
                $file = $this->getPhotoUrl($des[0], $des[1]);
                if (empty($file))
                    $file = $des[0] . $des[1];
            }
            if ($file) {
                try {
                    if ($this->getParam('resizePhotos', true)) {
                        $file_id = $this->_translatePhoto($file, array(
                            'parent_type' => 'music_playlist',
                            'parent_id' => $data['album_id'],
                            'user_id' => $data['user_id'],
                        ));
                    } else {
                        $file_id = $this->_translateFile($file, array(
                            'parent_type' => 'sitegroupmusic_playlist',
                            'parent_id' => $data['album_id'],
                            'user_id' => $data['user_id'],
                                ), true);
                    }
                } catch (Exception $e) {
                    $file_id = null;
                    $this->_warning($e->getMessage(), 1);
                }

                $newData['photo_id'] = $file_id;
            }
        }
        //INSERTION OF MUSIC PLAYLIST
        $this->getToDb()->insert('engine4_sitegroupmusic_playlists', $newData);

        //GET PLAYLIST ID
        $playlist_id = $this->getToDb()->lastInsertId();

        //GET SONGS INFORMATION
        $songsInfo = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'music_song', '*')
                ->where('album_id = ?', $data['album_id'])
                ->query()
                ->fetchAll();
        $songsData = array();
        //INSERTION OF EACH SONG OF THIS PLAYLIST
        foreach ($songsInfo as $songs) {
            $songsData['song_id'] = $songs['song_id'];
            $songsData['playlist_id'] = $playlist_id;
            $songsData['title'] = $songs['title'];
            $songsData['play_count'] = $songs['total_play'];
            $songsData['order'] = $songs['ordering'];
            if ($songs['song_path']) {
                $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/music' . DIRECTORY_SEPARATOR . $songs['song_path']);
                $file = $des[0];
                if (isset($des[1])) {
                    $file = $this->getPhotoUrl($des[0], $des[1]);
                    if (empty($file))
                        $file = $des[0] . $des[1];
                }

                //CREATION OF MUSIC FILE
                if ($file) {
                    try {

                        $file_id = $this->_translateFile($file, array(
                            'parent_type' => 'sitegroupmusic_song',
                            'parent_id' => $playlist_id,
                                ), true);
                    } catch (Exception $e) {
                        $file_id = null;
                        $this->_warning($e->getMessage(), 1);
                    }

                    $songsData['file_id'] = $file_id;
                }
            }
            // INSERTION OF SONG 
            $this->getToDb()->insert('engine4_sitegroupmusic_playlist_songs', $songsData);
            // SEARCH ENTRY
            $this->_insertSearch('sitegroupmusic_playlist_song', $songs['song_id'], $songsData['title']);
        }
        //PRIVACY
        try {
            $this->_insertPrivacy('sitegroupmusic_playlist', $playlist_id, 'view', $this->_translateMusicPrivacy($data['privacy']));
            $this->_insertPrivacy('sitegroupmusic_playlist', $playlist_id, 'comment', $this->_translateMusicPrivacy($data['privacy_comment']));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $playlist_id . ' : ' . $e->getMessage());
        }

        //SEARCH
        if (@$newData['search']) {
            $this->_insertSearch('sitegroupmusic_playlist', $playlist_id, @$newData['title']);
        }
        return false;
    }

}

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_music_album` (
  `album_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `view_id` int(10) unsigned NOT NULL DEFAULT '0',
  `privacy` tinyint(1) NOT NULL DEFAULT '0',
  `privacy_comment` tinyint(1) NOT NULL DEFAULT '0',
  `is_featured` tinyint(1) NOT NULL DEFAULT '0',
  `is_sponsor` tinyint(1) NOT NULL DEFAULT '0',
  `user_id` int(10) unsigned NOT NULL,
  `name` varchar(255) NOT NULL,
  `year` char(4) DEFAULT NULL,
  `image_path` varchar(75) DEFAULT NULL,
  `server_id` tinyint(1) NOT NULL DEFAULT '0',
  `total_track` smallint(4) unsigned NOT NULL DEFAULT '0',
  `total_play` int(10) unsigned NOT NULL DEFAULT '0',
  `total_comment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_like` int(10) unsigned NOT NULL DEFAULT '0',
  `total_dislike` int(10) unsigned NOT NULL DEFAULT '0',
  `total_score` decimal(4,2) NOT NULL DEFAULT '0.00',
  `total_rating` int(10) unsigned NOT NULL DEFAULT '0',
  `time_stamp` int(10) unsigned NOT NULL,
  `module_id` varchar(75) DEFAULT NULL,
  `item_id` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`album_id`),
  KEY `view_id` (`view_id`,`privacy`),
  KEY `view_id_2` (`view_id`,`privacy`,`is_featured`),
  KEY `user_id` (`user_id`),
  KEY `view_id_3` (`view_id`,`privacy`,`total_track`,`module_id`,`item_id`),
  KEY `view_id_4` (`view_id`,`privacy`,`total_track`,`item_id`),
  KEY `view_id_5` (`view_id`,`user_id`,`item_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;
 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_music_album_text` (
  `album_id` int(10) unsigned NOT NULL,
  `text` mediumtext,
  `text_parsed` mediumtext,
  UNIQUE KEY `album_id` (`album_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*
 * 
CREATE TABLE IF NOT EXISTS `engine4_sitegroupmusic_playlists` (
`playlist_id` int(11) unsigned NOT NULL,
  `title` varchar(63) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `description` text COLLATE utf8_unicode_ci NOT NULL,
  `group_id` int(10) NOT NULL,
  `photo_id` int(11) unsigned NOT NULL DEFAULT '0',
  `owner_id` int(11) unsigned NOT NULL,
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `play_count` int(11) unsigned NOT NULL DEFAULT '0',
  `like_count` int(11) unsigned NOT NULL DEFAULT '0',
  `featured` int(1) NOT NULL DEFAULT '0',
  `profile` tinyint(1) NOT NULL DEFAULT '0',
  `special` enum('wall','message') COLLATE utf8_unicode_ci DEFAULT NULL
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */

/*
 * 
CREATE TABLE IF NOT EXISTS `engine4_sitegroupmusic_playlist_songs` (
`song_id` int(11) unsigned NOT NULL,
  `playlist_id` int(11) unsigned NOT NULL,
  `file_id` int(11) unsigned NOT NULL,
  `title` varchar(60) COLLATE utf8_unicode_ci NOT NULL,
  `play_count` int(11) unsigned NOT NULL DEFAULT '0',
  `order` smallint(6) NOT NULL DEFAULT '0',
  `playlist_file_id` int(11) NOT NULL
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */
