<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    SitegroupnoteNotes.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_SitegroupnoteNotes extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_fromWhere = array('module_id=?' => 'pages');
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'blog';
        $this->_toTable = 'engine4_sitegroupnote_notes';
        $this->_warningMessage = array("key" => 'groupkit', 'value' => '<span style="font-weight:bolder;">Warning:</span>  Your PHPfox Groups Blogs, PHPfox Groups Music and PHPfox Groups Videos content are not migrated into SocialEngine PHP. You may ignore this warning or you can install <a target="_blank" href="http://www.socialengineaddons.com/socialengine-groups-communities-plugin" >Groups - Product Kit </a> on your SocialEngine PHP site to fix this warning. ');
    }

    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON GROUP COMMUNITY PLUGIN
        if ($this->getParam('import_group_segroup', 1) == 1)
            return false;
        $type_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog', null)
                ->join($this->getfromPrefix() . 'pages', $this->getfromPrefix() . 'pages.page_id=' . $this->getfromPrefix() . 'blog.item_id', 'type_id')
                ->where($this->getfromPrefix() . 'blog.blog_id = ?', $data['blog_id'])
                ->query()
                ->fetchColumn();
        if ($type_id != 3)
            return false;

        $newData = array();
        //Get Owner UserId
        $userId = $this->getFromDb()->query("SELECT  " . $this->getfromPrefix() . "pages.user_id FROM " . $this->getfromPrefix() . "user left join  " . $this->getfromPrefix() . "pages on page_id=profile_page_id where profile_page_id<>0 and  " . $this->getfromPrefix() . "user.user_id=" . $data['user_id'])->fetchColumn(0);
        if ($userId)
            $data['user_id'] = $userId;

        //GETTING CATEGORY ID
        $category_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog_category_data', 'category_id')
                ->where('blog_id = ?', $data['blog_id'])
                ->query()
                ->fetchColumn();

        //GETTING TEXT
        $text = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog_text', 'text')
                ->where('blog_id = ?', $data['blog_id'])
                ->query()
                ->fetchColumn();

        if (is_null($text) || $text === false)
            $text = '';

        $userInfo = array(
            'user_id' => $data['user_id'],
            'time_stamp' => $data['time_stamp'],
            'text' => $text,
            'item_id' => $data['blog_id'],
            'album_title' => 'Note Photos',
            'album_type' => 'note',
            'page_id' => $data['item_id'],
            'album_table' => 'sitegroup_albums',
            'categoryId' => 'blog'
        );
        //FIND BODY OF THIS NOTE
        $body = $this->getBody($userInfo);
        if (is_null($body))
            $body = '';

        //MAKING BLOG ARRAY FOR INSERTION
        $newData['note_id'] = $data['blog_id'];
        $newData['title'] = $data['title'];
        $newData['body'] = $body;
        $newData['owner_id'] = $data['user_id'];
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);

        if ($data['time_update']) {
            $newData['modified_date'] = $this->_translateTime($data['time_update']);
        } else {
            $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        }
        $newData['view_count'] = $data['total_view'];
        $newData['comment_count'] = $data['total_comment'];
        $newData['like_count'] = $data['total_like'];
        $newData['search'] = $data['is_approved'];
        if ($data['post_status'] == 1) {
            $newData['draft'] = 0;
        } else {
            $newData['draft'] = 1;
        }
        $newData['category_id'] = $category_id;
        $newData['parent_type'] = 'sitegroup_group';
        $newData['group_id'] = $data['item_id'];

        //PRIVACY
        try {
            $this->_insertPrivacy('sitegroupnote_note', $data['blog_id'], 'view', $this->_translateBlogPrivacy($data['privacy']));
            $this->_insertPrivacy('sitegroupnote_note', $data['blog_id'], 'comment', $this->_translateBlogPrivacy($data['privacy_comment']));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $data['blog_id'] . ' : ' . $e->getMessage());
        }

        //SEARCH
        if (@$newData['search']) {
            $this->_insertSearch('sitegroupnote_note', $data['blog_id'], @$newData['title'], @$newData['body']);
        }

        return $newData;
    }

}

/*
CREATE TABLE IF NOT EXISTS `phpfox_blog` (
  `blog_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` int(10) unsigned NOT NULL,
  `title` varchar(255) NOT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  `time_update` int(10) unsigned NOT NULL DEFAULT '0',
  `is_approved` tinyint(1) NOT NULL,
  `privacy` tinyint(1) NOT NULL DEFAULT '0',
  `privacy_comment` tinyint(1) NOT NULL DEFAULT '0',
  `post_status` tinyint(1) NOT NULL,
  `total_comment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_attachment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_view` int(10) unsigned NOT NULL DEFAULT '0',
  `total_like` int(10) unsigned NOT NULL DEFAULT '0',
  `total_dislike` int(10) unsigned NOT NULL DEFAULT '0',
  `module_id` varchar(75) NOT NULL DEFAULT 'blog',
  `item_id` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`blog_id`),
  KEY `public_view` (`is_approved`,`privacy`,`post_status`),
  KEY `user_id_2` (`user_id`,`is_approved`,`privacy`,`post_status`),
  KEY `time_stamp` (`time_stamp`,`is_approved`,`privacy`,`post_status`),
  KEY `user_id` (`user_id`,`time_stamp`,`is_approved`,`privacy`,`post_status`),
  KEY `title` (`title`,`is_approved`,`privacy`,`post_status`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;
 */

/*
CREATE TABLE IF NOT EXISTS `phpfox_blog_category_data` (
  `blog_id` int(10) unsigned NOT NULL,
  `category_id` int(10) unsigned NOT NULL,
  KEY `blog_id` (`blog_id`),
  KEY `category_id` (`category_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*
CREATE TABLE IF NOT EXISTS `phpfox_blog_text` (
  `blog_id` int(10) unsigned NOT NULL,
  `text` mediumtext,
  `text_parsed` mediumtext,
  PRIMARY KEY (`blog_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*

CREATE TABLE IF NOT EXISTS `engine4_sitegroupnote_notes` (
`note_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `body` longtext COLLATE utf8_unicode_ci NOT NULL,
  `owner_id` int(11) unsigned NOT NULL,
  `group_id` int(10) NOT NULL,
  `parent_type` varchar(64) COLLATE utf8_unicode_ci NOT NULL,
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `draft` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `photo_id` int(10) NOT NULL DEFAULT '0',
  `featured` tinyint(1) NOT NULL DEFAULT '0',
  `total_photos` int(11) NOT NULL DEFAULT '0',
  `like_count` int(11) NOT NULL DEFAULT '0',
  `category_id` int(11) NOT NULL DEFAULT '0'
) ENGINE=InnoDB AUTO_INCREMENT=35 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */