<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecitycontent
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Configuration.php 6590 2015-01-25 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecitycontent_Api_Configuration extends Core_Api_Abstract {

    protected $_db;
    protected $_sitemobileActive;
    protected $_pagesTable;
    protected $_contentTable;
    protected $_mobilePagesTable;
    protected $_mobileContentTable;
    protected $_tabletPagesTable;
    protected $_tabletContentTable;

    const DEFAULT_LOCATION_DISTANCE = 10;

    public function __construct() {
        $this->_db = Zend_Db_Table_Abstract::getDefaultAdapter();
        $this->_sitemobileActive = Engine_Api::_()->hasModuleBootstrap('sitemobile');

        $this->_pagesTable = Engine_Api::_()->getDbtable('pages', 'core');
        $this->_contentTable = Engine_Api::_()->getDbtable('content', 'core');
        $_getLocationFieldsType = $this->_getLocationFieldsType();

        if ($this->_sitemobileActive) {
            $this->_mobilePagesTable = Engine_Api::_()->getDbTable('pages', 'sitemobile');
            $this->_mobileContentTable = Engine_Api::_()->getDbTable('content', 'sitemobile');
            $this->_tabletPagesTable = Engine_Api::_()->getDbTable('tabletpages', 'sitemobile');
            $this->_tabletContentTable = Engine_Api::_()->getDbTable('tabletcontent', 'sitemobile');
        }

        //CLEAR THE MENUS CACHE
        Engine_Api::_()->seaocore()->clearMenuCache();

        if (empty($_getLocationFieldsType))
            return;
    }

    public function insertDefaultLocationSettings() {

        $settingsApi = Engine_Api::_()->getApi('settings', 'core');
        if (!$settingsApi->hasSetting('seaocore_locationspecific')) {
            $settingsApi->setSetting('seaocore_locationspecific', 1);
        }

        $locationSpecific = $settingsApi->getSetting('seaocore.locationspecific', 0);
        if ($locationSpecific) {

            $params = array();
            $params['columns'] = array('location');
            $getLocations = Engine_Api::_()->getDbTable('locationcontents', 'seaocore')->getLocations($params);
            if (Count($getLocations) > 0) {
                foreach ($getLocations as $getLocation) {
                    if ($getLocation->location) {
                        $globalSettings['seaocore_locationdefaultspecific'] = $getLocation->location;
                        break;
                    }
                }
            } else {
                $this->_db->query("INSERT INTO `engine4_seaocore_locationcontents` (`title`, `location`, `status`, `latitude`, `longitude`, `formatted_address`, `country`, `state`, `address`, `city`, `zipcode`) VALUE ('New York', 'New York, NY, United States', 1, 40.7127837, -74.0059413, 'New York, NY, USA', 'United States', 'New York', 'New York', 'New York County', ''),                    
('Los Angeles', 'Los Angeles, CA, United States', 1, 34.0522342, -118.2436849, 'Los Angeles, CA, USA', 'United States', 'California', 'Los Angeles', 'Los Angeles County', ''),
('Chicago', 'Chicago, IL, United States', 1, 41.8781136, -87.6297982, 'Chicago, IL, USA', 'United States', 'Illinois', 'Chicago', 'Cook County', ''),
('Houston', 'Houston, TX, United States', 1, 29.7604267, -95.3698028, 'Houston, TX, USA', 'United States', 'Texas', 'Houston', 'Harris County', '');");

                $globalSettings['seaocore_locationdefault'] = $globalSettings['seaocore_locationdefaultspecific'] = 'New York, NY, United States';
                $globalSettings['seaocore_locationdefaultlatitude'] = '40.7127837';
                $globalSettings['seaocore_locationdefaultlongitude'] = '-74.0059413';
                $globalSettings['seaocore_countrycities'] = 'US';
            }

            $globalSettings['seaocore_locationdefaultmiles'] = 10;
            //$globalSettings['seaocore_locationspecificcontent'] = 1;
        } else {
            if (!$settingsApi->hasSetting('seaocore_locationdefaultmiles')) {
                $globalSettings['seaocore_locationdefaultmiles'] = 10;
            }

            if (!$settingsApi->hasSetting('seaocore_locationdefault')) {
                $globalSettings['seaocore_locationdefault'] = 'New York, NY, United States';
                $globalSettings['seaocore_locationdefaultlatitude'] = '40.7127837';
                $globalSettings['seaocore_locationdefaultlongitude'] = '-74.0059413';
            }
        }

        $this->updateGlobalSettings($globalSettings, array(), '');
    }

    public function updatePluginMenus($menu = '', $enabledMenus = array()) {

        $this->_db->update('engine4_core_menuitems', array('enabled' => 0), array('`menu` = ?' => $menu, '`name` NOT IN (?)' => (array) $enabledMenus));

        $this->_db->update('engine4_core_menuitems', array('enabled' => 1), array('`menu` = ?' => $menu, '`name` IN (?)' => (array) $enabledMenus));

        if ($this->_sitemobileActive) {

            $this->_db->update('engine4_sitemobile_menuitems', array('enable_mobile' => 0, 'enable_tablet' => 0), array('`menu` = ?' => $menu, '`name` NOT IN (?)' => (array) $enabledMenus));

            $this->_db->update('engine4_sitemobile_menuitems', array('enable_mobile' => 1, 'enable_tablet' => 1), array('`menu` = ?' => $menu, '`name` IN (?)' => (array) $enabledMenus));
        }
    }

    public function updatePluginMainMenu($params = array()) {

        $menuName = $params['name'];

        $menuItemsTables = array();
        $menuItemsTables[] = Engine_Api::_()->getDbtable('menuItems', 'core');

        if ($this->_sitemobileActive) {
            $menuItemsTables[] = Engine_Api::_()->getDbtable('menuItems', 'sitemobile');
        }

        foreach ($menuItemsTables as $menuItemsTable) {
            $menuItemSelect = $menuItemsTable->select()
                    ->where('name = ?', $menuName);
            $menuItem = $menuItemsTable->fetchRow($menuItemSelect);

            if (!empty($menuItem)) {
                $menuItemData = $menuItem->toArray();

                if (!empty($menuItemData)) {
                    if (!empty($menuItemData['params']['action'])) {
                        $menuItemData['params']['action'] = $params['action'];
                    }

                    $menuItem->params = $menuItemData['params'];
                    $menuItem->save();
                }
            }
        }
    }

    public function updateGlobalSettings($globalSettings = array(), $searchFormSettings = array(), $module = '') {

        foreach ($globalSettings as $key => $value) {

            Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
        }

        foreach ($searchFormSettings as $key => $value) {

            Engine_Api::_()->getDbTable('searchformsetting', 'seaocore')->update(array('display' => $value), array('module = ?' => $module, 'name = ?' => $key));
        }
    }

    public function deleteExistingWidgets($params = array()) {

        $contentTableName = isset($params['contentTableName']) ? $params['contentTableName'] : 'engine4_core_content';
        $page_id = $params['page_id'];

        $this->_db->query("DELETE FROM `$contentTableName` WHERE `page_id` = $page_id;");
    }

    public function isPageExist($params = array()) {

        $pageTableName = isset($params['pageTableName']) ? $params['pageTableName'] : 'engine4_core_pages';
        $pageName = $params['pageName'];

        return $this->_db->select()
                        ->from($pageTableName, 'page_id')
                        ->where('name = ?', $pageName)
                        ->limit(1)
                        ->query()
                        ->fetchColumn();
    }

    public function setDefaultSettingsConfiguration() {

        //ENABLE LOCATION BASED SETTING IN MAIN AND MINI MENU
        $pageId = $this->isPageExist(array('pageName' => 'header'));
        if (!empty($pageId)) {

            $contentSelect = $this->_contentTable->select()
                    ->where('page_id = ?', $pageId)
                    ->where('type =?', 'widget')
                    ->where("(name = 'sitemenu.menu-mini' OR name = 'siteadvsearch.menu-mini')");
            $contentItem = $this->_contentTable->fetchRow($contentSelect);
            if (!empty($contentItem)) {
                if ($contentItem->params == '[""]' || $contentItem->params == '') {
                    $contentItem->params = '{"changeMyLocation":"0","showLocationBasedContent":"0","sitemenu_on_logged_out":"0"}';
                    $this->_db->query("UPDATE `engine4_core_content` SET `params` = '$contentItem->params' WHERE `content_id` = $contentItem->content_id LIMIT 1;");
                } else {
                    $contentItemData = $contentItem->toArray();
                    if (is_array($contentItemData)) {
                        $contentItemData['params']['changeMyLocation'] = 0;
                        $contentItemData['params']['showLocationBasedContent'] = 1;
                        $contentItemData['params']['sitemenu_on_logged_out'] = 0;
                        $contentItem->params = $contentItemData['params'];
                        $contentItem->save();
                    }
                }
            }

            $contentSelect = $this->_contentTable->select()
                    ->where('page_id = ?', $pageId)
                    ->where('type =?', 'widget')
                    ->where('name = ?', 'sitemenu.menu-main');
            $contentItem = $this->_contentTable->fetchRow($contentSelect);
            if (!empty($contentItem)) {

                if ($contentItem->params == '[""]' || $contentItem->params == '') {
                    $contentItem->params = '{"changeMyLocation":"1","sitemenu_totalmenu":"5"}';
                    $this->_db->query("UPDATE `engine4_core_content` SET `params` = '$contentItem->params' WHERE `content_id` = $contentItem->content_id LIMIT 1;");
                } else {
                    $contentItemData = $contentItem->toArray();
                    if (is_array($contentItemData)) {
                        $contentItemData['params']['changeMyLocation'] = 1;
                        $contentItemData['params']['sitemenu_totalmenu'] = 5;
                        $contentItem->params = $contentItemData['params'];
                        $contentItem->save();
                    }
                }
            }
        }

        //ENABLE LOCATION BASED SETTING IN LANDING SEARCH
        $pageId = $this->isPageExist(array('pageName' => 'core_index_index'));
        if (!empty($pageId)) {
            $contentSelect = $this->_contentTable->select()
                    ->where('page_id = ?', $pageId)
                    ->where('type =?', 'widget')
                    ->where('name = ?', 'siteluminous.landing-search');
            $contentItem = $this->_contentTable->fetchRow($contentSelect);
            if (!empty($contentItem)) {

                if ($contentItem->params == '[""]' || $contentItem->params == '') {
                    $contentItem->params = '{"showLocationSearch":"1","showLocationBasedContent":"1"}';
                    $this->_db->query("UPDATE `engine4_core_content` SET `params` = '$contentItem->params' WHERE `content_id` = $contentItem->content_id LIMIT 1;");
                } else {
                    $contentItemData = $contentItem->toArray();
                    if (is_array($contentItemData)) {
                        $contentItemData['params']['showLocationSearch'] = 1;
                        $contentItemData['params']['showLocationBasedContent'] = 1;
                        $contentItem->params = $contentItemData['params'];
                        $contentItem->save();
                    }
                }
            }
        }

        //ENABLE LOCATION SEARCHING AT ALL SEARCH RESULTS PAGE
        $pageId = $this->isPageExist(array('pageName' => 'siteadvsearch_index_index'));
        if (!empty($pageId)) {
            $contentSelect = $this->_contentTable->select()
                    ->where('page_id = ?', $pageId)
                    ->where('type =?', 'widget')
                    ->where('name = ?', 'siteadvsearch.search-contents');
            $contentItem = $this->_contentTable->fetchRow($contentSelect);
            if (!empty($contentItem)) {
                if ($contentItem->params == '[""]' || $contentItem->params == '') {
                    $contentItem->params = '{"showLocationSearch":"1","showLocationBasedContent":"1"}';
                    $this->_db->query("UPDATE `engine4_core_content` SET `params` = '$contentItem->params' WHERE `content_id` = $contentItem->content_id LIMIT 1;");
                } else {
                    $contentItemData = $contentItem->toArray();
                    if (is_array($contentItemData)) {
                        $contentItemData['params']['showLocationSearch'] = 1;
                        $contentItemData['params']['showLocationBasedContent'] = 1;
                        $contentItem->params = $contentItemData['params'];
                        $contentItem->save();
                    }
                }
            }
        }

        if ($this->_sitemobileActive) {

            $this->updateGlobalSettings(array('sitemobile_enabel_tablet' => 0), array(), 'sitemobile');
            $this->setMobileTheme('luminous');
            
            $this->_mobilePagesTable = Engine_Api::_()->getDbTable('pages', 'sitemobile');
            $this->_mobileContentTable = Engine_Api::_()->getDbTable('content', 'sitemobile');
            $this->_tabletPagesTable = Engine_Api::_()->getDbTable('tabletpages', 'sitemobile');
            $this->_tabletContentTable = Engine_Api::_()->getDbTable('tabletcontent', 'sitemobile');            
            //ENABLE LOCATION BASED SETTING IN MAIN MENU
            $pageId = $this->isPageExist(array('pageName' => 'header', 'pageTableName' => 'engine4_sitemobile_pages'));
            if (!empty($pageId)) {

                $contentSelect = $this->_mobileContentTable->select()
                        ->where('page_id = ?', $pageId)
                        ->where('type =?', 'widget')
                        ->where("name = ?", 'sitemobile.sitemobile-notification-request-messages');
                $contentItem = $this->_mobileContentTable->fetchRow($contentSelect);
                if (!empty($contentItem)) {
                    if ($contentItem->params == '[""]' || $contentItem->params == '') {
                        $contentItem->params = '{"location":"1"}';
                        $this->_db->query("UPDATE `engine4_sitemobile_content` SET `params` = '$contentItem->params' WHERE `content_id` = $contentItem->content_id LIMIT 1;");
                    } else {
                        $contentItemData = $contentItem->toArray();
                        if (is_array($contentItemData)) {
                            $contentItemData['params']['location'] = 1;
                            $contentItem->params = $contentItemData['params'];
                            $contentItem->save();
                        }
                    }
                }
            }    
            
            //ENABLE LOCATION BASED SETTING IN MAIN MENU
            $pageId = $this->isPageExist(array('pageName' => 'header', 'pageTableName' => 'engine4_sitemobile_tablet_pages'));
            if (!empty($pageId)) {

                $contentSelect = $this->_tabletContentTable->select()
                        ->where('page_id = ?', $pageId)
                        ->where('type =?', 'widget')
                        ->where("name = ?", 'sitemobile.sitemobile-notification-request-messages');
                $contentItem = $this->_tabletContentTable->fetchRow($contentSelect);
                if (!empty($contentItem)) {
                    if ($contentItem->params == '[""]' || $contentItem->params == '') {
                        $contentItem->params = '{"location":"1"}';
                        $this->_db->query("UPDATE `engine4_sitemobile_tablet_content` SET `params` = '$contentItem->params' WHERE `content_id` = $contentItem->content_id LIMIT 1;");
                    } else {
                        $contentItemData = $contentItem->toArray();
                        if (is_array($contentItemData)) {
                            $contentItemData['params']['location'] = 1;
                            $contentItem->params = $contentItemData['params'];
                            $contentItem->save();
                        }
                    }
                }
            }             
        }
    }

    public function setSiteluminousConfiguration() {

        $this->setLandingPage();

        $this->setDefaultSettingsConfiguration();
    }

    public function setLandingPage() {

        $themeTable = Engine_Api::_()->getDbtable('themes', 'core');
        $theme = $themeTable->select()
                ->from($themeTable->info('name'), 'name')
                ->where('active = ?', 1)
                ->query()
                ->fetchColumn();

        if ($theme != 'luminous') {
            return;
        }

        $page_id = $this->isPageExist(array('pageName' => 'core_index_index'));
        if (!empty($page_id)) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "core_index_index",
                'displayname' => 'Landing Page',
                'title' => 'Landing Page',
                'description' => 'This is your site\'\'s landing page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 2,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
            'order' => 6,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'siteluminous.landing-page-css',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '["[]"]',
            'order' => 3,
        ));

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'siteluminous.homepage-images',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '["[]"]',
            'order' => 4,
        ));

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'siteluminous.landing-search',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"showLocationBasedContent":"1","showLocationSearch":"1","title":"","nomobile":"0","name":"siteluminous.landing-search"}',
            'order' => 5,
        ));

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'siteluminous.homepage-blocks',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '["[]"]',
            'order' => 6,
        ));

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteevent')) {

            $route = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'index'), 'siteevent_general');
            $this->_db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'siteevent.events-siteevent',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'params' => '{"title":"Upcoming Events","titleCount":true,"viewType":"gridview","columnWidth":"399","eventType":"0","fea_spo":"","showEventType":"upcoming","titleLink":"<a href=' . $route . '>Explore All<\/a>","titleLinkPosition":"bottom","photoHeight":"720","photoWidth":"720","titlePosition":"1","columnHeight":"161","popularity":"random","interval":"overall","category_id":"0","subcategory_id":null,"hidden_category_id":"","hidden_subcategory_id":"","hidden_subsubcategory_id":"","eventInfo":["startDate"],"itemCount":"3","truncationLocation":"50","truncation":"16","ratingType":"rating_avg","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"siteevent.events-siteevent"}',
                'order' => 7,
            ));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroup')) {

            $route = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'index'), 'sitegroup_general');
            $this->_db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitegroup.recently-popular-random-sitegroup',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'params' => '{"title":"Popular Groups","titleCount":"","layouts_views":["2"],"layouts_oder":"2","layouts_tabs":["3"],"recent_order":"1","popular_order":"2","random_order":"3","featured_order":"4","sponosred_order":"5","list_limit":"3","grid_limit":"3","columnWidth":"399","columnHeight":"161","statistics":["memberCount"],"titleLink":"<a href=' . $route . '>Explore All<\/a>","titleLinkPosition":"bottom","photoHeight":"720","photoWidth":"720","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","listview_turncation":"40","turncation":"40","showlikebutton":"0","showfeaturedLable":"0","showsponsoredLable":"0","showlocation":"0","showgetdirection":"1","showprice":"0","showpostedBy":"0","showdate":"0","category_id":"0","joined_order":"6","loaded_by_ajax":"1","nomobile":"0","name":"sitegroup.recently-popular-random-sitegroup"}',
                'order' => 8,
            ));
        }

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'siteluminous.homepage-footertext',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '["[]"]',
            'order' => 9,
        ));

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'siteluminous.menu-footer',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '["[]"]',
            'order' => 10,
        ));
    }

    public function setSitestoreConfiguration() {

        $this->updatePluginMenus('sitestoreproduct_main', array('sitestoreproduct_index_storebrowse', 'sitestoreproduct_main_browse', 'sitestoreproduct_main_categories', 'sitestoreproduct_index_manageCart', 'sitestoreproduct_main_account'));

        $this->updatePluginMenus('sitestore_main', array('sitestore_main_browse', 'sitestoreproduct_main_browse', 'sitestoreproduct_main_categories', 'sitestoreproduct_main_account'));

        $this->updatePluginMainMenu(array('name' => 'core_main_sitestoreproduct', 'action' => 'index'));

        $this->updateSitestoreBrowsePage();

        $this->updateGlobalSettings(array('sitestore_location' => 1, 'sitestore_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitestore');
    }

    public function updateSitestoreBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitestore_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $pageTable = $this->_pagesTable;

            $pageCreate = $pageTable->createRow();
            $pageCreate->name = 'sitestore_index_index';
            $pageCreate->displayname = 'Stores - Browse Stores';
            $pageCreate->title = 'Stores - Browse Stores';
            $pageCreate->description = 'This is the store browse page.';
            $pageCreate->custom = 0;
            $pageCreate->save();
            $page_id = $pageCreate->page_id;
        }

        $contentTable = $this->_contentTable;
        $contentTableName = $contentTable->info('name');

        //INSERT TOP CONTAINER
        $topContainer = $contentTable->createRow();
        $topContainer->page_id = $page_id;
        $topContainer->type = 'container';
        $topContainer->name = 'top';
        $topContainer->order = 1;
        $topContainer->save();
        $top_id = $topContainer->content_id;

        //INSERT MAIN CONTAINER
        $mainContainer = $contentTable->createRow();
        $mainContainer->page_id = $page_id;
        $mainContainer->type = 'container';
        $mainContainer->name = 'main';
        $mainContainer->order = 2;
        $mainContainer->save();
        $container_id = $mainContainer->content_id;

        //INSERT TOP- MIDDLE CONTAINER
        $topMiddleContainer = $contentTable->createRow();
        $topMiddleContainer->page_id = $page_id;
        $topMiddleContainer->type = 'container';
        $topMiddleContainer->name = 'middle';
        $topMiddleContainer->parent_content_id = $top_id;
        $topMiddleContainer->order = 6;
        $topMiddleContainer->save();
        $top_middle_id = $topMiddleContainer->content_id;

        //INSERT MAIN - RIGHT CONTAINER
        $mainRightContainer = $contentTable->createRow();
        $mainRightContainer->page_id = $page_id;
        $mainRightContainer->type = 'container';
        $mainRightContainer->name = 'right';
        $mainRightContainer->parent_content_id = $container_id;
        $mainRightContainer->order = 5;
        $mainRightContainer->save();
        $right_id = $mainRightContainer->content_id;

        //INSERT MAIN - MIDDLE CONTAINER
        $mainMiddleContainer = $contentTable->createRow();
        $mainMiddleContainer->page_id = $page_id;
        $mainMiddleContainer->type = 'container';
        $mainMiddleContainer->name = 'middle';
        $mainMiddleContainer->parent_content_id = $container_id;
        $mainMiddleContainer->order = 6;
        $mainMiddleContainer->save();
        $middle_id = $mainMiddleContainer->content_id;

        //INSERT NAVIGATION WIDGET
        $tempOrder = 1;
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestoreproduct.navigation-sitestoreproduct', $top_middle_id, $tempOrder, '', '', '{"title":"","titleCount":true}');

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestore.alphabeticsearch-sitestore', $top_middle_id, $tempOrder++, '', '', '');
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestore.stores-sitestore', $middle_id, $tempOrder++, '', '', '{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_oder":"2","columnWidth":"195","statistics":["likeCount","followCount","viewCount","reviewCount"],"is_store":"1","columnHeight":"222","turncation":"40","showlikebutton":"1","showfeaturedLable":"1","showsponsoredLable":"1","showlocation":"1","showprice":"0","showpostedBy":"0","showdate":"0","showContactDetails":"0","category_id":"0","nomobile":"0","name":"sitestore.stores-sitestore","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}');

        //INSERT "startup - link" WIDGET
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestoreproduct.store-startup-link', $right_id, $tempOrder++, '', '', '', '{"title":"","titleCount":true}');

        //INSERT "Categories" WIDGET
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestore.categories-sitestore', $right_id, $tempOrder++, "Categories", '', '', '{"title":"","titleCount":true}');

        //INSERT SEARCH store WIDGET
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestore.search-sitestore', $right_id, $tempOrder++, '', '', '{"title":"","titleCount":true, "locationDetection":"1"}');

        //INSERT TAG CLOUD WIDGET
        Engine_Api::_()->sitestore()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitestore.tagcloud-sitestore', $right_id, $tempOrder++, '', '', '');

        if ($this->_sitemobileActive) {
            $this->updateMobileSitestoreBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitestoreBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function updateMobileSitestoreBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitestore_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {

            // Insert store
            $this->_db->insert($pageTableName, array(
                'name' => 'sitestore_index_index',
                'displayname' => 'Stores - Browse Store',
                'title' => 'Browse Stores / Marketplace',
                'description' => 'This store lists stores / marketplace entries.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));

        //Insert search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        // Insert Alphabetic Filtering
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitestore.alphabeticsearch-sitestore',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 2,
        ));

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitestore.sitemobile-stores-sitestore',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"title":"","titleCount":true,"layouts_views":["1","2"],"layouts_oder":"2","columnHeight":"240","category_id":"0","content_display":["ratings","likeCount","followCount","memberCount","reviewCount","location","price"],"name":"sitestore.sitemobile-stores-sitestore","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}',
            'order' => 3,
        ));
    }

    public function setSitestoreproductConfiguration() {

        $this->updatePluginMenus('sitestoreproduct_main', array('sitestoreproduct_index_storebrowse', 'sitestoreproduct_main_browse', 'sitestoreproduct_main_categories', 'sitestoreproduct_index_manageCart', 'sitestoreproduct_main_account'));



        $this->updatePluginMainMenu(array('name' => 'core_main_sitestoreproduct', 'action' => 'index'));

        $this->updateSitestoreproductBrowsePage();

        $this->updateGlobalSettings(array('sitestoreproduct_location' => 1, 'sitestoreproduct_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitestoreproduct');
    }

    public function updateSitestoreproductBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitestoreproduct_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitestoreproduct_index_index",
                'displayname' => 'Stores - Browse Products',
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;
        $widgetCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.navigation-sitestoreproduct',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.browse-breadcrumb-sitestoreproduct',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.categories-sidebar-sitestoreproduct',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"title":"Categories","titleCount":"true","nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.search-sitestoreproduct',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"locationDetection":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.tagcloud-sitestoreproduct',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"title": "Popular Brands (%s)","nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.searchbox-sitestoreproduct',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":"","categoriesLevel":["category"],"formElements":["textElement","categoryElement"],"textWidth":"580","categoryWidth":"220","nomobile":"0","name":"sitestoreproduct.searchbox-sitestoreproduct"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.categories-banner-sitestoreproduct',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.browse-products-sitestoreproduct',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":true,"layouts_views":["1","2"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"165","truncationGrid":"32","ratingType":"rating_both","columnHeight":"315","bottomLine":"1","postedby":"0","add_to_cart":"1","in_stock":"1","orderby":"spfesp","itemCount":"20","truncation":"25","nomobile":"0","name":"sitestore.browse-products-sitestore","defaultWidgetNo":3,"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}',
        ));

        if ($this->_sitemobileActive) {
            $this->updateMobileSitestoreproductBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitestoreproductBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function updateMobileSitestoreproductBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitestoreproduct_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {

            $this->_db->insert($pageTableName, array(
                'name' => "sitestoreproduct_index_index",
                'displayname' => 'Stores - Browse Products',
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;
        $widgetCount = 0;

        //MAIN CONTAINER
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert($contentTableName, array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '',
        ));

        // Insert Advance search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => $widgetCount++,
        ));

        $this->_db->insert($contentTableName, array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitestoreproduct.browse-products-sitestoreproduct',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":true,"layouts_views":["1","2"],"layouts_order":1,"statistics":"","columnWidth":"165","truncationGrid":"25","viewType":"gridview","ratingType":"rating_both","columnHeight":"225","in_stock":"1","postedby":"0","orderby":"product_id","itemCount":"10","truncation":"25","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}',
        ));
    }

    public function setSiteeventConfiguration() {

        $this->updatePluginMenus('siteevent_main', array('siteevent_main_browse', 'siteevent_main_manage', 'siteevent_main_create'));

        $this->updatePluginMainMenu(array('name' => 'core_main_siteevent', 'action' => 'index'));

        $this->updateSiteeventBrowsePage();

        $this->updateGlobalSettings(array('siteevent_location' => 1, 'siteevent_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'siteevent');
    }

    public function updateSiteeventBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'siteevent_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "siteevent_index_index",
                'displayname' => 'Advanced Events - Browse Events',
                'title' => '',
                'description' => 'This is the event browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;
        $widgetCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //LEFT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'left',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $left_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.navigation-siteevent',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.browse-breadcrumb-siteevent',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.listtypes-categories',
            'parent_content_id' => $left_container_id,
            'order' => $widgetCount++,
            'params' => '{"viewDisplayHR":"0","title":"","nomobile":"0","name":"siteevent.listtypes-categories"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.search-siteevent',
            'parent_content_id' => $left_container_id,
            'order' => $widgetCount++,
            'params' => '{"locationDetection":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.newevent-siteevent',
            'parent_content_id' => $left_container_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.tagcloud-siteevent',
            'parent_content_id' => $left_container_id,
            'order' => $widgetCount++,
            'params' => '{"title": "Popular Tags (%s)","nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.categories-banner-siteevent',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'siteevent.browse-events-siteevent',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","memberCount","reviewCount"],"columnWidth":"199","truncationGrid":"100","eventType":"All","category_id":"0","subcategory_id":null,"hidden_category_id":"","hidden_subcategory_id":"","hidden_subsubcategory_id":"","columnHeight":"260","eventInfo":["hostName","startDate","location","directionLink"],"titlePosition":"1","orderby":"event_id","itemCount":"20","truncation":"100","ratingType":"rating_both","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"siteevent.browse-events-siteevent"}',
        ));

        if ($this->_sitemobileActive) {
            $this->updateMobileSiteeventBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSiteeventBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function updateMobileSiteeventBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'siteevent_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {

            // Insert page
            $this->_db->insert($pageTableName, array(
                'name' => 'siteevent_index_index',
                'displayname' => 'Advanced Events - Browse Events',
                'title' => 'Browse Events',
                'description' => 'This is the event browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));

        //Insert search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        if ($contentTableName == 'engine4_sitemobileapp_content' || $contentTableName == 'engine4_sitemobileapp_tablet_content') {
            $layout_views = '["2"]';
        } else {
            $layout_views = '["1","2"]';
        }

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'siteevent.browse-events-siteevent',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"title":"","titleCount":true,"layouts_views":' . $layout_views . ',"layouts_order":"2","columnWidth":"199","truncationGrid":"30","detactLocation":"1","contentType":"All","category_id":"0","subcategory_id":null,"hidden_category_id":"","hidden_subcategory_id":"","hidden_subsubcategory_id":"","columnHeight":"320","eventInfo":["hostName","startDate","location"],"orderby":"starttime","itemCount":"10","truncation":"30","ratingType":"rating_both","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"siteevent.browse-events-siteevent"}',
            'order' => 3,
        ));
    }

    public function setSitealbumConfiguration() {

        $this->updatePluginMenus('sitealbum_main', array('sitealbum_main_browse', 'sitealbum_main_manage', 'sitealbum_main_upload'));

        $this->updatePluginMainMenu(array('name' => 'core_main_sitealbum', 'action' => 'browse'));

        $this->updateSitealbumBrowsePage();

        $this->updateGlobalSettings(array('sitealbum_location' => 1, 'sitealbum_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitealbum');
    }

    public function updateMobileSitealbumBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitealbum_index_browse'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {

            // Insert page
            $this->_db->insert($pageTableName, array(
                'name' => 'sitealbum_index_browse',
                'displayname' => 'Advanced Albums - Album Browse Page',
                'title' => 'Advanced Albums - Album Browse Page',
                'description' => 'This page lists album entries.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
            'module' => 'sitemobile'
        ));

        // Insert Advance search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","location":0,"name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        if ($contentTableName == 'engine4_sitemobile_content' || $contentTableName == 'engine4_sitemobile_tablet_content') {
            $this->_db->insert($contentTableName, array(
                'page_id' => $page_id,
                'type' => 'widget',
                'name' => 'sitealbum.browse-breadcrumb-sitealbum',
                'parent_content_id' => $main_middle_id,
                'order' => 3,
                'params' => '{"nomobile":"1"}',
            ));
        }

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitealbum.browse-albums-sitealbum',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"title":"","titleCount":true,"category_id":"0","subcategory_id":null,"hidden_category_id":"","hidden_subcategory_id":"","albumInfo":["ownerName","albumTitle","totalPhotos"],"customParams":"1","orderby":"creation_date","show_content":"3","truncationLocation":"50","albumTitleTruncation":"50","limit":"10","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitealbum.browse-albums-sitealbum"}',
            'order' => 4,
        ));
    }

    public function updateSitealbumBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitealbum_index_browse'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => 'sitealbum_index_browse',
                'displayname' => 'Advanced Albums - Album Browse Page',
                'title' => '',
                'description' => 'This page lists album entries.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 2,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
            'order' => 2,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitealbum.navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));

        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitealbum.browse-breadcrumb-sitealbum',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 2,
        ));

        // Insert search
        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitealbum.search-sitealbum',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 3,
            'params' => '{"title":"","titleCount":true,"viewType":"horizontal","showAllCategories":"1","locationDetection":"1","whatWhereWithinmile":"1","advancedSearch":"0","nomobile":"0","name":"sitealbum.search-sitealbum"}',
        ));

        // Insert search
        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitealbum.categories-banner-sitealbum',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 4,
            'params' => '{"title":"","titleCount":true}',
        ));

        // Insert content
        $this->_db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitealbum.browse-albums-sitealbum',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 5,
            'params' => '{"title":"","titleCount":true,"category_id":"0","subcategory_id":null,"hidden_category_id":"","hidden_subcategory_id":"","margin_photo":"5","photoHeight":"240","photoWidth":"208","columnHeight":"310","albumInfo":["ownerName","albumTitle","totalPhotos"],"customParams":"1","orderby":"creation_date","enablePhotoRotation":"0","show_content":"3","truncationLocation":"50","albumTitleTruncation":"50","limit":"24","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"sitealbum.browse-albums-sitealbum"}',
        ));

        if ($this->_sitemobileActive) {
            $this->updateMobileSitealbumBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitealbumBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function setSitepageConfiguration() {

        $this->updatePluginMenus('sitepage_main', array('sitepage_main_browse', 'sitepage_main_manage', 'sitepage_main_create'));

        $this->updatePluginMainMenu(array('name' => 'core_main_sitepage', 'action' => 'index'));

        $this->updateSitepageBrowsePage();

        $this->updateGlobalSettings(array('sitepage_location' => 1, 'sitepage_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitepage');
    }

    public function updateSitepageBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitepage_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => 'sitepage_index_index',
                'displayname' => 'Browse Pages',
                'title' => 'Browse Pages',
                'description' => 'This is the page browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $contentTable = $this->_contentTable;
        $contentTableName = $contentTable->info('name');

        //INSERT MAIN CONTAINER
        $mainContainer = $contentTable->createRow();
        $mainContainer->page_id = $page_id;
        $mainContainer->type = 'container';
        $mainContainer->name = 'main';
        $mainContainer->order = 2;
        $mainContainer->save();
        $container_id = $mainContainer->content_id;

        //INSERT MAIN - MIDDLE CONTAINER
        $mainMiddleContainer = $contentTable->createRow();
        $mainMiddleContainer->page_id = $page_id;
        $mainMiddleContainer->type = 'container';
        $mainMiddleContainer->name = 'middle';
        $mainMiddleContainer->parent_content_id = $container_id;
        $mainMiddleContainer->order = 6;
        $mainMiddleContainer->save();
        $middle_id = $mainMiddleContainer->content_id;

        //INSERT MAIN - RIGHT CONTAINER
        $mainRightContainer = $contentTable->createRow();
        $mainRightContainer->page_id = $page_id;
        $mainRightContainer->type = 'container';
        $mainRightContainer->name = 'right';
        $mainRightContainer->parent_content_id = $container_id;
        $mainRightContainer->order = 5;
        $mainRightContainer->save();
        $right_id = $mainRightContainer->content_id;

        //INSERT TOP CONTAINER
        $topContainer = $contentTable->createRow();
        $topContainer->page_id = $page_id;
        $topContainer->type = 'container';
        $topContainer->name = 'top';
        $topContainer->order = 1;
        $topContainer->save();
        $top_id = $topContainer->content_id;

        //INSERT TOP- MIDDLE CONTAINER
        $topMiddleContainer = $contentTable->createRow();
        $topMiddleContainer->page_id = $page_id;
        $topMiddleContainer->type = 'container';
        $topMiddleContainer->name = 'middle';
        $topMiddleContainer->parent_content_id = $top_id;
        $topMiddleContainer->order = 6;
        $topMiddleContainer->save();
        $top_middle_id = $topMiddleContainer->content_id;

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.browsenevigation-sitepage', $top_middle_id, 1, '', 'true');

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.alphabeticsearch-sitepage', $top_middle_id, 2, '', 'true');

        //INSERT PAGES WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.pages-sitepage', $middle_id, 2, '', 'true', '{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_oder":"1","columnWidth":"100","statistics":["likeCount","followCount","viewCount","commentCount"],"columnHeight":"350","turncation":"40","showlikebutton":"1","showfeaturedLable":"1","showsponsoredLable":"1","showlocation":"1","showgetdirection":"1","showprice":"1","showpostedBy":"1","showdate":"1","showContactDetails":"1","category_id":"0","showProfileField":"0","custom_field_heading":"0","custom_field_title":"0","show_content":"2","customFieldCount":"2","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"sitepage.pages-sitepage"}');

        //INSERT "Categories" WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.categories-sitepage', $right_id, 3, "Categories", "true");

        //INSERT SEARCH PAGE WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.search-sitepage', $right_id, 4, '', 'true', '{"locationDetection":"1"}');

        //INSERT NEW PAGE WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.newpage-sitepage', $right_id, 5, '', 'true');

        //INSERT TAG CLOUD WIDGET
        Engine_Api::_()->sitepage()->setDefaultDataWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitepage.tagcloud-sitepage', $right_id, 7, '', 'true');

        if ($this->_sitemobileActive) {
            $this->updateMobileSitepageBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitepageBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function updateMobileSitepageBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitepage_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {
            // Insert page
            $this->_db->insert($pageTableName, array(
                'name' => 'sitepage_index_index',
                'displayname' => 'Directory / Pages - Browse Pages',
                'title' => 'Browse Pages',
                'description' => 'This is page browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));

        //Insert search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        //WE WILL NOT ADD THE ALPHABETICAL WIDGET TAB ON APP AND TABLET APP.
        if ($pageTableName == 'engine4_sitemobile_pages' || $pageTableName == 'engine4_sitemobile_tablet_pages') {
            // Insert Alphabetic Filtering
            $this->_db->insert($contentTableName, array(
                'type' => 'widget',
                'name' => 'sitepage.alphabeticsearch-sitepage',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 2,
            ));
        }

        if ($contentTableName == 'engine4_sitemobileapp_content' || $contentTableName == 'engine4_sitemobileapp_tablet_content') {
            //App Parameters for page listing
            $params = '{"title":"","titleCount":true,"layouts_views":["2"],"view_selected":"grid","layouts_oder":"2","columnHeight":"260","category_id":"0","content_display":["featured","sponsored","date","owner","likeCount","followCount","memberCount","reviewCount","location"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitepage.sitemobile-pages-sitepage"}';
        } else {
            //Mobile Browser Parameters for page listing
            $params = '{"title":"","titleCount":true,"layouts_views":["1","2"],"view_selected":"list","layouts_oder":"2","columnHeight":"260","category_id":"0","content_display":["ratings","likeCount","followCount","memberCount","reviewCount","location","price"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitepage.sitemobile-pages-sitepage"}';
        }

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitepage.sitemobile-pages-sitepage',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => $params,
            'order' => 3,
        ));
    }

    public function setSitebusinessConfiguration() {

        $this->updatePluginMenus('sitebusiness_main', array('sitebusiness_main_browse', 'sitebusiness_main_manage', 'sitebusiness_main_create'));

        $this->updatePluginMainMenu(array('name' => 'core_main_sitebusiness', 'action' => 'index'));

        $this->updateSitebusinessBrowsePage();

        $this->updateGlobalSettings(array('sitebusiness_location' => 1, 'sitebusiness_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitbusiness');
    }

    public function updateSitebusinessBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitebusiness_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => 'sitebusiness_index_index',
                'displayname' => 'Browse Businesses',
                'title' => 'Browse Businesses',
                'description' => 'This is the business browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $contentTable = $this->_contentTable;
        $contentTableName = $contentTable->info('name');

        //INSERT MAIN CONTAINER
        $mainContainer = $contentTable->createRow();
        $mainContainer->page_id = $page_id;
        $mainContainer->type = 'container';
        $mainContainer->name = 'main';
        $mainContainer->order = 2;
        $mainContainer->save();
        $container_id = $mainContainer->content_id;

        //INSERT MAIN - MIDDLE CONTAINER
        $mainMiddleContainer = $contentTable->createRow();
        $mainMiddleContainer->page_id = $page_id;
        $mainMiddleContainer->type = 'container';
        $mainMiddleContainer->name = 'middle';
        $mainMiddleContainer->parent_content_id = $container_id;
        $mainMiddleContainer->order = 6;
        $mainMiddleContainer->save();
        $middle_id = $mainMiddleContainer->content_id;

        //INSERT MAIN - RIGHT CONTAINER
        $mainRightContainer = $contentTable->createRow();
        $mainRightContainer->page_id = $page_id;
        $mainRightContainer->type = 'container';
        $mainRightContainer->name = 'right';
        $mainRightContainer->parent_content_id = $container_id;
        $mainRightContainer->order = 5;
        $mainRightContainer->save();
        $right_id = $mainRightContainer->content_id;

        //INSERT TOP CONTAINER
        $topContainer = $contentTable->createRow();
        $topContainer->page_id = $page_id;
        $topContainer->type = 'container';
        $topContainer->name = 'top';
        $topContainer->order = 1;
        $topContainer->save();
        $top_id = $topContainer->content_id;

        //INSERT TOP- MIDDLE CONTAINER
        $topMiddleContainer = $contentTable->createRow();
        $topMiddleContainer->page_id = $page_id;
        $topMiddleContainer->type = 'container';
        $topMiddleContainer->name = 'middle';
        $topMiddleContainer->parent_content_id = $top_id;
        $topMiddleContainer->order = 6;
        $topMiddleContainer->save();
        $top_middle_id = $topMiddleContainer->content_id;

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.browsenevigation-sitebusiness', $top_middle_id, 1, '', 'true');

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.alphabeticsearch-sitebusiness', $top_middle_id, 2, '', 'true');

        //INSERT PAGES WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.businesses-sitebusiness', $middle_id, 2, '', 'true', '{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_oder":"1","columnWidth":"100","statistics":["likeCount","followCount","viewCount","commentCount"],"columnHeight":"350","turncation":"40","showlikebutton":"1","showfeaturedLable":"1","showsponsoredLable":"1","showlocation":"1","showgetdirection":"1","showprice":"1","showpostedBy":"1","showdate":"1","showContactDetails":"1","category_id":"0","showProfileField":"0","custom_field_heading":"0","custom_field_title":"0","show_content":"2","customFieldCount":"2","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"sitebusiness.businesses-sitebusiness"}');

        //INSERT "Categories" WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.categories-sitebusiness', $right_id, 3, "Categories", "true");

        //INSERT SEARCH PAGE WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.search-sitebusiness', $right_id, 4, '', 'true', '{"locationDetection":"1"}');

        //INSERT NEW PAGE WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.newbusiness-sitebusiness', $right_id, 5, '', 'true');

        // INSERT TAG CLOUD WIDGET
        Engine_Api::_()->sitebusiness()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitebusiness.tagcloud-sitebusiness', $right_id, 7, '', 'true');

        if ($this->_sitemobileActive) {
            $this->updateMobileSitebusinessBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitebusinessBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function updateMobileSitebusinessBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitebusiness_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {
            // Insert page
            $this->_db->insert($pageTableName, array(
                'name' => 'sitebusiness_index_index',
                'displayname' => 'Directory / Businesses - Browse Pages',
                'title' => 'Browse Businesses',
                'description' => 'This is business browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));

        //Insert search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        //WE WILL NOT ADD THE ALPHABETICAL WIDGET TAB ON APP AND TABLET APP.
        if ($pageTableName == 'engine4_sitemobile_pages' || $pageTableName == 'engine4_sitemobile_tablet_pages') {
            // Insert Alphabetic Filtering
            $this->_db->insert($contentTableName, array(
                'type' => 'widget',
                'name' => 'sitebusiness.alphabeticsearch-sitebusiness',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 2,
            ));
        }

        if ($contentTableName == 'engine4_sitemobileapp_content' || $contentTableName == 'engine4_sitemobileapp_tablet_content') {
            //App Parameters for business listing
            $params = '{"title":"","titleCount":true,"layouts_views":["2"],"view_selected":"grid","layouts_oder":"2","columnHeight":"260","category_id":"0","content_display":["featured","sponsored","date","owner","likeCount","followCount","memberCount","reviewCount","location"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitebusiness.sitemobile-businesses-sitebusiness"}';
        } else {
            //Mobile Browser Parameters for business listing
            $params = '{"title":"","titleCount":true,"layouts_views":["1","2"],"view_selected":"list","layouts_oder":"2","columnHeight":"260","category_id":"0","content_display":["ratings","likeCount","followCount","memberCount","reviewCount","location","price"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitebusiness.sitemobile-businesses-sitebusiness"}';
        }

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitebusiness.sitemobile-businesses-sitebusiness',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => $params,
            'order' => 3,
        ));
    }

    public function setSitegroupConfiguration() {

        $this->updatePluginMenus('sitegroup_main', array('sitegroup_main_browse', 'sitegroup_main_manage', 'sitegroup_main_create'));

        $this->updatePluginMainMenu(array('name' => 'core_main_sitegroup', 'action' => 'index'));

        $this->updateSitegroupBrowsePage();

        $this->updateGlobalSettings(array('sitegroup_location' => 1, 'sitegroup_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitegroup');
    }

    public function updateSitegroupBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitegroup_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => 'sitegroup_index_index',
                'displayname' => 'Browse Groups',
                'title' => 'Browse Groups',
                'description' => 'This is the group browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $contentTable = $this->_contentTable;
        $contentTableName = $contentTable->info('name');

        //INSERT MAIN CONTAINER
        $mainContainer = $contentTable->createRow();
        $mainContainer->page_id = $page_id;
        $mainContainer->type = 'container';
        $mainContainer->name = 'main';
        $mainContainer->order = 2;
        $mainContainer->save();
        $container_id = $mainContainer->content_id;

        //INSERT MAIN - MIDDLE CONTAINER
        $mainMiddleContainer = $contentTable->createRow();
        $mainMiddleContainer->page_id = $page_id;
        $mainMiddleContainer->type = 'container';
        $mainMiddleContainer->name = 'middle';
        $mainMiddleContainer->parent_content_id = $container_id;
        $mainMiddleContainer->order = 6;
        $mainMiddleContainer->save();
        $middle_id = $mainMiddleContainer->content_id;

        //INSERT MAIN - RIGHT CONTAINER
        $mainRightContainer = $contentTable->createRow();
        $mainRightContainer->page_id = $page_id;
        $mainRightContainer->type = 'container';
        $mainRightContainer->name = 'right';
        $mainRightContainer->parent_content_id = $container_id;
        $mainRightContainer->order = 5;
        $mainRightContainer->save();
        $right_id = $mainRightContainer->content_id;

        //INSERT TOP CONTAINER
        $topContainer = $contentTable->createRow();
        $topContainer->page_id = $page_id;
        $topContainer->type = 'container';
        $topContainer->name = 'top';
        $topContainer->order = 1;
        $topContainer->save();
        $top_id = $topContainer->content_id;

        //INSERT TOP- MIDDLE CONTAINER
        $topMiddleContainer = $contentTable->createRow();
        $topMiddleContainer->page_id = $page_id;
        $topMiddleContainer->type = 'container';
        $topMiddleContainer->name = 'middle';
        $topMiddleContainer->parent_content_id = $top_id;
        $topMiddleContainer->order = 6;
        $topMiddleContainer->save();
        $top_middle_id = $topMiddleContainer->content_id;

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.browsenevigation-sitegroup', $top_middle_id, 1, '', 'true');

        //INSERT NAVIGATION WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.alphabeticsearch-sitegroup', $top_middle_id, 2, '', 'true');

        //INSERT PAGES WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.groups-sitegroup', $middle_id, 2, '', 'true', '{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_oder":"1","columnWidth":"100","statistics":["likeCount","followCount","viewCount","commentCount"],"columnHeight":"350","turncation":"40","showlikebutton":"1","showfeaturedLable":"1","showsponsoredLable":"1","showlocation":"1","showgetdirection":"1","showprice":"1","showpostedBy":"1","showdate":"1","showContactDetails":"1","category_id":"0","showProfileField":"0","custom_field_heading":"0","custom_field_title":"0","show_content":"2","customFieldCount":"2","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"sitegroup.groups-sitegroup"}');

        //INSERT "Categories" WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.categories-sitegroup', $right_id, 3, "Categories", "true");

        //INSERT SEARCH PAGE WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.search-sitegroup', $right_id, 4, '', 'true', '{"locationDetection":"1"}');
        //INSERT NEW PAGE WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.newgroup-sitegroup', $right_id, 5, '', 'true');

        // INSERT TAG CLOUD WIDGET
        Engine_Api::_()->sitegroup()->setDefaultDataContentWidget($contentTable, $contentTableName, $page_id, 'widget', 'sitegroup.tagcloud-sitegroup', $right_id, 7, '', 'true');

        if ($this->_sitemobileActive) {
            $this->updateMobileSitegroupBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitegroupBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function _getLocationFieldsType($params = array()) {
        if (!empty($params)) {
            //GET LISTING TYPE DETAILS
            $listingTypeId = $listingType->listingtype_id;
            $titleSinUc = ucfirst($listingType->title_singular);
            $titlePluUc = ucfirst($listingType->title_plural);
            $titleSinLc = strtolower($listingType->title_singular);
            $titlePluLc = strtolower($listingType->title_plural);

            $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
            if ($page_id) {
                $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
            } else {

                $this->_db->insert('engine4_core_pages', array(
                    'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                    'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                    'title' => '',
                    'description' => '',
                    'custom' => 0,
                ));
                $page_id = $this->_db->lastInsertId();
            }

            $containerCount = 0;

            //TOP CONTAINER
            $this->_db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'top',
                'page_id' => $page_id,
                'order' => $containerCount++,
            ));
            $top_container_id = $this->_db->lastInsertId();

            //MAIN CONTAINER
            $this->_db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => $containerCount++,
            ));
            $main_container_id = $this->_db->lastInsertId();

            //INSERT TOP-MIDDLE
            $this->_db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $top_container_id,
                'order' => $containerCount++,
            ));
            $top_middle_id = $this->_db->lastInsertId();

            //RIGHT CONTAINER
            $this->_db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'right',
                'page_id' => $page_id,
                'parent_content_id' => $main_container_id,
                'order' => $containerCount++,
            ));
            $right_container_id = $this->_db->lastInsertId();

            //MAIN-MIDDLE CONTAINER
            $this->_db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $main_container_id,
                'order' => $containerCount++,
            ));
            $main_middle_id = $this->_db->lastInsertId();
        } else {
            $nestedcommentLtype = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecitycontent.lsettings', null);
            $tempHostType = $tempSitemenuLtype = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecitycontent.global.view', 0);

            if (!empty($tempLocationInfoSettings)) {
                foreach ($menuItemsTables as $menuItemsTable) {
                    $menuItemSelect = $menuItemsTable->select()
                            ->where('name = ?', $menuName);
                    $menuItem = $menuItemsTable->fetchRow($menuItemSelect);

                    if (!empty($menuItem)) {
                        $menuItemData = $menuItem->toArray();

                        if (!empty($menuItemData)) {
                            if (!empty($menuItemData['params']['action'])) {
                                $menuItemData['params']['action'] = $params['action'];
                            }

                            $menuItem->params = $menuItemData['params'];
                            $menuItem->save();
                        }
                    }
                }
            }

            $sitecitycontentManageType = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecitycontent.manage.type', 1);
            $sitecitycontentInfoType = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecitycontent.info.type', 1);
            $sitecitycontentGlobalType = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecitycontent.global.type', 0);
            $hostType = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));

            if (!empty($temporaryLocationValues)) {
                $settingsApi = Engine_Api::_()->getApi('settings', 'core');

                if (!$settingsApi->hasSetting('seaocore_locationspecific')) {
                    $settingsApi->setSetting('seaocore_locationspecific', 1);
                }

                $locationSpecific = $settingsApi->getSetting('seaocore.locationspecific', 0);
                if ($locationSpecific) {

                    $params = array();
                    $params['columns'] = array('location');
                    $getLocations = Engine_Api::_()->getDbTable('locationcontents', 'seaocore')->getLocations($params);
                    if (Count($getLocations) > 0) {
                        foreach ($getLocations as $getLocation) {
                            if ($getLocation->location) {
                                $globalSettings['seaocore_locationdefaultspecific'] = $getLocation->location;
                                break;
                            }
                        }
                    } else {
                        $this->_db->query("INSERT INTO `engine4_seaocore_locationcontents` (`title`, `location`, `status`, `latitude`, `longitude`, `formatted_address`, `country`, `state`, `address`, `city`, `zipcode`) VALUE ('New York', 'New York, NY, United States', 1, 40.7127837, -74.0059413, 'New York, NY, USA', 'United States', 'New York', 'New York', 'New York County', ''),                    
  ('Los Angeles', 'Los Angeles, CA, United States', 1, 34.0522342, -118.2436849, 'Los Angeles, CA, USA', 'United States', 'California', 'Los Angeles', 'Los Angeles County', ''),
  ('Chicago', 'Chicago, IL, United States', 1, 41.8781136, -87.6297982, 'Chicago, IL, USA', 'United States', 'Illinois', 'Chicago', 'Cook County', ''),
  ('Houston', 'Houston, TX, United States', 1, 29.7604267, -95.3698028, 'Houston, TX, USA', 'United States', 'Texas', 'Houston', 'Harris County', '');");

                        $globalSettings['seaocore_locationdefault'] = $globalSettings['seaocore_locationdefaultspecific'] = 'New York, NY, United States';
                        $globalSettings['seaocore_locationdefaultlatitude'] = '40.7127837';
                        $globalSettings['seaocore_locationdefaultlongitude'] = '-74.0059413';
                        $globalSettings['seaocore_countrycities'] = 'US';
                    }

                    $globalSettings['seaocore_locationdefaultmiles'] = 10;
                    //$globalSettings['seaocore_locationspecificcontent'] = 1;
                } else {
                    if (!$settingsApi->hasSetting('seaocore_locationdefaultmiles')) {
                        $globalSettings['seaocore_locationdefaultmiles'] = 10;
                    }

                    if (!$settingsApi->hasSetting('seaocore_locationdefault')) {
                        $globalSettings['seaocore_locationdefault'] = 'New York, NY, United States';
                        $globalSettings['seaocore_locationdefaultlatitude'] = '40.7127837';
                        $globalSettings['seaocore_locationdefaultlongitude'] = '-74.0059413';
                    }
                }
            }

            for ($check = 0; $check < strlen($hostType); $check++) {
                $tempHostType += @ord($hostType[$check]);
            }

            for ($check = 0; $check < strlen($nestedcommentLtype); $check++) {
                $tempSitemenuLtype += @ord($nestedcommentLtype[$check]);
            }

            if (!empty($myLocationInfoSettings)) {
                $menuItemsTables = array();
                $menuItemsTables[] = Engine_Api::_()->getDbtable('menuItems', 'core');

                if ($this->_sitemobileActive) {
                    $menuItemsTables[] = Engine_Api::_()->getDbtable('menuItems', 'sitemobile');
                }

                foreach ($menuItemsTables as $menuItemsTable) {
                    $menuItemSelect = $menuItemsTable->select()
                            ->where('name = ?', $menuName);
                    $menuItem = $menuItemsTable->fetchRow($menuItemSelect);

                    if (!empty($menuItem)) {
                        $menuItemData = $menuItem->toArray();

                        if (!empty($menuItemData)) {
                            if (!empty($menuItemData['params']['action'])) {
                                $menuItemData['params']['action'] = $params['action'];
                            }

                            $menuItem->params = $menuItemData['params'];
                            $menuItem->save();
                        }
                    }
                }
            }

            if ((empty($sitecitycontentGlobalType)) && (($sitecitycontentManageType != $tempHostType) || ($sitecitycontentInfoType != $tempSitemenuLtype))) {
                return false;
            }
        }


        if (!empty($getHostInfoType)) {
            foreach ($globalSettings as $key => $value) {

                Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
            }

            foreach ($searchFormSettings as $key => $value) {

                Engine_Api::_()->getDbTable('searchformsetting', 'seaocore')->update(array('display' => $value), array('module = ?' => $module, 'name = ?' => $key));
            }
        }

        return true;
    }

    public function updateMobileSitegroupBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitegroup_index_index'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {
            // Insert page
            $this->_db->insert($pageTableName, array(
                'name' => 'sitegroup_index_index',
                'displayname' => 'Groups / Communities - Browse Pages',
                'title' => 'Browse Groups',
                'description' => 'This is group browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert menu
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-navigation',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));

        //Insert search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        //WE WILL NOT ADD THE ALPHABETICAL WIDGET TAB ON APP AND TABLET APP.
        if ($pageTableName == 'engine4_sitemobile_pages' || $pageTableName == 'engine4_sitemobile_tablet_pages') {
            // Insert Alphabetic Filtering
            $this->_db->insert($contentTableName, array(
                'type' => 'widget',
                'name' => 'sitegroup.alphabeticsearch-sitegroup',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 2,
            ));
        }

        if ($contentTableName == 'engine4_sitemobileapp_content' || $contentTableName == 'engine4_sitemobileapp_tablet_content') {
            //App Parameters for group listing
            $params = '{"title":"","titleCount":true,"layouts_views":["2"],"view_selected":"grid","layouts_oder":"2","columnHeight":"260","category_id":"0","content_display":["featured","sponsored","date","owner","likeCount","followCount","memberCount","reviewCount","location"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitegroup.sitemobile-groups-sitegroup"}';
        } else {
            //Mobile Browser Parameters for group listing
            $params = '{"title":"","titleCount":true,"layouts_views":["1","2"],"view_selected":"list","layouts_oder":"2","columnHeight":"260","category_id":"0","content_display":["ratings","likeCount","followCount","memberCount","reviewCount","location","price"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitegroup.sitemobile-groups-sitegroup"}';
        }

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitegroup.sitemobile-groups-sitegroup',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => $params,
            'order' => 3,
        ));
    }

    public function setSitememberConfiguration() {

        $this->updateSitememberBrowsePage();

        $this->updateGlobalSettings(array('sitemember_location' => 1, 'sitemember_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), 'sitemember');
    }

    public function updateSitememberPopularMembersPage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitemember_review_top-rated'));

        if (!empty($page_id)) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {
            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitemember_review_most-recommended-members",
                'displayname' => 'Advanced Member - Most Recommended Members',
                'title' => 'Most Recommended Members',
                'description' => 'Display the most recommended members of our site on the basis of recommendation they get from the site members.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $widgetCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //TOP-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => 6,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemember.navigation-sitemember',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":true,"nomobile":"1"}',
        ));

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 2,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => 6,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemember.searchbox-sitemember',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":"","locationDetection":"1","formElements":["textElement","profileTypeElement","locationElement","locationmilesSearch"],"textWidth":"275","locationWidth":"250","locationmilesWidth":"125","categoryWidth":"150","nomobile":"0","name":"sitemember.searchbox-sitemember"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemember.top-rated-table-view',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","itemCount":"7","nomobile":"0","name":"sitemember.top-rated-table-view"}',
        ));

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => 5,
        ));
        $main_right_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemember.featured-reviews',
            'parent_content_id' => $main_right_id,
            'order' => $widgetCount++,
            'params' => '{"title":"Featured Reviews","itemCount":"3","nomobile":"0","name":"sitemember.featured-reviews"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemember.options-sitemember',
            'parent_content_id' => $main_right_id,
            'order' => $widgetCount++,
            'params' => '{"title":"Browse By","titleCount":true,"name":"sitemember.options-sitemember"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemember.most-rated-reviewed-recommend',
            'parent_content_id' => $main_right_id,
            'order' => $widgetCount++,
            'params' => '{"title":"Most Recommend Members","titleCount":true,"viewType":"listview","columnWidth":"180","columnHeight":"328","orderby":"recommend_count","memberInfo":["reviewCount","recommendCount"],"itemCount":"5","truncation":"16","nomobile":"0","name":"sitemember.most-rated-reviewed-recommend"}',
        ));
    }

    public function updateSitememberBrowsePage() {

        $page_id = $this->isPageExist(array('pageName' => 'sitemember_location_userby-locations'));

        if (!empty($page_id)) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {
            $this->_db->insert('engine4_core_pages', array(
                'name' => 'sitemember_location_userby-locations',
                'displayname' => 'Advanced Member - Browse Member',
                'title' => 'Advanced Member - Browse Member',
                'description' => 'This is browse members page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId('engine4_core_pages');
        }

        //CONTAINERS
        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'container',
            'name' => 'main',
            'parent_content_id' => Null,
            'order' => 2,
            'params' => '',
        ));
        $container_id = $this->_db->lastInsertId('engine4_core_content');

        if (!empty($container_id)) {

            //INSERT MAIN - MIDDLE CONTAINER
            $this->_db->insert('engine4_core_content', array(
                'page_id' => $page_id,
                'type' => 'container',
                'name' => 'middle',
                'parent_content_id' => $container_id,
                'order' => 2,
                'params' => '',
            ));
            $middle_id = $this->_db->lastInsertId('engine4_core_content');

            if (!empty($middle_id)) {

                //INSERT WIDGET OF LOCATION SEARCH AND CORE CONTENT
                $this->_db->insert('engine4_core_content', array(
                    'page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitemember.navigation-sitemember',
                    'parent_content_id' => $middle_id,
                    'order' => 1,
                    'params' => '{"0":"","title":"","titleCount":true}',
                ));

                $this->_db->insert('engine4_core_content', array(
                    'page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitemember.search-sitemember',
                    'parent_content_id' => $middle_id,
                    'order' => 3,
                    'params' => '{"title":"","titleCount":true,"viewType":"horizontal","locationDetection":"1","whatWhereWithinmile":"1","advancedSearch":"0","nomobile":"0","name":"sitemember.search-sitemember"}',
                ));

                $this->_db->insert('engine4_core_content', array(
                    'page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitemember.browse-members-sitemember',
                    'parent_content_id' => $middle_id,
                    'order' => 4,
                    'params' => '{"title":"","titleCount":true,"layouts_views":["1","2","3","4"],"layouts_order":"2","columnWidth":"202","truncationGrid":"50","columnHeight":"190","has_photo":"0","links":"","showDetailLink":"1","memberInfo":["ratingStar","location","directionLink","profileField","age"],"customParams":"5","custom_field_title":"0","custom_field_heading":"0","titlePosition":"1","orderby":"featured","show_content":"3","withoutStretch":"0","show_buttons":["facebook","twitter","pinit","like"],"pinboarditemWidth":"255","sitemember_map_sponsored":"1","itemCount":"20","truncation":"16","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"0","name":"sitemember.browse-members-sitemember"}',
                ));
            }
        }

        if ($this->_sitemobileActive) {
            $this->updateMobileSitememberBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable);
            $this->updateMobileSitememberBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable);
        }
    }

    public function updateMobileSitememberBrowsePage($pageTable, $contentTable) {

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => 'sitemember_location_userby-locations'));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {
            // Insert page
            $this->_db->insert($pageTableName, array(
                'name' => 'sitemember_location_userby-locations',
                'displayname' => 'Advanced Members - Browse Members’ Locations',
                'title' => 'Advanced Members - Browse Members’ Locations',
                'description' => 'This is browse members page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        // Insert main
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 1,
        ));
        $main_id = $this->_db->lastInsertId();

        // Insert main-middle
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        // Insert Advance search
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"search":"2","title":"","location":1,"name":"sitemobile.sitemobile-advancedsearch"}',
            'order' => 2,
        ));

        // Insert content
        $this->_db->insert($contentTableName, array(
            'type' => 'widget',
            'name' => 'sitemember.browse-members-sitemember',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'params' => '{"0":"","title":"","titleCount":true,"links":["addfriend","messege"],"has_photo":"0","orderby":"creationDate","itemCount":"10","truncation":"16","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitemember.browse-members-sitemember"}',
            'order' => 3,
        ));
    }

    public function setSitereviewConfiguration($listingtype_id) {

        $listingType = Engine_Api::_()->getItem('sitereview_listingtype', $listingtype_id);
        $enabledMenus = array("sitereview_main_browse_listtype_$listingtype_id", "sitereview_main_manage_listtype_$listingtype_id", "sitereview_main_create_listtype_$listingtype_id");

        if (strstr($listingType->slug_singular, 'blog') || strstr($listingType->slug_plural, 'blog')) {

            $this->setSitereviewBlogBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'tourism') || strstr($listingType->slug_plural, 'tourism')) {

            $this->setSitereviewTourismBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'fashion') || strstr($listingType->slug_plural, 'fashion')) {

            $this->setSitereviewFashionBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'electronic') || strstr($listingType->slug_plural, 'electronic')) {

            $this->setSitereviewElectronicBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'sport') || strstr($listingType->slug_plural, 'sport')) {

            $this->setSitereviewSportBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'property') || strstr($listingType->slug_plural, 'property') || strstr($listingType->slug_singular, 'properties') || strstr($listingType->slug_plural, 'properties')) {

            $this->setSitereviewPropertyBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'food') || strstr($listingType->slug_plural, 'food')) {

            $enabledMenus = array("sitereview_main_browse_listtype_$listingtype_id", "sitereview_main_manage_listtype_$listingtype_id", "sitereview_main_create_listtype_$listingtype_id", "sitereview_main_claim_listtype_$listingtype_id");
            $this->setSitereviewFoodBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'classified') || strstr($listingType->slug_plural, 'classified')) {

            $this->setSitereviewClassifiedBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'entertainment') || strstr($listingType->slug_plural, 'entertainment')) {

            $this->setSitereviewEntertainmentBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'article') || strstr($listingType->slug_plural, 'article')) {

            $this->setSitereviewArticleBrowsePage($listingType);
        } elseif (strstr($listingType->slug_singular, 'job') || strstr($listingType->slug_plural, 'job')) {

            $this->setSitereviewJobBrowsePage($listingType);
        } else {

            $this->setSitereviewProductBrowsePage($listingType);
        }

        if ($this->_sitemobileActive) {
            $this->updateMobileSitereviewBrowsePage($this->_mobilePagesTable, $this->_mobileContentTable, $listingType);
            $this->updateMobileSitereviewBrowsePage($this->_tabletPagesTable, $this->_tabletContentTable, $listingType);
        }

        $this->updatePluginMenus("sitereview_main_listtype_$listingtype_id", $enabledMenus);

        $this->updatePluginMainMenu(array('name' => "core_main_sitereview_listtype_$listingtype_id", 'action' => 'index'));

        $this->updateGlobalSettings(array('sitereview_proximitysearch' => 1), array('location' => 1, 'street' => 0, 'city' => 0, 'state' => 0, 'country' => 0), "sitereview_listtype_$listingtype_id");

        $this->_db->query("UPDATE `engine4_sitereview_listingtypes` SET `location` = 1, `redirection` = 'index' WHERE `listingtype_id` = $listingtype_id");

        $this->_db->query("UPDATE `engine4_core_menuitems` SET `enabled` = 0 WHERE `menu` = 'sitereview_main_common'");

        if ($this->_sitemobileActive) {

            $this->_db->query("UPDATE `engine4_sitemobile_menuitems` SET `enable_mobile` = 0, `enable_tablet` = 0 WHERE `menu` = 'sitereview_main_common'");
        }
    }

    public function updateMobileSitereviewBrowsePage($pageTable, $contentTable, $listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);
        $columnHeight = 358;
        $columnWidth = 200;

        $pageTableName = $pageTable->info('name');
        $contentTableName = $contentTable->info('name');

        $page_id = $this->isPageExist(array('pageTableName' => $pageTableName, 'pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if (!empty($page_id)) {

            $this->deleteExistingWidgets(array('contentTableName' => $contentTableName, 'page_id' => $page_id));
        } else {

            //CREATE PAGE
            $this->_db->insert($pageTableName, array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => 'Browse ' . $titlePluUc,
                'description' => 'This is the ' . $titleSinLc . ' browse page.',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;
        $widgetCount = 0;

        //TOP CONTAINER
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert($contentTableName, array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert($contentTableName, array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.navigation-sitereview',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '',
        ));

        $this->_db->insert($contentTableName, array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitemobile.sitemobile-advancedsearch',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"listingtype_id":"' . $listingTypeId . '"}',
        ));
        if ($contentTableName == 'engine4_sitemobile_content' || $contentTableName == 'engine4_sitemobile_tablet_content') {
            $this->_db->insert($contentTableName, array(
                'page_id' => $page_id,
                'type' => 'widget',
                'name' => 'sitereview.browse-breadcrumb-sitereview',
                'parent_content_id' => $main_middle_id,
                'order' => $widgetCount++,
                'params' => '{"nomobile":"1"}',
            ));
        }
        if ($contentTableName == 'engine4_sitemobileapp_content' || $contentTableName == 'engine4_sitemobileapp_tablet_content') {
            $layout_order = '2';
            $layout_views = '["2"]';
        } else {
            $layout_order = '1';
            $layout_views = '["1", "2"]';
        }

        $this->_db->insert($contentTableName, array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.browse-listings-sitereview',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"title":"","titleCount":true,"layouts_views":' . $layout_views . ',"layouts_order":"' . $layout_order . '","statistics":["viewCount","likeCount","reviewCount","commentCount"],"columnWidth":"200","truncationGrid":"100","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","columnHeight":"' . $columnHeight . '","showExpiry":"1","bottomLine":"2","postedby":"1","orderby":"spfesp","itemCount":"9","truncation":"100","name":"sitereview.browse-listings-sitereview","bottomLineGrid":"2","showContent":["price","location","endDate","postedDate"]}',
        ));
    }

    public function setSitereviewBlogBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //LEFT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'left',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $left_container_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),
(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.browse-breadcrumb-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.top-posters", ' . $left_container_id . ', 7, \'{"title":"Top posters","listingtype_id":"' . $listingTypeId . '","itemCount":"3","nomobile":"1","name":"sitereview.top-posters"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 8, \'{"title":"Latest Blogs","titleCount":"true","statistics":["viewCount","commentCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"newlabel","columnHeight":"328","popularity":"comment_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 9, \'{"title":"Most Commented Blogs","titleCount":"true","statistics":["viewCount","commentCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"comment_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 10, \'{"title":"Most Viewed Blogs","titleCount":"true","statistics":["viewCount","commentCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 12, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.categories-banner-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 13, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"193","truncationGrid":"45","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","columnHeight":"270","viewType":"0","bottomLine":"0","postedby":"1","orderby":"newlabel","itemCount":"15","truncation":"40","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-sidebar-sitereview", ' . $right_container_id . ', 15, \'{"title":"Categories","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.categories-sidebar-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $right_container_id . ', 16, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 17, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.newlisting-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 18, \'{"title":"Most Liked Blogs","titleCount":"true","statistics":["viewCount","likeCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"like_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.popularlocation-sitereview", ' . $right_container_id . ', 19, \'{"title":"Popular Locations","titleCount":"true","listingtype_id":"' . $listingTypeId . '","itemCount":"4","nomobile":"1","name":"sitereview.popularlocation-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 20, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","itemCount":"25","nomobile":"1","name":"sitereview.tagcloud-sitereview"}\', NULL);
');
    }

    public function setSitereviewElectronicBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),
(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.browse-breadcrumb-sitereview"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":"true","pluginName":"sitepageintegration","nomobile":"1"}\', NULL),  

(' . $page_id . ', "widget", "sitereview.sponsored-sitereview", ' . $main_middle_id . ', 7, \'{"title":"New Electronics Listings","titleCount":"true","showOptions":["rating","review","compare","wishlist"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","fea_spo":"newlabel","viewType":"0","blockHeight":"240","blockWidth":"150","itemCount":"4","popularity":"creation_date","featuredIcon":"1","sponsoredIcon":"1","newIcon":"1","interval":"300","truncation":"50","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.sponsored-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 8, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.categories-banner-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 9, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"1","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"180","truncationGrid":"90","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","columnHeight":"328","viewType":"1","bottomLine":"1","postedby":"1","orderby":"fespfe","itemCount":"10","truncation":"45","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.item-sitereview", ' . $right_container_id . ', 11, \'{"title":"' . $titleSinUc . ' of the Day","ratingType":"rating_both","nomobile":"1","name":"sitereview.item-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $right_container_id . ', 12, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","viewType":"vertical","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 13, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.newlisting-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 14, \'{"title":"Editors Choice","titleCount":"true","statistics":["reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_editor","fea_spo":"","columnHeight":"328","popularity":"rating_editor","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 15, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","itemCount":"10","nomobile":"1","name":"sitereview.tagcloud-sitereview"}\', NULL);
');
    }

    public function setSitereviewSportBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.browse-breadcrumb-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $top_middle_id . ', 6, \'{"title":"","titleCount":"true","pluginName":"sitepageintegration","nomobile":"1"}\', NULL),  
(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 8, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.categories-banner-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 9, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"196","truncationGrid":"90","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","columnHeight":"310","viewType":"1","bottomLine":"1","postedby":"1","orderby":"spfesp","itemCount":"16","truncation":"25","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 11, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.newlisting-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-sidebar-sitereview", ' . $right_container_id . ', 12, \'{"title":"Categories","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.categories-sidebar-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 13, \'{"title":"Most Viewed Listings","titleCount":"true","statistics":["viewCount","likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"3","truncation":"21","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","nomobile":"1","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.popular-reviews-sitereview", ' . $right_container_id . ', 14, \'{"title":"Most Popular Reviews","statistics":["viewCount","likeCount","helpfulCount"],"listingtype_id":"' . $listingTypeId . '","type":"user","status":"0","popularity":"like_count","interval":"overall","groupby":"1","itemCount":"3","truncation":"21","nomobile":"1","name":"sitereview.popular-reviews-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 15, \'{"title":"Most Reviewed Listings","titleCount":"true","statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"review_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 16, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","itemCount":"12","nomobile":"1","name":"sitereview.tagcloud-sitereview"}\', NULL);
');
    }

    public function setSitereviewPropertyBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //LEFT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'left',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $left_container_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('
INSERT INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":true}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":true,"listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":true,"nomobile":"1","name":"sitereview.browse-breadcrumb-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.popularlocation-sitereview", ' . $left_container_id . ', 8, \'{"title":"Popular Locations","titleCount":true,"listingtype_id":"' . $listingTypeId . '","itemCount":"10","nomobile":"1","name":"sitereview.popularlocation-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $left_container_id . ', 9, \'{"title":"","pluginName":"communityad","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 10, \'{"title":"Top Rated ","titleCount":true,"statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"rating_users","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"19","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 11, \'{"title":"Most Reviewed","titleCount":true,"statistics":["commentCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"19","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 12, \'{"title":"Most Recent","titleCount":true,"statistics":["reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"creation_date","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"19","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 13, \'{"title":"Most Liked","titleCount":true,"statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"19","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 15, \'{"title":"","titleCount":true,"nomobile":"1","name":"sitereview.categories-banner-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 16, \'{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"193","truncationGrid":"30","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","columnHeight":"328","viewType":"1","bottomLine":"0","postedby":"1","orderby":"creation_date","itemCount":"10","truncation":"25","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.item-sitereview", ' . $right_container_id . ', 18, \'{"title":"Property of the day","ratingType":"rating_avg","nomobile":"1","name":"sitereview.item-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 19, \'{"title":"","titleCount":true,"listingtype_id":"' . $listingTypeId . '","nomobile":"0","name":"sitereview.newlisting-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.sponsored-sitereview", ' . $right_container_id . ', 20, \'{"title":"Properties At Glance","titleCount":true,"showOptions":["category","rating","review","compare","wishlist"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","viewType":"1","blockHeight":"220","blockWidth":"190","itemCount":"2","popularity":"creation_date","featuredIcon":"0","sponsoredIcon":"0","newIcon":"1","interval":"300","truncation":"30","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.sponsored-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 21, \'{"title":"Most Viewed","titleCount":true,"statistics":["viewCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"3","truncation":"19","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 22, \'{"title":"Most Commented","titleCount":true,"statistics":["commentCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"like_count","interval":"overall","itemCount":"3","truncation":"19","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.recently-viewed-sitereview", ' . $right_container_id . ', 23, \'{"title":"Recently Viewed By Friends","titleCount":true,"statistics":["likeCount","reviewCount"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","show":"1","viewType":"listview","columnWidth":"180","columnHeight":"328","truncation":"19","count":"3","nomobile":"1","name":"sitereview.recently-viewed-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 24, \'{"title":"Popular Tags (%s)","titleCount":true,"listingtype_id":"' . $listingTypeId . '","itemCount":"25","nomobile":"0","name":"sitereview.tagcloud-sitereview"}\', NULL);
');
    }

    public function setSitereviewTourismBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {

            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {


            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //LEFT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'left',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $left_container_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('
 INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),

(' . $page_id . ', "widget", "sitereview.sponsored-sitereview", ' . $left_container_id . ', 6, \'{"title":"Most Recent Listings","titleCount":"true","showOptions":["category","rating","review","compare","wishlist"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","viewType":"1","blockHeight":"240","blockWidth":"200","itemCount":"2","popularity":"creation_date","featuredIcon":"1","sponsoredIcon":"1","newIcon":"1","interval":"300","truncation":"50","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.sponsored-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.sponsored-sitereview", ' . $left_container_id . ', 7, \'{"title":"Most Rated Listings","titleCount":"true","showOptions":["category","rating","review","compare","wishlist"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","viewType":"1","blockHeight":"240","blockWidth":"200","itemCount":"2","popularity":"rating_avg","featuredIcon":"1","sponsoredIcon":"1","newIcon":"1","interval":"300","truncation":"50","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.sponsored-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 9, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.categories-banner-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 10, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"190","truncationGrid":"90","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","columnHeight":"310","viewType":"1","bottomLine":"1","postedby":"1","orderby":"creation_date","itemCount":"12","truncation":"25","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-sidebar-sitereview", ' . $right_container_id . ', 12, \'{"title":"Categories","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.categories-sidebar-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $right_container_id . ', 13, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 14, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.newlisting-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 15, \'{"title":"Editors Choice","titleCount":"true","statistics":["viewCount","likeCount","commentCount","reviewCount"],"viewType":"gridview","columnWidth":"200","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_editor","fea_spo":"","columnHeight":"328","popularity":"rating_editor","interval":"overall","itemCount":"2","truncation":"90","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL);

');
    }

    public function setSitereviewFashionBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'left',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $left_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),
(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.browse-breadcrumb-sitereview"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $main_middle_id . ', 4, \'{"title":"","titleCount":"true","pluginName":"sitefaq","nomobile":"1"}\', NULL),   
(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $left_container_id . ', 4, \'{"title":"","titleCount":"true","pluginName":"suggestion","nomobile":"1"}\', NULL), 
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $left_container_id . ', 5, \'{"title":"","titleCount":"true","pluginName":"facebookse","nomobile":"1"}\', NULL),  
(' . $page_id . ', "widget", "sitereview.listtypes-categories", ' . $left_container_id . ', 8, \'{"listingtype_id":"' . $listingTypeId . '","viewDisplayHR":"0","title":"","nomobile":"1","name":"sitereview.listtypes-categories"}\', NULL),

(' . $page_id . ', "widget", "sitereview.item-sitereview", ' . $left_container_id . ', 9, \'{"title":"' . $titleSinUc . ' of the Day","ratingType":"rating_avg","nomobile":"1","name":"sitereview.item-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $left_container_id . ', 10, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1","name":"sitereview.newlisting-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 11, \'{"title":"Featured & Sponsored","titleCount":"true","statistics":["viewCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"fea_spo","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $left_container_id . ', 14, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","itemCount":"25","nomobile":"1","name":"sitereview.tagcloud-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 12, \'{"title":"Top Rated Items","titleCount":"true","statistics":["viewCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"rating_avg","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 13, \'{"title":"Most Liked Items","titleCount":"true","statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"like_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 16, \'{"title":"","titleCount":"true","nomobile":"1","name":"sitereview.categories-banner-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 17, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"198","truncationGrid":"30","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","columnHeight":"320","viewType":"1","bottomLine":"0","postedby":"1","orderby":"newlabel","itemCount":"20","truncation":"25","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL);
');
    }

    public function setSitereviewFoodBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //LEFT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'left',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $left_container_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('
        INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
        (' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),
(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $left_container_id . ', 7, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listtypes-categories", ' . $left_container_id . ', 8, \'{"listingtype_id":"' . $listingTypeId . '","viewDisplayHR":"0","title":"Search Food Items In","nomobile":"0","name":"sitereview.listtypes-categories"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $left_container_id . ', 9, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 10, \'{"title":"Most Commented Food Items","titleCount":"true","statistics":["commentCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"","columnHeight":"328","popularity":"comment_count","interval":"overall","itemCount":"2","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $left_container_id . ', 11, \'{"title":"Most Viewed Food Items","titleCount":"true","statistics":["viewCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"2","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.recently-viewed-sitereview", ' . $left_container_id . ', 12, \'{"title":"Recently Viewed by You","titleCount":"true","statistics":["likeCount","reviewCount"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","show":"0","viewType":"listview","columnWidth":"180","columnHeight":"328","truncation":"21","count":"2","nomobile":"1","name":"sitereview.recently-viewed-sitereview"}\', NULL),

(' . $page_id . ', "widget", "seaocore.layout-width", ' . $left_container_id . ', 13, \'{"title":"","layoutWidth":"200","layoutWidthType":"px","nomobile":"0","name":"seaocore.layout-width"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 15, \'{"title":"","titleCount":"true","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 16, \'{"title":"","titleCount":"true","layouts_views":["1","2"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"198","truncationGrid":"90","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","columnHeight":"300","viewType":"0","bottomLine":"1","postedby":"1","orderby":"fespfe","itemCount":"12","truncation":"40","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.sponsored-sitereview", ' . $right_container_id . ', 18, \'{"title":"Sponsored Today","titleCount":"true","showOptions":["rating","review","compare","wishlist"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"sponsored","viewType":"1","blockHeight":"190","blockWidth":"200","itemCount":"2","popularity":"review_count","featuredIcon":"0","sponsoredIcon":"0","newIcon":"0","interval":"300","truncation":"25","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.sponsored-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 19, \'{"title":"Most Recent Food Items","titleCount":"true","statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"creation_date","interval":"overall","itemCount":"2","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 20, \'{"title":"Most Liked Courses","titleCount":"true","statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"comment_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 21, \'{"title":"Highest Rated Desserts","titleCount":"true","statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"rating_users","interval":"overall","itemCount":"2","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 22, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL);
');
    }

    public function setSitereviewClassifiedBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"title":"","titleCount":"true","0":""}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "seaocore.scroll-top", ' . $top_middle_id . ', 5, \'["[]"]\', NULL),
(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $top_middle_id . ', 6, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 9, \'{"title":"","titleCount":"true","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 10, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"1","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"180","truncationGrid":"90","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","columnHeight":"328","viewType":"1","bottomLine":"1","postedby":"1","orderby":"newlabel","itemCount":"15","truncation":"45","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $right_container_id . ', 4, \'{"title":"","titleCount":"true","pluginName":"facebookse","nomobile":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $right_container_id . ', 5, \'{"title":"","titleCount":"true","pluginName":"suggestion","nomobile":"1"}\', NULL),  
(' . $page_id . ', "widget", "sitereview.categories-sidebar-sitereview", ' . $right_container_id . ', 12, \'{"title":"Categories","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 13, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 14, \'{"title":"Most Commented Classifieds","titleCount":"true","statistics":["commentCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"comment_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 15, \'{"title":"Most Viewed Classifieds","titleCount":"true","statistics":["viewCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 16, \'{"title":"Most Liked Calssifieds","titleCount":"true","statistics":["likeCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"3","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 17, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL);
');
    }

    public function setSitereviewEntertainmentBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":"true"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":"true","nomobile":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.ads-plugin-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":"true","pluginName":"sitepageintegration","nomobile":"1"}\', NULL),  
(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 7, \'{"title":"","titleCount":"true","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 8, \'{"title":"","titleCount":"true","layouts_views":["1","2","3"],"layouts_order":"2","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"197","truncationGrid":"90","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","columnHeight":"320","viewType":"1","bottomLine":"1","postedby":"1","orderby":"newlabel","itemCount":"10","truncation":"25","nomobile":"0","name":"sitereview.browse-listings-sitereview","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}\', NULL),

(' . $page_id . ', "widget", "sitereview.slideshow-sitereview", ' . $main_middle_id . ', 9, \'{"title":"Top Rated Featured Listings","titleCount":"true","statistics":["viewCount","likeCount","commentCount","reviewCount"],"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"featured","popularity":"rating_users","interval":"overall","featuredIcon":"0","sponsoredIcon":"0","newIcon":"0","truncation":"45","count":"10","nomobile":"1","name":"sitereview.slideshow-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.categories-sidebar-sitereview", ' . $right_container_id . ', 11, \'{"title":"Categories","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $right_container_id . ', 12, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 13, \'{"title":"","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 14, \'{"title":"Most Commented","titleCount":"true","statistics":["commentCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"comment_count","interval":"overall","itemCount":"2","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 15, \'{"title":"Most Viewed","titleCount":"true","statistics":["viewCount","reviewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_users","fea_spo":"","columnHeight":"328","popularity":"view_count","interval":"overall","itemCount":"2","truncation":"21","nomobile":"1","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 16, \'{"title":"Popular Tags (%s)","titleCount":"true","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}\', NULL);
');
    }

    public function setSitereviewArticleBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

 INSERT IGNORE INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"title":"","titleCount":"true"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":true,"nomobile":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":true,"listingtype_id":"' . $listingTypeId . '","viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),

(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 8, \'{"title":"","titleCount":true,"layouts_views":["1"],"layouts_order":"1","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"206","truncationGrid":"200","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","columnHeight":"328","showExpiry":"0","viewType":"1","bottomLine":"1","postedby":"1","orderby":"creation_date","itemCount":"7","truncation":"100","nomobile":"0","name":"sitereview.browse-listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 14, \'{"title":"Most Commented Articles","titleCount":true,"statistics":["commentCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"featured","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","columnHeight":"328","popularity":"view_count","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"16","nomobile":"0","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 16, \'{"title":"Most Discussed Articles","titleCount":true,"statistics":"","viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"featured","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","columnHeight":"328","popularity":"view_count","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"16","nomobile":"0","name":"sitereview.listings-sitereview"}\', NULL), 

(' . $page_id . ', "widget", "sitereview.listings-sitereview", ' . $right_container_id . ', 16, \'{"title":"Most Popular Articles","titleCount":true,"statistics":["viewCount"],"viewType":"listview","columnWidth":"180","listingtype_id":"' . $listingTypeId . '","ratingType":"rating_avg","fea_spo":"featured","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","columnHeight":"328","popularity":"view_count","interval":"overall","category_id":"0","hidden_category_id":"0","hidden_subcategory_id":"0","hidden_subsubcategory_id":"0","itemCount":"3","truncation":"16","nomobile":"0","name":"sitereview.listings-sitereview"}\', NULL),

(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 16, \'{"title":"Popular Tags (%s)","titleCount":true,"listingtype_id":"' . $listingTypeId . '","itemCount":"30","nomobile":"1","name":"sitereview.tagcloud-sitereview"}\', NULL);
');
    }

    public function setSitereviewJobBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->query('

INSERT INTO `engine4_core_content` (`page_id`, `type`, `name`, `parent_content_id`, `order`, `params`, `attribs`) VALUES
(' . $page_id . ', "widget", "sitereview.navigation-sitereview", ' . $top_middle_id . ', 3, \'{"0":"","title":"","titleCount":true}\', NULL),
(' . $page_id . ', "widget", "sitereview.browse-breadcrumb-sitereview", ' . $top_middle_id . ', 4, \'{"title":"","titleCount":true,"nomobile":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.search-sitereview", ' . $top_middle_id . ', 5, \'{"title":"","titleCount":true,"listingtype_id":' . $listingTypeId . ',"viewType":"horizontal","nomobile":"0","name":"sitereview.search-sitereview","locationDetection":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.categories-banner-sitereview", ' . $main_middle_id . ', 8, \'{"title":"","titleCount":true,"nomobile":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.browse-listings-sitereview", ' . $main_middle_id . ', 9, \'{"title":"","titleCount":true,"layouts_views":["1","2","3"],"layouts_order":"1","statistics":["viewCount","likeCount","commentCount","reviewCount"],"columnWidth":"199","truncationGrid":"90","listingtype_id":' . $listingTypeId . ',"ratingType":"rating_both","detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '","columnHeight":"308","showExpiry":"0","viewType":"0","bottomLine":"0","postedby":"0","orderby":"fespfe","itemCount":"12","truncation":"25","nomobile":"0","name":"sitereview.browse-listings-sitereview"}\', NULL),
(' . $page_id . ', "widget", "sitereview.categories-sidebar-sitereview", ' . $right_container_id . ', 11, \'{"title":"Categories","titleCount":"true","listingtype_id":' . $listingTypeId . ',"nomobile":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.newlisting-sitereview", ' . $right_container_id . ', 13, \'{"title":"","titleCount":true,"listingtype_id":' . $listingTypeId . ',"nomobile":"1"}\', NULL),
(' . $page_id . ', "widget", "sitereview.tagcloud-sitereview", ' . $right_container_id . ', 14, \'{"title":"Popular Tags (%s)","titleCount":true,"listingtype_id":' . $listingTypeId . ',"nomobile":"1"}\', NULL);
');
    }

    public function setSitereviewProductBrowsePage($listingType) {

        //GET LISTING TYPE DETAILS
        $listingTypeId = $listingType->listingtype_id;
        $titleSinUc = ucfirst($listingType->title_singular);
        $titlePluUc = ucfirst($listingType->title_plural);
        $titleSinLc = strtolower($listingType->title_singular);
        $titlePluLc = strtolower($listingType->title_plural);

        $page_id = $this->isPageExist(array('pageName' => "sitereview_index_index_listtype_" . $listingTypeId));
        if ($page_id) {
            $this->deleteExistingWidgets(array('contentTableName' => 'engine4_core_content', 'page_id' => $page_id));
        } else {

            $this->_db->insert('engine4_core_pages', array(
                'name' => "sitereview_index_index_listtype_" . $listingTypeId,
                'displayname' => 'Multiple Listing Types - Browse ' . $titlePluUc,
                'title' => '',
                'description' => '',
                'custom' => 0,
            ));
            $page_id = $this->_db->lastInsertId();
        }

        $containerCount = 0;
        $widgetCount = 0;

        //TOP CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $top_container_id = $this->_db->lastInsertId();

        //MAIN CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => $containerCount++,
        ));
        $main_container_id = $this->_db->lastInsertId();

        //INSERT TOP-MIDDLE
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_container_id,
            'order' => $containerCount++,
        ));
        $top_middle_id = $this->_db->lastInsertId();

        //RIGHT CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $right_container_id = $this->_db->lastInsertId();

        //MAIN-MIDDLE CONTAINER
        $this->_db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_container_id,
            'order' => $containerCount++,
        ));
        $main_middle_id = $this->_db->lastInsertId();

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.navigation-sitereview',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.browse-breadcrumb-sitereview',
            'parent_content_id' => $top_middle_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.categories-sidebar-sitereview',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"title":"Categories","listingtype_id":"' . $listingTypeId . '","titleCount":"true","nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.search-sitereview',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"listingtype_id":"' . $listingTypeId . '","locationDetection":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.newlisting-sitereview',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"listingtype_id":"' . $listingTypeId . '","nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.tagcloud-sitereview',
            'parent_content_id' => $right_container_id,
            'order' => $widgetCount++,
            'params' => '{"title": "Popular Tags (%s)","listingtype_id":"' . $listingTypeId . '","nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.categories-banner-sitereview',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"nomobile":"1"}',
        ));

        $this->_db->insert('engine4_core_content', array(
            'page_id' => $page_id,
            'type' => 'widget',
            'name' => 'sitereview.browse-listings-sitereview',
            'parent_content_id' => $main_middle_id,
            'order' => $widgetCount++,
            'params' => '{"listingtype_id":"' . $listingTypeId . '","ratingType":"rating_both","statistics":["viewCount","likeCount","commentCount","reviewCount"],"layouts_views":["1","2","3"],"detactLocation":"1","defaultLocationDistance":"' . self::DEFAULT_LOCATION_DISTANCE . '"}',
        ));
    }

    public function setMobileTheme($themeName = 'luminous') {

        $themeTable = Engine_Api::_()->getDbtable('themes', 'sitemobile');
        $themeSelect = $themeTable->select()
                ->where('name = ?', $themeName)
                ->where('active = ?', 0)
                ->limit(1);
        $theme = $themeTable->fetchRow($themeSelect);

        if ($theme) {

            $themeTable->update(array(
                'active' => 0,
                    ), array(
                '1 = ?' => 1,
            ));
            $theme->active = true;
            $theme->save();

            //CLEAR SCAFFOLD CACHE
            Core_Model_DbTable_Themes::clearScaffoldCache();

            //INCREMENT SITE COUNTER
            $settings = Engine_Api::_()->getApi('settings', 'core');
            $settings->core_site_counter = $settings->core_site_counter + 1;
        }
    }

}
